diff -pruN 2.3.3-3/backend/ipp.c 2.3.3op1-3/backend/ipp.c
--- 2.3.3-3/backend/ipp.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/backend/ipp.c	2020-11-27 14:25:26.000000000 +0000
@@ -2825,7 +2825,21 @@ new_request(
         */
 
         _httpDecodeURI(phone, keyword, sizeof(phone));
-        for (ptr = phone; *ptr;)
+        ptr = phone;
+
+        /*
+         * Weed out "Custom." in the beginning, this allows to put the
+         * "phone" option as custom string option into the PPD so that
+         * print dialogs not supporting fax display the option and
+         * allow entering the phone number. Print dialogs also send "None"
+         * if no phone number got entered, filter this, too.
+         */
+        if (!_cups_strcasecmp(phone, "None"))
+          *ptr = '\0';
+        if (!_cups_strncasecmp(phone, "Custom.", 7))
+          _cups_strcpy(ptr, ptr + 7);
+
+        for (; *ptr;)
 	{
 	  if (*ptr == ',')
 	    *ptr = 'p';
@@ -2835,20 +2849,36 @@ new_request(
 	    ptr ++;
         }
 
-        httpAssembleURI(HTTP_URI_CODING_ALL, tel_uri, sizeof(tel_uri), "tel", NULL, NULL, 0, phone);
-        ippAddString(destination, IPP_TAG_JOB, IPP_TAG_URI, "destination-uri", NULL, tel_uri);
-
-	if ((keyword = cupsGetOption("faxPrefix", num_options,
-	                             options)) != NULL && *keyword)
+        if (strlen(phone) > 0)
         {
-	  char	predial[1024];		/* Pre-dial string */
+          httpAssembleURI(HTTP_URI_CODING_ALL, tel_uri, sizeof(tel_uri), "tel", NULL, NULL, 0, phone);
+          ippAddString(destination, IPP_TAG_JOB, IPP_TAG_URI, "destination-uri", NULL, tel_uri);
+          fprintf(stderr, "DEBUG: Faxing to phone %s; destination-uri: %s\n", phone, tel_uri);
+
+          if ((keyword = cupsGetOption("faxPrefix", num_options, options)) != NULL && *keyword)
+          {
+            char	predial[1024];		/* Pre-dial string */
+
+            _httpDecodeURI(predial, keyword, sizeof(predial));
+            ptr = predial;
+            if (!_cups_strcasecmp(ptr, "None"))
+              *ptr = '\0';
+            if (!_cups_strncasecmp(ptr, "Custom.", 7))
+              ptr += 7;
+            if (strlen(ptr) > 0)
+            {
+              ippAddString(destination, IPP_TAG_JOB, IPP_TAG_TEXT, "pre-dial-string", NULL, ptr);
+              fprintf(stderr, "DEBUG: Pre-dialing %s; pre-dial-string: %s\n", ptr, ptr);
+            }
+            else
+              fprintf(stderr, "WARNING: Pre-dial number for fax not valid! Sending fax without pre-dial number.\n");
+          }
 
-	  _httpDecodeURI(predial, keyword, sizeof(predial));
-	  ippAddString(destination, IPP_TAG_JOB, IPP_TAG_TEXT, "pre-dial-string", NULL, predial);
-	}
-
-        ippAddCollection(request, IPP_TAG_JOB, "destination-uris", destination);
-        ippDelete(destination);
+          ippAddCollection(request, IPP_TAG_JOB, "destination-uris", destination);
+          ippDelete(destination);
+        }
+        else
+          fprintf(stderr, "ERROR: Phone number for fax not valid! Fax cannot be sent.\n");
       }
     }
     else
@@ -3075,7 +3105,7 @@ report_printer_state(ipp_t *ipp)	/* I -
   * Report alerts and messages...
   */
 
-  if ((pa = ippFindAttribute(ipp, "printer-alert", IPP_TAG_TEXT)) != NULL)
+  if ((pa = ippFindAttribute(ipp, "printer-alert", IPP_TAG_STRING)) != NULL)
     report_attr(pa);
 
   if ((pam = ippFindAttribute(ipp, "printer-alert-message",
@@ -3116,11 +3146,10 @@ report_printer_state(ipp_t *ipp)	/* I -
       if (*ptr < ' ' && *ptr > 0 && *ptr != '\t')
       {
        /*
-        * Substitute "<XX>" for the control character; sprintf is safe because
-	* we always leave 6 chars free at the end...
+        * Substitute "<XX>" for the control character...
 	*/
 
-        sprintf(valptr, "<%02X>", *ptr);
+        snprintf(valptr, sizeof(value) - (size_t)(valptr - value), "<%02X>", *ptr);
 	valptr += 4;
       }
       else
diff -pruN 2.3.3-3/backend/Makefile 2.3.3op1-3/backend/Makefile
--- 2.3.3-3/backend/Makefile	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/backend/Makefile	2020-11-27 14:25:26.000000000 +0000
@@ -13,7 +13,7 @@ include ../Makedefs
 # Object files...
 #
 
-# RBACKENDS are installed mode 0700 so cupsd will run them as root...
+# RBACKENDS are installed mode 0744 so cupsd will run them as root...
 #
 # UBACKENDS and ULBACKENDS are installed mode 0755 so cupsd will run them as
 # an unprivileged user...
@@ -118,7 +118,7 @@ install-exec:	$(INSTALLXPC)
 	echo Installing backends in $(SERVERBIN)/backend
 	$(INSTALL_DIR) -m 755 $(SERVERBIN)/backend
 	for file in $(RBACKENDS); do \
-		$(LIBTOOL) $(INSTALL_BIN) -m 700 $$file $(SERVERBIN)/backend; \
+		$(INSTALL_BIN) -m 744 $$file $(SERVERBIN)/backend; \
 	done
 	for file in $(UBACKENDS); do \
 		$(INSTALL_BIN) $$file $(SERVERBIN)/backend; \
@@ -142,7 +142,7 @@ install-exec:	$(INSTALLXPC)
 install-xpc:	ipp
 	echo Installing XPC backends in $(SERVERBIN)/apple
 	$(INSTALL_DIR) -m 755 $(SERVERBIN)/apple
-	$(LIBTOOL) $(INSTALL_BIN) ipp $(SERVERBIN)/apple
+	$(INSTALL_BIN) ipp $(SERVERBIN)/apple
 	for file in $(IPPALIASES); do \
 		$(RM) $(SERVERBIN)/apple/$$file; \
 		$(LN) ipp $(SERVERBIN)/apple/$$file; \
diff -pruN 2.3.3-3/backend/network.c 2.3.3op1-3/backend/network.c
--- 2.3.3-3/backend/network.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/backend/network.c	2020-11-27 14:25:26.000000000 +0000
@@ -258,7 +258,7 @@ backendNetworkSideCB(
 		         i < packet.object_value.string.num_bytes &&
 			     dataptr < (data + sizeof(data) - 3);
 			 i ++, dataptr += 2)
-		      sprintf(dataptr, "%02X", packet.object_value.string.bytes[i]);
+		      snprintf(dataptr, sizeof(data) - (size_t)(dataptr - data), "%02X", packet.object_value.string.bytes[i]);
 	            datalen += (int)strlen(dataptr);
 		    break;
 
diff -pruN 2.3.3-3/backend/org.cups.usb-quirks 2.3.3op1-3/backend/org.cups.usb-quirks
--- 2.3.3-3/backend/org.cups.usb-quirks	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/backend/org.cups.usb-quirks	2020-11-27 14:25:26.000000000 +0000
@@ -92,6 +92,9 @@
 # Canon, Inc. MP560 Printer (Issue #4155)
 0x04a9 0x173e unidir
 
+# Canon, Inc. PIXMA G1501 Printer (Issue #5831)
+0x04a9 0x1796 unidir
+
 # Canon, Inc. MF4150 Printer (https://bugs.launchpad.net/bugs/1160638)
 0x04a9 0x26a3 no-reattach
 
@@ -242,6 +245,9 @@
 # All Intermec devices (Issue #4553)
 0x067e no-reattach
 
+# HP LaserJet 1010 (Issue #5789)
+0x03f0 0x0c17 delay-close
+
 # HP LaserJet 1015 (Issue #5617)
 0x03f0 0x0e17 delay-close
 
@@ -302,3 +308,6 @@
 
 # Dymo 450 Turbo (Issue #5521)
 0x0922 0x0021 unidir
+
+# Citizen CT-S4000 (Issue #5823)
+0x2730 0x2008 unidir delay-close
diff -pruN 2.3.3-3/backend/snmp.c 2.3.3op1-3/backend/snmp.c
--- 2.3.3-3/backend/snmp.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/backend/snmp.c	2020-11-27 14:25:26.000000000 +0000
@@ -154,6 +154,8 @@ static const int	UriOID[] = { CUPS_OID_p
 static const int	LexmarkProductOID[] = { 1,3,6,1,4,1,641,2,1,2,1,2,1,-1 };
 static const int	LexmarkProductOID2[] = { 1,3,6,1,4,1,674,10898,100,2,1,2,1,2,1,-1 };
 static const int	LexmarkDeviceIdOID[] = { 1,3,6,1,4,1,641,2,1,2,1,3,1,-1 };
+static const int	HPDeviceIdOID[] = { 1,3,6,1,4,1,11,2,3,9,1,1,7,0,-1 };
+static const int	RicohDeviceIdOID[] = { 1,3,6,1,4,1,367,3,2,1,1,1,11,0,-1 };
 static const int	XeroxProductOID[] = { 1,3,6,1,4,1,128,2,1,3,1,2,0,-1 };
 static cups_array_t	*DeviceURIs = NULL;
 static int		HostNameLookups = 0;
@@ -970,8 +972,14 @@ read_snmp_response(int fd)		/* I - SNMP
 	               packet.community, CUPS_ASN1_GET_REQUEST,
 		       DEVICE_ID, LexmarkDeviceIdOID);
 	_cupsSNMPWrite(fd, &(packet.address), CUPS_SNMP_VERSION_1,
+		       packet.community, CUPS_ASN1_GET_REQUEST,
+		       DEVICE_ID, RicohDeviceIdOID);
+	_cupsSNMPWrite(fd, &(packet.address), CUPS_SNMP_VERSION_1,
 	               packet.community, CUPS_ASN1_GET_REQUEST,
 		       DEVICE_PRODUCT, XeroxProductOID);
+	_cupsSNMPWrite(fd, &(packet.address), CUPS_SNMP_VERSION_1,
+		       packet.community, CUPS_ASN1_GET_REQUEST,
+		       DEVICE_ID, HPDeviceIdOID);
         break;
 
     case DEVICE_DESCRIPTION :
diff -pruN 2.3.3-3/backend/usb-unix.c 2.3.3op1-3/backend/usb-unix.c
--- 2.3.3-3/backend/usb-unix.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/backend/usb-unix.c	2020-11-27 14:25:26.000000000 +0000
@@ -214,21 +214,21 @@ list_devices(void)
     * for USB printer devices.  We get the honor of trying them all...
     */
 
-    sprintf(device, "/dev/usblp%d", i);
+    snprintf(device, sizeof(device), "/dev/usblp%d", i);
 
     if ((fd = open(device, O_RDWR | O_EXCL)) < 0)
     {
       if (errno != ENOENT)
 	continue;
 
-      sprintf(device, "/dev/usb/lp%d", i);
+      snprintf(device, sizeof(device), "/dev/usb/lp%d", i);
 
       if ((fd = open(device, O_RDWR | O_EXCL)) < 0)
       {
 	if (errno != ENOENT)
 	  continue;
 
-	sprintf(device, "/dev/usb/usblp%d", i);
+	snprintf(device, sizeof(device), "/dev/usb/usblp%d", i);
 
     	if ((fd = open(device, O_RDWR | O_EXCL)) < 0)
 	  continue;
@@ -258,7 +258,7 @@ list_devices(void)
 
   for (i = 0; i < 8; i ++)
   {
-    sprintf(device, "/dev/usb/printer%d", i);
+    snprintf(device, sizeof(device), "/dev/usb/printer%d", i);
 
     if ((fd = open(device, O_WRONLY | O_EXCL)) >= 0)
     {
@@ -278,11 +278,11 @@ list_devices(void)
 
   for (i = 0; i < 8; i ++)
   {
-    sprintf(device, "/dev/ulpt%d", i);
+    snprintf(device, sizeof(device), "/dev/ulpt%d", i);
     if (!access(device, 0))
       printf("direct usb:%s \"Unknown\" \"USB Printer #%d\"\n", device, i + 1);
 
-    sprintf(device, "/dev/unlpt%d", i);
+    snprintf(device, sizeof(device), "/dev/unlpt%d", i);
     if (!access(device, 0))
       printf("direct usb:%s \"Unknown\" \"USB Printer #%d (no reset)\"\n", device, i + 1);
   }
@@ -344,15 +344,15 @@ open_device(const char *uri,		/* I - Dev
 	* for USB printer devices.  We get the honor of trying them all...
 	*/
 
-	sprintf(device, "/dev/usblp%d", i);
+	snprintf(device, sizeof(device), "/dev/usblp%d", i);
 
 	if ((fd = open(device, O_RDWR | O_EXCL)) < 0 && errno == ENOENT)
 	{
-	  sprintf(device, "/dev/usb/lp%d", i);
+	  snprintf(device, sizeof(device), "/dev/usb/lp%d", i);
 
 	  if ((fd = open(device, O_RDWR | O_EXCL)) < 0 && errno == ENOENT)
 	  {
-	    sprintf(device, "/dev/usb/usblp%d", i);
+	    snprintf(device, sizeof(device), "/dev/usb/usblp%d", i);
 
     	    if ((fd = open(device, O_RDWR | O_EXCL)) < 0 && errno == ENOENT)
 	      continue;
@@ -440,7 +440,7 @@ open_device(const char *uri,		/* I - Dev
     {
       for (i = 0, busy = 0; i < 8; i ++)
       {
-	sprintf(device, "/dev/usb/printer%d", i);
+	snprintf(device, sizeof(device), "/dev/usb/printer%d", i);
 
 	if ((fd = open(device, O_WRONLY | O_EXCL)) >= 0)
 	  backendGetDeviceID(fd, device_id, sizeof(device_id),
diff -pruN 2.3.3-3/berkeley/lpr.c 2.3.3op1-3/berkeley/lpr.c
--- 2.3.3-3/berkeley/lpr.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/berkeley/lpr.c	2020-11-27 14:25:26.000000000 +0000
@@ -234,6 +234,12 @@ main(int  argc,				/* I - Number of comm
 		_cupsLangPrintf(stderr, _("%s: Error - add '/version=1.1' to server name."), argv[0]);
 		return (1);
 	      }
+	      else if (cupsLastError() == IPP_STATUS_ERROR_NOT_FOUND)
+	      {
+		_cupsLangPrintf(stderr,
+				_("%s: Error - The printer or class does not exist."), argv[0]);
+		return (1);
+	      }
 	      break;
 
 	  case '#' : /* Number of copies */
@@ -260,8 +266,7 @@ main(int  argc,				/* I - Number of comm
 		return (1);
 	      }
 
-	      sprintf(buffer, "%d", num_copies);
-	      num_options = cupsAddOption("copies", buffer, num_options, &options);
+	      num_options = cupsAddIntegerOption("copies", num_copies, num_options, &options);
 	      break;
 
 	  case 'C' : /* Class */
diff -pruN 2.3.3-3/cgi-bin/admin.c 2.3.3op1-3/cgi-bin/admin.c
--- 2.3.3-3/cgi-bin/admin.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cgi-bin/admin.c	2020-11-27 14:25:26.000000000 +0000
@@ -208,7 +208,7 @@ main(void)
 	  * bytes left in the array...
 	  */
 
-	  sprintf(ptr, "%%%02X", *url & 255);
+	  snprintf(ptr, sizeof(encoded) - (size_t)(ptr - encoded), "%%%02X", *url & 255);
 	  ptr += 3;
 	}
 	else
@@ -763,6 +763,13 @@ do_am_printer(http_t *http,		/* I - HTTP
 
         cgiSetVariable("TEMPLATE_NAME", template);
       }
+
+     /*
+      * Set DEVICE_URI to the actual device uri, without make and model from
+      * html form.
+      */
+
+      cgiSetVariable("DEVICE_URI", var);
     }
   }
 
@@ -864,7 +871,7 @@ do_am_printer(http_t *http,		/* I - HTTP
         break;
       else
       {
-        sprintf(baudrate, "%d", baudrates[i]);
+        snprintf(baudrate, sizeof(baudrate), "%d", baudrates[i]);
 	cgiSetArray("BAUDRATES", i, baudrate);
       }
 
diff -pruN 2.3.3-3/cgi-bin/classes.c 2.3.3op1-3/cgi-bin/classes.c
--- 2.3.3-3/cgi-bin/classes.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cgi-bin/classes.c	2020-11-27 14:25:26.000000000 +0000
@@ -362,7 +362,7 @@ show_all_classes(http_t     *http,	/* I
     if (first < 0)
       first = 0;
 
-    sprintf(val, "%d", count);
+    snprintf(val, sizeof(val), "%d", count);
     cgiSetVariable("TOTAL", val);
 
     for (i = 0, pclass = (ipp_attribute_t *)cupsArrayIndex(classes, first);
@@ -378,13 +378,13 @@ show_all_classes(http_t     *http,	/* I
 
     if (first > 0)
     {
-      sprintf(val, "%d", first - CUPS_PAGE_MAX);
+      snprintf(val, sizeof(val), "%d", first - CUPS_PAGE_MAX);
       cgiSetVariable("PREV", val);
     }
 
     if ((first + CUPS_PAGE_MAX) < count)
     {
-      sprintf(val, "%d", first + CUPS_PAGE_MAX);
+      snprintf(val, sizeof(val), "%d", first + CUPS_PAGE_MAX);
       cgiSetVariable("NEXT", val);
     }
 
diff -pruN 2.3.3-3/cgi-bin/ipp-var.c 2.3.3op1-3/cgi-bin/ipp-var.c
--- 2.3.3-3/cgi-bin/ipp-var.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cgi-bin/ipp-var.c	2020-11-27 14:25:26.000000000 +0000
@@ -224,7 +224,7 @@ cgiGetIPPObjects(ipp_t *response,	/* I -
 	        char	buf[255];	/* Number buffer */
 
 
-                sprintf(buf, "%d", attr->values[i].integer);
+                snprintf(buf, sizeof(buf), "%d", attr->values[i].integer);
 
 		if (cgiDoSearch(search, buf))
 		  add = 1;
@@ -291,7 +291,7 @@ cgiMoveJobs(http_t     *http,		/* I - Co
       char	temp[255];		/* Temporary string */
 
 
-      sprintf(temp, "%d", job_id);
+      snprintf(temp, sizeof(temp), "%d", job_id);
       cgiSetVariable("JOB_ID", temp);
     }
 
@@ -1441,7 +1441,7 @@ cgiShowJobs(http_t     *http,		/* I - Co
 
     cgiSetVariable("SECTION", section);
 
-    sprintf(val, "%d", count);
+    snprintf(val, sizeof(val), "%d", count);
     cgiSetVariable("TOTAL", val);
 
     if (which_jobs)
@@ -1469,13 +1469,13 @@ cgiShowJobs(http_t     *http,		/* I - Co
 
     if (first > 0)
     {
-      sprintf(val, "%d", first - CUPS_PAGE_MAX);
+      snprintf(val, sizeof(val), "%d", first - CUPS_PAGE_MAX);
       cgiSetVariable("PREV", val);
     }
 
     if ((first + CUPS_PAGE_MAX) < count)
     {
-      sprintf(val, "%d", first + CUPS_PAGE_MAX);
+      snprintf(val, sizeof(val), "%d", first + CUPS_PAGE_MAX);
       cgiSetVariable("NEXT", val);
     }
 
diff -pruN 2.3.3-3/cgi-bin/printers.c 2.3.3op1-3/cgi-bin/printers.c
--- 2.3.3-3/cgi-bin/printers.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cgi-bin/printers.c	2020-11-27 14:25:26.000000000 +0000
@@ -379,7 +379,7 @@ show_all_printers(http_t     *http,	/* I
     if (first < 0)
       first = 0;
 
-    sprintf(val, "%d", count);
+    snprintf(val, sizeof(val), "%d", count);
     cgiSetVariable("TOTAL", val);
 
     for (i = 0, printer = (ipp_attribute_t *)cupsArrayIndex(printers, first);
@@ -395,13 +395,13 @@ show_all_printers(http_t     *http,	/* I
 
     if (first > 0)
     {
-      sprintf(val, "%d", first - CUPS_PAGE_MAX);
+      snprintf(val, sizeof(val), "%d", first - CUPS_PAGE_MAX);
       cgiSetVariable("PREV", val);
     }
 
     if ((first + CUPS_PAGE_MAX) < count)
     {
-      sprintf(val, "%d", first + CUPS_PAGE_MAX);
+      snprintf(val, sizeof(val), "%d", first + CUPS_PAGE_MAX);
       cgiSetVariable("NEXT", val);
     }
 
diff -pruN 2.3.3-3/cgi-bin/template.c 2.3.3op1-3/cgi-bin/template.c
--- 2.3.3-3/cgi-bin/template.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cgi-bin/template.c	2020-11-27 14:25:26.000000000 +0000
@@ -307,9 +307,9 @@ cgi_copy(FILE *out,			/* I - Output file
 	*/
 
         if (name[1])
-          sprintf(outval, "%d", cgiGetSize(name + 1));
+          snprintf(outval, sizeof(outval), "%d", cgiGetSize(name + 1));
 	else
-	  sprintf(outval, "%d", element + 1);
+	  snprintf(outval, sizeof(outval), "%d", element + 1);
 
         outptr = outval;
       }
@@ -457,7 +457,7 @@ cgi_copy(FILE *out,			/* I - Output file
 	    continue;
 	  else if (ch == '#')
 	  {
-	    sprintf(s, "%d", element + 1);
+	    snprintf(s, sizeof(compare) - (size_t)(s - compare), "%d", element + 1);
 	    s += strlen(s);
 	  }
 	  else if (ch == '{')
@@ -473,7 +473,7 @@ cgi_copy(FILE *out,			/* I - Output file
 	    *innerptr = '\0';
 
             if (innername[0] == '#')
-	      sprintf(s, "%d", cgiGetSize(innername + 1));
+	      snprintf(s, sizeof(compare) - (size_t)(s - compare), "%d", cgiGetSize(innername + 1));
 	    else if ((innerptr = strrchr(innername, '-')) != NULL &&
 	             isdigit(innerptr[1] & 255))
             {
diff -pruN 2.3.3-3/CHANGES-OPENPRINTING.md 2.3.3op1-3/CHANGES-OPENPRINTING.md
--- 2.3.3-3/CHANGES-OPENPRINTING.md	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/CHANGES-OPENPRINTING.md	2020-11-27 14:25:26.000000000 +0000
@@ -0,0 +1,71 @@
+OpenPrinting CUPS Changes
+=========================
+
+Changes in CUPS v2.3.3op1
+-------------------------
+
+- The automated test suite can now be activated using `make test` for
+  consistency with other projects and CI environments - the old `make check`
+  continues to work as well, and the previous test server behavior can be
+  accessed by running `make testserver`.
+- ippeveprinter now supports multiple icons and strings files.
+- ippeveprinter now uses the system's FQDN with Avahi.
+- ippeveprinter now supports Get-Printer-Attributes on "/".
+- ippeveprinter now uses a deterministic "printer-uuid" value.
+- ippeveprinter now uses system sounds on macOS for Identify-Printer.
+- Updated ippfind to look for files in "~/Desktop" on Windows.
+- Updated ippfind to honor `SKIP-XXX` directives with `PAUSE`.
+- Updated IPP Everywhere support to work around printers that only advertise
+  color raster support but really also support grayscale (Issue #1)
+- ipptool now supports DNS-SD URIs like `ipps://My%20Printer._ipps._tcp.local`
+  (Issue #5)
+- The scheduler now allows root backends to have world read permissions but not
+  world execute permissions (Issue #21)
+- Failures to bind IPv6 listener sockets no longer cause errors if IPv6 is
+  disabled on the host (Issue #25)
+- The SNMP backend now supports the HP and Ricoh vendor MIBs (Issue #28)
+- The scheduler no longer includes a timestamp in files it writes (Issue #29)
+- The systemd service names are now "cups.service" and "cups-lpd.service"
+  (Issue #30, Issue #31)
+- The scheduler no longer adds the local hostname to the ServerAlias list
+  (Issue #32)
+- Added `LogFileGroup` directive in "cups-files.conf" to control the group
+  owner of log files (Issue #34)
+- Added `--with-max-log-size` configure option (Issue #35)
+- Added `--enable-sync-on-close` configure option (Issue #37)
+- Added `--with-error-policy` configure option (Issue #38)
+- IPP Everywhere PPDs could have an "unknown" default InputSlot (Issue #44)
+- The `httpAddrListen` function now uses a listen backlog of 128.
+- Added USB quirks (Apple issue #5789, #5823, #5831)
+- Fixed IPP Everywhere v1.1 conformance issues in ippeveprinter.
+- Fixed DNS-SD name collision support in ippeveprinter.
+- Fixed compiler and code analyzer warnings.
+- Fixed TLS support on Windows.
+- Fixed ippfind sub-type searches with Avahi.
+- Fixed the default hostname used by ippeveprinter on macOS.
+- Fixed resolution of local IPP-USB printers with Avahi.
+- Fixed coverity issues (Issue #2)
+- Fixed `httpAddrConnect` issues (Issue #3)
+- Fixed web interface device URI issue (Issue #4)
+- Fixed lp/lpr "printer/class not found" error reporting (Issue #6)
+- Fixed xinetd support for LPD clients (Issue #7)
+- Fixed libtool build issue (Issue #11)
+- Fixed a memory leak in the scheduler (Issue #12)
+- Fixed a potential integer overflow in the PPD hashing code (Issue #13)
+- Fixed output-bin and print-quality handling issues (Issue #18)
+- Fixed PPD options getting mapped to odd IPP values like "tray---4" (Issue #23)
+- Fixed remote access to the cupsd.conf and log files (Issue #24)
+- Fixed the automated test suite when running in certain build/CI environments
+  (Issue #25)
+- Fixed a logging regression caused by a previous change for Apple issue #5604
+  (Issue #25)
+- Fixed fax phone number handling with GNOME (Issue #40)
+- Fixed potential rounding error in rastertopwg filter (Issue #41)
+- Fixed the "uri-security-supported" value from the scheduler (Issue #42)
+- Fixed IPP backend crash bug with "printer-alert" values (Issue #43)
+- Removed old Solaris inetconv(1m) reference in cups-lpd man page (Issue #46)
+- Fixed default options that incorrectly use the "custom" prefix (Issue #48)
+- Fixed a memory leak when resolving DNS-SD URIs (Issue #49)
+- Fixed systemd status reporting by adopting the notify interface (Issue #51)
+- Fixed crash in rastertopwg (Apple issue #5773)
+- Fixed cupsManualCopies values in IPP Everywhere PPDs (Apple issue #5807)
diff -pruN 2.3.3-3/.codacy.yml 2.3.3op1-3/.codacy.yml
--- 2.3.3-3/.codacy.yml	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/.codacy.yml	2020-11-27 14:25:26.000000000 +0000
@@ -0,0 +1,7 @@
+engines:
+  cppcheck:
+    exclude_paths:
+      - **/*
+  shellcheck:
+    exclude_paths:
+      - **/*
diff -pruN 2.3.3-3/conf/cupsd.conf.in 2.3.3op1-3/conf/cupsd.conf.in
--- 2.3.3-3/conf/cupsd.conf.in	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/conf/cupsd.conf.in	2020-11-27 14:25:26.000000000 +0000
@@ -8,6 +8,12 @@
 LogLevel @CUPS_LOG_LEVEL@
 @CUPS_PAGE_LOG_FORMAT@
 
+# Specifies the maximum size of the log files before they are rotated.  The value "0" disables log rotation.
+MaxLogSize @CUPS_MAX_LOG_SIZE@
+
+# Default error policy for printers
+ErrorPolicy @CUPS_ERROR_POLICY@
+
 # Only listen for connections from the local machine.
 Listen localhost:@DEFAULT_IPP_PORT@
 @CUPS_LISTEN_DOMAINSOCKET@
diff -pruN 2.3.3-3/conf/cups-files.conf.in 2.3.3op1-3/conf/cups-files.conf.in
--- 2.3.3-3/conf/cups-files.conf.in	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/conf/cups-files.conf.in	2020-11-27 14:25:26.000000000 +0000
@@ -7,7 +7,7 @@
 #FatalErrors @CUPS_FATAL_ERRORS@
 
 # Do we call fsync() after writing configuration or status files?
-#SyncOnClose No
+#SyncOnClose @CUPS_SYNC_ON_CLOSE@
 
 # Default user and group for filters/backends/helper programs; this cannot be
 # any user or group that resolves to ID 0 for security reasons...
diff -pruN 2.3.3-3/config.h.in 2.3.3op1-3/config.h.in
--- 2.3.3-3/config.h.in	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/config.h.in	2020-11-27 14:25:26.000000000 +0000
@@ -1,6 +1,7 @@
 /*
  * Configuration file for CUPS.
  *
+ * Copyright 2020 by Michael R Sweet
  * Copyright 2007-2019 by Apple Inc.
  * Copyright 1997-2007 by Easy Software Products.
  *
@@ -45,6 +46,7 @@
 
 #define CUPS_DEFAULT_LOG_LEVEL	"warn"
 #define CUPS_DEFAULT_ACCESS_LOG_LEVEL "actions"
+#define CUPS_DEFAULT_MAX_LOG_SIZE "1m"
 
 
 /*
@@ -86,6 +88,13 @@
 
 
 /*
+ * Default ErrorPolicy value...
+ */
+
+#define CUPS_DEFAULT_ERROR_POLICY "stop-printer"
+
+
+/*
  * Default MaxCopies value...
  */
 
@@ -93,6 +102,13 @@
 
 
 /*
+ * Default SyncOnClose value...
+ */
+
+#undef CUPS_DEFAULT_SYNC_ON_CLOSE
+
+
+/*
  * Do we have domain socket support, and if so what is the default one?
  */
 
diff -pruN 2.3.3-3/config-scripts/cups-compiler.m4 2.3.3op1-3/config-scripts/cups-compiler.m4
--- 2.3.3-3/config-scripts/cups-compiler.m4	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/config-scripts/cups-compiler.m4	2020-11-27 14:25:26.000000000 +0000
@@ -175,15 +175,15 @@ if test -n "$GCC"; then
 	# doesn't trigger...
 	gccversion=`$CC --version | head -1 | awk '{print $NF}'`
 	case "$gccversion" in
-		7.* | 8.*)
+		7.* | 8.* | 9.* | 10.* | 11.* | 12.*)
 			WARNING_OPTIONS="$WARNING_OPTIONS -Wno-format-truncation -Wno-tautological-compare"
 			;;
 	esac
 
 	# Additional warning options for development testing...
-	if test -d .git; then
-		WARNING_OPTIONS="-Werror -Wno-error=deprecated-declarations $WARNING_OPTIONS"
-	fi
+#	if test -d .git; then
+#		WARNING_OPTIONS="-Werror -Wno-error=deprecated-declarations $WARNING_OPTIONS"
+#	fi
 else
 	# Add vendor-specific compiler options...
 	case $host_os_name in
diff -pruN 2.3.3-3/config-scripts/cups-defaults.m4 2.3.3op1-3/config-scripts/cups-defaults.m4
--- 2.3.3-3/config-scripts/cups-defaults.m4	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/config-scripts/cups-defaults.m4	2020-11-27 14:25:26.000000000 +0000
@@ -93,6 +93,20 @@ AC_ARG_WITH(log_file_perm, [  --with-log
 AC_SUBST(CUPS_LOG_FILE_PERM)
 AC_DEFINE_UNQUOTED(CUPS_DEFAULT_LOG_FILE_PERM, 0$CUPS_LOG_FILE_PERM)
 
+dnl Default MaxLogSize
+AC_ARG_WITH(max_log_size, [  --with-max-log-size     set default MaxLogSize value, default=1m],
+	CUPS_MAX_LOG_SIZE="$withval",
+	CUPS_MAX_LOG_SIZE="1m")
+AC_SUBST(CUPS_MAX_LOG_SIZE)
+AC_DEFINE_UNQUOTED(CUPS_DEFAULT_MAX_LOG_SIZE, "$CUPS_MAX_LOG_SIZE")
+
+dnl Default ErrorPolicy
+AC_ARG_WITH(error_policy, [  --with-error-policy     set default ErrorPolicy value, default=stop-printer],
+	CUPS_ERROR_POLICY="$withval",
+	CUPS_ERROR_POLICY="stop-printer")
+AC_SUBST(CUPS_ERROR_POLICY)
+AC_DEFINE_UNQUOTED(CUPS_DEFAULT_ERROR_POLICY, "$CUPS_ERROR_POLICY")
+
 dnl Default FatalErrors
 AC_ARG_WITH(fatal_errors, [  --with-fatal-errors     set default FatalErrors value, default=config],
 	CUPS_FATAL_ERRORS="$withval",
@@ -123,6 +137,16 @@ else
 fi
 AC_SUBST(CUPS_PAGE_LOG_FORMAT)
 
+dnl Default SyncOnClose
+AC_ARG_ENABLE(sync_on_close, [  --enable-sync-on-close  enable SyncOnClose (off by default)])
+if test "x$enable_sync_on_close" = xyes; then
+	CUPS_SYNC_ON_CLOSE="Yes"
+	AC_DEFINE(CUPS_DEFAULT_SYNC_ON_CLOSE)
+else
+	CUPS_SYNC_ON_CLOSE="No"
+fi
+AC_SUBST(CUPS_SYNC_ON_CLOSE)
+
 dnl Default Browsing
 AC_ARG_ENABLE(browsing, [  --disable-browsing      disable Browsing by default])
 if test "x$enable_browsing" = xno; then
diff -pruN 2.3.3-3/config-scripts/cups-dnssd.m4 2.3.3op1-3/config-scripts/cups-dnssd.m4
--- 2.3.3-3/config-scripts/cups-dnssd.m4	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/config-scripts/cups-dnssd.m4	2020-11-27 14:25:26.000000000 +0000
@@ -60,9 +60,9 @@ if test "x$DNSSD_BACKEND" = x -a x$enabl
 					AC_MSG_RESULT(yes)
 					AC_DEFINE(HAVE_DNSSD)
 					DNSSDLIBS="-ldns_sd"
-					DNSSD_BACKEND="dnssd",
+					DNSSD_BACKEND="dnssd"
 					IPPFIND_BIN="ippfind"
-					IPPFIND_MAN="ippfind.1"
+					IPPFIND_MAN="ippfind.1",
 					AC_MSG_RESULT(no))
 				LIBS="$SAVELIBS"
 				;;
diff -pruN 2.3.3-3/configure 2.3.3op1-3/configure
--- 2.3.3-3/configure	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/configure	2020-11-27 14:25:26.000000000 +0000
@@ -1,8 +1,8 @@
 #! /bin/sh
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.69 for CUPS 2.3.3.
+# Generated by GNU Autoconf 2.69 for CUPS 2.3.3op1.
 #
-# Report bugs to <https://github.com/apple/cups/issues>.
+# Report bugs to <https://github.com/openprinting/cups/issues>.
 #
 #
 # Copyright (C) 1992-1996, 1998-2012 Free Software Foundation, Inc.
@@ -267,8 +267,8 @@ fi
     $as_echo "$0: be upgraded to zsh 4.3.4 or later."
   else
     $as_echo "$0: Please tell bug-autoconf@gnu.org and
-$0: https://github.com/apple/cups/issues about your system,
-$0: including any error possibly output before this
+$0: https://github.com/openprinting/cups/issues about your
+$0: system, including any error possibly output before this
 $0: message. Then install a modern shell, or manually run
 $0: the script under such a shell if you do have one."
   fi
@@ -580,10 +580,10 @@ MAKEFLAGS=
 # Identity of this package.
 PACKAGE_NAME='CUPS'
 PACKAGE_TARNAME='cups'
-PACKAGE_VERSION='2.3.3'
-PACKAGE_STRING='CUPS 2.3.3'
-PACKAGE_BUGREPORT='https://github.com/apple/cups/issues'
-PACKAGE_URL='https://www.cups.org/'
+PACKAGE_VERSION='2.3.3op1'
+PACKAGE_STRING='CUPS 2.3.3op1'
+PACKAGE_BUGREPORT='https://github.com/openprinting/cups/issues'
+PACKAGE_URL='https://openprinting.github.io/'
 
 # Factoring default headers for most tests.
 ac_includes_default="\
@@ -642,10 +642,13 @@ CUPS_USER
 CUPS_DEFAULT_SHARED
 CUPS_BROWSE_LOCAL_PROTOCOLS
 CUPS_BROWSING
+CUPS_SYNC_ON_CLOSE
 CUPS_PAGE_LOG_FORMAT
 CUPS_ACCESS_LOG_LEVEL
 CUPS_LOG_LEVEL
 CUPS_FATAL_ERRORS
+CUPS_ERROR_POLICY
+CUPS_MAX_LOG_SIZE
 CUPS_LOG_FILE_PERM
 CUPS_CUPSD_FILE_PERM
 CUPS_CONFIG_FILE_PERM
@@ -895,10 +898,13 @@ with_exe_file_perm
 with_config_file_perm
 with_cupsd_file_perm
 with_log_file_perm
+with_max_log_size
+with_error_policy
 with_fatal_errors
 with_log_level
 with_access_log_level
 enable_page_logging
+enable_sync_on_close
 enable_browsing
 with_local_protocols
 enable_default_shared
@@ -1467,7 +1473,7 @@ if test "$ac_init_help" = "long"; then
   # Omit some internal or obsolete options to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
-\`configure' configures CUPS 2.3.3 to adapt to many kinds of systems.
+\`configure' configures CUPS 2.3.3op1 to adapt to many kinds of systems.
 
 Usage: $0 [OPTION]... [VAR=VALUE]...
 
@@ -1532,7 +1538,7 @@ fi
 
 if test -n "$ac_init_help"; then
   case $ac_init_help in
-     short | recursive ) echo "Configuration of CUPS 2.3.3:";;
+     short | recursive ) echo "Configuration of CUPS 2.3.3op1:";;
    esac
   cat <<\_ACEOF
 
@@ -1569,6 +1575,7 @@ Optional Features:
   --disable-systemd       disable systemd support
   --enable-upstart        enable upstart support
   --enable-page-logging   enable page_log by default
+  --enable-sync-on-close  enable SyncOnClose (off by default)
   --disable-browsing      disable Browsing by default
   --disable-default-shared
 			  disable DefaultShared by default
@@ -1619,6 +1626,8 @@ Optional Packages:
   --with-config-file-perm set default ConfigFilePerm value, default=0640
   --with-cupsd-file-perm  set default cupsd permissions, default=0500
   --with-log-file-perm    set default LogFilePerm value, default=0644
+  --with-max-log-size     set default MaxLogSize value, default=1m
+  --with-error-policy     set default ErrorPolicy value, default=stop-printer
   --with-fatal-errors     set default FatalErrors value, default=config
   --with-log-level        set default LogLevel value, default=warn
   --with-access-log-level set default AccessLogLevel value, default=none
@@ -1649,8 +1658,8 @@ Some influential environment variables:
 Use these variables to override the choices made by `configure' or to help
 it to find libraries and programs with nonstandard names/locations.
 
-Report bugs to <https://github.com/apple/cups/issues>.
-CUPS home page: <https://www.cups.org/>.
+Report bugs to <https://github.com/openprinting/cups/issues>.
+CUPS home page: <https://openprinting.github.io/>.
 _ACEOF
 ac_status=$?
 fi
@@ -1713,7 +1722,7 @@ fi
 test -n "$ac_init_help" && exit $ac_status
 if $ac_init_version; then
   cat <<\_ACEOF
-CUPS configure 2.3.3
+CUPS configure 2.3.3op1
 generated by GNU Autoconf 2.69
 
 Copyright (C) 2012 Free Software Foundation, Inc.
@@ -1998,9 +2007,9 @@ $as_echo "$as_me: WARNING: $2: see the A
 $as_echo "$as_me: WARNING: $2:     section \"Present But Cannot Be Compiled\"" >&2;}
     { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: $2: proceeding with the compiler's result" >&5
 $as_echo "$as_me: WARNING: $2: proceeding with the compiler's result" >&2;}
-( $as_echo "## --------------------------------------------------- ##
-## Report this to https://github.com/apple/cups/issues ##
-## --------------------------------------------------- ##"
+( $as_echo "## ---------------------------------------------------------- ##
+## Report this to https://github.com/openprinting/cups/issues ##
+## ---------------------------------------------------------- ##"
      ) | sed "s/^/$as_me: WARNING:     /" >&2
     ;;
 esac
@@ -2177,7 +2186,7 @@ cat >config.log <<_ACEOF
 This file contains any messages produced by compilers while
 running configure, to aid debugging if configure makes a mistake.
 
-It was created by CUPS $as_me 2.3.3, which was
+It was created by CUPS $as_me 2.3.3op1, which was
 generated by GNU Autoconf 2.69.  Invocation command line was
 
   $ $0 $@
@@ -2694,7 +2703,7 @@ done
 ac_config_headers="$ac_config_headers config.h"
 
 
-CUPS_VERSION="2.3.3"
+CUPS_VERSION="2.3.3op1"
 CUPS_REVISION=""
 CUPS_BUILD="cups-$CUPS_VERSION"
 
@@ -6911,15 +6920,15 @@ rm -f core conftest.err conftest.$ac_obj
 	# doesn't trigger...
 	gccversion=`$CC --version | head -1 | awk '{print $NF}'`
 	case "$gccversion" in
-		7.* | 8.* | 9.*)
-			WARNING_OPTIONS="$WARNING_OPTIONS -Wno-format-truncation -Wno-format-overflow -Wno-tautological-compare"
+		7.* | 8.* | 9.* | 10.* | 11.* | 12.*)
+			WARNING_OPTIONS="$WARNING_OPTIONS -Wno-format-truncation -Wno-tautological-compare"
 			;;
 	esac
 
 	# Additional warning options for development testing...
-	if test -d .git; then
-		WARNING_OPTIONS="-Werror -Wno-error=deprecated-declarations $WARNING_OPTIONS"
-	fi
+#	if test -d .git; then
+#		WARNING_OPTIONS="-Werror -Wno-error=deprecated-declarations $WARNING_OPTIONS"
+#	fi
 else
 	# Add vendor-specific compiler options...
 	case $host_os_name in
@@ -8970,10 +8979,10 @@ $as_echo "yes" >&6; }
 
 					DNSSDLIBS="-ldns_sd"
 					DNSSD_BACKEND="dnssd"
-else
-  IPPFIND_BIN="ippfind"
+					IPPFIND_BIN="ippfind"
 					IPPFIND_MAN="ippfind.1"
-					{ $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+else
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
 $as_echo "no" >&6; }
 fi
 rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
@@ -9372,6 +9381,34 @@ _ACEOF
 
 
 
+# Check whether --with-max_log_size was given.
+if test "${with_max_log_size+set}" = set; then :
+  withval=$with_max_log_size; CUPS_MAX_LOG_SIZE="$withval"
+else
+  CUPS_MAX_LOG_SIZE="1m"
+fi
+
+
+cat >>confdefs.h <<_ACEOF
+#define CUPS_DEFAULT_MAX_LOG_SIZE "$CUPS_MAX_LOG_SIZE"
+_ACEOF
+
+
+
+# Check whether --with-error_policy was given.
+if test "${with_error_policy+set}" = set; then :
+  withval=$with_error_policy; CUPS_ERROR_POLICY="$withval"
+else
+  CUPS_ERROR_POLICY="stop-printer"
+fi
+
+
+cat >>confdefs.h <<_ACEOF
+#define CUPS_DEFAULT_ERROR_POLICY "$CUPS_ERROR_POLICY"
+_ACEOF
+
+
+
 # Check whether --with-fatal_errors was given.
 if test "${with_fatal_errors+set}" = set; then :
   withval=$with_fatal_errors; CUPS_FATAL_ERRORS="$withval"
@@ -9425,6 +9462,20 @@ else
 fi
 
 
+# Check whether --enable-sync_on_close was given.
+if test "${enable_sync_on_close+set}" = set; then :
+  enableval=$enable_sync_on_close;
+fi
+
+if test "x$enable_sync_on_close" = xyes; then
+	CUPS_SYNC_ON_CLOSE="Yes"
+	$as_echo "#define CUPS_DEFAULT_SYNC_ON_CLOSE 1" >>confdefs.h
+
+else
+	CUPS_SYNC_ON_CLOSE="No"
+fi
+
+
 # Check whether --enable-browsing was given.
 if test "${enable_browsing+set}" = set; then :
   enableval=$enable_browsing;
@@ -9877,7 +9928,7 @@ fi
 
 
 
-ac_config_files="$ac_config_files Makedefs conf/cups-files.conf conf/cupsd.conf conf/mime.convs conf/pam.std conf/snmp.conf cups-config desktop/cups.desktop doc/index.html scheduler/cups-lpd.xinetd scheduler/cups.sh scheduler/cups.xml scheduler/org.cups.cups-lpd.plist scheduler/org.cups.cups-lpdAT.service scheduler/org.cups.cupsd.path scheduler/org.cups.cupsd.service scheduler/org.cups.cupsd.socket templates/header.tmpl packaging/cups.list $LANGFILES"
+ac_config_files="$ac_config_files Makedefs conf/cups-files.conf conf/cupsd.conf conf/mime.convs conf/pam.std conf/snmp.conf cups-config desktop/cups.desktop doc/index.html scheduler/cups-lpd.xinetd scheduler/cups.sh scheduler/cups.xml scheduler/org.cups.cups-lpd.plist scheduler/cups-lpdAT.service scheduler/cups.path scheduler/cups.service scheduler/cups.socket templates/header.tmpl packaging/cups.list $LANGFILES"
 
 cat >confcache <<\_ACEOF
 # This file is a shell script that caches the results of configure
@@ -10385,7 +10436,7 @@ cat >>$CONFIG_STATUS <<\_ACEOF || ac_wri
 # report actual input values of CONFIG_FILES etc. instead of their
 # values after options handling.
 ac_log="
-This file was extended by CUPS $as_me 2.3.3, which was
+This file was extended by CUPS $as_me 2.3.3op1, which was
 generated by GNU Autoconf 2.69.  Invocation command line was
 
   CONFIG_FILES    = $CONFIG_FILES
@@ -10441,14 +10492,14 @@ $config_files
 Configuration headers:
 $config_headers
 
-Report bugs to <https://github.com/apple/cups/issues>.
-CUPS home page: <https://www.cups.org/>."
+Report bugs to <https://github.com/openprinting/cups/issues>.
+CUPS home page: <https://openprinting.github.io/>."
 
 _ACEOF
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
 ac_cs_version="\\
-CUPS config.status 2.3.3
+CUPS config.status 2.3.3op1
 configured by $0, generated by GNU Autoconf 2.69,
   with options \\"\$ac_cs_config\\"
 
@@ -10584,10 +10635,10 @@ do
     "scheduler/cups.sh") CONFIG_FILES="$CONFIG_FILES scheduler/cups.sh" ;;
     "scheduler/cups.xml") CONFIG_FILES="$CONFIG_FILES scheduler/cups.xml" ;;
     "scheduler/org.cups.cups-lpd.plist") CONFIG_FILES="$CONFIG_FILES scheduler/org.cups.cups-lpd.plist" ;;
-    "scheduler/org.cups.cups-lpdAT.service") CONFIG_FILES="$CONFIG_FILES scheduler/org.cups.cups-lpdAT.service" ;;
-    "scheduler/org.cups.cupsd.path") CONFIG_FILES="$CONFIG_FILES scheduler/org.cups.cupsd.path" ;;
-    "scheduler/org.cups.cupsd.service") CONFIG_FILES="$CONFIG_FILES scheduler/org.cups.cupsd.service" ;;
-    "scheduler/org.cups.cupsd.socket") CONFIG_FILES="$CONFIG_FILES scheduler/org.cups.cupsd.socket" ;;
+    "scheduler/cups-lpdAT.service") CONFIG_FILES="$CONFIG_FILES scheduler/cups-lpdAT.service" ;;
+    "scheduler/cups.path") CONFIG_FILES="$CONFIG_FILES scheduler/cups.path" ;;
+    "scheduler/cups.service") CONFIG_FILES="$CONFIG_FILES scheduler/cups.service" ;;
+    "scheduler/cups.socket") CONFIG_FILES="$CONFIG_FILES scheduler/cups.socket" ;;
     "templates/header.tmpl") CONFIG_FILES="$CONFIG_FILES templates/header.tmpl" ;;
     "packaging/cups.list") CONFIG_FILES="$CONFIG_FILES packaging/cups.list" ;;
     "$LANGFILES") CONFIG_FILES="$CONFIG_FILES $LANGFILES" ;;
diff -pruN 2.3.3-3/configure.ac 2.3.3op1-3/configure.ac
--- 2.3.3-3/configure.ac	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/configure.ac	2020-11-27 14:25:26.000000000 +0000
@@ -1,6 +1,7 @@
 dnl
 dnl Configuration script for CUPS.
 dnl
+dnl Copyright © 2020 by Michael R Sweet
 dnl Copyright © 2007-2019 by Apple Inc.
 dnl Copyright © 1997-2007 by Easy Software Products, all rights reserved.
 dnl
@@ -12,7 +13,7 @@ dnl We need at least autoconf 2.60...
 AC_PREREQ(2.60)
 
 dnl Package name and version...
-AC_INIT([CUPS], [2.3.3], [https://github.com/apple/cups/issues], [cups], [https://www.cups.org/])
+AC_INIT([CUPS], [2.3.3op1], [https://github.com/openprinting/cups/issues], [cups], [https://openprinting.github.io/])
 
 sinclude(config-scripts/cups-opsys.m4)
 sinclude(config-scripts/cups-common.m4)
@@ -70,10 +71,10 @@ AC_OUTPUT(Makedefs
 	  scheduler/cups.sh
 	  scheduler/cups.xml
 	  scheduler/org.cups.cups-lpd.plist
-	  scheduler/org.cups.cups-lpdAT.service
-	  scheduler/org.cups.cupsd.path
-	  scheduler/org.cups.cupsd.service
-	  scheduler/org.cups.cupsd.socket
+	  scheduler/cups-lpdAT.service
+	  scheduler/cups.path
+	  scheduler/cups.service
+	  scheduler/cups.socket
  	  templates/header.tmpl
           packaging/cups.list
 	  $LANGFILES)
diff -pruN 2.3.3-3/cups/dest.c 2.3.3op1-3/cups/dest.c
--- 2.3.3-3/cups/dest.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cups/dest.c	2020-11-27 14:25:26.000000000 +0000
@@ -1839,7 +1839,10 @@ cupsGetNamedDest(http_t     *http,	/* I
       cupsEnumDests(0, 1000, NULL, 0, 0, (cups_dest_cb_t)cups_name_cb, &data);
 
       if (!data.dest)
+      {
+        _cupsSetError(IPP_STATUS_ERROR_NOT_FOUND, _("The printer or class does not exist."), 1);
         return (NULL);
+      }
 
       dest = data.dest;
     }
diff -pruN 2.3.3-3/cups/getifaddrs-internal.h 2.3.3op1-3/cups/getifaddrs-internal.h
--- 2.3.3-3/cups/getifaddrs-internal.h	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cups/getifaddrs-internal.h	2020-11-27 14:25:26.000000000 +0000
@@ -25,6 +25,7 @@
 #    include <unistd.h>
 #    include <fcntl.h>
 #    include <sys/socket.h>
+#    include <netinet/in.h>
 #    define CUPS_SOCAST
 #  endif /* _WIN32 */
 
diff -pruN 2.3.3-3/cups/hash.c 2.3.3op1-3/cups/hash.c
--- 2.3.3-3/cups/hash.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cups/hash.c	2020-11-27 14:25:26.000000000 +0000
@@ -199,7 +199,7 @@ cupsHashData(const char    *algorithm,	/
       goto too_small;
 
     _cupsMD5Init(&state);
-    _cupsMD5Append(&state, data, datalen);
+    _cupsMD5Append(&state, data, (int)datalen);
     _cupsMD5Finish(&state, hash);
 
     return (16);
diff -pruN 2.3.3-3/cups/http-addr.c 2.3.3op1-3/cups/http-addr.c
--- 2.3.3-3/cups/http-addr.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cups/http-addr.c	2020-11-27 14:25:26.000000000 +0000
@@ -243,7 +243,7 @@ httpAddrListen(http_addr_t *addr,	/* I -
   * Listen...
   */
 
-  if (listen(fd, 5))
+  if (listen(fd, 128))
   {
     _cupsSetHTTPError(HTTP_STATUS_ERROR);
 
diff -pruN 2.3.3-3/cups/http-addrlist.c 2.3.3op1-3/cups/http-addrlist.c
--- 2.3.3-3/cups/http-addrlist.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cups/http-addrlist.c	2020-11-27 14:25:26.000000000 +0000
@@ -238,7 +238,14 @@ httpAddrConnect2(
     }
 
     if (!addrlist && nfds == 0)
+    {
+#ifdef _WIN32
+      errno = WSAEHOSTDOWN;
+#else
+      errno = EHOSTDOWN;
+#endif // _WIN32
       break;
+    }
 
    /*
     * See if we can connect to any of the addresses so far...
@@ -369,6 +376,9 @@ httpAddrConnect2(
       remaining -= 250;
   }
 
+  if (remaining <= 0)
+    errno = ETIMEDOUT;
+
   while (nfds > 0)
   {
     nfds --;
diff -pruN 2.3.3-3/cups/http-support.c 2.3.3op1-3/cups/http-support.c
--- 2.3.3-3/cups/http-support.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cups/http-support.c	2020-11-27 14:25:26.000000000 +0000
@@ -1,8 +1,9 @@
 /*
  * HTTP support routines for CUPS.
  *
- * Copyright 2007-2019 by Apple Inc.
- * Copyright 1997-2007 by Easy Software Products, all rights reserved.
+ * Copyright © 2020 by Michael R Sweet
+ * Copyright © 2007-2019 by Apple Inc.
+ * Copyright © 1997-2007 by Easy Software Products, all rights reserved.
  *
  * Licensed under Apache License v2.0.  See the file "LICENSE" for more
  * information.
@@ -26,6 +27,7 @@
 #elif defined(HAVE_AVAHI)
 #  include <avahi-client/client.h>
 #  include <avahi-client/lookup.h>
+#  include <avahi-common/malloc.h>
 #  include <avahi-common/simple-watch.h>
 #endif /* HAVE_DNSSD */
 
@@ -841,6 +843,13 @@ httpGetDateTime(const char *s)		/* I - D
                 "min=%d, sec=%d", day, mon, year, hour, min, sec));
 
  /*
+  * Check for invalid year (RFC 7231 says it's 4DIGIT)
+  */
+
+  if (year > 9999)
+    return (0);
+
+ /*
   * Convert the month name to a number from 0 to 11.
   */
 
@@ -2483,7 +2492,7 @@ http_poll_cb(
 static void
 http_resolve_cb(
     AvahiServiceResolver   *resolver,	/* I - Resolver (unused) */
-    AvahiIfIndex           interface,	/* I - Interface index (unused) */
+    AvahiIfIndex           interface,	/* I - Interface index */
     AvahiProtocol          protocol,	/* I - Network protocol (unused) */
     AvahiResolverEvent     event,	/* I - Event (found, etc.) */
     const char             *name,	/* I - Service name */
@@ -2504,6 +2513,8 @@ http_resolve_cb(
 			*resdefault;	/* Default path */
   char			resource[257],	/* Remote path */
 			fqdn[256];	/* FQDN of the .local name */
+  char			ifname[IF_NAMESIZE];
+					/* Interface name */
   AvahiStringList	*pair;		/* Current TXT record key/value pair */
   char			*value;		/* Value for "rp" key */
   size_t		valueLen = 0;	/* Length of "rp" key */
@@ -2536,6 +2547,8 @@ http_resolve_cb(
     memcpy(uuid, value, valueLen);
     uuid[valueLen] = '\0';
 
+    avahi_free(value);
+
     if (_cups_strcasecmp(uuid, uribuf->uuid))
     {
       if (uribuf->options & _HTTP_RESOLVE_STDERR)
@@ -2620,6 +2633,8 @@ http_resolve_cb(
       memcpy(resource + 1, value, valueLen);
       resource[valueLen + 1] = '\0';
     }
+
+    avahi_free(value);
   }
   else
   {
@@ -2631,12 +2646,32 @@ http_resolve_cb(
   }
 
  /*
-  * Lookup the FQDN if needed...
+  * Get the name of the interface this is coming from...
   */
 
-  if ((uribuf->options & _HTTP_RESOLVE_FQDN) &&
-      (hostptr = hostTarget + strlen(hostTarget) - 6) > hostTarget &&
-      !_cups_strcasecmp(hostptr, ".local"))
+  if (!if_indextoname((unsigned int)interface, ifname))
+  {
+    if (uribuf->options & _HTTP_RESOLVE_STDERR)
+      fprintf(stderr, "DEBUG: Unable to find interface name for interface %d: %s\n", interface, strerror(errno));
+    DEBUG_printf(("Unable to find interface name for interface %d: %s\n", interface, strerror(errno)));
+    ifname[0] = '\0';
+  }
+
+  if (!strcmp(ifname, "lo"))
+  {
+   /*
+    * If this service is registered on loopback interface ("lo"), force the host
+    * name to "localhost"...
+    */
+
+    if (uribuf->options & _HTTP_RESOLVE_STDERR)
+      fputs("DEBUG: Service comes from loopback interface \"lo\", setting \"localhost\" as host name.\n", stderr);
+    DEBUG_puts("Service comes from loopback interface \"lo\", setting \"localhost\" as host name.");
+    hostTarget = "localhost";
+  }
+  else if ((uribuf->options & _HTTP_RESOLVE_FQDN) &&
+	   (hostptr = hostTarget + strlen(hostTarget) - 6) > hostTarget &&
+	   !_cups_strcasecmp(hostptr, ".local"))
   {
    /*
     * OK, we got a .local name but the caller needs a real domain.  Start by
@@ -2682,8 +2717,7 @@ http_resolve_cb(
   * Assemble the final device URI using the resolved hostname...
   */
 
-  httpAssembleURI(HTTP_URI_CODING_ALL, uribuf->buffer, (int)uribuf->bufsize, scheme,
-                  NULL, hostTarget, port, resource);
+  httpAssembleURI(HTTP_URI_CODING_ALL, uribuf->buffer, (int)uribuf->bufsize, scheme, NULL, hostTarget, port, resource);
   DEBUG_printf(("5http_resolve_cb: Resolved URI is \"%s\".", uribuf->buffer));
 
   avahi_simple_poll_quit(uribuf->poll);
diff -pruN 2.3.3-3/cups/ipp-support.c 2.3.3op1-3/cups/ipp-support.c
--- 2.3.3-3/cups/ipp-support.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cups/ipp-support.c	2020-11-27 14:25:26.000000000 +0000
@@ -2262,7 +2262,7 @@ ippErrorString(ipp_status_t error)	/* I
   * No, build an "0xxxxx" error string...
   */
 
-  sprintf(cg->ipp_unknown, "0x%04x", error);
+  snprintf(cg->ipp_unknown, sizeof(cg->ipp_unknown), "0x%04x", error);
 
   return (cg->ipp_unknown);
 }
@@ -2339,7 +2339,7 @@ ippOpString(ipp_op_t op)		/* I - Operati
   * No, build an "0xxxxx" operation string...
   */
 
-  sprintf(cg->ipp_unknown, "0x%04x", op);
+  snprintf(cg->ipp_unknown, sizeof(cg->ipp_unknown), "0x%04x", op);
 
   return (cg->ipp_unknown);
 }
diff -pruN 2.3.3-3/cups/ipp-vars.c 2.3.3op1-3/cups/ipp-vars.c
--- 2.3.3-3/cups/ipp-vars.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cups/ipp-vars.c	2020-11-27 14:25:26.000000000 +0000
@@ -12,7 +12,7 @@
  * Include necessary headers...
  */
 
-#include <cups/cups.h>
+#include "cups-private.h"
 #include "ipp-private.h"
 #include "string-private.h"
 #include "debug-internal.h"
@@ -220,10 +220,22 @@ _ippVarsSet(_ipp_vars_t *v,		/* I - IPP
 {
   if (!strcmp(name, "uri"))
   {
-    char		uri[1024];	/* New printer URI */
-    http_uri_status_t	uri_status;	/* URI status */
+    char	uri[1024];		/* New printer URI */
+    char	resolved[1024];		/* Resolved mDNS URI */
 
-    if ((uri_status = httpSeparateURI(HTTP_URI_CODING_ALL, value, v->scheme, sizeof(v->scheme), v->username, sizeof(v->username), v->host, sizeof(v->host), &(v->port), v->resource, sizeof(v->resource))) < HTTP_URI_STATUS_OK)
+    if (strstr(value, "._tcp"))
+    {
+     /*
+      * Resolve URI...
+      */
+
+      if (!_httpResolveURI(value, resolved, sizeof(resolved), _HTTP_RESOLVE_DEFAULT, NULL, NULL))
+        return (0);
+
+      value = resolved;
+    }
+
+    if (httpSeparateURI(HTTP_URI_CODING_ALL, value, v->scheme, sizeof(v->scheme), v->username, sizeof(v->username), v->host, sizeof(v->host), &(v->port), v->resource, sizeof(v->resource)) < HTTP_URI_STATUS_OK)
       return (0);
 
     if (v->username[0])
diff -pruN 2.3.3-3/cups/ppd.c 2.3.3op1-3/cups/ppd.c
--- 2.3.3-3/cups/ppd.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cups/ppd.c	2020-11-27 14:25:26.000000000 +0000
@@ -1496,6 +1496,27 @@ _ppdOpen(
 	goto error;
       }
 
+      if (!_cups_strcasecmp(option->defchoice, "custom") || !_cups_strncasecmp(option->defchoice, "custom.", 7))
+      {
+       /*
+	* "*DefaultOption: Custom..." may set the default to a custom value
+	* or (for a very small number of incompatible PPD files) select a
+	* standard choice for the option, which CUPS renames to "_Custom..."
+	* to avoid compatibility issues.  See which this is...
+	*/
+
+        char tchoice[PPD_MAX_NAME];	/* Temporary choice name */
+
+	snprintf(tchoice, sizeof(tchoice), "_%s", option->defchoice);
+
+	if (ppdFindChoice(option, tchoice))
+	{
+	  strlcpy(option->defchoice, tchoice, sizeof(option->defchoice));
+
+	  DEBUG_printf(("2_ppdOpen: Reset Default%s to %s...", option->keyword, tchoice));
+	}
+      }
+
       option = NULL;
 
       free(string);
@@ -1510,6 +1531,27 @@ _ppdOpen(
 	goto error;
       }
 
+      if (!_cups_strcasecmp(option->defchoice, "custom") || !_cups_strncasecmp(option->defchoice, "custom.", 7))
+      {
+       /*
+	* "*DefaultOption: Custom..." may set the default to a custom value
+	* or (for a very small number of incompatible PPD files) select a
+	* standard choice for the option, which CUPS renames to "_Custom..."
+	* to avoid compatibility issues.  See which this is...
+	*/
+
+        char tchoice[PPD_MAX_NAME];	/* Temporary choice name */
+
+	snprintf(tchoice, sizeof(tchoice), "_%s", option->defchoice);
+
+	if (ppdFindChoice(option, tchoice))
+	{
+	  strlcpy(option->defchoice, tchoice, sizeof(option->defchoice));
+
+	  DEBUG_printf(("2_ppdOpen: Reset Default%s to %s...", option->keyword, tchoice));
+	}
+      }
+
       option = NULL;
 
       free(string);
@@ -1668,11 +1710,9 @@ _ppdOpen(
         * Set the default as part of the current option...
 	*/
 
-        DEBUG_printf(("2_ppdOpen: Setting %s to %s...", keyword, string));
-
-        strlcpy(option->defchoice, string, sizeof(option->defchoice));
+	strlcpy(option->defchoice, string, sizeof(option->defchoice));
 
-        DEBUG_printf(("2_ppdOpen: %s is now %s...", keyword, option->defchoice));
+        DEBUG_printf(("2_ppdOpen: Set %s to %s...", keyword, option->defchoice));
       }
       else
       {
@@ -1682,11 +1722,27 @@ _ppdOpen(
 
         ppd_option_t	*toption;	/* Temporary option */
 
-
         if ((toption = ppdFindOption(ppd, keyword + 7)) != NULL)
 	{
-	  DEBUG_printf(("2_ppdOpen: Setting %s to %s...", keyword, string));
-	  strlcpy(toption->defchoice, string, sizeof(toption->defchoice));
+	  if (!_cups_strcasecmp(string, "custom") || !_cups_strncasecmp(string, "custom.", 7))
+	  {
+	   /*
+	    * "*DefaultOption: Custom..." may set the default to a custom value
+	    * or (for a very small number of incompatible PPD files) select a
+	    * standard choice for the option, which CUPS renames to "_Custom..."
+	    * to avoid compatibility issues.  See which this is...
+	    */
+
+	    snprintf(toption->defchoice, sizeof(toption->defchoice), "_%s", string);
+	    if (!ppdFindChoice(toption, toption->defchoice))
+	      strlcpy(toption->defchoice, string, sizeof(toption->defchoice));
+	  }
+	  else
+	  {
+	    strlcpy(toption->defchoice, string, sizeof(toption->defchoice));
+	  }
+
+	  DEBUG_printf(("2_ppdOpen: Set %s to %s...", keyword, toption->defchoice));
 	}
       }
     }
@@ -2839,7 +2895,7 @@ ppd_hash_option(ppd_option_t *option)	/*
 
 
   for (hash = option->keyword[0], k = option->keyword + 1; *k;)
-    hash = 33 * hash + *k++;
+    hash = (int)(33U * (unsigned)hash) + *k++;
 
   return (hash & 511);
 }
diff -pruN 2.3.3-3/cups/ppd-cache.c 2.3.3op1-3/cups/ppd-cache.c
--- 2.3.3-3/cups/ppd-cache.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cups/ppd-cache.c	2020-11-27 14:25:26.000000000 +0000
@@ -3228,7 +3228,7 @@ _ppdCreateFromIPP(char   *buffer,	/* I -
         cupsFilePuts(fp, "*cupsFilter2: \"application/vnd.cups-pdf application/pdf 10 -\"\n");
     }
     else
-      cupsFilePuts(fp, "*cupsManualCopies: true\n");
+      cupsFilePuts(fp, "*cupsManualCopies: True\n");
     if (is_apple)
       cupsFilePuts(fp, "*cupsFilter2: \"image/urf image/urf 100 -\"\n");
     if (is_pwg)
@@ -3620,10 +3620,12 @@ _ppdCreateFromIPP(char   *buffer,	/* I -
   if ((attr = ippFindAttribute(ippGetCollection(defattr, 0), "media-source", IPP_TAG_ZERO)) != NULL)
     pwg_ppdize_name(ippGetString(attr, 0, NULL), ppdname, sizeof(ppdname));
   else
-    strlcpy(ppdname, "Unknown", sizeof(ppdname));
+    ppdname[0] = '\0';
 
   if ((attr = ippFindAttribute(response, "media-source-supported", IPP_TAG_ZERO)) != NULL && (count = ippGetCount(attr)) > 1)
   {
+    int have_default = ppdname[0] != '\0';
+					/* Do we have a default InputSlot? */
     static const char * const sources[] =
     {					/* Standard "media-source" strings */
       "auto",
@@ -3678,15 +3680,20 @@ _ppdCreateFromIPP(char   *buffer,	/* I -
       "roll-10"
     };
 
-    cupsFilePrintf(fp, "*OpenUI *InputSlot: PickOne\n"
-                       "*OrderDependency: 10 AnySetup *InputSlot\n"
-                       "*DefaultInputSlot: %s\n", ppdname);
+    cupsFilePuts(fp, "*OpenUI *InputSlot: PickOne\n"
+                     "*OrderDependency: 10 AnySetup *InputSlot\n");
+    if (have_default)
+      cupsFilePrintf(fp, "*DefaultInputSlot: %s\n", ppdname);
+
     for (i = 0, count = ippGetCount(attr); i < count; i ++)
     {
       keyword = ippGetString(attr, i, NULL);
 
       pwg_ppdize_name(keyword, ppdname, sizeof(ppdname));
 
+      if (i == 0 && !have_default)
+	cupsFilePrintf(fp, "*DefaultInputSlot: %s\n", ppdname);
+
       for (j = 0; j < (int)(sizeof(sources) / sizeof(sources[0])); j ++)
         if (!strcmp(sources[j], keyword))
 	{
@@ -3790,6 +3797,11 @@ _ppdCreateFromIPP(char   *buffer,	/* I -
 	PRINTF_COLOROPTION("RGB", _("Color"), CUPS_CSPACE_SRGB, 8)
 
 	default_color = "RGB";
+
+        // Apparently some printers only advertise color support, so make sure
+        // we also do grayscale for these printers...
+	if (!ippContainsString(attr, "sgray_8") && !ippContainsString(attr, "black_1") && !ippContainsString(attr, "black_8"))
+	  PRINTF_COLOROPTION("Gray", _("GrayScale"), CUPS_CSPACE_SW, 8)
       }
       else if (!strcasecmp(keyword, "adobe-rgb_16") || !strcmp(keyword, "ADOBERGB48") || !strcmp(keyword, "ADOBERGB24-48"))
       {
@@ -3924,7 +3936,7 @@ _ppdCreateFromIPP(char   *buffer,	/* I -
   else
     strlcpy(ppdname, "Unknown", sizeof(ppdname));
 
-  if ((attr = ippFindAttribute(response, "output-bin-supported", IPP_TAG_ZERO)) != NULL && (count = ippGetCount(attr)) > 1)
+  if ((attr = ippFindAttribute(response, "output-bin-supported", IPP_TAG_ZERO)) != NULL && (count = ippGetCount(attr)) > 0)
   {
     ipp_attribute_t	*trays = ippFindAttribute(response, "printer-output-tray", IPP_TAG_STRING);
 					/* printer-output-tray attribute, if any */
@@ -5140,6 +5152,8 @@ pwg_unppdize_name(const char *ppd,	/* I
 {
   char	*ptr,				/* Pointer into name buffer */
 	*end;				/* End of name buffer */
+  int   nodash = 1;                     /* Next char in IPP name cannot be a
+                                           dash (first char or after a dash) */
 
 
   if (_cups_islower(*ppd))
@@ -5151,7 +5165,9 @@ pwg_unppdize_name(const char *ppd,	/* I
     const char *ppdptr;			/* Pointer into PPD keyword */
 
     for (ppdptr = ppd + 1; *ppdptr; ppdptr ++)
-      if (_cups_isupper(*ppdptr) || strchr(dashchars, *ppdptr))
+      if (_cups_isupper(*ppdptr) || strchr(dashchars, *ppdptr) ||
+	  (*ppdptr == '-' && *(ppdptr - 1) == '-') ||
+	  (*ppdptr == '-' && *(ppdptr + 1) == '\0'))
         break;
 
     if (!*ppdptr)
@@ -5163,19 +5179,44 @@ pwg_unppdize_name(const char *ppd,	/* I
 
   for (ptr = name, end = name + namesize - 1; *ppd && ptr < end; ppd ++)
   {
-    if (_cups_isalnum(*ppd) || *ppd == '-')
+    if (_cups_isalnum(*ppd))
+    {
       *ptr++ = (char)tolower(*ppd & 255);
-    else if (strchr(dashchars, *ppd))
-      *ptr++ = '-';
+      nodash = 0;
+    }
+    else if (*ppd == '-' || strchr(dashchars, *ppd))
+    {
+      if (nodash == 0)
+      {
+	*ptr++ = '-';
+	nodash = 1;
+      }
+    }
     else
+    {
       *ptr++ = *ppd;
+      nodash = 0;
+    }
 
-    if (!_cups_isupper(*ppd) && _cups_isalnum(*ppd) &&
-	_cups_isupper(ppd[1]) && ptr < end)
-      *ptr++ = '-';
-    else if (!isdigit(*ppd & 255) && isdigit(ppd[1] & 255))
-      *ptr++ = '-';
+    if (nodash == 0)
+    {
+      if (!_cups_isupper(*ppd) && _cups_isalnum(*ppd) &&
+	  _cups_isupper(ppd[1]) && ptr < end)
+      {
+	*ptr++ = '-';
+	nodash = 1;
+      }
+      else if (!isdigit(*ppd & 255) && isdigit(ppd[1] & 255))
+      {
+	*ptr++ = '-';
+	nodash = 1;
+      }
+    }
   }
 
+  /* Remove trailing dashes */
+  while (ptr > name && *(ptr - 1) == '-')
+    ptr --;
+
   *ptr = '\0';
 }
diff -pruN 2.3.3-3/cups/ppd-mark.c 2.3.3op1-3/cups/ppd-mark.c
--- 2.3.3-3/cups/ppd-mark.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cups/ppd-mark.c	2020-11-27 14:25:26.000000000 +0000
@@ -307,7 +307,7 @@ cupsMarkOptions(
         * Look it up in the PPD file...
 	*/
 
-	sprintf(s, "%d", j);
+	snprintf(s, sizeof(s), "%d", j);
 
         if ((attr = ppdFindAttr(ppd, "cupsIPPFinishings", s)) == NULL)
 	  continue;
diff -pruN 2.3.3-3/cups/request.c 2.3.3op1-3/cups/request.c
--- 2.3.3-3/cups/request.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cups/request.c	2020-11-27 14:25:26.000000000 +0000
@@ -395,7 +395,7 @@ cupsGetResponse(http_t     *http,	/* I -
       ippDelete(response);
       response = NULL;
 
-      http->status = status = HTTP_STATUS_ERROR;
+      http->status = HTTP_STATUS_ERROR;
       http->error  = EINVAL;
     }
   }
@@ -422,7 +422,7 @@ cupsGetResponse(http_t     *http,	/* I -
       if (!cupsDoAuthentication(http, "POST", resource))
         httpReconnect2(http, 30000, NULL);
       else
-        http->status = status = HTTP_STATUS_CUPS_AUTHORIZATION_CANCELED;
+        http->status = HTTP_STATUS_CUPS_AUTHORIZATION_CANCELED;
     }
 
 #ifdef HAVE_SSL
diff -pruN 2.3.3-3/cups/snprintf.c 2.3.3op1-3/cups/snprintf.c
--- 2.3.3-3/cups/snprintf.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cups/snprintf.c	2020-11-27 14:25:26.000000000 +0000
@@ -171,7 +171,7 @@ _cups_vsnprintf(char       *buffer,	/* O
 	    if ((width + 2) > sizeof(temp))
 	      break;
 
-	    sprintf(temp, tformat, va_arg(ap, double));
+	    snprintf(temp, sizeof(temp), tformat, va_arg(ap, double));
 	    templen = strlen(temp);
 
             bytes += (int)templen;
@@ -202,7 +202,7 @@ _cups_vsnprintf(char       *buffer,	/* O
 	    if ((width + 2) > sizeof(temp))
 	      break;
 
-	    sprintf(temp, tformat, va_arg(ap, int));
+	    snprintf(temp, sizeof(temp), tformat, va_arg(ap, int));
 	    templen = strlen(temp);
 
             bytes += (int)templen;
@@ -226,7 +226,7 @@ _cups_vsnprintf(char       *buffer,	/* O
 	    if ((width + 2) > sizeof(temp))
 	      break;
 
-	    sprintf(temp, tformat, va_arg(ap, void *));
+	    snprintf(temp, sizeof(temp), tformat, va_arg(ap, void *));
 	    templen = strlen(temp);
 
             bytes += (int)templen;
diff -pruN 2.3.3-3/cups/testclient.c 2.3.3op1-3/cups/testclient.c
--- 2.3.3-3/cups/testclient.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cups/testclient.c	2020-11-27 14:25:26.000000000 +0000
@@ -1,6 +1,7 @@
 /*
  * Simulated client test program for CUPS.
  *
+ * Copyright © 2020 by Michael R Sweet
  * Copyright © 2017-2019 by Apple Inc.
  *
  * Licensed under Apache License v2.0.  See the file "LICENSE" for more
@@ -24,7 +25,7 @@
  * Constants...
  */
 
-#define MAX_CLIENTS	16		/* Maximum number of client threads */
+#define MAX_CLIENTS	100		/* Maximum number of client threads */
 
 
 /*
@@ -44,12 +45,12 @@ typedef struct _client_data_s
   int			grayscale,	/* Force grayscale? */
 			keepfile;	/* Keep temporary file? */
   ipp_pstate_t		printer_state;	/* Current printer state */
-  char                  printer_state_reasons[1024];
-                                        /* Current printer-state-reasons */
+  char			printer_state_reasons[1024];
+					/* Current printer-state-reasons */
   int			job_id; 	/* Job ID for submitted job */
   ipp_jstate_t		job_state;	/* Current job state */
-  char                  job_state_reasons[1024];
-                                        /* Current job-state-reasons */
+  char			job_state_reasons[1024];
+					/* Current job-state-reasons */
 } _client_data_t;
 
 
@@ -66,12 +67,12 @@ static int		verbosity = 0;
  * Local functions...
  */
 
-static const char       *make_raster_file(ipp_t *response, int grayscale, char *tempname, size_t tempsize, const char **format);
-static void	        *monitor_printer(_client_data_t *data);
+static const char	*make_raster_file(ipp_t *response, int grayscale, char *tempname, size_t tempsize, const char **format);
+static void		*monitor_printer(_client_data_t *data);
 static void		*run_client(_client_data_t *data);
-static void             show_attributes(const char *title, int request, ipp_t *ipp);
-static void             show_capabilities(ipp_t *response);
-static void             usage(void);
+static void		show_attributes(const char *title, int request, ipp_t *ipp);
+static void		show_capabilities(ipp_t *response);
+static void		usage(void);
 
 
 /*
@@ -396,15 +397,7 @@ make_raster_file(ipp_t      *response,
   * Figure out the the media, resolution, and color mode...
   */
 
-  if ((attr = ippFindAttribute(response, "media-default", IPP_TAG_KEYWORD)) != NULL)
-  {
-   /*
-    * Use default media...
-    */
-
-    media = pwgMediaForPWG(ippGetString(attr, 0, NULL));
-  }
-  else if ((attr = ippFindAttribute(response, "media-ready", IPP_TAG_KEYWORD)) != NULL)
+  if ((attr = ippFindAttribute(response, "media-ready", IPP_TAG_KEYWORD)) != NULL)
   {
    /*
     * Use ready media...
@@ -417,6 +410,14 @@ make_raster_file(ipp_t      *response,
     else
       media = pwgMediaForPWG(ippGetString(attr, 0, NULL));
   }
+  else if ((attr = ippFindAttribute(response, "media-default", IPP_TAG_KEYWORD)) != NULL)
+  {
+   /*
+    * Use default media...
+    */
+
+    media = pwgMediaForPWG(ippGetString(attr, 0, NULL));
+  }
   else
   {
     puts("No default or ready media reported by printer, aborting.");
@@ -486,15 +487,15 @@ make_raster_file(ipp_t      *response,
 
   header.cupsInteger[CUPS_RASTER_PWG_TotalPageCount] = 1;
 
-  if (header.cupsWidth > (4 * header.HWResolution[0]))
+  if (header.cupsWidth > (2 * header.HWResolution[0]))
   {
     xoff = header.HWResolution[0] / 2;
     yoff = header.HWResolution[1] / 2;
   }
   else
   {
-    xoff = 0;
-    yoff = 0;
+    xoff = header.HWResolution[0] / 4;
+    yoff = header.HWResolution[1] / 4;
   }
 
   xrep = (header.cupsWidth - 2 * xoff) / 140;
@@ -603,6 +604,8 @@ make_raster_file(ipp_t      *response,
   for (y = 0; y < header.cupsHeight; y ++)
     cupsRasterWritePixels(ras, line, header.cupsBytesPerLine);
 
+  free(line);
+
   cupsRasterClose(ras);
 
   close(fd);
@@ -768,11 +771,8 @@ run_client(
   ipp_attribute_t *attr;		/* Attribute in response */
   static const char * const pattrs[] =  /* Printer attributes we are interested in */
   {
-    "job-template",
-    "printer-defaults",
-    "printer-description",
-    "media-col-database",
-    "media-col-ready"
+    "all",
+    "media-col-database"
   };
 
 
diff -pruN 2.3.3-3/cups/testdest.c 2.3.3op1-3/cups/testdest.c
--- 2.3.3-3/cups/testdest.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cups/testdest.c	2020-11-27 14:25:26.000000000 +0000
@@ -410,7 +410,6 @@ print_file(http_t        *http,		/* I -
 {
   cups_file_t	*fp;			/* File to print */
   int		job_id;			/* Job ID */
-  ipp_status_t	status;			/* Submission status */
   const char	*title;			/* Title of job */
   char		buffer[32768];		/* File buffer */
   ssize_t	bytes;			/* Bytes read/to write */
@@ -427,7 +426,7 @@ print_file(http_t        *http,		/* I -
   else
     title = filename;
 
-  if ((status = cupsCreateDestJob(http, dest, dinfo, &job_id, title, num_options, options)) > IPP_STATUS_OK_IGNORED_OR_SUBSTITUTED)
+  if (cupsCreateDestJob(http, dest, dinfo, &job_id, title, num_options, options) > IPP_STATUS_OK_IGNORED_OR_SUBSTITUTED)
   {
     printf("Unable to create job: %s\n", cupsLastErrorString());
     cupsFileClose(fp);
@@ -454,7 +453,7 @@ print_file(http_t        *http,		/* I -
 
   cupsFileClose(fp);
 
-  if ((status = cupsFinishDestDocument(http, dest, dinfo)) > IPP_STATUS_OK_IGNORED_OR_SUBSTITUTED)
+  if (cupsFinishDestDocument(http, dest, dinfo) > IPP_STATUS_OK_IGNORED_OR_SUBSTITUTED)
   {
     printf("Unable to send document: %s\n", cupsLastErrorString());
     return;
diff -pruN 2.3.3-3/cups/testi18n.c 2.3.3op1-3/cups/testi18n.c
--- 2.3.3-3/cups/testi18n.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cups/testi18n.c	2020-11-27 14:25:26.000000000 +0000
@@ -410,7 +410,7 @@ main(int  argc,				/* I - Argument Count
       puts("PASS");
   }
 
-#ifndef __linux
+#if !defined(__linux__) && !defined(__GLIBC__)
   fputs("cupsCharsetToUTF8(CUPS_EUC_JP): ", stdout);
 
   strlcpy(legsrc, legdest, sizeof(legsrc));
@@ -432,7 +432,7 @@ main(int  argc,				/* I - Argument Count
   }
   else
     puts("PASS");
-#endif /* !__linux */
+#endif /* !__linux && !__GLIBC__ */
 
  /*
   * Test UTF-8 to/from legacy charset (Windows 950)...
diff -pruN 2.3.3-3/cups/testppd.c 2.3.3op1-3/cups/testppd.c
--- 2.3.3-3/cups/testppd.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cups/testppd.c	2020-11-27 14:25:26.000000000 +0000
@@ -658,6 +658,12 @@ main(int  argc,				/* I - Number of comm
     * Test localization...
     */
 
+    /* Force US English base locale */
+    putenv("LANG=en");
+    putenv("LC_ALL=en");
+    putenv("LC_CTYPE=en");
+    putenv("LC_MESSAGES=en");
+
     fputs("ppdLocalizeIPPReason(text): ", stdout);
     if (ppdLocalizeIPPReason(ppd, "foo", NULL, buffer, sizeof(buffer)) &&
         !strcmp(buffer, "Foo Reason"))
@@ -698,6 +704,7 @@ main(int  argc,				/* I - Number of comm
       printf("FAIL (\"%s\" instead of \"/help/foo/bar.html\")\n", buffer);
     }
 
+    /* Force French */
     putenv("LANG=fr");
     putenv("LC_ALL=fr");
     putenv("LC_CTYPE=fr");
@@ -713,6 +720,7 @@ main(int  argc,				/* I - Number of comm
       printf("FAIL (\"%s\" instead of \"La Long Foo Reason\")\n", buffer);
     }
 
+    /* Force Simplified Chinese */
     putenv("LANG=zh_TW");
     putenv("LC_ALL=zh_TW");
     putenv("LC_CTYPE=zh_TW");
@@ -732,6 +740,7 @@ main(int  argc,				/* I - Number of comm
     * cupsMarkerName localization...
     */
 
+    /* Force US English base locale */
     putenv("LANG=en");
     putenv("LC_ALL=en");
     putenv("LC_CTYPE=en");
@@ -759,6 +768,7 @@ main(int  argc,				/* I - Number of comm
              text ? text : "(null)");
     }
 
+    /* Force French locale */
     putenv("LANG=fr");
     putenv("LC_ALL=fr");
     putenv("LC_CTYPE=fr");
@@ -775,6 +785,7 @@ main(int  argc,				/* I - Number of comm
              text ? text : "(null)");
     }
 
+    /* Force Simplified Chinese locale */
     putenv("LANG=zh_TW");
     putenv("LC_ALL=zh_TW");
     putenv("LC_CTYPE=zh_TW");
@@ -793,6 +804,12 @@ main(int  argc,				/* I - Number of comm
 
     ppdClose(ppd);
 
+    /* Force US English base locale */
+    putenv("LANG=en");
+    putenv("LC_ALL=en");
+    putenv("LC_CTYPE=en");
+    putenv("LC_MESSAGES=en");
+
    /*
     * Test new constraints...
     */
diff -pruN 2.3.3-3/cups/tls-sspi.c 2.3.3op1-3/cups/tls-sspi.c
--- 2.3.3-3/cups/tls-sspi.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/cups/tls-sspi.c	2020-11-27 14:25:26.000000000 +0000
@@ -1332,8 +1332,6 @@ http_sspi_client(http_t     *http,	/* I
   SecBufferDesc	outBuffer;		/* Array of SecBuffer structs */
   SecBuffer	outBuffers[1];		/* Security package buffer */
   int		ret = 0;		/* Return value */
-  char		username[1024],		/* Current username */
-		common_name[1024];	/* CN=username */
 
 
   DEBUG_printf(("4http_sspi_client(http=%p, hostname=\"%s\")", http, hostname));
@@ -1349,16 +1347,11 @@ http_sspi_client(http_t     *http,	/* I
   * Lookup the client certificate...
   */
 
-  dwSize = sizeof(username);
-  GetUserNameA(username, &dwSize);
-  snprintf(common_name, sizeof(common_name), "CN=%s", username);
-
-  if (!http_sspi_find_credentials(http, L"ClientContainer", common_name))
-    if (!http_sspi_make_credentials(http->tls, L"ClientContainer", common_name, _HTTP_MODE_CLIENT, 10))
-    {
-      DEBUG_puts("5http_sspi_client: Unable to get client credentials.");
-      return (-1);
-    }
+  if (!http_sspi_find_credentials(http, L"ClientContainer", NULL))
+  {
+    DEBUG_puts("5http_sspi_client: Unable to get client credentials.");
+    return (-1);
+  }
 
  /*
   * Initiate a ClientHello message and generate a token.
@@ -1711,48 +1704,55 @@ http_sspi_find_credentials(
     goto cleanup;
   }
 
-  dwSize = 0;
-
-  if (!CertStrToNameA(X509_ASN_ENCODING, common_name, CERT_OID_NAME_STR, NULL, NULL, &dwSize, NULL))
+  if (common_name)
   {
-    DEBUG_printf(("5http_sspi_find_credentials: CertStrToName failed: %s", http_sspi_strerror(sspi->error, sizeof(sspi->error), GetLastError())));
-    ok = FALSE;
-    goto cleanup;
-  }
+    dwSize = 0;
 
-  p = (PBYTE)malloc(dwSize);
+    if (!CertStrToNameA(X509_ASN_ENCODING, common_name, CERT_OID_NAME_STR, NULL, NULL, &dwSize, NULL))
+    {
+      DEBUG_printf(("5http_sspi_find_credentials: CertStrToName failed: %s", http_sspi_strerror(sspi->error, sizeof(sspi->error), GetLastError())));
+      ok = FALSE;
+      goto cleanup;
+    }
 
-  if (!p)
-  {
-    DEBUG_printf(("5http_sspi_find_credentials: malloc failed for %d bytes.", dwSize));
-    ok = FALSE;
-    goto cleanup;
-  }
+    p = (PBYTE)malloc(dwSize);
 
-  if (!CertStrToNameA(X509_ASN_ENCODING, common_name, CERT_OID_NAME_STR, NULL, p, &dwSize, NULL))
-  {
-    DEBUG_printf(("5http_sspi_find_credentials: CertStrToName failed: %s", http_sspi_strerror(sspi->error, sizeof(sspi->error), GetLastError())));
-    ok = FALSE;
-    goto cleanup;
-  }
+    if (!p)
+    {
+      DEBUG_printf(("5http_sspi_find_credentials: malloc failed for %d bytes.", dwSize));
+      ok = FALSE;
+      goto cleanup;
+    }
 
-  sib.cbData = dwSize;
-  sib.pbData = p;
+    if (!CertStrToNameA(X509_ASN_ENCODING, common_name, CERT_OID_NAME_STR, NULL, p, &dwSize, NULL))
+    {
+      DEBUG_printf(("5http_sspi_find_credentials: CertStrToName failed: %s", http_sspi_strerror(sspi->error, sizeof(sspi->error), GetLastError())));
+      ok = FALSE;
+      goto cleanup;
+    }
 
-  storedContext = CertFindCertificateInStore(store, X509_ASN_ENCODING | PKCS_7_ASN_ENCODING, 0, CERT_FIND_SUBJECT_NAME, &sib, NULL);
+    sib.cbData = dwSize;
+    sib.pbData = p;
 
-  if (!storedContext)
-  {
-    DEBUG_printf(("5http_sspi_find_credentials: Unable to find credentials for \"%s\".", common_name));
-    ok = FALSE;
-    goto cleanup;
+    storedContext = CertFindCertificateInStore(store, X509_ASN_ENCODING | PKCS_7_ASN_ENCODING, 0, CERT_FIND_SUBJECT_NAME, &sib, NULL);
+
+    if (!storedContext)
+    {
+      DEBUG_printf(("5http_sspi_find_credentials: Unable to find credentials for \"%s\".", common_name));
+      ok = FALSE;
+      goto cleanup;
+    }
   }
 
   ZeroMemory(&SchannelCred, sizeof(SchannelCred));
 
   SchannelCred.dwVersion = SCHANNEL_CRED_VERSION;
-  SchannelCred.cCreds    = 1;
-  SchannelCred.paCred    = &storedContext;
+
+  if (common_name)
+  {
+    SchannelCred.cCreds = 1;
+    SchannelCred.paCred = &storedContext;
+  }
 
  /*
   * Set supported protocols (can also be overriden in the registry...)
@@ -2018,13 +2018,6 @@ http_sspi_make_credentials(
   SchannelCred.paCred    = &storedContext;
 
  /*
-  * SSPI doesn't seem to like it if grbitEnabledProtocols is set for a client.
-  */
-
-  if (mode == _HTTP_MODE_SERVER)
-    SchannelCred.grbitEnabledProtocols = SP_PROT_SSL3TLS1;
-
- /*
   * Create an SSPI credential.
   */
 
diff -pruN 2.3.3-3/debian/changelog 2.3.3op1-3/debian/changelog
--- 2.3.3-3/debian/changelog	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/changelog	2020-12-04 09:32:55.000000000 +0000
@@ -1,3 +1,57 @@
+cups (2.3.3op1-3) unstable; urgency=medium
+
+  [ Helge Kreutzmann ]
+  * Update German man page (2211t)
+
+  [ Didier Raboud ]
+  * Patch configure scripts to fix FTBFS on freebsd-gnu systems
+
+ -- Didier Raboud <odyx@debian.org>  Fri, 04 Dec 2020 10:32:55 +0100
+
+cups (2.3.3op1-2) unstable; urgency=medium
+
+  * Backport upstream "Force a 5 second sleep to wait for the job control file
+    to be written" patch, to address s390x test suite timing issue
+
+ -- Didier Raboud <odyx@debian.org>  Sat, 28 Nov 2020 16:50:59 +0100
+
+cups (2.3.3op1-1) unstable; urgency=medium
+
+  * Use OpenPrinting CUPS fork instead of Apple's codebase
+    - Update d/upstream/metadata, d/watch
+    - d/upstream/signing-key.asc: Swap Apple's with Michael R Sweet's
+  * Large patch-suite cleanup thanks to lots of Debian proposals merged
+    upstream; from 40 to 9;
+    - Reorder (upstream-mergeable first, Debian-specific later)
+    - Reword and refresh metadata for the last patches
+  * Set Debian customizations in d/rules instead of patches;
+    - Set --with-max-log-size=0
+    - Set --enable-sync-on-close
+    - Set --with-error-policy=retry-job
+  * Packaging cleanup;
+    - Drop the Debian-specific systemd units' renaming, now upstream
+    - Drop pre-oldstable postinst ConfigFilePerm handling
+    - Add missing BSD-2-Clause block in debian/copyright
+    - Convert debian/po files to UTF-8
+    - Drop --as-needed as it's now default in Debian
+    - Drop Ubuntu-specific patch handling, in favour of compile-time option
+      for --disable-browsing
+    - Bump S-V to 4.5.1 without changes needed
+    - Use debian/main as head branch; update d/gbp.conf accordingly
+    - Drop outdated d/source/options
+   * Refresh manpage translation pofiles for 2.3.3op1
+
+ -- Didier Raboud <odyx@debian.org>  Fri, 27 Nov 2020 17:27:21 +0100
+
+cups (2.3.3-4) unstable; urgency=medium
+
+  * Drop Ubuntu "Make lpoptions list a printer's options correctly also when
+    CUPS is running on an alternative port" patch, refused upstream
+    (Closes: #970725)
+  * Use upstream-merged patches for fax numbers' fix and rastertopwg rounding
+
+ -- Didier Raboud <odyx@debian.org>  Tue, 24 Nov 2020 08:49:46 +0100
+
 cups (2.3.3-3) unstable; urgency=medium
 
   [ Didier Raboud ]
diff -pruN 2.3.3-3/debian/control 2.3.3op1-3/debian/control
--- 2.3.3-3/debian/control	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/control	2020-12-04 09:32:55.000000000 +0000
@@ -37,7 +37,7 @@ Build-Depends: debhelper-compat (= 12),
                zlib1g-dev
 # libgmp-dev is not GPL-2 compatible before it's 6 release, which makes it also GPL-2+
 Build-Conflicts: libgmp-dev (<< 2:6)
-Standards-Version: 4.5.0
+Standards-Version: 4.5.1
 Vcs-Browser: https://salsa.debian.org/printing-team/cups
 Vcs-Git: https://salsa.debian.org/printing-team/cups.git
 Homepage: https://www.cups.org/
diff -pruN 2.3.3-3/debian/copyright 2.3.3op1-3/debian/copyright
--- 2.3.3-3/debian/copyright	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/copyright	2020-12-04 09:32:55.000000000 +0000
@@ -94,6 +94,31 @@ License: Apache-2.0-with-GPL2-LGPL2-Exce
  the License, but only in their entirety and only with respect to the Combined
  Software.
 
+License: BSD-2-Clause
+ Redistribution and use in source and binary forms, with or without
+ modification, are permitted provided that the following conditions
+ are met:
+ .
+   Redistributions of source code must retain the above copyright
+   notice, this list of conditions and the following disclaimer.
+ .
+   Redistributions in binary form must reproduce the above copyright
+   notice, this list of conditions and the following disclaimer in the
+   documentation and/or other materials provided with the distribution.
+ .
+ THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
+ FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+ COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
+ INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+ (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
+ SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
+ STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
+ OF THE POSSIBILITY OF SUCH DAMAGE.
+
 License: BSD-3-clause
  This software is Copyright (c) 2019 by foo.
  This is free software, licensed under:
diff -pruN 2.3.3-3/debian/cups-daemon.postinst 2.3.3op1-3/debian/cups-daemon.postinst
--- 2.3.3-3/debian/cups-daemon.postinst	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/cups-daemon.postinst	2020-12-04 09:32:55.000000000 +0000
@@ -15,23 +15,6 @@ if [ "$1" = configure ]; then
         fi
     done
 
-    # Enforce the ConfigFilePerm on ppd file if we upgrade to 2.1.x
-    if dpkg --compare-versions "$2" lt-nl "2.1.0-2~"; then
-        configfileperm=`egrep '^ConfigFilePerm ' /etc/cups/cupsd.conf | awk '{print $2}' | tail -n 1`
-        if [ -z "$configfileperm" ]; then
-            configfileperm=0640
-        fi
-	if [ -d /etc/cups/ppd ]; then
-            for i in /etc/cups/ppd/*
-            do
-		if [ -f $i ]; then
-                    chown root:lp $i
-                    chmod $configfileperm $i
-		fi
-            done
-	fi
-    fi
-
     # Manage printcap file and associated symlinks
     if [ -e /etc/cups/cupsd.conf ]; then
 	if [ -e /etc/printcap.cups ]; then
diff -pruN 2.3.3-3/debian/gbp.conf 2.3.3op1-3/debian/gbp.conf
--- 2.3.3-3/debian/gbp.conf	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/gbp.conf	2020-12-04 09:32:55.000000000 +0000
@@ -1,4 +1,4 @@
 [DEFAULT]
-debian-branch = debian/master
+debian-branch = debian/main
 upstream-branch = upstream/latest
 pristine-tar = True
diff -pruN 2.3.3-3/debian/manpage-po4a/po/cups.pot 2.3.3op1-3/debian/manpage-po4a/po/cups.pot
--- 2.3.3-3/debian/manpage-po4a/po/cups.pot	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/manpage-po4a/po/cups.pot	2020-12-04 09:32:55.000000000 +0000
@@ -7,13 +7,13 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: PACKAGE VERSION\n"
-"POT-Creation-Date: 2019-12-13 17:30+0100\n"
+"POT-Creation-Date: 2020-11-27 16:31+0100\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
 "Language: \n"
 "MIME-Version: 1.0\n"
-"Content-Type: text/plain; charset=CHARSET\n"
+"Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
 #. type: TH
@@ -23,25 +23,59 @@ msgid "backend"
 msgstr ""
 
 #. type: TH
-#: backend.7:10 cancel.1:10 classes.conf.5:10 client.conf.5:10 cups.1:10 cupsaccept.8:10 cups-config.1:10 cupsctl.8:10 cupsd.8:10 cupsd.conf.5:10 cupsd-helper.8:10 cupsd-logs.5:10 cupsenable.8:10 cups-files.conf.5:10 cupsfilter.8:9 cups-lpd.8:10 cups-snmp.8:9 cups-snmp.conf.5:10 cupstestppd.1:10 filter.7:10 ippevepcl.7:9 ippeveprinter.1:9 ipptool.1:9 ipptoolfile.5:9 lp.1:10 lpadmin.8:10 lpc.8:10 lpinfo.8:10 lpmove.8:10 lpoptions.1:10 lpq.1:10 lpr.1:10 lprm.1:10 lpstat.1:9 mailto.conf.5:10 mime.convs.5:10 mime.types.5:10 notifier.7:10 ppdc.1:10 ppdcfile.5:10 ppdhtml.1:10 ppdi.1:10 ppdmerge.1:10 ppdpo.1:10 printers.conf.5:9 subscriptions.conf.5:10
+#: backend.7:10 cancel.1:10 classes.conf.5:10 client.conf.5:10 cups.1:10
+#: cupsaccept.8:10 cups-config.1:10 cupsctl.8:10 cupsd.8:10 cupsd.conf.5:10
+#: cupsd-helper.8:10 cupsd-logs.5:10 cupsenable.8:10 cups-files.conf.5:11
+#: cupsfilter.8:9 cups-lpd.8:11 cups-snmp.8:9 cups-snmp.conf.5:10
+#: cupstestppd.1:10 filter.7:10 ippevepcl.7:9 ippeveprinter.1:9 ipptool.1:9
+#: ipptoolfile.5:9 lp.1:10 lpadmin.8:10 lpc.8:10 lpinfo.8:10 lpmove.8:10
+#: lpoptions.1:10 lpq.1:10 lpr.1:10 lprm.1:10 lpstat.1:9 mailto.conf.5:10
+#: mime.convs.5:10 mime.types.5:10 notifier.7:10 ppdc.1:10 ppdcfile.5:10
+#: ppdhtml.1:10 ppdi.1:10 ppdmerge.1:10 ppdpo.1:10 printers.conf.5:9
+#: subscriptions.conf.5:10
 #, no-wrap
 msgid "CUPS"
 msgstr ""
 
 #. type: TH
-#: backend.7:10 cancel.1:10 classes.conf.5:10 cups.1:10 cupsaccept.8:10 cups-config.1:10 cupsctl.8:10 cupsd.8:10 cupsd-helper.8:10 cupsd-logs.5:10 cupsenable.8:10 cups-files.conf.5:10 cupsfilter.8:9 cups-lpd.8:10 cups-snmp.8:9 cups-snmp.conf.5:10 cupstestppd.1:10 filter.7:10 ippfind.1:9 ipptool.1:9 lp.1:10 lpadmin.8:10 lpc.8:10 lpinfo.8:10 lpmove.8:10 lpoptions.1:10 lpq.1:10 lpr.1:10 lprm.1:10 lpstat.1:9 mailto.conf.5:10 mime.convs.5:10 mime.types.5:10 notifier.7:10 ppdc.1:10 ppdcfile.5:10 ppdhtml.1:10 ppdi.1:10 ppdmerge.1:10 ppdpo.1:10 printers.conf.5:9 subscriptions.conf.5:10
+#: backend.7:10 cancel.1:10 classes.conf.5:10 cups.1:10 cupsaccept.8:10
+#: cups-config.1:10 cupsctl.8:10 cupsd.8:10 cupsd-helper.8:10 cupsd-logs.5:10
+#: cupsenable.8:10 cupsfilter.8:9 cups-snmp.8:9 cups-snmp.conf.5:10
+#: cupstestppd.1:10 filter.7:10 ippfind.1:9 ipptool.1:9 lp.1:10 lpadmin.8:10
+#: lpc.8:10 lpinfo.8:10 lpmove.8:10 lpoptions.1:10 lpq.1:10 lpr.1:10 lprm.1:10
+#: lpstat.1:9 mailto.conf.5:10 mime.convs.5:10 mime.types.5:10 notifier.7:10
+#: ppdcfile.5:10 ppdhtml.1:10 ppdi.1:10 ppdmerge.1:10 ppdpo.1:10
+#: printers.conf.5:9 subscriptions.conf.5:10
 #, no-wrap
 msgid "26 April 2019"
 msgstr ""
 
 #. type: TH
-#: backend.7:10 cancel.1:10 classes.conf.5:10 client.conf.5:10 cups.1:10 cupsaccept.8:10 cups-config.1:10 cupsctl.8:10 cupsd.8:10 cupsd.conf.5:10 cupsd-helper.8:10 cupsd-logs.5:10 cupsenable.8:10 cups-files.conf.5:10 cupsfilter.8:9 cups-lpd.8:10 cups-snmp.8:9 cups-snmp.conf.5:10 cupstestppd.1:10 filter.7:10 ippevepcl.7:9 ippeveprinter.1:9 ippfind.1:9 ipptool.1:9 ipptoolfile.5:9 lp.1:10 lpadmin.8:10 lpc.8:10 lpinfo.8:10 lpmove.8:10 lpoptions.1:10 lpq.1:10 lpr.1:10 lprm.1:10 lpstat.1:9 mailto.conf.5:10 mime.convs.5:10 mime.types.5:10 notifier.7:10 ppdc.1:10 ppdcfile.5:10 ppdhtml.1:10 ppdi.1:10 ppdmerge.1:10 ppdpo.1:10 printers.conf.5:9 subscriptions.conf.5:10
+#: backend.7:10 cancel.1:10 classes.conf.5:10 client.conf.5:10 cups.1:10
+#: cupsaccept.8:10 cups-config.1:10 cupsctl.8:10 cupsd.8:10 cupsd.conf.5:10
+#: cupsd-helper.8:10 cupsd-logs.5:10 cupsenable.8:10 cups-files.conf.5:11
+#: cupsfilter.8:9 cups-lpd.8:11 cups-snmp.8:9 cups-snmp.conf.5:10
+#: cupstestppd.1:10 filter.7:10 ippevepcl.7:9 ippeveprinter.1:9 ippfind.1:9
+#: ipptool.1:9 ipptoolfile.5:9 lp.1:10 lpadmin.8:10 lpc.8:10 lpinfo.8:10
+#: lpmove.8:10 lpoptions.1:10 lpq.1:10 lpr.1:10 lprm.1:10 lpstat.1:9
+#: mailto.conf.5:10 mime.convs.5:10 mime.types.5:10 notifier.7:10 ppdc.1:10
+#: ppdcfile.5:10 ppdhtml.1:10 ppdi.1:10 ppdmerge.1:10 ppdpo.1:10
+#: printers.conf.5:9 subscriptions.conf.5:10
 #, no-wrap
 msgid "Apple Inc."
 msgstr ""
 
 #. type: SH
-#: backend.7:11 cancel.1:11 classes.conf.5:11 client.conf.5:11 cups.1:11 cupsaccept.8:11 cups-config.1:11 cupsctl.8:11 cupsd.8:11 cupsd.conf.5:11 cupsd-helper.8:11 cupsd-logs.5:11 cupsenable.8:11 cups-files.conf.5:11 cupsfilter.8:10 cups-lpd.8:11 cups-snmp.8:10 cups-snmp.conf.5:11 cupstestppd.1:11 filter.7:11 ippevepcl.7:10 ippeveprinter.1:10 ippfind.1:10 ipptool.1:10 ipptoolfile.5:10 lp.1:11 lpadmin.8:11 lpc.8:11 lpinfo.8:11 lpmove.8:11 lpoptions.1:11 lpq.1:11 lpr.1:11 lprm.1:11 lpstat.1:10 mailto.conf.5:11 mime.convs.5:11 mime.types.5:11 notifier.7:11 ppdc.1:11 ppdcfile.5:11 ppdhtml.1:11 ppdi.1:11 ppdmerge.1:11 ppdpo.1:11 printers.conf.5:10 subscriptions.conf.5:11
+#: backend.7:11 cancel.1:11 classes.conf.5:11 client.conf.5:11 cups.1:11
+#: cupsaccept.8:11 cups-config.1:11 cupsctl.8:11 cupsd.8:11 cupsd.conf.5:11
+#: cupsd-helper.8:11 cupsd-logs.5:11 cupsenable.8:11 cups-files.conf.5:12
+#: cupsfilter.8:10 cups-lpd.8:12 cups-snmp.8:10 cups-snmp.conf.5:11
+#: cupstestppd.1:11 filter.7:11 ippevepcl.7:10 ippeveprinter.1:10 ippfind.1:10
+#: ipptool.1:10 ipptoolfile.5:10 lp.1:11 lpadmin.8:11 lpc.8:11 lpinfo.8:11
+#: lpmove.8:11 lpoptions.1:11 lpq.1:11 lpr.1:11 lprm.1:11 lpstat.1:10
+#: mailto.conf.5:11 mime.convs.5:11 mime.types.5:11 notifier.7:11 ppdc.1:11
+#: ppdcfile.5:11 ppdhtml.1:11 ppdi.1:11 ppdmerge.1:11 ppdpo.1:11
+#: printers.conf.5:10 subscriptions.conf.5:11
 #, no-wrap
 msgid "NAME"
 msgstr ""
@@ -52,7 +86,13 @@ msgid "backend - cups backend transmissi
 msgstr ""
 
 #. type: SH
-#: backend.7:13 cancel.1:13 cupsaccept.8:13 cups-config.1:13 cupsctl.8:13 cupsd.8:13 cupsd-helper.8:13 cupsenable.8:13 cupsfilter.8:12 cups-lpd.8:13 cups-snmp.8:12 cupstestppd.1:13 filter.7:13 ippevepcl.7:12 ippeveprinter.1:12 ippfind.1:12 ipptool.1:12 lp.1:13 lpadmin.8:13 lpc.8:13 lpinfo.8:13 lpmove.8:13 lpoptions.1:13 lpq.1:13 lpr.1:13 lprm.1:13 lpstat.1:12 notifier.7:13 ppdc.1:13 ppdhtml.1:13 ppdi.1:13 ppdmerge.1:13 ppdpo.1:13
+#: backend.7:13 cancel.1:13 cupsaccept.8:13 cups-config.1:13 cupsctl.8:13
+#: cupsd.8:13 cupsd-helper.8:13 cupsenable.8:13 cupsfilter.8:12 cups-lpd.8:14
+#: cups-snmp.8:12 cupstestppd.1:13 filter.7:13 ippevepcl.7:12
+#: ippeveprinter.1:12 ippfind.1:12 ipptool.1:12 lp.1:13 lpadmin.8:13 lpc.8:13
+#: lpinfo.8:13 lpmove.8:13 lpoptions.1:13 lpq.1:13 lpr.1:13 lprm.1:13
+#: lpstat.1:12 notifier.7:13 ppdc.1:13 ppdhtml.1:13 ppdi.1:13 ppdmerge.1:13
+#: ppdpo.1:13
 #, no-wrap
 msgid "SYNOPSIS"
 msgstr ""
@@ -119,7 +159,16 @@ msgid ""
 msgstr ""
 
 #. type: SH
-#: backend.7:49 cancel.1:37 classes.conf.5:13 client.conf.5:13 cups.1:13 cupsaccept.8:40 cups-config.1:49 cupsctl.8:36 cupsd.8:32 cupsd.conf.5:13 cupsd-helper.8:46 cupsd-logs.5:13 cupsenable.8:46 cups-files.conf.5:13 cupsfilter.8:54 cups-lpd.8:23 cups-snmp.8:23 cups-snmp.conf.5:13 cupstestppd.1:51 filter.7:51 ippevepcl.7:22 ippeveprinter.1:84 ippfind.1:32 ipptool.1:75 ipptoolfile.5:12 lp.1:84 lpadmin.8:54 lpc.8:20 lpinfo.8:60 lpmove.8:37 lpoptions.1:53 lpq.1:31 lpr.1:53 lprm.1:31 lpstat.1:65 mailto.conf.5:13 mime.convs.5:13 mime.types.5:13 notifier.7:19 ppdc.1:45 ppdcfile.5:13 ppdhtml.1:22 ppdi.1:26 ppdmerge.1:24 ppdpo.1:25 printers.conf.5:12 subscriptions.conf.5:13
+#: backend.7:49 cancel.1:37 classes.conf.5:13 client.conf.5:13 cups.1:13
+#: cupsaccept.8:40 cups-config.1:49 cupsctl.8:36 cupsd.8:32 cupsd.conf.5:13
+#: cupsd-helper.8:46 cupsd-logs.5:13 cupsenable.8:46 cups-files.conf.5:14
+#: cupsfilter.8:54 cups-lpd.8:24 cups-snmp.8:23 cups-snmp.conf.5:13
+#: cupstestppd.1:51 filter.7:51 ippevepcl.7:22 ippeveprinter.1:84 ippfind.1:32
+#: ipptool.1:75 ipptoolfile.5:12 lp.1:84 lpadmin.8:54 lpc.8:20 lpinfo.8:60
+#: lpmove.8:37 lpoptions.1:53 lpq.1:31 lpr.1:53 lprm.1:31 lpstat.1:65
+#: mailto.conf.5:13 mime.convs.5:13 mime.types.5:13 notifier.7:19 ppdc.1:45
+#: ppdcfile.5:13 ppdhtml.1:22 ppdi.1:26 ppdmerge.1:24 ppdpo.1:25
+#: printers.conf.5:12 subscriptions.conf.5:13
 #, no-wrap
 msgid "DESCRIPTION"
 msgstr ""
@@ -309,7 +358,8 @@ msgid ""
 msgstr ""
 
 #. type: SH
-#: backend.7:135 cupsfilter.8:102 cupstestppd.1:110 ippevepcl.7:39 ippeveprinter.1:200 ippfind.1:214 ipptool.1:191
+#: backend.7:135 cupsfilter.8:102 cupstestppd.1:110 ippevepcl.7:39
+#: ippeveprinter.1:200 ippfind.1:214 ipptool.1:191
 #, no-wrap
 msgid "EXIT STATUS"
 msgstr ""
@@ -434,7 +484,8 @@ msgid "All other exit code values are re
 msgstr ""
 
 #. type: SH
-#: backend.7:173 cups.1:60 cupsfilter.8:105 cups-snmp.8:37 ippevepcl.7:41 ippeveprinter.1:211 ippfind.1:216
+#: backend.7:173 cups.1:60 cupsfilter.8:105 cups-snmp.8:37 ippevepcl.7:41
+#: ippeveprinter.1:211 ippfind.1:216
 #, no-wrap
 msgid "ENVIRONMENT"
 msgstr ""
@@ -458,7 +509,9 @@ msgid "The device URI associated with th
 msgstr ""
 
 #. type: SH
-#: backend.7:182 cups.1:114 cupsd.8:71 cupsd-helper.8:56 cupsfilter.8:110 cups-lpd.8:54 cups-snmp.8:40 ipptool.1:195 lpoptions.1:104 mime.convs.5:37 mime.types.5:87
+#: backend.7:182 cups.1:114 cupsd.8:71 cupsd-helper.8:56 cupsfilter.8:110
+#: cups-lpd.8:55 cups-snmp.8:40 ipptool.1:195 lpoptions.1:104 mime.convs.5:37
+#: mime.types.5:87
 #, no-wrap
 msgid "FILES"
 msgstr ""
@@ -469,7 +522,12 @@ msgid "I</etc/cups/cups-files.conf>"
 msgstr ""
 
 #. type: SH
-#: backend.7:184 backend.7:204 cancel.1:81 classes.conf.5:19 client.conf.5:126 cups.1:122 cupsd.conf.5:858 cupsd-helper.8:77 cups-files.conf.5:273 cupsfilter.8:117 cups-lpd.8:60 cups-snmp.8:44 cups-snmp.conf.5:58 cupstestppd.1:138 filter.7:201 lpadmin.8:203 lpc.8:40 lpinfo.8:117 lpr.1:151 mime.convs.5:50 ppdc.1:90 ppdcfile.5:149 ppdhtml.1:35 ppdi.1:42 ppdmerge.1:35 ppdpo.1:42 printers.conf.5:16 subscriptions.conf.5:19
+#: backend.7:184 backend.7:204 cancel.1:81 classes.conf.5:19 client.conf.5:126
+#: cups.1:122 cupsd.conf.5:858 cupsd-helper.8:77 cups-files.conf.5:279
+#: cupsfilter.8:117 cups-lpd.8:61 cups-snmp.8:44 cups-snmp.conf.5:58
+#: cupstestppd.1:138 filter.7:201 lpadmin.8:203 lpc.8:40 lpinfo.8:117 lpr.1:151
+#: mime.convs.5:50 ppdc.1:90 ppdcfile.5:149 ppdhtml.1:35 ppdi.1:42
+#: ppdmerge.1:35 ppdpo.1:42 printers.conf.5:16 subscriptions.conf.5:19
 #, no-wrap
 msgid "NOTES"
 msgstr ""
@@ -506,7 +564,16 @@ msgid ""
 msgstr ""
 
 #. type: SH
-#: backend.7:208 cancel.1:84 classes.conf.5:21 client.conf.5:138 cups.1:126 cupsaccept.8:77 cups-config.1:105 cupsctl.8:92 cupsd.8:109 cupsd.conf.5:895 cupsd-helper.8:81 cupsd-logs.5:216 cupsenable.8:88 cups-files.conf.5:280 cupsfilter.8:131 cups-lpd.8:111 cups-snmp.8:49 cups-snmp.conf.5:62 cupstestppd.1:142 filter.7:212 ippevepcl.7:45 ippeveprinter.1:268 ippfind.1:255 ipptool.1:246 ipptoolfile.5:649 lp.1:219 lpadmin.8:224 lpc.8:47 lpinfo.8:121 lpmove.8:66 lpoptions.1:110 lpq.1:56 lpr.1:171 lprm.1:74 lpstat.1:140 mailto.conf.5:40 mime.convs.5:54 mime.types.5:100 notifier.7:31 ppdc.1:94 ppdcfile.5:153 ppdhtml.1:39 ppdi.1:46 ppdmerge.1:42 ppdpo.1:46 printers.conf.5:18 subscriptions.conf.5:21
+#: backend.7:208 cancel.1:84 classes.conf.5:21 client.conf.5:138 cups.1:126
+#: cupsaccept.8:77 cups-config.1:105 cupsctl.8:92 cupsd.8:109 cupsd.conf.5:895
+#: cupsd-helper.8:81 cupsd-logs.5:216 cupsenable.8:88 cups-files.conf.5:286
+#: cupsfilter.8:131 cups-lpd.8:108 cups-snmp.8:49 cups-snmp.conf.5:62
+#: cupstestppd.1:142 filter.7:212 ippevepcl.7:45 ippeveprinter.1:268
+#: ippfind.1:255 ipptool.1:246 ipptoolfile.5:649 lp.1:219 lpadmin.8:224
+#: lpc.8:47 lpinfo.8:121 lpmove.8:66 lpoptions.1:110 lpq.1:56 lpr.1:171
+#: lprm.1:74 lpstat.1:140 mailto.conf.5:40 mime.convs.5:54 mime.types.5:100
+#: notifier.7:31 ppdc.1:94 ppdcfile.5:153 ppdhtml.1:39 ppdi.1:46 ppdmerge.1:42
+#: ppdpo.1:46 printers.conf.5:18 subscriptions.conf.5:21
 #, no-wrap
 msgid "SEE ALSO"
 msgstr ""
@@ -524,13 +591,30 @@ msgid "CUPS Online Help (http://localhos
 msgstr ""
 
 #. type: SH
-#: backend.7:219 cancel.1:90 classes.conf.5:29 client.conf.5:142 cups.1:142 cupsaccept.8:85 cups-config.1:108 cupsctl.8:97 cupsd.8:125 cupsd.conf.5:904 cupsd-helper.8:89 cupsd-logs.5:221 cupsenable.8:96 cups-files.conf.5:290 cupsfilter.8:138 cups-lpd.8:118 cups-snmp.8:55 cups-snmp.conf.5:65 cupstestppd.1:146 filter.7:220 ippevepcl.7:47 ippeveprinter.1:272 ippfind.1:257 ipptool.1:251 ipptoolfile.5:654 lp.1:228 lpadmin.8:230 lpc.8:57 lpinfo.8:124 lpmove.8:73 lpoptions.1:117 lpq.1:63 lpr.1:180 lprm.1:81 lpstat.1:147 mailto.conf.5:43 mime.convs.5:61 mime.types.5:107 notifier.7:35 ppdc.1:101 ppdcfile.5:160 ppdhtml.1:46 ppdi.1:53 ppdmerge.1:49 ppdpo.1:53 printers.conf.5:27 subscriptions.conf.5:30
+#: backend.7:219 cancel.1:90 classes.conf.5:29 client.conf.5:142 cups.1:142
+#: cupsaccept.8:85 cups-config.1:108 cupsctl.8:97 cupsd.8:125 cupsd.conf.5:904
+#: cupsd-helper.8:89 cupsd-logs.5:221 cupsenable.8:96 cups-files.conf.5:296
+#: cupsfilter.8:138 cups-lpd.8:116 cups-snmp.8:55 cups-snmp.conf.5:65
+#: cupstestppd.1:146 filter.7:220 ippevepcl.7:47 ippeveprinter.1:272
+#: ippfind.1:257 ipptool.1:251 ipptoolfile.5:654 lp.1:228 lpadmin.8:230
+#: lpc.8:57 lpinfo.8:124 lpmove.8:73 lpoptions.1:117 lpq.1:63 lpr.1:180
+#: lprm.1:81 lpstat.1:147 mailto.conf.5:43 mime.convs.5:61 mime.types.5:107
+#: notifier.7:35 ppdc.1:101 ppdcfile.5:160 ppdhtml.1:46 ppdi.1:53 ppdmerge.1:49
+#: ppdpo.1:53 printers.conf.5:27 subscriptions.conf.5:30
 #, no-wrap
 msgid "COPYRIGHT"
 msgstr ""
 
 #. type: Plain text
-#: backend.7:220 cancel.1:91 classes.conf.5:30 client.conf.5:143 cups.1:143 cupsaccept.8:86 cups-config.1:109 cupsctl.8:98 cupsd.8:126 cupsd.conf.5:905 cupsd-helper.8:90 cupsd-logs.5:222 cupsenable.8:97 cups-files.conf.5:291 cupsfilter.8:139 cups-lpd.8:119 cups-snmp.8:56 cups-snmp.conf.5:66 cupstestppd.1:147 filter.7:221 ippeveprinter.1:273 ipptool.1:252 ipptoolfile.5:655 lp.1:229 lpadmin.8:231 lpc.8:58 lpinfo.8:125 lpmove.8:74 lpoptions.1:118 lpq.1:64 lpr.1:181 lprm.1:82 lpstat.1:148 mailto.conf.5:44 mime.convs.5:62 mime.types.5:108 notifier.7:36 ppdc.1:102 ppdcfile.5:161 ppdhtml.1:47 ppdi.1:54 ppdmerge.1:50 ppdpo.1:54 printers.conf.5:28 subscriptions.conf.5:31
+#: backend.7:220 cancel.1:91 classes.conf.5:30 client.conf.5:143 cups.1:143
+#: cupsaccept.8:86 cups-config.1:109 cupsctl.8:98 cupsd.8:126 cupsd.conf.5:905
+#: cupsd-helper.8:90 cupsd-logs.5:222 cupsenable.8:97 cupsfilter.8:139
+#: cups-snmp.8:56 cups-snmp.conf.5:66 cupstestppd.1:147 filter.7:221
+#: ippeveprinter.1:273 ipptool.1:252 ipptoolfile.5:655 lp.1:229 lpadmin.8:231
+#: lpc.8:58 lpinfo.8:125 lpmove.8:74 lpoptions.1:118 lpq.1:64 lpr.1:181
+#: lprm.1:82 lpstat.1:148 mailto.conf.5:44 mime.convs.5:62 mime.types.5:108
+#: notifier.7:36 ppdc.1:102 ppdcfile.5:161 ppdhtml.1:47 ppdi.1:54 ppdmerge.1:50
+#: ppdpo.1:54 printers.conf.5:28 subscriptions.conf.5:31
 msgid "Copyright \\[co] 2007-2019 by Apple Inc."
 msgstr ""
 
@@ -562,7 +646,12 @@ msgid ""
 msgstr ""
 
 #. type: SH
-#: cancel.1:40 cupsaccept.8:50 cups-config.1:52 cupsctl.8:40 cupsd.8:37 cupsd.conf.5:485 cupsenable.8:51 cupsfilter.8:59 cups-lpd.8:32 cupstestppd.1:58 filter.7:60 ippeveprinter.1:87 ippfind.1:191 ipptool.1:88 lp.1:94 lpadmin.8:73 lpinfo.8:63 lpmove.8:39 lpoptions.1:68 lpq.1:36 lpr.1:64 lprm.1:36 lpstat.1:68 ppdc.1:48 ppdhtml.1:25 ppdi.1:30 ppdmerge.1:28 ppdpo.1:28
+#: cancel.1:40 cupsaccept.8:50 cups-config.1:52 cupsctl.8:40 cupsd.8:37
+#: cupsd.conf.5:485 cupsenable.8:51 cupsfilter.8:59 cups-lpd.8:33
+#: cupstestppd.1:58 filter.7:60 ippeveprinter.1:87 ippfind.1:191 ipptool.1:88
+#: lp.1:94 lpadmin.8:73 lpinfo.8:63 lpmove.8:39 lpoptions.1:68 lpq.1:36
+#: lpr.1:64 lprm.1:36 lpstat.1:68 ppdc.1:48 ppdhtml.1:25 ppdi.1:30
+#: ppdmerge.1:28 ppdpo.1:28
 #, no-wrap
 msgid "OPTIONS"
 msgstr ""
@@ -586,13 +675,16 @@ msgid ""
 msgstr ""
 
 #. type: TP
-#: cancel.1:46 cupsaccept.8:55 cupsctl.8:42 cupsenable.8:53 ipptool.1:125 lp.1:99 lpadmin.8:175 lpinfo.8:65 lpmove.8:41 lpoptions.1:70 lpq.1:38 lpr.1:66 lprm.1:40 lpstat.1:70
+#: cancel.1:46 cupsaccept.8:55 cupsctl.8:42 cupsenable.8:53 ipptool.1:125
+#: lp.1:99 lpadmin.8:175 lpinfo.8:65 lpmove.8:41 lpoptions.1:70 lpq.1:38
+#: lpr.1:66 lprm.1:40 lpstat.1:70
 #, no-wrap
 msgid "B<-E>"
 msgstr ""
 
 #. type: Plain text
-#: cancel.1:49 cupsaccept.8:58 lp.1:102 lpinfo.8:68 lpmove.8:44 lpq.1:41 lpr.1:69 lprm.1:43 lpstat.1:73
+#: cancel.1:49 cupsaccept.8:58 lp.1:102 lpinfo.8:68 lpmove.8:44 lpq.1:41
+#: lpr.1:69 lprm.1:43 lpstat.1:73
 msgid "Forces encryption when connecting to the server."
 msgstr ""
 
@@ -608,7 +700,8 @@ msgid "Specifies an alternate server."
 msgstr ""
 
 #. type: TP
-#: cancel.1:52 cupsaccept.8:58 cupsctl.8:45 cupsenable.8:56 lp.1:102 lpmove.8:44 lpq.1:44 lpr.1:82 lprm.1:46 lpstat.1:79
+#: cancel.1:52 cupsaccept.8:58 cupsctl.8:45 cupsenable.8:56 lp.1:102
+#: lpmove.8:44 lpq.1:44 lpr.1:82 lprm.1:46 lpstat.1:79
 #, no-wrap
 msgid "B<-U >I<username>"
 msgstr ""
@@ -641,7 +734,10 @@ msgid "Deletes job data files in additio
 msgstr ""
 
 #. type: SH
-#: cancel.1:61 cups.1:119 cupsaccept.8:67 cupsd.8:81 cupsd.conf.5:873 cupsenable.8:77 cups-lpd.8:46 cups-snmp.8:47 filter.7:199 ippeveprinter.1:207 ipptool.1:229 lp.1:196 lpadmin.8:197 lpinfo.8:97 lpoptions.1:108 lprm.1:52 lpstat.1:133
+#: cancel.1:61 cups.1:119 cupsaccept.8:67 cupsd.8:81 cupsd.conf.5:873
+#: cupsenable.8:77 cups-lpd.8:47 cups-snmp.8:47 filter.7:199
+#: ippeveprinter.1:207 ipptool.1:229 lp.1:196 lpadmin.8:197 lpinfo.8:97
+#: lpoptions.1:108 lprm.1:52 lpstat.1:133
 #, no-wrap
 msgid "CONFORMING TO"
 msgstr ""
@@ -655,7 +751,9 @@ msgid ""
 msgstr ""
 
 #. type: SH
-#: cancel.1:63 cups-config.1:87 cupsctl.8:66 cupsd.8:84 cupsd.conf.5:875 cupstestppd.1:125 ippeveprinter.1:252 ippfind.1:242 ipptool.1:233 lp.1:201 lpinfo.8:99 lpmove.8:50 lpr.1:153 lprm.1:56 mime.convs.5:43 mime.types.5:89
+#: cancel.1:63 cups-config.1:87 cupsctl.8:66 cupsd.8:84 cupsd.conf.5:875
+#: cupstestppd.1:125 ippeveprinter.1:252 ippfind.1:242 ipptool.1:233 lp.1:201
+#: lpinfo.8:99 lpmove.8:50 lpr.1:153 lprm.1:56 mime.convs.5:43 mime.types.5:89
 #, no-wrap
 msgid "EXAMPLES"
 msgstr ""
@@ -781,7 +879,7 @@ msgid ""
 msgstr ""
 
 #. type: SS
-#: client.conf.5:21 cups-files.conf.5:22 cups-snmp.conf.5:21 mailto.conf.5:20
+#: client.conf.5:21 cups-files.conf.5:23 cups-snmp.conf.5:21 mailto.conf.5:20
 #, no-wrap
 msgid "DIRECTIVES"
 msgstr ""
@@ -1869,7 +1967,8 @@ msgid ""
 msgstr ""
 
 #. type: TP
-#: cupsctl.8:48 cupsenable.8:62 lpinfo.8:68 lpmove.8:47 lpoptions.1:78 lpq.1:50 lpstat.1:100
+#: cupsctl.8:48 cupsenable.8:62 lpinfo.8:68 lpmove.8:47 lpoptions.1:78 lpq.1:50
+#: lpstat.1:100
 #, no-wrap
 msgid "B<-h >I<server>[B<:>I<port>]"
 msgstr ""
@@ -2072,7 +2171,8 @@ msgid "Shows the program usage."
 msgstr ""
 
 #. type: TP
-#: cupsd.8:57 ippfind.1:74 ipptool.1:172 lpinfo.8:71 lpoptions.1:81 lpq.1:53 lpr.1:91 lpstat.1:103
+#: cupsd.8:57 ippfind.1:74 ipptool.1:172 lpinfo.8:71 lpoptions.1:81 lpq.1:53
+#: lpr.1:91 lpstat.1:103
 #, no-wrap
 msgid "B<-l>"
 msgstr ""
@@ -2530,8 +2630,7 @@ msgstr ""
 #: cupsd.conf.5:144
 msgid ""
 "Specifies that a failed print job should be retried at a later time unless "
-"otherwise specified for the printer. The 'retry-job' error policy is the "
-"default."
+"otherwise specified for the printer."
 msgstr ""
 
 #. type: TP
@@ -2545,7 +2644,7 @@ msgstr ""
 #: cupsd.conf.5:148
 msgid ""
 "Specifies that a failed print job should stop the printer unless otherwise "
-"specified for the printer."
+"specified for the printer. The 'stop-printer' error policy is the default."
 msgstr ""
 
 #. type: TP
@@ -4514,7 +4613,7 @@ msgid ""
 msgstr ""
 
 #. type: SS
-#: cupsd.conf.5:815 cups-files.conf.5:230
+#: cupsd.conf.5:815 cups-files.conf.5:236
 #, no-wrap
 msgid "DEPRECATED DIRECTIVES"
 msgstr ""
@@ -5503,18 +5602,24 @@ msgid ""
 msgstr ""
 
 #. type: TH
-#: cups-files.conf.5:10
+#: cups-files.conf.5:11
 #, no-wrap
 msgid "cups-files.conf"
 msgstr ""
 
+#. type: TH
+#: cups-files.conf.5:11 cups-lpd.8:11
+#, no-wrap
+msgid "14 November 2020"
+msgstr ""
+
 #. type: Plain text
-#: cups-files.conf.5:13
+#: cups-files.conf.5:14
 msgid "cups-files.conf - file and directory configuration file for cups"
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:17
+#: cups-files.conf.5:18
 msgid ""
 "The B<cups-files.conf> file configures the files and directories used by the "
 "CUPS scheduler, B<cupsd>(8).  It is normally located in the I</etc/cups> "
@@ -5522,7 +5627,7 @@ msgid ""
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:22 mailto.conf.5:20
+#: cups-files.conf.5:23 mailto.conf.5:20
 msgid ""
 "Each line in the file can be a configuration directive, a blank line, or a "
 "comment.  Configuration directives typically consist of a name and zero or "
@@ -5532,36 +5637,36 @@ msgstr ""
 
 #. #AccessLog
 #. type: Plain text
-#: cups-files.conf.5:26
+#: cups-files.conf.5:27
 msgid "The following directives are understood by B<cupsd>(8):"
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:26
+#: cups-files.conf.5:27
 #, no-wrap
 msgid "B<AccessLog>"
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:28
+#: cups-files.conf.5:29
 #, no-wrap
 msgid "B<AccessLog >I<filename>"
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:30
+#: cups-files.conf.5:31
 #, no-wrap
 msgid "B<AccessLog stderr>"
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:32
+#: cups-files.conf.5:33
 #, no-wrap
 msgid "B<AccessLog syslog>"
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:39
+#: cups-files.conf.5:40
 msgid ""
 "Defines the access log filename.  Specifying a blank filename disables "
 "access log generation.  The value \"stderr\" causes log entries to be sent "
@@ -5573,26 +5678,26 @@ msgid ""
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:42
+#: cups-files.conf.5:43
 #, no-wrap
 msgid "    AccessLog /var/log/cups/%s-access_log\n"
 msgstr ""
 
 #. #CacheDir
 #. type: Plain text
-#: cups-files.conf.5:46
+#: cups-files.conf.5:47
 msgid "The default is \"/var/log/cups/access_log\"."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:46
+#: cups-files.conf.5:47
 #, no-wrap
 msgid "B<CacheDir >I<directory>"
 msgstr ""
 
 #. #ConfigFilePerm
 #. type: Plain text
-#: cups-files.conf.5:51
+#: cups-files.conf.5:52
 msgid ""
 "Specifies the directory to use for long-lived temporary (cache) files.  The "
 "default is \"/var/spool/cups/cache\" or \"/var/cache/cups\" depending on the "
@@ -5600,13 +5705,13 @@ msgid ""
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:51
+#: cups-files.conf.5:52
 #, no-wrap
 msgid "B<ConfigFilePerm >I<mode>"
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:55
+#: cups-files.conf.5:56
 msgid ""
 "Specifies the permissions for all configuration files that the scheduler "
 "writes.  The default is \"0644\" on macOS and \"0640\" on all other "
@@ -5615,7 +5720,7 @@ msgstr ""
 
 #. #CreateSelfSignedCerts
 #. type: Plain text
-#: cups-files.conf.5:60
+#: cups-files.conf.5:61
 msgid ""
 "B<Note:> The permissions for the I<printers.conf> file are currently masked "
 "to only allow access from the scheduler user (typically root).  This is done "
@@ -5625,79 +5730,79 @@ msgid ""
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:60
+#: cups-files.conf.5:61
 #, no-wrap
 msgid "B<CreateSelfSignedCerts yes>"
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:62
+#: cups-files.conf.5:63
 #, no-wrap
 msgid "B<CreateSelfSignedCerts no>"
 msgstr ""
 
 #. #DataDir
 #. type: Plain text
-#: cups-files.conf.5:67
+#: cups-files.conf.5:68
 msgid ""
 "Specifies whether the scheduler automatically creates self-signed "
 "certificates for client connections using TLS.  The default is yes."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:67
+#: cups-files.conf.5:68
 #, no-wrap
 msgid "B<DataDir >I<path>"
 msgstr ""
 
 #. #DocumentRoot
 #. type: Plain text
-#: cups-files.conf.5:72
+#: cups-files.conf.5:73
 msgid ""
 "Specifies the directory where data files can be found.  The default is "
 "usually \"/usr/share/cups\"."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:72
+#: cups-files.conf.5:73
 #, no-wrap
 msgid "B<DocumentRoot >I<directory>"
 msgstr ""
 
 #. #ErrorLog
 #. type: Plain text
-#: cups-files.conf.5:77
+#: cups-files.conf.5:78
 msgid ""
 "Specifies the root directory for the CUPS web interface content.  The "
 "default is usually \"/usr/share/doc/cups\"."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:77
+#: cups-files.conf.5:78
 #, no-wrap
 msgid "B<ErrorLog>"
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:79
+#: cups-files.conf.5:80
 #, no-wrap
 msgid "B<ErrorLog >I<filename>"
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:81
+#: cups-files.conf.5:82
 #, no-wrap
 msgid "B<ErrorLog stderr>"
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:83
+#: cups-files.conf.5:84
 #, no-wrap
 msgid "B<ErrorLog syslog>"
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:90
+#: cups-files.conf.5:91
 msgid ""
 "Defines the error log filename.  Specifying a blank filename disables error "
 "log generation.  The value \"stderr\" causes log entries to be sent to the "
@@ -5708,132 +5813,131 @@ msgid ""
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:93
+#: cups-files.conf.5:94
 #, no-wrap
 msgid "    ErrorLog /var/log/cups/%s-error_log\n"
 msgstr ""
 
 #. #FatalErrors
 #. type: Plain text
-#: cups-files.conf.5:97
+#: cups-files.conf.5:98
 msgid "The default is \"/var/log/cups/error_log\"."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:97
+#: cups-files.conf.5:98
 #, no-wrap
 msgid "B<FatalErrors none>"
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:99
+#: cups-files.conf.5:100
 #, no-wrap
 msgid "B<FatalErrors all >I<-kind >[ ... I<-kind >]"
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:101
+#: cups-files.conf.5:102
 #, no-wrap
 msgid "B<FatalErrors >I<kind >[ ... I<kind >]"
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:106
+#: cups-files.conf.5:107
 msgid ""
 "Specifies which errors are fatal, causing the scheduler to exit.  The "
 "default is \"config\".  The I<kind> strings are:"
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:107
+#: cups-files.conf.5:108
 #, no-wrap
 msgid "B<none>"
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:110
+#: cups-files.conf.5:111
 msgid "No errors are fatal."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:110
+#: cups-files.conf.5:111
 #, no-wrap
 msgid "B<all>"
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:113
+#: cups-files.conf.5:114
 msgid "All of the errors below are fatal."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:113
+#: cups-files.conf.5:114
 #, no-wrap
 msgid "B<browse>"
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:116
+#: cups-files.conf.5:117
 msgid ""
 "Browsing initialization errors are fatal, for example failed connections to "
 "the DNS-SD daemon."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:116
+#: cups-files.conf.5:117
 #, no-wrap
 msgid "B<config>"
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:119
+#: cups-files.conf.5:120
 msgid "Configuration file syntax errors are fatal."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:119
+#: cups-files.conf.5:120
 #, no-wrap
 msgid "B<listen>"
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:122
+#: cups-files.conf.5:123
 msgid ""
 "Listen or Port errors are fatal, except for IPv6 failures on the loopback or "
 "\"any\" addresses."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:122
+#: cups-files.conf.5:123
 #, no-wrap
 msgid "B<log>"
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:125
+#: cups-files.conf.5:126
 msgid "Log file creation or write errors are fatal."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:125
+#: cups-files.conf.5:126
 #, no-wrap
 msgid "B<permissions>"
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:128
+#: cups-files.conf.5:129
 msgid ""
 "Bad startup file permissions are fatal, for example shared TLS certificate "
 "and key files with world-read permissions."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:130
+#: cups-files.conf.5:131
 #, no-wrap
 msgid "B<Group >I<group-name-or-number>"
 msgstr ""
 
-#. #LogFilePerm
 #. type: Plain text
 #: cups-files.conf.5:135
 msgid ""
@@ -5843,39 +5947,53 @@ msgid ""
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:135
+#: cups-files.conf.5:137
+#, no-wrap
+msgid "B<LogFileGroup >I<group-name-or-number>"
+msgstr ""
+
+#. #LogFilePerm
+#. type: Plain text
+#: cups-files.conf.5:142
+msgid ""
+"Specifies the group name or ID that will be used for log files.  The default "
+"group is operating system specific but is usually \"lp\" or \"nobody\"."
+msgstr ""
+
+#. type: TP
+#: cups-files.conf.5:142
 #, no-wrap
 msgid "B<LogFilePerm >I<mode>"
 msgstr ""
 
 #. #PageLog
 #. type: Plain text
-#: cups-files.conf.5:140
+#: cups-files.conf.5:147
 msgid ""
 "Specifies the permissions of all log files that the scheduler writes.  The "
 "default is \"0644\"."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:140
+#: cups-files.conf.5:147
 #, no-wrap
 msgid "B<PageLog >[ I<filename> ]"
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:142
+#: cups-files.conf.5:149
 #, no-wrap
 msgid "B<PageLog stderr>"
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:144
+#: cups-files.conf.5:151
 #, no-wrap
 msgid "B<PageLog syslog>"
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:151
+#: cups-files.conf.5:158
 msgid ""
 "Defines the page log filename.  The value \"stderr\" causes log entries to "
 "be sent to the standard error file when the scheduler is running in the "
@@ -5886,26 +6004,26 @@ msgid ""
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:154
+#: cups-files.conf.5:161
 #, no-wrap
 msgid "    PageLog /var/log/cups/%s-page_log\n"
 msgstr ""
 
 #. #PassEnv
 #. type: Plain text
-#: cups-files.conf.5:158
+#: cups-files.conf.5:165
 msgid "The default is \"/var/log/cups/page_log\"."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:158
+#: cups-files.conf.5:165
 #, no-wrap
 msgid "B<PassEnv >I<variable >[ ... I<variable >]"
 msgstr ""
 
 #. #RemoteRoot
 #. type: Plain text
-#: cups-files.conf.5:163
+#: cups-files.conf.5:170
 msgid ""
 "Passes the specified environment variable(s) to child processes.  Note: the "
 "standard CUPS filter and backend environment variables cannot be overridden "
@@ -5913,48 +6031,48 @@ msgid ""
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:163
+#: cups-files.conf.5:170
 #, no-wrap
 msgid "B<RemoteRoot >I<username>"
 msgstr ""
 
 #. #RequestRoot
 #. type: Plain text
-#: cups-files.conf.5:168
+#: cups-files.conf.5:175
 msgid ""
 "Specifies the username that is associated with unauthenticated accesses by "
 "clients claiming to be the root user.  The default is \"remroot\"."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:168
+#: cups-files.conf.5:175
 #, no-wrap
 msgid "B<RequestRoot >I<directory>"
 msgstr ""
 
 #. #Sandboxing
 #. type: Plain text
-#: cups-files.conf.5:173
+#: cups-files.conf.5:180
 msgid ""
 "Specifies the directory that contains print jobs and other HTTP request "
 "data.  The default is \"/var/spool/cups\"."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:173
+#: cups-files.conf.5:180
 #, no-wrap
 msgid "B<Sandboxing relaxed>"
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:175
+#: cups-files.conf.5:182
 #, no-wrap
 msgid "B<Sandboxing strict>"
 msgstr ""
 
 #. #ServerBin
 #. type: Plain text
-#: cups-files.conf.5:181
+#: cups-files.conf.5:188
 msgid ""
 "Specifies the level of security sandboxing that is applied to print filters, "
 "backends, and other child processes of the scheduler.  The default is "
@@ -5962,14 +6080,14 @@ msgid ""
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:181
+#: cups-files.conf.5:188
 #, no-wrap
 msgid "B<ServerBin >I<directory>"
 msgstr ""
 
 #. #ServerKeychain
 #. type: Plain text
-#: cups-files.conf.5:186
+#: cups-files.conf.5:193
 msgid ""
 "Specifies the directory containing the backends, CGI programs, filters, "
 "helper programs, notifiers, and port monitors.  The default is "
@@ -5977,14 +6095,14 @@ msgid ""
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:186
+#: cups-files.conf.5:193
 #, no-wrap
 msgid "B<ServerKeychain >I<path>"
 msgstr ""
 
 #. #ServerRoot
 #. type: Plain text
-#: cups-files.conf.5:192
+#: cups-files.conf.5:199
 msgid ""
 "Specifies the location of TLS certificates and private keys.  The default is "
 "\"/Library/Keychains/System.keychain\" on macOS and \"/etc/cups/ssl\" on all "
@@ -5995,28 +6113,28 @@ msgid ""
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:192
+#: cups-files.conf.5:199
 #, no-wrap
 msgid "B<ServerRoot >I<directory>"
 msgstr ""
 
 #. #SetEnv
 #. type: Plain text
-#: cups-files.conf.5:197
+#: cups-files.conf.5:204
 msgid ""
 "Specifies the directory containing the server configuration files.  The "
 "default is \"/etc/cups\"."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:197
+#: cups-files.conf.5:204
 #, no-wrap
 msgid "B<SetEnv >I<variable value>"
 msgstr ""
 
 #. #StateDir
 #. type: Plain text
-#: cups-files.conf.5:202
+#: cups-files.conf.5:209
 msgid ""
 "Set the specified environment variable to be passed to child processes.  "
 "Note: the standard CUPS filter and backend environment variables cannot be "
@@ -6024,48 +6142,48 @@ msgid ""
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:202
+#: cups-files.conf.5:209
 #, no-wrap
 msgid "B<StateDir >I<directory>"
 msgstr ""
 
 #. #SyncOnClose
 #. type: Plain text
-#: cups-files.conf.5:207
+#: cups-files.conf.5:214
 msgid ""
 "Specifies the directory to use for PID and local certificate files.  The "
 "default is \"/var/run/cups\" or \"/etc/cups\" depending on the platform."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:207
+#: cups-files.conf.5:214
 #, no-wrap
 msgid "B<SyncOnClose Yes>"
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:209
+#: cups-files.conf.5:216
 #, no-wrap
 msgid "B<SyncOnClose No>"
 msgstr ""
 
 #. #SystemGroup
 #. type: Plain text
-#: cups-files.conf.5:216
+#: cups-files.conf.5:222
 msgid ""
 "Specifies whether the scheduler calls B<fsync>(2)  after writing "
-"configuration or state files.  The default is \"Yes\"."
+"configuration or state files."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:216
+#: cups-files.conf.5:222
 #, no-wrap
 msgid "B<SystemGroup >I<group-name >[ ... I<group-name> ]"
 msgstr ""
 
 #. #TempDir
 #. type: Plain text
-#: cups-files.conf.5:221
+#: cups-files.conf.5:227
 msgid ""
 "Specifies the group(s) to use for I<@SYSTEM> group authentication.  The "
 "default contains \"admin\", \"lpadmin\", \"root\", \"sys\", and/or "
@@ -6073,27 +6191,27 @@ msgid ""
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:221
+#: cups-files.conf.5:227
 #, no-wrap
 msgid "B<TempDir >I<directory>"
 msgstr ""
 
 #. #User
 #. type: Plain text
-#: cups-files.conf.5:226
+#: cups-files.conf.5:232
 msgid ""
 "Specifies the directory where short-term temporary files are stored.  The "
 "default is \"/var/spool/cups/tmp\"."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:226
+#: cups-files.conf.5:232
 #, no-wrap
 msgid "B<User >I<username>"
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:230
+#: cups-files.conf.5:236
 msgid ""
 "Specifies the user name or ID that is used when running external programs.  "
 "The default is \"lp\"."
@@ -6101,27 +6219,27 @@ msgstr ""
 
 #. #FileDevice
 #. type: Plain text
-#: cups-files.conf.5:233
+#: cups-files.conf.5:239
 msgid ""
 "The following directives are deprecated and will be removed from a future "
 "version of CUPS:"
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:233
+#: cups-files.conf.5:239
 #, no-wrap
 msgid "B<FileDevice Yes>"
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:235
+#: cups-files.conf.5:241
 #, no-wrap
 msgid "B<FileDevice No>"
 msgstr ""
 
 #. #FontPath
 #. type: Plain text
-#: cups-files.conf.5:243
+#: cups-files.conf.5:249
 msgid ""
 "Specifies whether the file pseudo-device can be used for new printer "
 "queues.  The URI \"file:///dev/null\" is always allowed.  File devices "
@@ -6131,14 +6249,14 @@ msgid ""
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:243
+#: cups-files.conf.5:249
 #, no-wrap
 msgid "B<FontPath >I<directory[:...:directoryN]>"
 msgstr ""
 
 #. #LPDConfigFile
 #. type: Plain text
-#: cups-files.conf.5:251
+#: cups-files.conf.5:257
 msgid ""
 "Specifies a colon separated list of directories where fonts can be found.  "
 "On Linux the B<font-config>(1)  mechanism is used instead.  On macOS the "
@@ -6146,50 +6264,50 @@ msgid ""
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:251
+#: cups-files.conf.5:257
 #, no-wrap
 msgid " B<LPDConfigFile >I<filename>"
 msgstr ""
 
 #. #Printcap
 #. type: Plain text
-#: cups-files.conf.5:255
+#: cups-files.conf.5:261
 msgid "Specifies the LPD service configuration file to update."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:255
+#: cups-files.conf.5:261
 #, no-wrap
 msgid "B<Printcap >I<filename>"
 msgstr ""
 
 #. #PrintcapFormat
 #. type: Plain text
-#: cups-files.conf.5:259
+#: cups-files.conf.5:265
 msgid "Specifies a file that is filled with a list of local print queues."
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:259
+#: cups-files.conf.5:265
 #, no-wrap
 msgid "B<PrintcapFormat bsd>"
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:261
+#: cups-files.conf.5:267
 #, no-wrap
 msgid "B<PrintcapFormat plist>"
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:263
+#: cups-files.conf.5:269
 #, no-wrap
 msgid "B<PrintcapFormat solaris>"
 msgstr ""
 
 #. #SMBConfigFile
 #. type: Plain text
-#: cups-files.conf.5:270
+#: cups-files.conf.5:276
 msgid ""
 "Specifies the format to use for the Printcap file.  \"bsd\" is the "
 "historical LPD printcap file format.  \"plist\" is the Apple plist file "
@@ -6197,18 +6315,18 @@ msgid ""
 msgstr ""
 
 #. type: TP
-#: cups-files.conf.5:270
+#: cups-files.conf.5:276
 #, no-wrap
 msgid "B<SMBConfigFile >I<filename>"
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:273
+#: cups-files.conf.5:279
 msgid "Specifies the SMB service configuration file to update."
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:280
+#: cups-files.conf.5:286
 msgid ""
 "The scheduler MUST be restarted manually after making changes to the "
 "B<cups-files.conf> file.  On Linux this is typically done using the "
@@ -6217,13 +6335,20 @@ msgid ""
 msgstr ""
 
 #. type: Plain text
-#: cups-files.conf.5:290
+#: cups-files.conf.5:296
 msgid ""
 "B<classes.conf>(5), B<cups>(1), B<cupsd>(8), B<cupsd.conf>(5), "
 "B<mime.convs>(5), B<mime.types>(5), B<printers.conf>(5), "
 "B<subscriptions.conf>(5), CUPS Online Help (http://localhost:631/help)"
 msgstr ""
 
+#. type: Plain text
+#: cups-files.conf.5:298 cups-lpd.8:118
+msgid ""
+"Copyright \\[co] 2020 by Michael R Sweet Copyright \\[co] 2007-2019 by Apple "
+"Inc."
+msgstr ""
+
 #. type: TH
 #: cupsfilter.8:9
 #, no-wrap
@@ -6371,7 +6496,7 @@ msgid "Specifies the number of copies to
 msgstr ""
 
 #. type: TP
-#: cupsfilter.8:90 cups-lpd.8:41
+#: cupsfilter.8:90 cups-lpd.8:42
 #, no-wrap
 msgid "B<-o >I<name=value>"
 msgstr ""
@@ -6455,7 +6580,7 @@ msgid ""
 msgstr ""
 
 #. type: SH
-#: cupsfilter.8:125 cups-lpd.8:86 lpadmin.8:217
+#: cupsfilter.8:125 cups-lpd.8:87 lpadmin.8:217
 #, no-wrap
 msgid "EXAMPLE"
 msgstr ""
@@ -6481,27 +6606,27 @@ msgid ""
 msgstr ""
 
 #. type: TH
-#: cups-lpd.8:10
+#: cups-lpd.8:11
 #, no-wrap
 msgid "cups-lpd"
 msgstr ""
 
 #. type: Plain text
-#: cups-lpd.8:13
+#: cups-lpd.8:14
 msgid ""
 "cups-lpd - receive print jobs and report printer status to lpd clients "
 "(deprecated)"
 msgstr ""
 
 #. type: Plain text
-#: cups-lpd.8:23
+#: cups-lpd.8:24
 msgid ""
 "B<cups-lpd> [ B<-h >I<hostname>[B<:>I<port>] ] [ B<-n> ] [ B<-o> "
 "I<option=value> ]"
 msgstr ""
 
 #. type: Plain text
-#: cups-lpd.8:32
+#: cups-lpd.8:33
 msgid ""
 "B<cups-lpd> is the CUPS Line Printer Daemon (\"LPD\") mini-server that "
 "supports legacy client systems that use the LPD protocol.  B<cups-lpd> does "
@@ -6511,31 +6636,31 @@ msgid ""
 msgstr ""
 
 #. type: TP
-#: cups-lpd.8:33 lp.1:112
+#: cups-lpd.8:34 lp.1:112
 #, no-wrap
 msgid "B<-h >I<hostname>[B<:>I<port>]"
 msgstr ""
 
 #. type: Plain text
-#: cups-lpd.8:36
+#: cups-lpd.8:37
 msgid "Sets the CUPS server (and port) to use."
 msgstr ""
 
 #. type: TP
-#: cups-lpd.8:36
+#: cups-lpd.8:37
 #, no-wrap
 msgid "B<-n>"
 msgstr ""
 
 #. type: Plain text
-#: cups-lpd.8:41
+#: cups-lpd.8:42
 msgid ""
 "Disables reverse address lookups; normally B<cups-lpd> will try to discover "
 "the hostname of the client via a reverse DNS lookup."
 msgstr ""
 
 #. type: Plain text
-#: cups-lpd.8:46
+#: cups-lpd.8:47
 msgid ""
 "Inserts options for all print queues. Most often this is used to disable the "
 "\"l\" filter so that remote print jobs are filtered as needed for printing; "
@@ -6545,7 +6670,7 @@ msgid ""
 msgstr ""
 
 #. type: Plain text
-#: cups-lpd.8:50
+#: cups-lpd.8:51
 msgid ""
 "B<cups-lpd> does not enforce the restricted source port number specified in "
 "RFC 1179, as using restricted ports does not prevent users from submitting "
@@ -6554,7 +6679,7 @@ msgid ""
 msgstr ""
 
 #. type: Plain text
-#: cups-lpd.8:52
+#: cups-lpd.8:53
 msgid ""
 "The output of the status requests follows RFC 2569, Mapping between LPD and "
 "IPP Protocols. Since many LPD implementations stray from this definition, "
@@ -6562,18 +6687,18 @@ msgid ""
 msgstr ""
 
 #. type: SH
-#: cups-lpd.8:52
+#: cups-lpd.8:53
 #, no-wrap
 msgid "ERRORS"
 msgstr ""
 
 #. type: Plain text
-#: cups-lpd.8:54
+#: cups-lpd.8:55
 msgid "Errors are sent to the system log."
 msgstr ""
 
 #. type: Plain text
-#: cups-lpd.8:59
+#: cups-lpd.8:60
 #, no-wrap
 msgid ""
 "I</etc/inetd.conf>\n"
@@ -6582,20 +6707,20 @@ msgid ""
 msgstr ""
 
 #. type: Plain text
-#: cups-lpd.8:64
+#: cups-lpd.8:65
 msgid ""
 "The B<cups-lpd> program is deprecated and will no longer be supported in a "
 "future feature release of CUPS."
 msgstr ""
 
 #. type: SS
-#: cups-lpd.8:64
+#: cups-lpd.8:65
 #, no-wrap
 msgid "PERFORMANCE"
 msgstr ""
 
 #. type: Plain text
-#: cups-lpd.8:69
+#: cups-lpd.8:70
 msgid ""
 "B<cups-lpd> performs well with small numbers of clients and printers.  "
 "However, since a new process is created for each connection and since each "
@@ -6605,13 +6730,13 @@ msgid ""
 msgstr ""
 
 #. type: SS
-#: cups-lpd.8:69
+#: cups-lpd.8:70
 #, no-wrap
 msgid "SECURITY"
 msgstr ""
 
 #. type: Plain text
-#: cups-lpd.8:76
+#: cups-lpd.8:77
 msgid ""
 "B<cups-lpd> currently does not perform any access control based on the "
 "settings in I<cupsd.conf(5)> or in the I<hosts.allow(5)> or I<hosts.deny(5)> "
@@ -6621,7 +6746,7 @@ msgid ""
 msgstr ""
 
 #. type: Plain text
-#: cups-lpd.8:82
+#: cups-lpd.8:83
 msgid ""
 "While B<xinetd>(8)  has built-in access control support, you should use the "
 "TCP wrappers package with B<inetd>(8)  to limit access to only those "
@@ -6629,7 +6754,7 @@ msgid ""
 msgstr ""
 
 #. type: Plain text
-#: cups-lpd.8:86
+#: cups-lpd.8:87
 msgid ""
 "B<cups-lpd> is not enabled by the standard CUPS distribution.  Please "
 "consult with your operating system vendor to determine whether it is enabled "
@@ -6637,14 +6762,14 @@ msgid ""
 msgstr ""
 
 #. type: Plain text
-#: cups-lpd.8:92
+#: cups-lpd.8:93
 msgid ""
 "If you are using B<inetd>(8), add the following line to the I<inetd.conf> "
 "file to enable the B<cups-lpd> mini-server:"
 msgstr ""
 
 #. type: Plain text
-#: cups-lpd.8:96
+#: cups-lpd.8:97
 #, no-wrap
 msgid ""
 "    printer stream tcp nowait lp /usr/lib/cups/daemon/cups-lpd cups-lpd "
@@ -6653,14 +6778,7 @@ msgid ""
 msgstr ""
 
 #. type: Plain text
-#: cups-lpd.8:102
-msgid ""
-"I<Note:> If you are using Solaris 10 or higher, you must run the "
-"B<inetdconv>(1m)  program to register the changes to the I<inetd.conf> file."
-msgstr ""
-
-#. type: Plain text
-#: cups-lpd.8:111
+#: cups-lpd.8:108
 msgid ""
 "CUPS includes configuration files for B<launchd>(8), B<systemd>(8), and "
 "B<xinetd>(8).  Simply enable the B<cups-lpd> service using the corresponding "
@@ -6668,10 +6786,10 @@ msgid ""
 msgstr ""
 
 #. type: Plain text
-#: cups-lpd.8:118
+#: cups-lpd.8:116
 msgid ""
-"B<cupsd>(8), B<inetd>(8), B<launchd>(8), B<xinetd>(8), CUPS Online Help "
-"(http://localhost:631/help), RFC 2569"
+"B<cups>(1), B<cupsd>(8), B<inetd>(8), B<launchd>(8), B<xinetd>(8), CUPS "
+"Online Help (http://localhost:631/help), RFC 2569"
 msgstr ""
 
 #. type: TH
@@ -7233,7 +7351,8 @@ msgid ""
 msgstr ""
 
 #. type: Plain text
-#: cupstestppd.1:142 ppdc.1:94 ppdcfile.5:153 ppdhtml.1:39 ppdi.1:46 ppdmerge.1:39 ppdpo.1:46
+#: cupstestppd.1:142 ppdc.1:94 ppdcfile.5:153 ppdhtml.1:39 ppdi.1:46
+#: ppdmerge.1:39 ppdpo.1:46
 msgid ""
 "PPD files are deprecated and will no longer be supported in a future feature "
 "release of CUPS.  Printers that do not support IPP can be supported using "
@@ -13684,6 +13803,12 @@ msgstr ""
 msgid "ppdc"
 msgstr ""
 
+#. type: TH
+#: ppdc.1:10
+#, no-wrap
+msgid "28 October 2020"
+msgstr ""
+
 #. type: Plain text
 #: ppdc.1:13
 msgid "ppdc - cups ppd compiler (deprecated)"
@@ -13782,7 +13907,7 @@ msgstr ""
 #: ppdc.1:73
 msgid ""
 "Specifies that the output filename should be based on the ModelName value "
-"instead of FileName or PCFilenName."
+"instead of FileName or PCFileName."
 msgstr ""
 
 #. type: Plain text
diff -pruN 2.3.3-3/debian/manpage-po4a/po/de.po 2.3.3op1-3/debian/manpage-po4a/po/de.po
--- 2.3.3-3/debian/manpage-po4a/po/de.po	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/manpage-po4a/po/de.po	2020-12-04 09:32:55.000000000 +0000
@@ -1,5 +1,5 @@
 # Translation of cups man pages to German
-# Copyright (C) Helge Kreutzmann <debian@helgefjell.de>, 2008-2019
+# Copyright (C) Helge Kreutzmann <debian@helgefjell.de>, 2008-2020
 # Chris Leick <c.leick@vollbio.de>, 2009.
 # This file is distributed under the same license as the cups package.
 #
@@ -10,9 +10,9 @@
 #
 msgid ""
 msgstr ""
-"Project-Id-Version: cups man pages 2.3.1-1\n"
-"POT-Creation-Date: 2019-12-13 17:30+0100\n"
-"PO-Revision-Date: 2019-12-24 06:37+0100\n"
+"Project-Id-Version: cups man pages 2.3.3op1-2\n"
+"POT-Creation-Date: 2020-11-27 16:31+0100\n"
+"PO-Revision-Date: 2020-12-02 19:50+0100\n"
 "Last-Translator: Helge Kreutzmann <debian@helgefjell.de>\n"
 "Language-Team: de <debian-l10n-german@lists.debian.org>\n"
 "Language: de\n"
@@ -30,8 +30,8 @@ msgstr "Backend"
 #. type: TH
 #: backend.7:10 cancel.1:10 classes.conf.5:10 client.conf.5:10 cups.1:10
 #: cupsaccept.8:10 cups-config.1:10 cupsctl.8:10 cupsd.8:10 cupsd.conf.5:10
-#: cupsd-helper.8:10 cupsd-logs.5:10 cupsenable.8:10 cups-files.conf.5:10
-#: cupsfilter.8:9 cups-lpd.8:10 cups-snmp.8:9 cups-snmp.conf.5:10
+#: cupsd-helper.8:10 cupsd-logs.5:10 cupsenable.8:10 cups-files.conf.5:11
+#: cupsfilter.8:9 cups-lpd.8:11 cups-snmp.8:9 cups-snmp.conf.5:10
 #: cupstestppd.1:10 filter.7:10 ippevepcl.7:9 ippeveprinter.1:9 ipptool.1:9
 #: ipptoolfile.5:9 lp.1:10 lpadmin.8:10 lpc.8:10 lpinfo.8:10 lpmove.8:10
 #: lpoptions.1:10 lpq.1:10 lpr.1:10 lprm.1:10 lpstat.1:9 mailto.conf.5:10
@@ -45,13 +45,12 @@ msgstr "CUPS"
 #. type: TH
 #: backend.7:10 cancel.1:10 classes.conf.5:10 cups.1:10 cupsaccept.8:10
 #: cups-config.1:10 cupsctl.8:10 cupsd.8:10 cupsd-helper.8:10 cupsd-logs.5:10
-#: cupsenable.8:10 cups-files.conf.5:10 cupsfilter.8:9 cups-lpd.8:10
-#: cups-snmp.8:9 cups-snmp.conf.5:10 cupstestppd.1:10 filter.7:10 ippfind.1:9
-#: ipptool.1:9 lp.1:10 lpadmin.8:10 lpc.8:10 lpinfo.8:10 lpmove.8:10
-#: lpoptions.1:10 lpq.1:10 lpr.1:10 lprm.1:10 lpstat.1:9 mailto.conf.5:10
-#: mime.convs.5:10 mime.types.5:10 notifier.7:10 ppdc.1:10 ppdcfile.5:10
-#: ppdhtml.1:10 ppdi.1:10 ppdmerge.1:10 ppdpo.1:10 printers.conf.5:9
-#: subscriptions.conf.5:10
+#: cupsenable.8:10 cupsfilter.8:9 cups-snmp.8:9 cups-snmp.conf.5:10
+#: cupstestppd.1:10 filter.7:10 ippfind.1:9 ipptool.1:9 lp.1:10 lpadmin.8:10
+#: lpc.8:10 lpinfo.8:10 lpmove.8:10 lpoptions.1:10 lpq.1:10 lpr.1:10 lprm.1:10
+#: lpstat.1:9 mailto.conf.5:10 mime.convs.5:10 mime.types.5:10 notifier.7:10
+#: ppdcfile.5:10 ppdhtml.1:10 ppdi.1:10 ppdmerge.1:10 ppdpo.1:10
+#: printers.conf.5:9 subscriptions.conf.5:10
 #, no-wrap
 msgid "26 April 2019"
 msgstr "26. April 2019"
@@ -59,8 +58,8 @@ msgstr "26. April 2019"
 #. type: TH
 #: backend.7:10 cancel.1:10 classes.conf.5:10 client.conf.5:10 cups.1:10
 #: cupsaccept.8:10 cups-config.1:10 cupsctl.8:10 cupsd.8:10 cupsd.conf.5:10
-#: cupsd-helper.8:10 cupsd-logs.5:10 cupsenable.8:10 cups-files.conf.5:10
-#: cupsfilter.8:9 cups-lpd.8:10 cups-snmp.8:9 cups-snmp.conf.5:10
+#: cupsd-helper.8:10 cupsd-logs.5:10 cupsenable.8:10 cups-files.conf.5:11
+#: cupsfilter.8:9 cups-lpd.8:11 cups-snmp.8:9 cups-snmp.conf.5:10
 #: cupstestppd.1:10 filter.7:10 ippevepcl.7:9 ippeveprinter.1:9 ippfind.1:9
 #: ipptool.1:9 ipptoolfile.5:9 lp.1:10 lpadmin.8:10 lpc.8:10 lpinfo.8:10
 #: lpmove.8:10 lpoptions.1:10 lpq.1:10 lpr.1:10 lprm.1:10 lpstat.1:9
@@ -74,8 +73,8 @@ msgstr "Apple Inc."
 #. type: SH
 #: backend.7:11 cancel.1:11 classes.conf.5:11 client.conf.5:11 cups.1:11
 #: cupsaccept.8:11 cups-config.1:11 cupsctl.8:11 cupsd.8:11 cupsd.conf.5:11
-#: cupsd-helper.8:11 cupsd-logs.5:11 cupsenable.8:11 cups-files.conf.5:11
-#: cupsfilter.8:10 cups-lpd.8:11 cups-snmp.8:10 cups-snmp.conf.5:11
+#: cupsd-helper.8:11 cupsd-logs.5:11 cupsenable.8:11 cups-files.conf.5:12
+#: cupsfilter.8:10 cups-lpd.8:12 cups-snmp.8:10 cups-snmp.conf.5:11
 #: cupstestppd.1:11 filter.7:11 ippevepcl.7:10 ippeveprinter.1:10 ippfind.1:10
 #: ipptool.1:10 ipptoolfile.5:10 lp.1:11 lpadmin.8:11 lpc.8:11 lpinfo.8:11
 #: lpmove.8:11 lpoptions.1:11 lpq.1:11 lpr.1:11 lprm.1:11 lpstat.1:10
@@ -93,7 +92,7 @@ msgstr "backend - CUPS Backend-Übertrag
 
 #. type: SH
 #: backend.7:13 cancel.1:13 cupsaccept.8:13 cups-config.1:13 cupsctl.8:13
-#: cupsd.8:13 cupsd-helper.8:13 cupsenable.8:13 cupsfilter.8:12 cups-lpd.8:13
+#: cupsd.8:13 cupsd-helper.8:13 cupsenable.8:13 cupsfilter.8:12 cups-lpd.8:14
 #: cups-snmp.8:12 cupstestppd.1:13 filter.7:13 ippevepcl.7:12
 #: ippeveprinter.1:12 ippfind.1:12 ipptool.1:12 lp.1:13 lpadmin.8:13 lpc.8:13
 #: lpinfo.8:13 lpmove.8:13 lpoptions.1:13 lpq.1:13 lpr.1:13 lprm.1:13
@@ -183,8 +182,8 @@ msgstr ""
 #. type: SH
 #: backend.7:49 cancel.1:37 classes.conf.5:13 client.conf.5:13 cups.1:13
 #: cupsaccept.8:40 cups-config.1:49 cupsctl.8:36 cupsd.8:32 cupsd.conf.5:13
-#: cupsd-helper.8:46 cupsd-logs.5:13 cupsenable.8:46 cups-files.conf.5:13
-#: cupsfilter.8:54 cups-lpd.8:23 cups-snmp.8:23 cups-snmp.conf.5:13
+#: cupsd-helper.8:46 cupsd-logs.5:13 cupsenable.8:46 cups-files.conf.5:14
+#: cupsfilter.8:54 cups-lpd.8:24 cups-snmp.8:23 cups-snmp.conf.5:13
 #: cupstestppd.1:51 filter.7:51 ippevepcl.7:22 ippeveprinter.1:84 ippfind.1:32
 #: ipptool.1:75 ipptoolfile.5:12 lp.1:84 lpadmin.8:54 lpc.8:20 lpinfo.8:60
 #: lpmove.8:37 lpoptions.1:53 lpq.1:31 lpr.1:53 lprm.1:31 lpstat.1:65
@@ -618,7 +617,7 @@ msgstr "Die mit dem Drucker verbundene G
 
 #. type: SH
 #: backend.7:182 cups.1:114 cupsd.8:71 cupsd-helper.8:56 cupsfilter.8:110
-#: cups-lpd.8:54 cups-snmp.8:40 ipptool.1:195 lpoptions.1:104 mime.convs.5:37
+#: cups-lpd.8:55 cups-snmp.8:40 ipptool.1:195 lpoptions.1:104 mime.convs.5:37
 #: mime.types.5:87
 #, no-wrap
 msgid "FILES"
@@ -631,8 +630,8 @@ msgstr "I</etc/cups/cups-files.conf>"
 
 #. type: SH
 #: backend.7:184 backend.7:204 cancel.1:81 classes.conf.5:19 client.conf.5:126
-#: cups.1:122 cupsd.conf.5:858 cupsd-helper.8:77 cups-files.conf.5:273
-#: cupsfilter.8:117 cups-lpd.8:60 cups-snmp.8:44 cups-snmp.conf.5:58
+#: cups.1:122 cupsd.conf.5:858 cupsd-helper.8:77 cups-files.conf.5:279
+#: cupsfilter.8:117 cups-lpd.8:61 cups-snmp.8:44 cups-snmp.conf.5:58
 #: cupstestppd.1:138 filter.7:201 lpadmin.8:203 lpc.8:40 lpinfo.8:117 lpr.1:151
 #: mime.convs.5:50 ppdc.1:90 ppdcfile.5:149 ppdhtml.1:35 ppdi.1:42
 #: ppdmerge.1:35 ppdpo.1:42 printers.conf.5:16 subscriptions.conf.5:19
@@ -693,8 +692,8 @@ msgstr ""
 #. type: SH
 #: backend.7:208 cancel.1:84 classes.conf.5:21 client.conf.5:138 cups.1:126
 #: cupsaccept.8:77 cups-config.1:105 cupsctl.8:92 cupsd.8:109 cupsd.conf.5:895
-#: cupsd-helper.8:81 cupsd-logs.5:216 cupsenable.8:88 cups-files.conf.5:280
-#: cupsfilter.8:131 cups-lpd.8:111 cups-snmp.8:49 cups-snmp.conf.5:62
+#: cupsd-helper.8:81 cupsd-logs.5:216 cupsenable.8:88 cups-files.conf.5:286
+#: cupsfilter.8:131 cups-lpd.8:108 cups-snmp.8:49 cups-snmp.conf.5:62
 #: cupstestppd.1:142 filter.7:212 ippevepcl.7:45 ippeveprinter.1:268
 #: ippfind.1:255 ipptool.1:246 ipptoolfile.5:649 lp.1:219 lpadmin.8:224
 #: lpc.8:47 lpinfo.8:121 lpmove.8:66 lpoptions.1:110 lpq.1:56 lpr.1:171
@@ -722,8 +721,8 @@ msgstr "CUPS-Online-Hilfe (http://localh
 #. type: SH
 #: backend.7:219 cancel.1:90 classes.conf.5:29 client.conf.5:142 cups.1:142
 #: cupsaccept.8:85 cups-config.1:108 cupsctl.8:97 cupsd.8:125 cupsd.conf.5:904
-#: cupsd-helper.8:89 cupsd-logs.5:221 cupsenable.8:96 cups-files.conf.5:290
-#: cupsfilter.8:138 cups-lpd.8:118 cups-snmp.8:55 cups-snmp.conf.5:65
+#: cupsd-helper.8:89 cupsd-logs.5:221 cupsenable.8:96 cups-files.conf.5:296
+#: cupsfilter.8:138 cups-lpd.8:116 cups-snmp.8:55 cups-snmp.conf.5:65
 #: cupstestppd.1:146 filter.7:220 ippevepcl.7:47 ippeveprinter.1:272
 #: ippfind.1:257 ipptool.1:251 ipptoolfile.5:654 lp.1:228 lpadmin.8:230
 #: lpc.8:57 lpinfo.8:124 lpmove.8:73 lpoptions.1:117 lpq.1:63 lpr.1:180
@@ -737,14 +736,13 @@ msgstr "COPYRIGHT"
 #. type: Plain text
 #: backend.7:220 cancel.1:91 classes.conf.5:30 client.conf.5:143 cups.1:143
 #: cupsaccept.8:86 cups-config.1:109 cupsctl.8:98 cupsd.8:126 cupsd.conf.5:905
-#: cupsd-helper.8:90 cupsd-logs.5:222 cupsenable.8:97 cups-files.conf.5:291
-#: cupsfilter.8:139 cups-lpd.8:119 cups-snmp.8:56 cups-snmp.conf.5:66
-#: cupstestppd.1:147 filter.7:221 ippeveprinter.1:273 ipptool.1:252
-#: ipptoolfile.5:655 lp.1:229 lpadmin.8:231 lpc.8:58 lpinfo.8:125 lpmove.8:74
-#: lpoptions.1:118 lpq.1:64 lpr.1:181 lprm.1:82 lpstat.1:148 mailto.conf.5:44
-#: mime.convs.5:62 mime.types.5:108 notifier.7:36 ppdc.1:102 ppdcfile.5:161
-#: ppdhtml.1:47 ppdi.1:54 ppdmerge.1:50 ppdpo.1:54 printers.conf.5:28
-#: subscriptions.conf.5:31
+#: cupsd-helper.8:90 cupsd-logs.5:222 cupsenable.8:97 cupsfilter.8:139
+#: cups-snmp.8:56 cups-snmp.conf.5:66 cupstestppd.1:147 filter.7:221
+#: ippeveprinter.1:273 ipptool.1:252 ipptoolfile.5:655 lp.1:229 lpadmin.8:231
+#: lpc.8:58 lpinfo.8:125 lpmove.8:74 lpoptions.1:118 lpq.1:64 lpr.1:181
+#: lprm.1:82 lpstat.1:148 mailto.conf.5:44 mime.convs.5:62 mime.types.5:108
+#: notifier.7:36 ppdc.1:102 ppdcfile.5:161 ppdhtml.1:47 ppdi.1:54 ppdmerge.1:50
+#: ppdpo.1:54 printers.conf.5:28 subscriptions.conf.5:31
 msgid "Copyright \\[co] 2007-2019 by Apple Inc."
 msgstr "Copyright \\[co] 2007-2019 by Apple Inc."
 
@@ -782,7 +780,7 @@ msgstr ""
 
 #. type: SH
 #: cancel.1:40 cupsaccept.8:50 cups-config.1:52 cupsctl.8:40 cupsd.8:37
-#: cupsd.conf.5:485 cupsenable.8:51 cupsfilter.8:59 cups-lpd.8:32
+#: cupsd.conf.5:485 cupsenable.8:51 cupsfilter.8:59 cups-lpd.8:33
 #: cupstestppd.1:58 filter.7:60 ippeveprinter.1:87 ippfind.1:191 ipptool.1:88
 #: lp.1:94 lpadmin.8:73 lpinfo.8:63 lpmove.8:39 lpoptions.1:68 lpq.1:36
 #: lpr.1:64 lprm.1:36 lpstat.1:68 ppdc.1:48 ppdhtml.1:25 ppdi.1:30
@@ -874,7 +872,7 @@ msgstr "Löscht Auftragsdatendateien zus
 
 #. type: SH
 #: cancel.1:61 cups.1:119 cupsaccept.8:67 cupsd.8:81 cupsd.conf.5:873
-#: cupsenable.8:77 cups-lpd.8:46 cups-snmp.8:47 filter.7:199
+#: cupsenable.8:77 cups-lpd.8:47 cups-snmp.8:47 filter.7:199
 #: ippeveprinter.1:207 ipptool.1:229 lp.1:196 lpadmin.8:197 lpinfo.8:97
 #: lpoptions.1:108 lprm.1:52 lpstat.1:133
 #, no-wrap
@@ -1047,7 +1045,7 @@ msgstr ""
 "Informationen."
 
 #. type: SS
-#: client.conf.5:21 cups-files.conf.5:22 cups-snmp.conf.5:21 mailto.conf.5:20
+#: client.conf.5:21 cups-files.conf.5:23 cups-snmp.conf.5:21 mailto.conf.5:20
 #, no-wrap
 msgid "DIRECTIVES"
 msgstr "DIREKTIVEN"
@@ -3078,12 +3076,11 @@ msgstr "B<ErrorPolicy retry-job>"
 #: cupsd.conf.5:144
 msgid ""
 "Specifies that a failed print job should be retried at a later time unless "
-"otherwise specified for the printer. The 'retry-job' error policy is the "
-"default."
+"otherwise specified for the printer."
 msgstr ""
 "Legt fest, dass ein fehlgeschlagener Druckauftrag zu einem späteren "
 "Zeitpunkt neu versucht werden soll, es sei denn, es wurde anders für den "
-"Drucker festgelegt. Die Fehler-Richtlinie »retry-job« ist die Vorgabe."
+"Drucker festgelegt."
 
 #. type: TP
 #: cupsd.conf.5:144
@@ -3096,10 +3093,11 @@ msgstr "B<ErrorPolicy stop-printer>"
 #: cupsd.conf.5:148
 msgid ""
 "Specifies that a failed print job should stop the printer unless otherwise "
-"specified for the printer."
+"specified for the printer. The 'stop-printer' error policy is the default."
 msgstr ""
-"Legt fest, dass ein fehlgeschlagener Druckauftrag den Drucker anhalten soll, "
-"es sei denn, es wurde anders für den Drucker festgelegt."
+"Legt fest, dass ein fehlgeschlagener Druckauftrag den Drucker stoppen soll, "
+"außer etwas anderes wurde für den Drucker festgelegt. Die Fehler-Richtlinie "
+"»stop-printer« ist die Vorgabe."
 
 #. type: TP
 #: cupsd.conf.5:148
@@ -5288,7 +5286,7 @@ msgstr ""
 "»notify-recipient-uri«, »notify-subscriber-user-name« und »notify-user-data«."
 
 #. type: SS
-#: cupsd.conf.5:815 cups-files.conf.5:230
+#: cupsd.conf.5:815 cups-files.conf.5:236
 #, no-wrap
 msgid "DEPRECATED DIRECTIVES"
 msgstr "VERALTETE DIREKTIVEN"
@@ -6513,18 +6511,24 @@ msgstr ""
 "B<lpstat>(1), CUPS-Online-Hilfe (http://localhost:631/help)"
 
 #. type: TH
-#: cups-files.conf.5:10
+#: cups-files.conf.5:11
 #, no-wrap
 msgid "cups-files.conf"
 msgstr "cups-files.conf"
 
+#. type: TH
+#: cups-files.conf.5:11 cups-lpd.8:11
+#, no-wrap
+msgid "14 November 2020"
+msgstr "14. November 2020"
+
 #. type: Plain text
-#: cups-files.conf.5:13
+#: cups-files.conf.5:14
 msgid "cups-files.conf - file and directory configuration file for cups"
 msgstr "cups-files.conf - Datei- und Verzeichnis-Konfigurationsdatei für CUPS"
 
 #. type: Plain text
-#: cups-files.conf.5:17
+#: cups-files.conf.5:18
 msgid ""
 "The B<cups-files.conf> file configures the files and directories used by the "
 "CUPS scheduler, B<cupsd>(8).  It is normally located in the I</etc/cups> "
@@ -6535,7 +6539,7 @@ msgstr ""
 "sich normalerweise im Verzeichnis I</etc/cups>."
 
 #. type: Plain text
-#: cups-files.conf.5:22 mailto.conf.5:20
+#: cups-files.conf.5:23 mailto.conf.5:20
 msgid ""
 "Each line in the file can be a configuration directive, a blank line, or a "
 "comment.  Configuration directives typically consist of a name and zero or "
@@ -6551,36 +6555,36 @@ msgstr ""
 
 #. #AccessLog
 #. type: Plain text
-#: cups-files.conf.5:26
+#: cups-files.conf.5:27
 msgid "The following directives are understood by B<cupsd>(8):"
 msgstr "Die nachfolgenden Direktiven werden von B<cupsd>(8) verstanden:"
 
 #. type: TP
-#: cups-files.conf.5:26
+#: cups-files.conf.5:27
 #, no-wrap
 msgid "B<AccessLog>"
 msgstr "B<AccessLog>"
 
 #. type: TP
-#: cups-files.conf.5:28
+#: cups-files.conf.5:29
 #, no-wrap
 msgid "B<AccessLog >I<filename>"
 msgstr "B<AccessLog >I<Dateiname>"
 
 #. type: TP
-#: cups-files.conf.5:30
+#: cups-files.conf.5:31
 #, no-wrap
 msgid "B<AccessLog stderr>"
 msgstr "B<AccessLog stderr>"
 
 #. type: TP
-#: cups-files.conf.5:32
+#: cups-files.conf.5:33
 #, no-wrap
 msgid "B<AccessLog syslog>"
 msgstr "B<AccessLog syslog>"
 
 #. type: Plain text
-#: cups-files.conf.5:39
+#: cups-files.conf.5:40
 msgid ""
 "Defines the access log filename.  Specifying a blank filename disables "
 "access log generation.  The value \"stderr\" causes log entries to be sent "
@@ -6598,26 +6602,26 @@ msgstr ""
 "Zeichenkette »%s« kann der Servername in Dateinamen eingebettet werden, z.B.:"
 
 #. type: Plain text
-#: cups-files.conf.5:42
+#: cups-files.conf.5:43
 #, no-wrap
 msgid "    AccessLog /var/log/cups/%s-access_log\n"
 msgstr "    AccessLog /var/log/cups/%s-access_log\n"
 
 #. #CacheDir
 #. type: Plain text
-#: cups-files.conf.5:46
+#: cups-files.conf.5:47
 msgid "The default is \"/var/log/cups/access_log\"."
 msgstr "Die Vorgabe ist »/var/log/cups/access_log«."
 
 #. type: TP
-#: cups-files.conf.5:46
+#: cups-files.conf.5:47
 #, no-wrap
 msgid "B<CacheDir >I<directory>"
 msgstr "B<CacheDir >I<Verzeichnis>"
 
 #. #ConfigFilePerm
 #. type: Plain text
-#: cups-files.conf.5:51
+#: cups-files.conf.5:52
 msgid ""
 "Specifies the directory to use for long-lived temporary (cache) files.  The "
 "default is \"/var/spool/cups/cache\" or \"/var/cache/cups\" depending on the "
@@ -6628,13 +6632,13 @@ msgstr ""
 "cups«, abhängig von der Plattform."
 
 #. type: TP
-#: cups-files.conf.5:51
+#: cups-files.conf.5:52
 #, no-wrap
 msgid "B<ConfigFilePerm >I<mode>"
 msgstr "B<ConfigFilePerm >I<Modus>"
 
 #. type: Plain text
-#: cups-files.conf.5:55
+#: cups-files.conf.5:56
 msgid ""
 "Specifies the permissions for all configuration files that the scheduler "
 "writes.  The default is \"0644\" on macOS and \"0640\" on all other "
@@ -6646,7 +6650,7 @@ msgstr ""
 
 #. #CreateSelfSignedCerts
 #. type: Plain text
-#: cups-files.conf.5:60
+#: cups-files.conf.5:61
 msgid ""
 "B<Note:> The permissions for the I<printers.conf> file are currently masked "
 "to only allow access from the scheduler user (typically root).  This is done "
@@ -6662,20 +6666,20 @@ msgstr ""
 "zu deaktivieren."
 
 #. type: TP
-#: cups-files.conf.5:60
+#: cups-files.conf.5:61
 #, no-wrap
 msgid "B<CreateSelfSignedCerts yes>"
 msgstr "B<CreateSelfSignedCerts yes>"
 
 #. type: TP
-#: cups-files.conf.5:62
+#: cups-files.conf.5:63
 #, no-wrap
 msgid "B<CreateSelfSignedCerts no>"
 msgstr "B<CreateSelfSignedCerts no>"
 
 #. #DataDir
 #. type: Plain text
-#: cups-files.conf.5:67
+#: cups-files.conf.5:68
 msgid ""
 "Specifies whether the scheduler automatically creates self-signed "
 "certificates for client connections using TLS.  The default is yes."
@@ -6684,14 +6688,14 @@ msgstr ""
 "die Clientverbindungen mittels TLS erzeugt. Die Vorgabe ist »yes«."
 
 #. type: TP
-#: cups-files.conf.5:67
+#: cups-files.conf.5:68
 #, no-wrap
 msgid "B<DataDir >I<path>"
 msgstr "B<DataDir >I<Pfad>"
 
 #. #DocumentRoot
 #. type: Plain text
-#: cups-files.conf.5:72
+#: cups-files.conf.5:73
 msgid ""
 "Specifies the directory where data files can be found.  The default is "
 "usually \"/usr/share/cups\"."
@@ -6700,14 +6704,14 @@ msgstr ""
 "Vorgabe ist normalerweise »/usr/share/cups«."
 
 #. type: TP
-#: cups-files.conf.5:72
+#: cups-files.conf.5:73
 #, no-wrap
 msgid "B<DocumentRoot >I<directory>"
 msgstr "B<DocumentRoot >I<Verzeichnis>"
 
 #. #ErrorLog
 #. type: Plain text
-#: cups-files.conf.5:77
+#: cups-files.conf.5:78
 msgid ""
 "Specifies the root directory for the CUPS web interface content.  The "
 "default is usually \"/usr/share/doc/cups\"."
@@ -6716,31 +6720,31 @@ msgstr ""
 "Vorgabe ist normalerweise »/usr/share/doc/cups«."
 
 #. type: TP
-#: cups-files.conf.5:77
+#: cups-files.conf.5:78
 #, no-wrap
 msgid "B<ErrorLog>"
 msgstr "B<ErrorLog>"
 
 #. type: TP
-#: cups-files.conf.5:79
+#: cups-files.conf.5:80
 #, no-wrap
 msgid "B<ErrorLog >I<filename>"
 msgstr "B<ErrorLog >I<Dateiname>"
 
 #. type: TP
-#: cups-files.conf.5:81
+#: cups-files.conf.5:82
 #, no-wrap
 msgid "B<ErrorLog stderr>"
 msgstr "B<ErrorLog stderr>"
 
 #. type: TP
-#: cups-files.conf.5:83
+#: cups-files.conf.5:84
 #, no-wrap
 msgid "B<ErrorLog syslog>"
 msgstr "B<ErrorLog syslog>"
 
 #. type: Plain text
-#: cups-files.conf.5:90
+#: cups-files.conf.5:91
 msgid ""
 "Defines the error log filename.  Specifying a blank filename disables error "
 "log generation.  The value \"stderr\" causes log entries to be sent to the "
@@ -6759,37 +6763,37 @@ msgstr ""
 "eingebettet werden, z.B.:"
 
 #. type: Plain text
-#: cups-files.conf.5:93
+#: cups-files.conf.5:94
 #, no-wrap
 msgid "    ErrorLog /var/log/cups/%s-error_log\n"
 msgstr "    ErrorLog /var/log/cups/%s-error_log\n"
 
 #. #FatalErrors
 #. type: Plain text
-#: cups-files.conf.5:97
+#: cups-files.conf.5:98
 msgid "The default is \"/var/log/cups/error_log\"."
 msgstr "Die Vorgabe ist »/var/log/cups/error_log«."
 
 #. type: TP
-#: cups-files.conf.5:97
+#: cups-files.conf.5:98
 #, no-wrap
 msgid "B<FatalErrors none>"
 msgstr "B<FatalErrors none>"
 
 #. type: TP
-#: cups-files.conf.5:99
+#: cups-files.conf.5:100
 #, no-wrap
 msgid "B<FatalErrors all >I<-kind >[ ... I<-kind >]"
 msgstr "B<FatalErrors all >I<-Art >[ … I<-Art >]"
 
 #. type: TP
-#: cups-files.conf.5:101
+#: cups-files.conf.5:102
 #, no-wrap
 msgid "B<FatalErrors >I<kind >[ ... I<kind >]"
 msgstr "B<FatalErrors >I<Art >[ … I<Art >]"
 
 #. type: Plain text
-#: cups-files.conf.5:106
+#: cups-files.conf.5:107
 msgid ""
 "Specifies which errors are fatal, causing the scheduler to exit.  The "
 "default is \"config\".  The I<kind> strings are:"
@@ -6799,35 +6803,35 @@ msgstr ""
 "Zeichenketten sein:"
 
 #. type: TP
-#: cups-files.conf.5:107
+#: cups-files.conf.5:108
 #, no-wrap
 msgid "B<none>"
 msgstr "B<none>"
 
 #. type: Plain text
-#: cups-files.conf.5:110
+#: cups-files.conf.5:111
 msgid "No errors are fatal."
 msgstr "Keine Fehler sind fatal."
 
 #. type: TP
-#: cups-files.conf.5:110
+#: cups-files.conf.5:111
 #, no-wrap
 msgid "B<all>"
 msgstr "B<all>"
 
 #. type: Plain text
-#: cups-files.conf.5:113
+#: cups-files.conf.5:114
 msgid "All of the errors below are fatal."
 msgstr "Alle der weiter unten aufgeführten Fehler sind fatal."
 
 #. type: TP
-#: cups-files.conf.5:113
+#: cups-files.conf.5:114
 #, no-wrap
 msgid "B<browse>"
 msgstr "B<browse>"
 
 #. type: Plain text
-#: cups-files.conf.5:116
+#: cups-files.conf.5:117
 msgid ""
 "Browsing initialization errors are fatal, for example failed connections to "
 "the DNS-SD daemon."
@@ -6836,24 +6840,24 @@ msgstr ""
 "fehlgeschlagene Verbindungen zu dem DNS-SD-Daemon."
 
 #. type: TP
-#: cups-files.conf.5:116
+#: cups-files.conf.5:117
 #, no-wrap
 msgid "B<config>"
 msgstr "B<config>"
 
 #. type: Plain text
-#: cups-files.conf.5:119
+#: cups-files.conf.5:120
 msgid "Configuration file syntax errors are fatal."
 msgstr "Syntaxfehler in der Konfigurationsdatei sind fatal."
 
 #. type: TP
-#: cups-files.conf.5:119
+#: cups-files.conf.5:120
 #, no-wrap
 msgid "B<listen>"
 msgstr "B<listen>"
 
 #. type: Plain text
-#: cups-files.conf.5:122
+#: cups-files.conf.5:123
 msgid ""
 "Listen or Port errors are fatal, except for IPv6 failures on the loopback or "
 "\"any\" addresses."
@@ -6862,24 +6866,24 @@ msgstr ""
 "Fehler auf der Loopback- oder der »any«-Adresse."
 
 #. type: TP
-#: cups-files.conf.5:122
+#: cups-files.conf.5:123
 #, no-wrap
 msgid "B<log>"
 msgstr "B<log>"
 
 #. type: Plain text
-#: cups-files.conf.5:125
+#: cups-files.conf.5:126
 msgid "Log file creation or write errors are fatal."
 msgstr "Protokolldateierstellungs- oder -schreibfehler sind fatal."
 
 #. type: TP
-#: cups-files.conf.5:125
+#: cups-files.conf.5:126
 #, no-wrap
 msgid "B<permissions>"
 msgstr "B<permissions>"
 
 #. type: Plain text
-#: cups-files.conf.5:128
+#: cups-files.conf.5:129
 msgid ""
 "Bad startup file permissions are fatal, for example shared TLS certificate "
 "and key files with world-read permissions."
@@ -6889,12 +6893,11 @@ msgstr ""
 "Leserechten für alle."
 
 #. type: TP
-#: cups-files.conf.5:130
+#: cups-files.conf.5:131
 #, no-wrap
 msgid "B<Group >I<group-name-or-number>"
 msgstr "B<Group >I<Gruppenname-oder-Nummer>"
 
-#. #LogFilePerm
 #. type: Plain text
 #: cups-files.conf.5:135
 msgid ""
@@ -6907,14 +6910,31 @@ msgstr ""
 "Betriebssystem; gewöhnlich ist sie »lp« oder »nobody«."
 
 #. type: TP
-#: cups-files.conf.5:135
+#: cups-files.conf.5:137
+#, no-wrap
+msgid "B<LogFileGroup >I<group-name-or-number>"
+msgstr "B<LogFileGroup >I<Gruppenname-oder-Nummer>"
+
+#. #LogFilePerm
+#. type: Plain text
+#: cups-files.conf.5:142
+msgid ""
+"Specifies the group name or ID that will be used for log files.  The default "
+"group is operating system specific but is usually \"lp\" or \"nobody\"."
+msgstr ""
+"Legt den Gruppenname oder deren ID, die für Protokolldateien verwandt wird, "
+"fest. Die Vorgabegruppe ist abhängig vom "
+"Betriebssystem; gewöhnlich ist sie »lp« oder »nobody«."
+
+#. type: TP
+#: cups-files.conf.5:142
 #, no-wrap
 msgid "B<LogFilePerm >I<mode>"
 msgstr "B<LogFilePerm >I<Modus>"
 
 #. #PageLog
 #. type: Plain text
-#: cups-files.conf.5:140
+#: cups-files.conf.5:147
 msgid ""
 "Specifies the permissions of all log files that the scheduler writes.  The "
 "default is \"0644\"."
@@ -6923,25 +6943,25 @@ msgstr ""
 "Protokolldateien fest. Die Vorgabe ist »0644«."
 
 #. type: TP
-#: cups-files.conf.5:140
+#: cups-files.conf.5:147
 #, no-wrap
 msgid "B<PageLog >[ I<filename> ]"
 msgstr "B<PageLog >[ I<Dateiname> ]"
 
 #. type: TP
-#: cups-files.conf.5:142
+#: cups-files.conf.5:149
 #, no-wrap
 msgid "B<PageLog stderr>"
 msgstr "B<PageLog stderr>"
 
 #. type: TP
-#: cups-files.conf.5:144
+#: cups-files.conf.5:151
 #, no-wrap
 msgid "B<PageLog syslog>"
 msgstr "B<PageLog syslog>"
 
 #. type: Plain text
-#: cups-files.conf.5:151
+#: cups-files.conf.5:158
 msgid ""
 "Defines the page log filename.  The value \"stderr\" causes log entries to "
 "be sent to the standard error file when the scheduler is running in the "
@@ -6960,26 +6980,26 @@ msgstr ""
 "z.B.:"
 
 #. type: Plain text
-#: cups-files.conf.5:154
+#: cups-files.conf.5:161
 #, no-wrap
 msgid "    PageLog /var/log/cups/%s-page_log\n"
 msgstr "    PageLog /var/log/cups/%s-page_log\n"
 
 #. #PassEnv
 #. type: Plain text
-#: cups-files.conf.5:158
+#: cups-files.conf.5:165
 msgid "The default is \"/var/log/cups/page_log\"."
 msgstr "Die Vorgabe ist »/var/log/cups/page_log«."
 
 #. type: TP
-#: cups-files.conf.5:158
+#: cups-files.conf.5:165
 #, no-wrap
 msgid "B<PassEnv >I<variable >[ ... I<variable >]"
 msgstr "B<PassEnv >I<Variable >[ … I<Variable >]"
 
 #. #RemoteRoot
 #. type: Plain text
-#: cups-files.conf.5:163
+#: cups-files.conf.5:170
 msgid ""
 "Passes the specified environment variable(s) to child processes.  Note: the "
 "standard CUPS filter and backend environment variables cannot be overridden "
@@ -6990,14 +7010,14 @@ msgstr ""
 "Direktive nicht außer Kraft gesetzt werden."
 
 #. type: TP
-#: cups-files.conf.5:163
+#: cups-files.conf.5:170
 #, no-wrap
 msgid "B<RemoteRoot >I<username>"
 msgstr "B<RemoteRoot >I<Benutzername>"
 
 #. #RequestRoot
 #. type: Plain text
-#: cups-files.conf.5:168
+#: cups-files.conf.5:175
 msgid ""
 "Specifies the username that is associated with unauthenticated accesses by "
 "clients claiming to be the root user.  The default is \"remroot\"."
@@ -7007,14 +7027,14 @@ msgstr ""
 "Die Vorgabe ist »remroot«."
 
 #. type: TP
-#: cups-files.conf.5:168
+#: cups-files.conf.5:175
 #, no-wrap
 msgid "B<RequestRoot >I<directory>"
 msgstr "B<RequestRoot >I<Verzeichnis>"
 
 #. #Sandboxing
 #. type: Plain text
-#: cups-files.conf.5:173
+#: cups-files.conf.5:180
 msgid ""
 "Specifies the directory that contains print jobs and other HTTP request "
 "data.  The default is \"/var/spool/cups\"."
@@ -7023,20 +7043,20 @@ msgstr ""
 "enthalten sind, fest. Die Vorgabe ist »/var/spool/cups«."
 
 #. type: TP
-#: cups-files.conf.5:173
+#: cups-files.conf.5:180
 #, no-wrap
 msgid "B<Sandboxing relaxed>"
 msgstr "B<Sandboxing relaxed>"
 
 #. type: TP
-#: cups-files.conf.5:175
+#: cups-files.conf.5:182
 #, no-wrap
 msgid "B<Sandboxing strict>"
 msgstr "B<Sandboxing strict>"
 
 #. #ServerBin
 #. type: Plain text
-#: cups-files.conf.5:181
+#: cups-files.conf.5:188
 msgid ""
 "Specifies the level of security sandboxing that is applied to print filters, "
 "backends, and other child processes of the scheduler.  The default is "
@@ -7048,14 +7068,14 @@ msgstr ""
 "verwandt/unterstützt."
 
 #. type: TP
-#: cups-files.conf.5:181
+#: cups-files.conf.5:188
 #, no-wrap
 msgid "B<ServerBin >I<directory>"
 msgstr "B<ServerBin >I<Verzeichnis>"
 
 #. #ServerKeychain
 #. type: Plain text
-#: cups-files.conf.5:186
+#: cups-files.conf.5:193
 msgid ""
 "Specifies the directory containing the backends, CGI programs, filters, "
 "helper programs, notifiers, and port monitors.  The default is \"/usr/lib/"
@@ -7067,14 +7087,14 @@ msgstr ""
 "Plattform."
 
 #. type: TP
-#: cups-files.conf.5:186
+#: cups-files.conf.5:193
 #, no-wrap
 msgid "B<ServerKeychain >I<path>"
 msgstr "B<ServerKeychain >I<Pfad>"
 
 #. #ServerRoot
 #. type: Plain text
-#: cups-files.conf.5:192
+#: cups-files.conf.5:199
 msgid ""
 "Specifies the location of TLS certificates and private keys.  The default is "
 "\"/Library/Keychains/System.keychain\" on macOS and \"/etc/cups/ssl\" on all "
@@ -7091,14 +7111,14 @@ msgstr ""
 "Zertifikate und *.key für PEM-kodierte private Schlüssel verwenden."
 
 #. type: TP
-#: cups-files.conf.5:192
+#: cups-files.conf.5:199
 #, no-wrap
 msgid "B<ServerRoot >I<directory>"
 msgstr "B<ServerRoot >I<Verzeichnis>"
 
 #. #SetEnv
 #. type: Plain text
-#: cups-files.conf.5:197
+#: cups-files.conf.5:204
 msgid ""
 "Specifies the directory containing the server configuration files.  The "
 "default is \"/etc/cups\"."
@@ -7107,14 +7127,14 @@ msgstr ""
 "Die Vorgabe ist »/etc/cups«."
 
 #. type: TP
-#: cups-files.conf.5:197
+#: cups-files.conf.5:204
 #, no-wrap
 msgid "B<SetEnv >I<variable value>"
 msgstr "B<SetEnv >I<Variable Wert>"
 
 #. #StateDir
 #. type: Plain text
-#: cups-files.conf.5:202
+#: cups-files.conf.5:209
 msgid ""
 "Set the specified environment variable to be passed to child processes.  "
 "Note: the standard CUPS filter and backend environment variables cannot be "
@@ -7126,14 +7146,14 @@ msgstr ""
 "werden."
 
 #. type: TP
-#: cups-files.conf.5:202
+#: cups-files.conf.5:209
 #, no-wrap
 msgid "B<StateDir >I<directory>"
 msgstr "B<StateDir >I<Verzeichnis>"
 
 #. #SyncOnClose
 #. type: Plain text
-#: cups-files.conf.5:207
+#: cups-files.conf.5:214
 msgid ""
 "Specifies the directory to use for PID and local certificate files.  The "
 "default is \"/var/run/cups\" or \"/etc/cups\" depending on the platform."
@@ -7143,36 +7163,36 @@ msgstr ""
 "Plattform."
 
 #. type: TP
-#: cups-files.conf.5:207
+#: cups-files.conf.5:214
 #, no-wrap
 msgid "B<SyncOnClose Yes>"
 msgstr "B<SyncOnClose Yes>"
 
 #. type: TP
-#: cups-files.conf.5:209
+#: cups-files.conf.5:216
 #, no-wrap
 msgid "B<SyncOnClose No>"
 msgstr "B<SyncOnClose No>"
 
 #. #SystemGroup
 #. type: Plain text
-#: cups-files.conf.5:216
+#: cups-files.conf.5:222
 msgid ""
 "Specifies whether the scheduler calls B<fsync>(2)  after writing "
-"configuration or state files.  The default is \"Yes\"."
+"configuration or state files."
 msgstr ""
 "Legt fest, ob der Auftragsplaner nach dem Schreiben der Konfigurations- oder "
-"Zustandsdateien B<fsync>(2) aufruft. Die Vorgabe ist »Yes«."
+"Zustandsdateien B<fsync>(2) aufruft."
 
 #. type: TP
-#: cups-files.conf.5:216
+#: cups-files.conf.5:222
 #, no-wrap
 msgid "B<SystemGroup >I<group-name >[ ... I<group-name> ]"
 msgstr "B<SystemGroup >I<Gruppenname >[ … I<Gruppenname> ]"
 
 #. #TempDir
 #. type: Plain text
-#: cups-files.conf.5:221
+#: cups-files.conf.5:227
 msgid ""
 "Specifies the group(s) to use for I<@SYSTEM> group authentication.  The "
 "default contains \"admin\", \"lpadmin\", \"root\", \"sys\", and/or \"system"
@@ -7183,14 +7203,14 @@ msgstr ""
 "»system«."
 
 #. type: TP
-#: cups-files.conf.5:221
+#: cups-files.conf.5:227
 #, no-wrap
 msgid "B<TempDir >I<directory>"
 msgstr "B<TempDir >I<Verzeichnis>"
 
 #. #User
 #. type: Plain text
-#: cups-files.conf.5:226
+#: cups-files.conf.5:232
 msgid ""
 "Specifies the directory where short-term temporary files are stored.  The "
 "default is \"/var/spool/cups/tmp\"."
@@ -7199,13 +7219,13 @@ msgstr ""
 "werden, fest. Die Vorgabe ist »/var/spool/cups/tmp«."
 
 #. type: TP
-#: cups-files.conf.5:226
+#: cups-files.conf.5:232
 #, no-wrap
 msgid "B<User >I<username>"
 msgstr "B<User >I<Benutzername>"
 
 #. type: Plain text
-#: cups-files.conf.5:230
+#: cups-files.conf.5:236
 msgid ""
 "Specifies the user name or ID that is used when running external programs.  "
 "The default is \"lp\"."
@@ -7215,7 +7235,7 @@ msgstr ""
 
 #. #FileDevice
 #. type: Plain text
-#: cups-files.conf.5:233
+#: cups-files.conf.5:239
 msgid ""
 "The following directives are deprecated and will be removed from a future "
 "version of CUPS:"
@@ -7224,20 +7244,20 @@ msgstr ""
 "Version von CUPS entfernt werden>:"
 
 #. type: TP
-#: cups-files.conf.5:233
+#: cups-files.conf.5:239
 #, no-wrap
 msgid "B<FileDevice Yes>"
 msgstr "B<FileDevice Yes>"
 
 #. type: TP
-#: cups-files.conf.5:235
+#: cups-files.conf.5:241
 #, no-wrap
 msgid "B<FileDevice No>"
 msgstr "B<FileDevice No>"
 
 #. #FontPath
 #. type: Plain text
-#: cups-files.conf.5:243
+#: cups-files.conf.5:249
 msgid ""
 "Specifies whether the file pseudo-device can be used for new printer "
 "queues.  The URI \"file:///dev/null\" is always allowed.  File devices "
@@ -7252,14 +7272,14 @@ msgstr ""
 "Schreiben in Verzeichnisse wird nicht unterstützt."
 
 #. type: TP
-#: cups-files.conf.5:243
+#: cups-files.conf.5:249
 #, no-wrap
 msgid "B<FontPath >I<directory[:...:directoryN]>"
 msgstr "B<FontPath >I<Verzeichnis[:…:VerzeichnisN]>"
 
 #. #LPDConfigFile
 #. type: Plain text
-#: cups-files.conf.5:251
+#: cups-files.conf.5:257
 msgid ""
 "Specifies a colon separated list of directories where fonts can be found.  "
 "On Linux the B<font-config>(1)  mechanism is used instead.  On macOS the "
@@ -7271,52 +7291,52 @@ msgstr ""
 "Font Book die systemweit installierten Schriften."
 
 #. type: TP
-#: cups-files.conf.5:251
+#: cups-files.conf.5:257
 #, no-wrap
 msgid " B<LPDConfigFile >I<filename>"
 msgstr " B<LPDConfigFile >I<Dateiname>"
 
 #. #Printcap
 #. type: Plain text
-#: cups-files.conf.5:255
+#: cups-files.conf.5:261
 msgid "Specifies the LPD service configuration file to update."
 msgstr "Gibt die zu aktualisierende LPD-Dienstekonfigurationsdatei an."
 
 #. type: TP
-#: cups-files.conf.5:255
+#: cups-files.conf.5:261
 #, no-wrap
 msgid "B<Printcap >I<filename>"
 msgstr "B<Printcap >I<Dateiname>"
 
 #. #PrintcapFormat
 #. type: Plain text
-#: cups-files.conf.5:259
+#: cups-files.conf.5:265
 msgid "Specifies a file that is filled with a list of local print queues."
 msgstr ""
 "Gibt eine Datei an, die mit einer Liste von lokalen Druckerwarteschlangen "
 "gefüllt werden soll."
 
 #. type: TP
-#: cups-files.conf.5:259
+#: cups-files.conf.5:265
 #, no-wrap
 msgid "B<PrintcapFormat bsd>"
 msgstr "B<PrintcapFormat bsd>"
 
 #. type: TP
-#: cups-files.conf.5:261
+#: cups-files.conf.5:267
 #, no-wrap
 msgid "B<PrintcapFormat plist>"
 msgstr "B<PrintcapFormat plist>"
 
 #. type: TP
-#: cups-files.conf.5:263
+#: cups-files.conf.5:269
 #, no-wrap
 msgid "B<PrintcapFormat solaris>"
 msgstr "B<PrintcapFormat solaris>"
 
 #. #SMBConfigFile
 #. type: Plain text
-#: cups-files.conf.5:270
+#: cups-files.conf.5:276
 msgid ""
 "Specifies the format to use for the Printcap file.  \"bsd\" is the "
 "historical LPD printcap file format.  \"plist\" is the Apple plist file "
@@ -7327,18 +7347,18 @@ msgstr ""
 "Dateiformat. »solaris« ist das historische Solaris-LPD-Printcap-Dateiformat."
 
 #. type: TP
-#: cups-files.conf.5:270
+#: cups-files.conf.5:276
 #, no-wrap
 msgid "B<SMBConfigFile >I<filename>"
 msgstr "B<SMBConfigFile >I<Dateiname>"
 
 #. type: Plain text
-#: cups-files.conf.5:273
+#: cups-files.conf.5:279
 msgid "Specifies the SMB service configuration file to update."
 msgstr "Gibt die zu aktualisierende SMB-Dienstekonfigurationsdatei an."
 
 #. type: Plain text
-#: cups-files.conf.5:280
+#: cups-files.conf.5:286
 msgid ""
 "The scheduler MUST be restarted manually after making changes to the B<cups-"
 "files.conf> file.  On Linux this is typically done using the "
@@ -7351,7 +7371,7 @@ msgstr ""
 "Befehl B<launchctl>(8) verwandt wird."
 
 #. type: Plain text
-#: cups-files.conf.5:290
+#: cups-files.conf.5:296
 msgid ""
 "B<classes.conf>(5), B<cups>(1), B<cupsd>(8), B<cupsd.conf>(5), B<mime."
 "convs>(5), B<mime.types>(5), B<printers.conf>(5), B<subscriptions.conf>(5), "
@@ -7361,6 +7381,15 @@ msgstr ""
 "convs>(5), B<mime.types>(5), B<printers.conf>(5), B<subscriptions.conf>(5), "
 "CUPS-Online-Hilfe (http://localhost:631/help)"
 
+#. type: Plain text
+#: cups-files.conf.5:298 cups-lpd.8:118
+msgid ""
+"Copyright \\[co] 2020 by Michael R Sweet Copyright \\[co] 2007-2019 by Apple "
+"Inc."
+msgstr ""
+"Copyright \\[co] 2020 Michael R Sweet Copyright \\[co] 2007-2019 Apple "
+"Inc."
+
 #. type: TH
 #: cupsfilter.8:9
 #, no-wrap
@@ -7529,7 +7558,7 @@ msgid "Specifies the number of copies to
 msgstr "Legt die Anzahl der zu erstellenden Kopien fest."
 
 #. type: TP
-#: cupsfilter.8:90 cups-lpd.8:41
+#: cupsfilter.8:90 cups-lpd.8:42
 #, no-wrap
 msgid "B<-o >I<name=value>"
 msgstr "B<-o >I<Name=Wert>"
@@ -7629,7 +7658,7 @@ msgstr ""
 "zu anderer Ausgabe oder unerwartetem Verhalten führen."
 
 #. type: SH
-#: cupsfilter.8:125 cups-lpd.8:86 lpadmin.8:217
+#: cupsfilter.8:125 cups-lpd.8:87 lpadmin.8:217
 #, no-wrap
 msgid "EXAMPLE"
 msgstr "BEISPIEL"
@@ -7660,13 +7689,13 @@ msgstr ""
 "types>(7), CUPS-Online-Hilfe (http://localhost:631/help)"
 
 #. type: TH
-#: cups-lpd.8:10
+#: cups-lpd.8:11
 #, no-wrap
 msgid "cups-lpd"
 msgstr "cups-lpd"
 
 #. type: Plain text
-#: cups-lpd.8:13
+#: cups-lpd.8:14
 msgid ""
 "cups-lpd - receive print jobs and report printer status to lpd clients "
 "(deprecated)"
@@ -7675,7 +7704,7 @@ msgstr ""
 "Clients (veraltet)"
 
 #. type: Plain text
-#: cups-lpd.8:23
+#: cups-lpd.8:24
 msgid ""
 "B<cups-lpd> [ B<-h >I<hostname>[B<:>I<port>] ] [ B<-n> ] [ B<-o> "
 "I<option=value> ]"
@@ -7684,7 +7713,7 @@ msgstr ""
 "I<Option=Wert> ]"
 
 #. type: Plain text
-#: cups-lpd.8:32
+#: cups-lpd.8:33
 msgid ""
 "B<cups-lpd> is the CUPS Line Printer Daemon (\"LPD\") mini-server that "
 "supports legacy client systems that use the LPD protocol.  B<cups-lpd> does "
@@ -7698,24 +7727,24 @@ msgstr ""
 "der Internet-»Super-Server« wie B<inetd>(8), B<launchd>(8) und B<systemd>(8)."
 
 #. type: TP
-#: cups-lpd.8:33 lp.1:112
+#: cups-lpd.8:34 lp.1:112
 #, no-wrap
 msgid "B<-h >I<hostname>[B<:>I<port>]"
 msgstr "B<-h >I<Hostname>[B<:>I<Port>]"
 
 #. type: Plain text
-#: cups-lpd.8:36
+#: cups-lpd.8:37
 msgid "Sets the CUPS server (and port) to use."
 msgstr "Setzt den zu benutzenden CUPS-Server (und Port)."
 
 #. type: TP
-#: cups-lpd.8:36
+#: cups-lpd.8:37
 #, no-wrap
 msgid "B<-n>"
 msgstr "B<-n>"
 
 #. type: Plain text
-#: cups-lpd.8:41
+#: cups-lpd.8:42
 msgid ""
 "Disables reverse address lookups; normally B<cups-lpd> will try to discover "
 "the hostname of the client via a reverse DNS lookup."
@@ -7725,7 +7754,7 @@ msgstr ""
 "ermitteln."
 
 #. type: Plain text
-#: cups-lpd.8:46
+#: cups-lpd.8:47
 msgid ""
 "Inserts options for all print queues. Most often this is used to disable the "
 "\"l\" filter so that remote print jobs are filtered as needed for printing; "
@@ -7741,7 +7770,7 @@ msgstr ""
 "wird."
 
 #. type: Plain text
-#: cups-lpd.8:50
+#: cups-lpd.8:51
 msgid ""
 "B<cups-lpd> does not enforce the restricted source port number specified in "
 "RFC 1179, as using restricted ports does not prevent users from submitting "
@@ -7755,7 +7784,7 @@ msgstr ""
 "normalen Betrieb von Clients nicht betreffen."
 
 #. type: Plain text
-#: cups-lpd.8:52
+#: cups-lpd.8:53
 msgid ""
 "The output of the status requests follows RFC 2569, Mapping between LPD and "
 "IPP Protocols. Since many LPD implementations stray from this definition, "
@@ -7767,18 +7796,18 @@ msgstr ""
 "sein."
 
 #. type: SH
-#: cups-lpd.8:52
+#: cups-lpd.8:53
 #, no-wrap
 msgid "ERRORS"
 msgstr "FEHLER"
 
 #. type: Plain text
-#: cups-lpd.8:54
+#: cups-lpd.8:55
 msgid "Errors are sent to the system log."
 msgstr "Fehler werden an das Systemprotokolliersystem gesandt."
 
 #. type: Plain text
-#: cups-lpd.8:59
+#: cups-lpd.8:60
 #, no-wrap
 msgid ""
 "I</etc/inetd.conf>\n"
@@ -7790,7 +7819,7 @@ msgstr ""
 "I</System/Library/LaunchDaemons/org.cups.cups-lpd.plist>\n"
 
 #. type: Plain text
-#: cups-lpd.8:64
+#: cups-lpd.8:65
 msgid ""
 "The B<cups-lpd> program is deprecated and will no longer be supported in a "
 "future feature release of CUPS."
@@ -7799,13 +7828,13 @@ msgstr ""
 "Veröffentlichung von CUPS nicht mehr unterstützt werden."
 
 #. type: SS
-#: cups-lpd.8:64
+#: cups-lpd.8:65
 #, no-wrap
 msgid "PERFORMANCE"
 msgstr "DURCHSATZ"
 
 #. type: Plain text
-#: cups-lpd.8:69
+#: cups-lpd.8:70
 msgid ""
 "B<cups-lpd> performs well with small numbers of clients and printers.  "
 "However, since a new process is created for each connection and since each "
@@ -7821,13 +7850,13 @@ msgstr ""
 "verwenden."
 
 #. type: SS
-#: cups-lpd.8:69
+#: cups-lpd.8:70
 #, no-wrap
 msgid "SECURITY"
 msgstr "SICHERHEIT"
 
 #. type: Plain text
-#: cups-lpd.8:76
+#: cups-lpd.8:77
 msgid ""
 "B<cups-lpd> currently does not perform any access control based on the "
 "settings in I<cupsd.conf(5)> or in the I<hosts.allow(5)> or I<hosts.deny(5)> "
@@ -7842,7 +7871,7 @@ msgstr ""
 "möglicherweise allen im Internet) erlauben, auf Ihrem Server zu drucken."
 
 #. type: Plain text
-#: cups-lpd.8:82
+#: cups-lpd.8:83
 msgid ""
 "While B<xinetd>(8)  has built-in access control support, you should use the "
 "TCP wrappers package with B<inetd>(8)  to limit access to only those "
@@ -7854,7 +7883,7 @@ msgstr ""
 "drucken."
 
 #. type: Plain text
-#: cups-lpd.8:86
+#: cups-lpd.8:87
 msgid ""
 "B<cups-lpd> is not enabled by the standard CUPS distribution.  Please "
 "consult with your operating system vendor to determine whether it is enabled "
@@ -7865,7 +7894,7 @@ msgstr ""
 "standardmäßig aktiviert ist oder nicht."
 
 #. type: Plain text
-#: cups-lpd.8:92
+#: cups-lpd.8:93
 msgid ""
 "If you are using B<inetd>(8), add the following line to the I<inetd.conf> "
 "file to enable the B<cups-lpd> mini-server:"
@@ -7874,7 +7903,7 @@ msgstr ""
 "I<inetd.conf> hinzu, um den B<cups-lpd>-Miniserver zu aktivieren:"
 
 #. type: Plain text
-#: cups-lpd.8:96
+#: cups-lpd.8:97
 #, no-wrap
 msgid ""
 "    printer stream tcp nowait lp /usr/lib/cups/daemon/cups-lpd cups-lpd \\e\n"
@@ -7884,17 +7913,7 @@ msgstr ""
 "        -o document-format=application/octet-stream\n"
 
 #. type: Plain text
-#: cups-lpd.8:102
-msgid ""
-"I<Note:> If you are using Solaris 10 or higher, you must run the "
-"B<inetdconv>(1m)  program to register the changes to the I<inetd.conf> file."
-msgstr ""
-"I<Hinweis:> Falls Sie Solaris 10 oder höher betreiben, müssen Sie das "
-"Programm B<inetdconv>(1m) ausführen, um die Änderungen an der Datei I<inetd."
-"conf> zu registrieren."
-
-#. type: Plain text
-#: cups-lpd.8:111
+#: cups-lpd.8:108
 msgid ""
 "CUPS includes configuration files for B<launchd>(8), B<systemd>(8), and "
 "B<xinetd>(8).  Simply enable the B<cups-lpd> service using the corresponding "
@@ -7905,13 +7924,13 @@ msgstr ""
 "korrespondierenden Steuerungsprogramms."
 
 #. type: Plain text
-#: cups-lpd.8:118
+#: cups-lpd.8:116
 msgid ""
-"B<cupsd>(8), B<inetd>(8), B<launchd>(8), B<xinetd>(8), CUPS Online Help "
-"(http://localhost:631/help), RFC 2569"
+"B<cups>(1), B<cupsd>(8), B<inetd>(8), B<launchd>(8), B<xinetd>(8), CUPS "
+"Online Help (http://localhost:631/help), RFC 2569"
 msgstr ""
-"B<cupsd>(8), B<inetd>(8), B<launchd>(8), B<xinetd>(8), CUPS-Online-Hilfe "
-"(http://localhost:631/help), RFC 2569"
+"B<cups>(1), B<cupsd>(8), B<inetd>(8), B<launchd>(8), B<xinetd>(8), CUPS-"
+"Online-Hilfe (http://localhost:631/help), RFC 2569"
 
 #. type: TH
 #: cups-snmp.8:9
@@ -9439,14 +9458,14 @@ msgid ""
 "v[vvv]> ] I<service-name>"
 msgstr ""
 "B<ippeveprinter> [ B<--help> ] [ B<--no-web-forms> ] [ B<--pam-service> "
-"I<Dienst> ][ B<--version> ] "
-"[ B<-2> ]  [ B<-A> ] [ B<-D> I<Geräte-URI> ] [ B<-F> I<Ausgabetyp/-untertyp> ] [ B<-K> "
-"I<Schlüsselpfad> ] [ B<-M> I<Hersteller> ] [ B<-P> I<Dateiname.ppd> ] [ B<-"
-"V> I<IPP-Version> ] [ B<-a> I<Dateiname.conf> ] [ B<-c> I<Befehl> ] [ B<-d> "
-"I<Spool-Verzeichnis> ] [ B<-f> I<Typ/Untertyp[,…]> ] [ B<-i> I<Icon-Datei."
-"png> ] [ B<-k> ] [ B<-l> I<Ort> ] [ B<-m> I<Modell> ] [ B<-n> "
-"I<Rechnername> ] [ B<-p> I<Port> ] [ B<-r> I<Untertyp[,Untertyp]> ] [ B<-s> "
-"I<Geschwindigkeit[,Farbgeschwindigkeit]> ] [ B<-v[vvv]> ] I<Dienstename>"
+"I<Dienst> ][ B<--version> ] [ B<-2> ]  [ B<-A> ] [ B<-D> I<Geräte-URI> ] "
+"[ B<-F> I<Ausgabetyp/-untertyp> ] [ B<-K> I<Schlüsselpfad> ] [ B<-M> "
+"I<Hersteller> ] [ B<-P> I<Dateiname.ppd> ] [ B<-V> I<IPP-Version> ] [ B<-a> "
+"I<Dateiname.conf> ] [ B<-c> I<Befehl> ] [ B<-d> I<Spool-Verzeichnis> ] [ B<-"
+"f> I<Typ/Untertyp[,…]> ] [ B<-i> I<Icon-Datei.png> ] [ B<-k> ] [ B<-l> "
+"I<Ort> ] [ B<-m> I<Modell> ] [ B<-n> I<Rechnername> ] [ B<-p> I<Port> ] [ B<-"
+"r> I<Untertyp[,Untertyp]> ] [ B<-s> I<Geschwindigkeit[,"
+"Farbgeschwindigkeit]> ] [ B<-v[vvv]> ] I<Dienstename>"
 
 #. type: Plain text
 #: ippeveprinter.1:87
@@ -9494,8 +9513,7 @@ msgstr "B<--pam-service >I<Dienst>"
 #. type: Plain text
 #: ippeveprinter.1:100
 msgid "Set the PAM service name.  The default service is \"cups\"."
-msgstr ""
-"Legt den PAM-Dienstenamen fest. Der Vorgabedienst ist »cups«."
+msgstr "Legt den PAM-Dienstenamen fest. Der Vorgabedienst ist »cups«."
 
 #. type: Plain text
 #: ippeveprinter.1:103
@@ -16311,6 +16329,12 @@ msgstr ""
 msgid "ppdc"
 msgstr "ppdc"
 
+#. type: TH
+#: ppdc.1:10
+#, no-wrap
+msgid "28 October 2020"
+msgstr "28. Oktober 2020"
+
 #. type: Plain text
 #: ppdc.1:13
 msgid "ppdc - cups ppd compiler (deprecated)"
@@ -16431,10 +16455,10 @@ msgstr ""
 #: ppdc.1:73
 msgid ""
 "Specifies that the output filename should be based on the ModelName value "
-"instead of FileName or PCFilenName."
+"instead of FileName or PCFileName."
 msgstr ""
 "Legt fest, dass der Ausgabename auf dem Wert von ModelName statt von "
-"FileName oder PCFilenName basieren soll."
+"FileName oder PCFileName basieren soll."
 
 #. type: Plain text
 #: ppdc.1:76
@@ -17259,6 +17283,22 @@ msgstr ""
 "B<mime.convs>(5), B<mime.types>(5), B<printers.conf>(5), CUPS-Online-Hilfe "
 "(http://localhost:631/help)"
 
+#~ msgid ""
+#~ "Specifies that a failed print job should stop the printer unless "
+#~ "otherwise specified for the printer."
+#~ msgstr ""
+#~ "Legt fest, dass ein fehlgeschlagener Druckauftrag den Drucker anhalten "
+#~ "soll, es sei denn, es wurde anders für den Drucker festgelegt."
+
+#~ msgid ""
+#~ "I<Note:> If you are using Solaris 10 or higher, you must run the "
+#~ "B<inetdconv>(1m)  program to register the changes to the I<inetd.conf> "
+#~ "file."
+#~ msgstr ""
+#~ "I<Hinweis:> Falls Sie Solaris 10 oder höher betreiben, müssen Sie das "
+#~ "Programm B<inetdconv>(1m) ausführen, um die Änderungen an der Datei "
+#~ "I<inetd.conf> zu registrieren."
+
 #~ msgid "17 May 2019"
 #~ msgstr "17. Mai 2019"
 
@@ -17993,14 +18033,6 @@ msgstr ""
 #~ msgid "Sets a job option."
 #~ msgstr "Setzt eine Auftrags-Option."
 
-#~ msgid ""
-#~ "Specifies that a failed print job should be retried at a later time "
-#~ "unless otherwise specified for the printer."
-#~ msgstr ""
-#~ "Legt fest, dass ein fehlgeschlagener Druckauftrag zu einem späteren "
-#~ "Zeitpunkt neu versucht werden soll, es sei denn, es wurde anders für den "
-#~ "Drucker festgelegt."
-
 #~ msgid "8 July 2014"
 #~ msgstr "8. Juli 2014"
 
@@ -18255,10 +18287,6 @@ msgstr ""
 #~ msgstr ""
 #~ "Es sollte leichter sein, den kompletten Windows-Treibersatz zu bekommen."
 
-# type: TH
-#~ msgid "23 October 2008"
-#~ msgstr "23. Oktober 2008"
-
 #~ msgid "11 January 2013"
 #~ msgstr "11. Januar 2013"
 
@@ -18843,9 +18871,6 @@ msgstr ""
 #~ msgid "LIMITATIONS"
 #~ msgstr "EINSCHRÄNKUNGEN"
 
-#~ msgid "19 November 2009"
-#~ msgstr "19. November 2009"
-
 #~ msgid "-q"
 #~ msgstr "-q"
 
diff -pruN 2.3.3-3/debian/manpage-po4a/po/fr.po 2.3.3op1-3/debian/manpage-po4a/po/fr.po
--- 2.3.3-3/debian/manpage-po4a/po/fr.po	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/manpage-po4a/po/fr.po	2020-12-04 09:32:55.000000000 +0000
@@ -10,7 +10,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: cups-2.0.3-6\n"
-"POT-Creation-Date: 2019-12-13 17:30+0100\n"
+"POT-Creation-Date: 2020-11-27 16:31+0100\n"
 "PO-Revision-Date: 2018-04-25 11:57+0200\n"
 "Last-Translator: Jean-Paul Guillonneau <guillonneau.jeanpaul@free.fr>\n"
 "Language-Team: French <debian-l10n-french@lists.debian.org>\n"
@@ -30,8 +30,8 @@ msgstr "backend"
 #. type: TH
 #: backend.7:10 cancel.1:10 classes.conf.5:10 client.conf.5:10 cups.1:10
 #: cupsaccept.8:10 cups-config.1:10 cupsctl.8:10 cupsd.8:10 cupsd.conf.5:10
-#: cupsd-helper.8:10 cupsd-logs.5:10 cupsenable.8:10 cups-files.conf.5:10
-#: cupsfilter.8:9 cups-lpd.8:10 cups-snmp.8:9 cups-snmp.conf.5:10
+#: cupsd-helper.8:10 cupsd-logs.5:10 cupsenable.8:10 cups-files.conf.5:11
+#: cupsfilter.8:9 cups-lpd.8:11 cups-snmp.8:9 cups-snmp.conf.5:10
 #: cupstestppd.1:10 filter.7:10 ippevepcl.7:9 ippeveprinter.1:9 ipptool.1:9
 #: ipptoolfile.5:9 lp.1:10 lpadmin.8:10 lpc.8:10 lpinfo.8:10 lpmove.8:10
 #: lpoptions.1:10 lpq.1:10 lpr.1:10 lprm.1:10 lpstat.1:9 mailto.conf.5:10
@@ -46,13 +46,12 @@ msgstr "CUPS"
 #. type: TH
 #: backend.7:10 cancel.1:10 classes.conf.5:10 cups.1:10 cupsaccept.8:10
 #: cups-config.1:10 cupsctl.8:10 cupsd.8:10 cupsd-helper.8:10 cupsd-logs.5:10
-#: cupsenable.8:10 cups-files.conf.5:10 cupsfilter.8:9 cups-lpd.8:10
-#: cups-snmp.8:9 cups-snmp.conf.5:10 cupstestppd.1:10 filter.7:10 ippfind.1:9
-#: ipptool.1:9 lp.1:10 lpadmin.8:10 lpc.8:10 lpinfo.8:10 lpmove.8:10
-#: lpoptions.1:10 lpq.1:10 lpr.1:10 lprm.1:10 lpstat.1:9 mailto.conf.5:10
-#: mime.convs.5:10 mime.types.5:10 notifier.7:10 ppdc.1:10 ppdcfile.5:10
-#: ppdhtml.1:10 ppdi.1:10 ppdmerge.1:10 ppdpo.1:10 printers.conf.5:9
-#: subscriptions.conf.5:10
+#: cupsenable.8:10 cupsfilter.8:9 cups-snmp.8:9 cups-snmp.conf.5:10
+#: cupstestppd.1:10 filter.7:10 ippfind.1:9 ipptool.1:9 lp.1:10 lpadmin.8:10
+#: lpc.8:10 lpinfo.8:10 lpmove.8:10 lpoptions.1:10 lpq.1:10 lpr.1:10 lprm.1:10
+#: lpstat.1:9 mailto.conf.5:10 mime.convs.5:10 mime.types.5:10 notifier.7:10
+#: ppdcfile.5:10 ppdhtml.1:10 ppdi.1:10 ppdmerge.1:10 ppdpo.1:10
+#: printers.conf.5:9 subscriptions.conf.5:10
 #, no-wrap
 msgid "26 April 2019"
 msgstr "26 avril 2019"
@@ -61,8 +60,8 @@ msgstr "26 avril 2019"
 #. type: TH
 #: backend.7:10 cancel.1:10 classes.conf.5:10 client.conf.5:10 cups.1:10
 #: cupsaccept.8:10 cups-config.1:10 cupsctl.8:10 cupsd.8:10 cupsd.conf.5:10
-#: cupsd-helper.8:10 cupsd-logs.5:10 cupsenable.8:10 cups-files.conf.5:10
-#: cupsfilter.8:9 cups-lpd.8:10 cups-snmp.8:9 cups-snmp.conf.5:10
+#: cupsd-helper.8:10 cupsd-logs.5:10 cupsenable.8:10 cups-files.conf.5:11
+#: cupsfilter.8:9 cups-lpd.8:11 cups-snmp.8:9 cups-snmp.conf.5:10
 #: cupstestppd.1:10 filter.7:10 ippevepcl.7:9 ippeveprinter.1:9 ippfind.1:9
 #: ipptool.1:9 ipptoolfile.5:9 lp.1:10 lpadmin.8:10 lpc.8:10 lpinfo.8:10
 #: lpmove.8:10 lpoptions.1:10 lpq.1:10 lpr.1:10 lprm.1:10 lpstat.1:9
@@ -77,8 +76,8 @@ msgstr "Apple Inc."
 #. type: SH
 #: backend.7:11 cancel.1:11 classes.conf.5:11 client.conf.5:11 cups.1:11
 #: cupsaccept.8:11 cups-config.1:11 cupsctl.8:11 cupsd.8:11 cupsd.conf.5:11
-#: cupsd-helper.8:11 cupsd-logs.5:11 cupsenable.8:11 cups-files.conf.5:11
-#: cupsfilter.8:10 cups-lpd.8:11 cups-snmp.8:10 cups-snmp.conf.5:11
+#: cupsd-helper.8:11 cupsd-logs.5:11 cupsenable.8:11 cups-files.conf.5:12
+#: cupsfilter.8:10 cups-lpd.8:12 cups-snmp.8:10 cups-snmp.conf.5:11
 #: cupstestppd.1:11 filter.7:11 ippevepcl.7:10 ippeveprinter.1:10 ippfind.1:10
 #: ipptool.1:10 ipptoolfile.5:10 lp.1:11 lpadmin.8:11 lpc.8:11 lpinfo.8:11
 #: lpmove.8:11 lpoptions.1:11 lpq.1:11 lpr.1:11 lprm.1:11 lpstat.1:10
@@ -98,7 +97,7 @@ msgstr "backend - Programme de transmiss
 # type: SH
 #. type: SH
 #: backend.7:13 cancel.1:13 cupsaccept.8:13 cups-config.1:13 cupsctl.8:13
-#: cupsd.8:13 cupsd-helper.8:13 cupsenable.8:13 cupsfilter.8:12 cups-lpd.8:13
+#: cupsd.8:13 cupsd-helper.8:13 cupsenable.8:13 cupsfilter.8:12 cups-lpd.8:14
 #: cups-snmp.8:12 cupstestppd.1:13 filter.7:13 ippevepcl.7:12
 #: ippeveprinter.1:12 ippfind.1:12 ipptool.1:12 lp.1:13 lpadmin.8:13 lpc.8:13
 #: lpinfo.8:13 lpmove.8:13 lpoptions.1:13 lpq.1:13 lpr.1:13 lprm.1:13
@@ -191,8 +190,8 @@ msgstr ""
 #. type: SH
 #: backend.7:49 cancel.1:37 classes.conf.5:13 client.conf.5:13 cups.1:13
 #: cupsaccept.8:40 cups-config.1:49 cupsctl.8:36 cupsd.8:32 cupsd.conf.5:13
-#: cupsd-helper.8:46 cupsd-logs.5:13 cupsenable.8:46 cups-files.conf.5:13
-#: cupsfilter.8:54 cups-lpd.8:23 cups-snmp.8:23 cups-snmp.conf.5:13
+#: cupsd-helper.8:46 cupsd-logs.5:13 cupsenable.8:46 cups-files.conf.5:14
+#: cupsfilter.8:54 cups-lpd.8:24 cups-snmp.8:23 cups-snmp.conf.5:13
 #: cupstestppd.1:51 filter.7:51 ippevepcl.7:22 ippeveprinter.1:84 ippfind.1:32
 #: ipptool.1:75 ipptoolfile.5:12 lp.1:84 lpadmin.8:54 lpc.8:20 lpinfo.8:60
 #: lpmove.8:37 lpoptions.1:53 lpq.1:31 lpr.1:53 lprm.1:31 lpstat.1:65
@@ -687,7 +686,7 @@ msgstr "L'URI du périphérique associé
 # type: SH
 #. type: SH
 #: backend.7:182 cups.1:114 cupsd.8:71 cupsd-helper.8:56 cupsfilter.8:110
-#: cups-lpd.8:54 cups-snmp.8:40 ipptool.1:195 lpoptions.1:104 mime.convs.5:37
+#: cups-lpd.8:55 cups-snmp.8:40 ipptool.1:195 lpoptions.1:104 mime.convs.5:37
 #: mime.types.5:87
 #, no-wrap
 msgid "FILES"
@@ -702,8 +701,8 @@ msgstr "I</etc/cups/cups-files.conf>"
 # type: SH
 #. type: SH
 #: backend.7:184 backend.7:204 cancel.1:81 classes.conf.5:19 client.conf.5:126
-#: cups.1:122 cupsd.conf.5:858 cupsd-helper.8:77 cups-files.conf.5:273
-#: cupsfilter.8:117 cups-lpd.8:60 cups-snmp.8:44 cups-snmp.conf.5:58
+#: cups.1:122 cupsd.conf.5:858 cupsd-helper.8:77 cups-files.conf.5:279
+#: cupsfilter.8:117 cups-lpd.8:61 cups-snmp.8:44 cups-snmp.conf.5:58
 #: cupstestppd.1:138 filter.7:201 lpadmin.8:203 lpc.8:40 lpinfo.8:117 lpr.1:151
 #: mime.convs.5:50 ppdc.1:90 ppdcfile.5:149 ppdhtml.1:35 ppdi.1:42
 #: ppdmerge.1:35 ppdpo.1:42 printers.conf.5:16 subscriptions.conf.5:19
@@ -767,8 +766,8 @@ msgstr ""
 #. type: SH
 #: backend.7:208 cancel.1:84 classes.conf.5:21 client.conf.5:138 cups.1:126
 #: cupsaccept.8:77 cups-config.1:105 cupsctl.8:92 cupsd.8:109 cupsd.conf.5:895
-#: cupsd-helper.8:81 cupsd-logs.5:216 cupsenable.8:88 cups-files.conf.5:280
-#: cupsfilter.8:131 cups-lpd.8:111 cups-snmp.8:49 cups-snmp.conf.5:62
+#: cupsd-helper.8:81 cupsd-logs.5:216 cupsenable.8:88 cups-files.conf.5:286
+#: cupsfilter.8:131 cups-lpd.8:108 cups-snmp.8:49 cups-snmp.conf.5:62
 #: cupstestppd.1:142 filter.7:212 ippevepcl.7:45 ippeveprinter.1:268
 #: ippfind.1:255 ipptool.1:246 ipptoolfile.5:649 lp.1:219 lpadmin.8:224
 #: lpc.8:47 lpinfo.8:121 lpmove.8:66 lpoptions.1:110 lpq.1:56 lpr.1:171
@@ -799,8 +798,8 @@ msgstr "Aide en ligne de CUPS : E<lt>UR
 #. type: SH
 #: backend.7:219 cancel.1:90 classes.conf.5:29 client.conf.5:142 cups.1:142
 #: cupsaccept.8:85 cups-config.1:108 cupsctl.8:97 cupsd.8:125 cupsd.conf.5:904
-#: cupsd-helper.8:89 cupsd-logs.5:221 cupsenable.8:96 cups-files.conf.5:290
-#: cupsfilter.8:138 cups-lpd.8:118 cups-snmp.8:55 cups-snmp.conf.5:65
+#: cupsd-helper.8:89 cupsd-logs.5:221 cupsenable.8:96 cups-files.conf.5:296
+#: cupsfilter.8:138 cups-lpd.8:116 cups-snmp.8:55 cups-snmp.conf.5:65
 #: cupstestppd.1:146 filter.7:220 ippevepcl.7:47 ippeveprinter.1:272
 #: ippfind.1:257 ipptool.1:251 ipptoolfile.5:654 lp.1:228 lpadmin.8:230
 #: lpc.8:57 lpinfo.8:124 lpmove.8:73 lpoptions.1:117 lpq.1:63 lpr.1:180
@@ -815,14 +814,13 @@ msgstr "COPYRIGHT"
 #. type: Plain text
 #: backend.7:220 cancel.1:91 classes.conf.5:30 client.conf.5:143 cups.1:143
 #: cupsaccept.8:86 cups-config.1:109 cupsctl.8:98 cupsd.8:126 cupsd.conf.5:905
-#: cupsd-helper.8:90 cupsd-logs.5:222 cupsenable.8:97 cups-files.conf.5:291
-#: cupsfilter.8:139 cups-lpd.8:119 cups-snmp.8:56 cups-snmp.conf.5:66
-#: cupstestppd.1:147 filter.7:221 ippeveprinter.1:273 ipptool.1:252
-#: ipptoolfile.5:655 lp.1:229 lpadmin.8:231 lpc.8:58 lpinfo.8:125 lpmove.8:74
-#: lpoptions.1:118 lpq.1:64 lpr.1:181 lprm.1:82 lpstat.1:148 mailto.conf.5:44
-#: mime.convs.5:62 mime.types.5:108 notifier.7:36 ppdc.1:102 ppdcfile.5:161
-#: ppdhtml.1:47 ppdi.1:54 ppdmerge.1:50 ppdpo.1:54 printers.conf.5:28
-#: subscriptions.conf.5:31
+#: cupsd-helper.8:90 cupsd-logs.5:222 cupsenable.8:97 cupsfilter.8:139
+#: cups-snmp.8:56 cups-snmp.conf.5:66 cupstestppd.1:147 filter.7:221
+#: ippeveprinter.1:273 ipptool.1:252 ipptoolfile.5:655 lp.1:229 lpadmin.8:231
+#: lpc.8:58 lpinfo.8:125 lpmove.8:74 lpoptions.1:118 lpq.1:64 lpr.1:181
+#: lprm.1:82 lpstat.1:148 mailto.conf.5:44 mime.convs.5:62 mime.types.5:108
+#: notifier.7:36 ppdc.1:102 ppdcfile.5:161 ppdhtml.1:47 ppdi.1:54 ppdmerge.1:50
+#: ppdpo.1:54 printers.conf.5:28 subscriptions.conf.5:31
 msgid "Copyright \\[co] 2007-2019 by Apple Inc."
 msgstr "Copyright 2007-2019 par Apple Inc."
 
@@ -864,7 +862,7 @@ msgstr ""
 # type: SH
 #. type: SH
 #: cancel.1:40 cupsaccept.8:50 cups-config.1:52 cupsctl.8:40 cupsd.8:37
-#: cupsd.conf.5:485 cupsenable.8:51 cupsfilter.8:59 cups-lpd.8:32
+#: cupsd.conf.5:485 cupsenable.8:51 cupsfilter.8:59 cups-lpd.8:33
 #: cupstestppd.1:58 filter.7:60 ippeveprinter.1:87 ippfind.1:191 ipptool.1:88
 #: lp.1:94 lpadmin.8:73 lpinfo.8:63 lpmove.8:39 lpoptions.1:68 lpq.1:36
 #: lpr.1:64 lprm.1:36 lpstat.1:68 ppdc.1:48 ppdhtml.1:25 ppdi.1:30
@@ -963,7 +961,7 @@ msgstr "Supprimer les fichiers de donné
 
 #. type: SH
 #: cancel.1:61 cups.1:119 cupsaccept.8:67 cupsd.8:81 cupsd.conf.5:873
-#: cupsenable.8:77 cups-lpd.8:46 cups-snmp.8:47 filter.7:199
+#: cupsenable.8:77 cups-lpd.8:47 cups-snmp.8:47 filter.7:199
 #: ippeveprinter.1:207 ipptool.1:229 lp.1:196 lpadmin.8:197 lpinfo.8:97
 #: lpoptions.1:108 lprm.1:52 lpstat.1:133
 #, no-wrap
@@ -1153,7 +1151,7 @@ msgstr ""
 
 # type: SH
 #. type: SS
-#: client.conf.5:21 cups-files.conf.5:22 cups-snmp.conf.5:21 mailto.conf.5:20
+#: client.conf.5:21 cups-files.conf.5:23 cups-snmp.conf.5:21 mailto.conf.5:20
 #, no-wrap
 msgid "DIRECTIVES"
 msgstr "DIRECTIVES"
@@ -3368,12 +3366,10 @@ msgstr "B<ErrorPolicy> I<retry-job>"
 #: cupsd.conf.5:144
 msgid ""
 "Specifies that a failed print job should be retried at a later time unless "
-"otherwise specified for the printer. The 'retry-job' error policy is the "
-"default."
+"otherwise specified for the printer."
 msgstr ""
 "Indiquer qu’une tâche d’impression ayant échoué sera recommencée plus tard à "
-"moins d’indication contraire pour l’imprimante. Par défaut, « retry-job » "
-"est la politique d'erreur."
+"moins d’indication contraire pour l’imprimante."
 
 # type: TP
 #. type: TP
@@ -3386,12 +3382,18 @@ msgstr "B<ErrorPolicy> I<stop-printer>"
 #. #FilterLimit
 #. type: Plain text
 #: cupsd.conf.5:148
+#, fuzzy
+#| msgid ""
+#| "Specifies that a failed print job should be retried at a later time "
+#| "unless otherwise specified for the printer. The 'retry-job' error policy "
+#| "is the default."
 msgid ""
 "Specifies that a failed print job should stop the printer unless otherwise "
-"specified for the printer."
+"specified for the printer. The 'stop-printer' error policy is the default."
 msgstr ""
-"Indiquer qu’une tâche d’impression ayant échoué arrêtera l’imprimante à "
-"moins d’indication contraire pour l’imprimante."
+"Indiquer qu’une tâche d’impression ayant échoué sera recommencée plus tard à "
+"moins d’indication contraire pour l’imprimante. Par défaut, « retry-job » "
+"est la politique d'erreur."
 
 # type: TP
 #. type: TP
@@ -5721,7 +5723,7 @@ msgstr ""
 
 # type: SH
 #. type: SS
-#: cupsd.conf.5:815 cups-files.conf.5:230
+#: cupsd.conf.5:815 cups-files.conf.5:236
 #, no-wrap
 msgid "DEPRECATED DIRECTIVES"
 msgstr "DIRECTIVES OBSOLÈTES"
@@ -6987,14 +6989,22 @@ msgstr ""
 
 # type: TH
 #. type: TH
-#: cups-files.conf.5:10
+#: cups-files.conf.5:11
 #, no-wrap
 msgid "cups-files.conf"
 msgstr "cups-files.conf"
 
+# type: TH
+#. type: TH
+#: cups-files.conf.5:11 cups-lpd.8:11
+#, fuzzy, no-wrap
+#| msgid "19 November 2009"
+msgid "14 November 2020"
+msgstr "19 novembre 2009"
+
 # type: Plain text
 #. type: Plain text
-#: cups-files.conf.5:13
+#: cups-files.conf.5:14
 msgid "cups-files.conf - file and directory configuration file for cups"
 msgstr ""
 "cups-files.conf - Fichier de configuration des fichiers et dossiers du "
@@ -7002,7 +7012,7 @@ msgstr ""
 
 # type: Plain text
 #. type: Plain text
-#: cups-files.conf.5:17
+#: cups-files.conf.5:18
 msgid ""
 "The B<cups-files.conf> file configures the files and directories used by the "
 "CUPS scheduler, B<cupsd>(8).  It is normally located in the I</etc/cups> "
@@ -7014,7 +7024,7 @@ msgstr ""
 
 # type: Plain text
 #. type: Plain text
-#: cups-files.conf.5:22 mailto.conf.5:20
+#: cups-files.conf.5:23 mailto.conf.5:20
 msgid ""
 "Each line in the file can be a configuration directive, a blank line, or a "
 "comment.  Configuration directives typically consist of a name and zero or "
@@ -7031,40 +7041,40 @@ msgstr ""
 # type: Plain text
 #. #AccessLog
 #. type: Plain text
-#: cups-files.conf.5:26
+#: cups-files.conf.5:27
 msgid "The following directives are understood by B<cupsd>(8):"
 msgstr "Les directives suivantes sont comprises par B<cupsd>(8) :"
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:26
+#: cups-files.conf.5:27
 #, no-wrap
 msgid "B<AccessLog>"
 msgstr "B<AccessLog>"
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:28
+#: cups-files.conf.5:29
 #, no-wrap
 msgid "B<AccessLog >I<filename>"
 msgstr "B<AccessLog> I<nom_fichier>"
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:30
+#: cups-files.conf.5:31
 #, no-wrap
 msgid "B<AccessLog stderr>"
 msgstr "B<AccessLog stderr>"
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:32
+#: cups-files.conf.5:33
 #, no-wrap
 msgid "B<AccessLog syslog>"
 msgstr "B<AccessLog syslog>"
 
 #. type: Plain text
-#: cups-files.conf.5:39
+#: cups-files.conf.5:40
 msgid ""
 "Defines the access log filename.  Specifying a blank filename disables "
 "access log generation.  The value \"stderr\" causes log entries to be sent "
@@ -7083,27 +7093,27 @@ msgstr ""
 "utilisant la chaîne « %s », par exemple :"
 
 #. type: Plain text
-#: cups-files.conf.5:42
+#: cups-files.conf.5:43
 #, no-wrap
 msgid "    AccessLog /var/log/cups/%s-access_log\n"
 msgstr "    AccessLog /var/log/cups/%s-access_log\n"
 
 #. #CacheDir
 #. type: Plain text
-#: cups-files.conf.5:46
+#: cups-files.conf.5:47
 msgid "The default is \"/var/log/cups/access_log\"."
 msgstr "Par défaut, I</var/log/cups/access_log>."
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:46
+#: cups-files.conf.5:47
 #, no-wrap
 msgid "B<CacheDir >I<directory>"
 msgstr "B<CacheDir> I<répertoire>"
 
 #. #ConfigFilePerm
 #. type: Plain text
-#: cups-files.conf.5:51
+#: cups-files.conf.5:52
 msgid ""
 "Specifies the directory to use for long-lived temporary (cache) files.  The "
 "default is \"/var/spool/cups/cache\" or \"/var/cache/cups\" depending on the "
@@ -7115,14 +7125,14 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:51
+#: cups-files.conf.5:52
 #, no-wrap
 msgid "B<ConfigFilePerm >I<mode>"
 msgstr "B<ConfigFilePerm> I<mode>"
 
 # type: Plain text
 #. type: Plain text
-#: cups-files.conf.5:55
+#: cups-files.conf.5:56
 msgid ""
 "Specifies the permissions for all configuration files that the scheduler "
 "writes.  The default is \"0644\" on macOS and \"0640\" on all other "
@@ -7134,7 +7144,7 @@ msgstr ""
 
 #. #CreateSelfSignedCerts
 #. type: Plain text
-#: cups-files.conf.5:60
+#: cups-files.conf.5:61
 msgid ""
 "B<Note:> The permissions for the I<printers.conf> file are currently masked "
 "to only allow access from the scheduler user (typically root).  This is done "
@@ -7150,20 +7160,20 @@ msgstr ""
 "de sécurité ne peut être désactivée."
 
 #. type: TP
-#: cups-files.conf.5:60
+#: cups-files.conf.5:61
 #, no-wrap
 msgid "B<CreateSelfSignedCerts yes>"
 msgstr "B<CreateSelfSignedCerts> I<yes>"
 
 #. type: TP
-#: cups-files.conf.5:62
+#: cups-files.conf.5:63
 #, no-wrap
 msgid "B<CreateSelfSignedCerts no>"
 msgstr "B<CreateSelfSignedCerts> I<no>"
 
 #. #DataDir
 #. type: Plain text
-#: cups-files.conf.5:67
+#: cups-files.conf.5:68
 msgid ""
 "Specifies whether the scheduler automatically creates self-signed "
 "certificates for client connections using TLS.  The default is yes."
@@ -7174,7 +7184,7 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:67
+#: cups-files.conf.5:68
 #, no-wrap
 msgid "B<DataDir >I<path>"
 msgstr "B<DataDir> I<chemin>"
@@ -7182,7 +7192,7 @@ msgstr "B<DataDir> I<chemin>"
 # type: Plain text
 #. #DocumentRoot
 #. type: Plain text
-#: cups-files.conf.5:72
+#: cups-files.conf.5:73
 msgid ""
 "Specifies the directory where data files can be found.  The default is "
 "usually \"/usr/share/cups\"."
@@ -7192,7 +7202,7 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:72
+#: cups-files.conf.5:73
 #, no-wrap
 msgid "B<DocumentRoot >I<directory>"
 msgstr "B<DocumentRoot> I<répertoire>"
@@ -7200,7 +7210,7 @@ msgstr "B<DocumentRoot> I<répertoire>"
 # type: Plain text
 #. #ErrorLog
 #. type: Plain text
-#: cups-files.conf.5:77
+#: cups-files.conf.5:78
 msgid ""
 "Specifies the root directory for the CUPS web interface content.  The "
 "default is usually \"/usr/share/doc/cups\"."
@@ -7210,34 +7220,34 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:77
+#: cups-files.conf.5:78
 #, no-wrap
 msgid "B<ErrorLog>"
 msgstr "B<ErrorLog>"
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:79
+#: cups-files.conf.5:80
 #, no-wrap
 msgid "B<ErrorLog >I<filename>"
 msgstr "B<ErrorLog> I<nom_fichier>"
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:81
+#: cups-files.conf.5:82
 #, no-wrap
 msgid "B<ErrorLog stderr>"
 msgstr "B<ErrorLog stderr>"
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:83
+#: cups-files.conf.5:84
 #, no-wrap
 msgid "B<ErrorLog syslog>"
 msgstr "B<ErrorLog syslog>"
 
 #. type: Plain text
-#: cups-files.conf.5:90
+#: cups-files.conf.5:91
 msgid ""
 "Defines the error log filename.  Specifying a blank filename disables error "
 "log generation.  The value \"stderr\" causes log entries to be sent to the "
@@ -7256,37 +7266,37 @@ msgstr ""
 "utilisant la chaîne « %s », par exemple :"
 
 #. type: Plain text
-#: cups-files.conf.5:93
+#: cups-files.conf.5:94
 #, no-wrap
 msgid "    ErrorLog /var/log/cups/%s-error_log\n"
 msgstr "    ErrorLog /var/log/cups/%s-error_log\n"
 
 #. #FatalErrors
 #. type: Plain text
-#: cups-files.conf.5:97
+#: cups-files.conf.5:98
 msgid "The default is \"/var/log/cups/error_log\"."
 msgstr "Par défaut, I</var/log/cups/error_log>."
 
 #. type: TP
-#: cups-files.conf.5:97
+#: cups-files.conf.5:98
 #, no-wrap
 msgid "B<FatalErrors none>"
 msgstr "B<FatalErrors> I<none>"
 
 #. type: TP
-#: cups-files.conf.5:99
+#: cups-files.conf.5:100
 #, no-wrap
 msgid "B<FatalErrors all >I<-kind >[ ... I<-kind >]"
 msgstr "B<FatalErrors all >I<-type> [... I<-type>]"
 
 #. type: TP
-#: cups-files.conf.5:101
+#: cups-files.conf.5:102
 #, no-wrap
 msgid "B<FatalErrors >I<kind >[ ... I<kind >]"
 msgstr "B<FatalErrors> I<type> [... I<type>]"
 
 #. type: Plain text
-#: cups-files.conf.5:106
+#: cups-files.conf.5:107
 msgid ""
 "Specifies which errors are fatal, causing the scheduler to exit.  The "
 "default is \"config\".  The I<kind> strings are:"
@@ -7295,35 +7305,35 @@ msgstr ""
 "Par défaut, « config ». Les chaînes I<type> sont les suivantes :"
 
 #. type: TP
-#: cups-files.conf.5:107
+#: cups-files.conf.5:108
 #, no-wrap
 msgid "B<none>"
 msgstr "B<none>"
 
 #. type: Plain text
-#: cups-files.conf.5:110
+#: cups-files.conf.5:111
 msgid "No errors are fatal."
 msgstr "Aucune erreur n’est fatale."
 
 #. type: TP
-#: cups-files.conf.5:110
+#: cups-files.conf.5:111
 #, no-wrap
 msgid "B<all>"
 msgstr "B<all>"
 
 #. type: Plain text
-#: cups-files.conf.5:113
+#: cups-files.conf.5:114
 msgid "All of the errors below are fatal."
 msgstr "Toutes les erreurs ci-dessous sont fatales."
 
 #. type: TP
-#: cups-files.conf.5:113
+#: cups-files.conf.5:114
 #, no-wrap
 msgid "B<browse>"
 msgstr "B<browse>"
 
 #. type: Plain text
-#: cups-files.conf.5:116
+#: cups-files.conf.5:117
 msgid ""
 "Browsing initialization errors are fatal, for example failed connections to "
 "the DNS-SD daemon."
@@ -7333,25 +7343,25 @@ msgstr ""
 
 # type: Plain text
 #. type: TP
-#: cups-files.conf.5:116
+#: cups-files.conf.5:117
 #, no-wrap
 msgid "B<config>"
 msgstr "B<config>"
 
 # type: Plain text
 #. type: Plain text
-#: cups-files.conf.5:119
+#: cups-files.conf.5:120
 msgid "Configuration file syntax errors are fatal."
 msgstr "Les erreurs de syntaxe du fichier de configuration sont fatales."
 
 #. type: TP
-#: cups-files.conf.5:119
+#: cups-files.conf.5:120
 #, no-wrap
 msgid "B<listen>"
 msgstr "B<listen>"
 
 #. type: Plain text
-#: cups-files.conf.5:122
+#: cups-files.conf.5:123
 msgid ""
 "Listen or Port errors are fatal, except for IPv6 failures on the loopback or "
 "\"any\" addresses."
@@ -7360,25 +7370,25 @@ msgstr ""
 "sur loopback ou les adresses « any »."
 
 #. type: TP
-#: cups-files.conf.5:122
+#: cups-files.conf.5:123
 #, no-wrap
 msgid "B<log>"
 msgstr "B<log>"
 
 #. type: Plain text
-#: cups-files.conf.5:125
+#: cups-files.conf.5:126
 msgid "Log file creation or write errors are fatal."
 msgstr ""
 "Les erreurs de création ou d’écriture du fichier de journal sont fatales."
 
 #. type: TP
-#: cups-files.conf.5:125
+#: cups-files.conf.5:126
 #, no-wrap
 msgid "B<permissions>"
 msgstr "B<permissions>"
 
 #. type: Plain text
-#: cups-files.conf.5:128
+#: cups-files.conf.5:129
 msgid ""
 "Bad startup file permissions are fatal, for example shared TLS certificate "
 "and key files with world-read permissions."
@@ -7388,13 +7398,12 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:130
+#: cups-files.conf.5:131
 #, no-wrap
 msgid "B<Group >I<group-name-or-number>"
 msgstr "B<Group> I<nom_groupe>-ou-I<identifiant_numérique>"
 
 # type: Plain text
-#. #LogFilePerm
 #. type: Plain text
 #: cups-files.conf.5:135
 msgid ""
@@ -7408,7 +7417,32 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:135
+#: cups-files.conf.5:137
+#, fuzzy, no-wrap
+#| msgid "B<Group >I<group-name-or-number>"
+msgid "B<LogFileGroup >I<group-name-or-number>"
+msgstr "B<Group> I<nom_groupe>-ou-I<identifiant_numérique>"
+
+# type: Plain text
+#. #LogFilePerm
+#. type: Plain text
+#: cups-files.conf.5:142
+#, fuzzy
+#| msgid ""
+#| "Specifies the group name or ID that will be used when executing external "
+#| "programs.  The default group is operating system specific but is usually "
+#| "\"lp\" or \"nobody\"."
+msgid ""
+"Specifies the group name or ID that will be used for log files.  The default "
+"group is operating system specific but is usually \"lp\" or \"nobody\"."
+msgstr ""
+"Définir le nom ou l'identifiant numérique du groupe qui sera utilisé lors de "
+"l'exécution de programmes externes. Le groupe par défaut dépend du système "
+"d’exploitation, mais est couramment « lp » ou « nobody »."
+
+# type: TP
+#. type: TP
+#: cups-files.conf.5:142
 #, no-wrap
 msgid "B<LogFilePerm >I<mode>"
 msgstr "B<LogFilePerm> I<mode>"
@@ -7416,7 +7450,7 @@ msgstr "B<LogFilePerm> I<mode>"
 # type: Plain text
 #. #PageLog
 #. type: Plain text
-#: cups-files.conf.5:140
+#: cups-files.conf.5:147
 msgid ""
 "Specifies the permissions of all log files that the scheduler writes.  The "
 "default is \"0644\"."
@@ -7426,27 +7460,27 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:140
+#: cups-files.conf.5:147
 #, no-wrap
 msgid "B<PageLog >[ I<filename> ]"
 msgstr "B<PageLog> [ I<nom_fichier> ]"
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:142
+#: cups-files.conf.5:149
 #, no-wrap
 msgid "B<PageLog stderr>"
 msgstr "B<PageLog stderr>"
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:144
+#: cups-files.conf.5:151
 #, no-wrap
 msgid "B<PageLog syslog>"
 msgstr "B<PageLog syslog>"
 
 #. type: Plain text
-#: cups-files.conf.5:151
+#: cups-files.conf.5:158
 msgid ""
 "Defines the page log filename.  The value \"stderr\" causes log entries to "
 "be sent to the standard error file when the scheduler is running in the "
@@ -7465,27 +7499,27 @@ msgstr ""
 "utilisant la chaîne « %s », par exemple :"
 
 #. type: Plain text
-#: cups-files.conf.5:154
+#: cups-files.conf.5:161
 #, no-wrap
 msgid "    PageLog /var/log/cups/%s-page_log\n"
 msgstr "    PageLog /var/log/cups/%s-page_log\n"
 
 #. #PassEnv
 #. type: Plain text
-#: cups-files.conf.5:158
+#: cups-files.conf.5:165
 msgid "The default is \"/var/log/cups/page_log\"."
 msgstr "Par défaut, I</var/log/cups/page_log>."
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:158
+#: cups-files.conf.5:165
 #, no-wrap
 msgid "B<PassEnv >I<variable >[ ... I<variable >]"
 msgstr "B<PassEnv> I<variable> [... I<variable>]"
 
 #. #RemoteRoot
 #. type: Plain text
-#: cups-files.conf.5:163
+#: cups-files.conf.5:170
 msgid ""
 "Passes the specified environment variable(s) to child processes.  Note: the "
 "standard CUPS filter and backend environment variables cannot be overridden "
@@ -7494,7 +7528,7 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:163
+#: cups-files.conf.5:170
 #, no-wrap
 msgid "B<RemoteRoot >I<username>"
 msgstr "B<RemoteRoot> I<identifiant>"
@@ -7502,7 +7536,7 @@ msgstr "B<RemoteRoot> I<identifiant>"
 # type: Plain text
 #. #RequestRoot
 #. type: Plain text
-#: cups-files.conf.5:168
+#: cups-files.conf.5:175
 msgid ""
 "Specifies the username that is associated with unauthenticated accesses by "
 "clients claiming to be the root user.  The default is \"remroot\"."
@@ -7512,7 +7546,7 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:168
+#: cups-files.conf.5:175
 #, no-wrap
 msgid "B<RequestRoot >I<directory>"
 msgstr "B<RequestRoot> I<répertoire>"
@@ -7520,7 +7554,7 @@ msgstr "B<RequestRoot> I<répertoire>"
 # type: Plain text
 #. #Sandboxing
 #. type: Plain text
-#: cups-files.conf.5:173
+#: cups-files.conf.5:180
 msgid ""
 "Specifies the directory that contains print jobs and other HTTP request "
 "data.  The default is \"/var/spool/cups\"."
@@ -7529,20 +7563,20 @@ msgstr ""
 "requêtes HTTP. Par défaut, I</var/spool/cups>."
 
 #. type: TP
-#: cups-files.conf.5:173
+#: cups-files.conf.5:180
 #, no-wrap
 msgid "B<Sandboxing relaxed>"
 msgstr "B<Sandboxing> I<relaxed>"
 
 #. type: TP
-#: cups-files.conf.5:175
+#: cups-files.conf.5:182
 #, no-wrap
 msgid "B<Sandboxing strict>"
 msgstr "B<Sandboxing> I<strict>"
 
 #. #ServerBin
 #. type: Plain text
-#: cups-files.conf.5:181
+#: cups-files.conf.5:188
 msgid ""
 "Specifies the level of security sandboxing that is applied to print filters, "
 "backends, and other child processes of the scheduler.  The default is "
@@ -7555,14 +7589,14 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:181
+#: cups-files.conf.5:188
 #, no-wrap
 msgid "B<ServerBin >I<directory>"
 msgstr "B<ServerBin> I<répertoire>"
 
 #. #ServerKeychain
 #. type: Plain text
-#: cups-files.conf.5:186
+#: cups-files.conf.5:193
 msgid ""
 "Specifies the directory containing the backends, CGI programs, filters, "
 "helper programs, notifiers, and port monitors.  The default is \"/usr/lib/"
@@ -7574,14 +7608,14 @@ msgstr ""
 "usr/libexec/cups> en fonction de la plateforme."
 
 #. type: TP
-#: cups-files.conf.5:186
+#: cups-files.conf.5:193
 #, no-wrap
 msgid "B<ServerKeychain >I<path>"
 msgstr "B<ServerKeychain >I<chemin>"
 
 #. #ServerRoot
 #. type: Plain text
-#: cups-files.conf.5:192
+#: cups-files.conf.5:199
 msgid ""
 "Specifies the location of TLS certificates and private keys.  The default is "
 "\"/Library/Keychains/System.keychain\" on macOS and \"/etc/cups/ssl\" on all "
@@ -7599,7 +7633,7 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:192
+#: cups-files.conf.5:199
 #, no-wrap
 msgid "B<ServerRoot >I<directory>"
 msgstr "B<ServerRoot> I<répertoire>"
@@ -7607,7 +7641,7 @@ msgstr "B<ServerRoot> I<répertoire>"
 # type: Plain text
 #. #SetEnv
 #. type: Plain text
-#: cups-files.conf.5:197
+#: cups-files.conf.5:204
 msgid ""
 "Specifies the directory containing the server configuration files.  The "
 "default is \"/etc/cups\"."
@@ -7617,14 +7651,14 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:197
+#: cups-files.conf.5:204
 #, no-wrap
 msgid "B<SetEnv >I<variable value>"
 msgstr "B<SetEnv variable> I<valeur>"
 
 #. #StateDir
 #. type: Plain text
-#: cups-files.conf.5:202
+#: cups-files.conf.5:209
 msgid ""
 "Set the specified environment variable to be passed to child processes.  "
 "Note: the standard CUPS filter and backend environment variables cannot be "
@@ -7633,14 +7667,14 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:202
+#: cups-files.conf.5:209
 #, no-wrap
 msgid "B<StateDir >I<directory>"
 msgstr "B<StateDir> I<répertoire>"
 
 #. #SyncOnClose
 #. type: Plain text
-#: cups-files.conf.5:207
+#: cups-files.conf.5:214
 msgid ""
 "Specifies the directory to use for PID and local certificate files.  The "
 "default is \"/var/run/cups\" or \"/etc/cups\" depending on the platform."
@@ -7650,37 +7684,41 @@ msgstr ""
 "plateforme."
 
 #. type: TP
-#: cups-files.conf.5:207
+#: cups-files.conf.5:214
 #, no-wrap
 msgid "B<SyncOnClose Yes>"
 msgstr "B<SyncOnClose> I<Yes>"
 
 #. type: TP
-#: cups-files.conf.5:209
+#: cups-files.conf.5:216
 #, no-wrap
 msgid "B<SyncOnClose No>"
 msgstr "B<SyncOnClose> I<No>"
 
 #. #SystemGroup
 #. type: Plain text
-#: cups-files.conf.5:216
+#: cups-files.conf.5:222
+#, fuzzy
+#| msgid ""
+#| "Specifies whether the scheduler calls B<fsync>(2)  after writing "
+#| "configuration or state files.  The default is \"Yes\"."
 msgid ""
 "Specifies whether the scheduler calls B<fsync>(2)  after writing "
-"configuration or state files.  The default is \"Yes\"."
+"configuration or state files."
 msgstr ""
 "Indiquer si l'ordonnanceur appelle B<fsyncr>(2) après écriture des fichiers "
 "d’état ou de configuration. La valeur par défaut est « Yes »."
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:216
+#: cups-files.conf.5:222
 #, no-wrap
 msgid "B<SystemGroup >I<group-name >[ ... I<group-name> ]"
 msgstr "B<SystemGroup> I<groupe> [ ... I<groupe>]"
 
 #. #TempDir
 #. type: Plain text
-#: cups-files.conf.5:221
+#: cups-files.conf.5:227
 msgid ""
 "Specifies the group(s) to use for I<@SYSTEM> group authentication.  The "
 "default contains \"admin\", \"lpadmin\", \"root\", \"sys\", and/or \"system"
@@ -7692,7 +7730,7 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:221
+#: cups-files.conf.5:227
 #, no-wrap
 msgid "B<TempDir >I<directory>"
 msgstr "B<TempDir> I<répertoire>"
@@ -7700,7 +7738,7 @@ msgstr "B<TempDir> I<répertoire>"
 # type: Plain text
 #. #User
 #. type: Plain text
-#: cups-files.conf.5:226
+#: cups-files.conf.5:232
 msgid ""
 "Specifies the directory where short-term temporary files are stored.  The "
 "default is \"/var/spool/cups/tmp\"."
@@ -7710,14 +7748,14 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:226
+#: cups-files.conf.5:232
 #, no-wrap
 msgid "B<User >I<username>"
 msgstr "B<-U> I<identifiant>"
 
 # type: Plain text
 #. type: Plain text
-#: cups-files.conf.5:230
+#: cups-files.conf.5:236
 msgid ""
 "Specifies the user name or ID that is used when running external programs.  "
 "The default is \"lp\"."
@@ -7727,7 +7765,7 @@ msgstr ""
 
 #. #FileDevice
 #. type: Plain text
-#: cups-files.conf.5:233
+#: cups-files.conf.5:239
 msgid ""
 "The following directives are deprecated and will be removed from a future "
 "version of CUPS:"
@@ -7737,21 +7775,21 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:233
+#: cups-files.conf.5:239
 #, no-wrap
 msgid "B<FileDevice Yes>"
 msgstr "B<FileDevice> I<Yes>"
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:235
+#: cups-files.conf.5:241
 #, no-wrap
 msgid "B<FileDevice No>"
 msgstr "B<FileDevice> I<No>"
 
 #. #FontPath
 #. type: Plain text
-#: cups-files.conf.5:243
+#: cups-files.conf.5:249
 msgid ""
 "Specifies whether the file pseudo-device can be used for new printer "
 "queues.  The URI \"file:///dev/null\" is always allowed.  File devices "
@@ -7768,14 +7806,14 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:243
+#: cups-files.conf.5:249
 #, no-wrap
 msgid "B<FontPath >I<directory[:...:directoryN]>"
 msgstr "B<FontPath> I<répertoire>[:...:I<répertoireN>]"
 
 #. #LPDConfigFile
 #. type: Plain text
-#: cups-files.conf.5:251
+#: cups-files.conf.5:257
 msgid ""
 "Specifies a colon separated list of directories where fonts can be found.  "
 "On Linux the B<font-config>(1)  mechanism is used instead.  On macOS the "
@@ -7788,7 +7826,7 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:251
+#: cups-files.conf.5:257
 #, no-wrap
 msgid " B<LPDConfigFile >I<filename>"
 msgstr " B<LPDConfigFile >I<nom-fichier>"
@@ -7796,13 +7834,13 @@ msgstr " B<LPDConfigFile >I<nom-fichier>
 # type: Plain text
 #. #Printcap
 #. type: Plain text
-#: cups-files.conf.5:255
+#: cups-files.conf.5:261
 msgid "Specifies the LPD service configuration file to update."
 msgstr "Définir le fichier de configuration du service LPD à mettre à jour."
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:255
+#: cups-files.conf.5:261
 #, no-wrap
 msgid "B<Printcap >I<filename>"
 msgstr "B<Printcap> I<nom-fichier>"
@@ -7810,7 +7848,7 @@ msgstr "B<Printcap> I<nom-fichier>"
 # type: Plain text
 #. #PrintcapFormat
 #. type: Plain text
-#: cups-files.conf.5:259
+#: cups-files.conf.5:265
 msgid "Specifies a file that is filled with a list of local print queues."
 msgstr ""
 "Définir le fichier rempli par une liste de files d’attente d’impression "
@@ -7818,28 +7856,28 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:259
+#: cups-files.conf.5:265
 #, no-wrap
 msgid "B<PrintcapFormat bsd>"
 msgstr "B<PrintcapFormat> I<bsd>"
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:261
+#: cups-files.conf.5:267
 #, no-wrap
 msgid "B<PrintcapFormat plist>"
 msgstr "B<PrintcapFormat> I<plist>"
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:263
+#: cups-files.conf.5:269
 #, no-wrap
 msgid "B<PrintcapFormat solaris>"
 msgstr "B<PrintcapFormat> I<solaris>"
 
 #. #SMBConfigFile
 #. type: Plain text
-#: cups-files.conf.5:270
+#: cups-files.conf.5:276
 msgid ""
 "Specifies the format to use for the Printcap file.  \"bsd\" is the "
 "historical LPD printcap file format.  \"plist\" is the Apple plist file "
@@ -7852,19 +7890,19 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-files.conf.5:270
+#: cups-files.conf.5:276
 #, no-wrap
 msgid "B<SMBConfigFile >I<filename>"
 msgstr "B<SMBConfigFile >I<nom-fichier>"
 
 # type: Plain text
 #. type: Plain text
-#: cups-files.conf.5:273
+#: cups-files.conf.5:279
 msgid "Specifies the SMB service configuration file to update."
 msgstr "Définir le fichier de configuration du service SMB à mettre à jour."
 
 #. type: Plain text
-#: cups-files.conf.5:280
+#: cups-files.conf.5:286
 msgid ""
 "The scheduler MUST be restarted manually after making changes to the B<cups-"
 "files.conf> file.  On Linux this is typically done using the "
@@ -7874,7 +7912,7 @@ msgstr ""
 
 # type: Plain text
 #. type: Plain text
-#: cups-files.conf.5:290
+#: cups-files.conf.5:296
 msgid ""
 "B<classes.conf>(5), B<cups>(1), B<cupsd>(8), B<cupsd.conf>(5), B<mime."
 "convs>(5), B<mime.types>(5), B<printers.conf>(5), B<subscriptions.conf>(5), "
@@ -7884,6 +7922,16 @@ msgstr ""
 "convs>(5), B<mime.types>(5), B<printers.conf>(5), B<subscriptions.conf>(5), "
 "aide en ligne de CUPS E<lt>URL:I<http://localhost:631/help>E<gt>"
 
+# type: Plain text
+#. type: Plain text
+#: cups-files.conf.5:298 cups-lpd.8:118
+#, fuzzy
+#| msgid "Copyright \\[co] 2007-2019 by Apple Inc."
+msgid ""
+"Copyright \\[co] 2020 by Michael R Sweet Copyright \\[co] 2007-2019 by Apple "
+"Inc."
+msgstr "Copyright 2007-2019 par Apple Inc."
+
 # type: TP
 #. type: TH
 #: cupsfilter.8:9
@@ -8070,7 +8118,7 @@ msgstr "Indiquer le nombre de copies à
 
 # type: TP
 #. type: TP
-#: cupsfilter.8:90 cups-lpd.8:41
+#: cupsfilter.8:90 cups-lpd.8:42
 #, no-wrap
 msgid "B<-o >I<name=value>"
 msgstr "B<-o> I<nom=valeur>"
@@ -8173,7 +8221,7 @@ msgstr ""
 
 # type: SH
 #. type: SH
-#: cupsfilter.8:125 cups-lpd.8:86 lpadmin.8:217
+#: cupsfilter.8:125 cups-lpd.8:87 lpadmin.8:217
 #, no-wrap
 msgid "EXAMPLE"
 msgstr "EXEMPLE"
@@ -8205,14 +8253,14 @@ msgstr ""
 
 # type: TH
 #. type: TH
-#: cups-lpd.8:10
+#: cups-lpd.8:11
 #, no-wrap
 msgid "cups-lpd"
 msgstr "cups-lpd"
 
 # type: Plain text
 #. type: Plain text
-#: cups-lpd.8:13
+#: cups-lpd.8:14
 #, fuzzy
 msgid ""
 "cups-lpd - receive print jobs and report printer status to lpd clients "
@@ -8223,7 +8271,7 @@ msgstr ""
 
 # type: Plain text
 #. type: Plain text
-#: cups-lpd.8:23
+#: cups-lpd.8:24
 msgid ""
 "B<cups-lpd> [ B<-h >I<hostname>[B<:>I<port>] ] [ B<-n> ] [ B<-o> "
 "I<option=value> ]"
@@ -8233,7 +8281,7 @@ msgstr ""
 
 # type: Plain text
 #. type: Plain text
-#: cups-lpd.8:32
+#: cups-lpd.8:33
 msgid ""
 "B<cups-lpd> is the CUPS Line Printer Daemon (\"LPD\") mini-server that "
 "supports legacy client systems that use the LPD protocol.  B<cups-lpd> does "
@@ -8249,26 +8297,26 @@ msgstr ""
 
 # type: TP
 #. type: TP
-#: cups-lpd.8:33 lp.1:112
+#: cups-lpd.8:34 lp.1:112
 #, no-wrap
 msgid "B<-h >I<hostname>[B<:>I<port>]"
 msgstr "B<-h> I<nom_hôte>[B<:>I<port>]"
 
 # type: Plain text
 #. type: Plain text
-#: cups-lpd.8:36
+#: cups-lpd.8:37
 msgid "Sets the CUPS server (and port) to use."
 msgstr "Définir le serveur CUPS (et le port) à utiliser."
 
 #. type: TP
-#: cups-lpd.8:36
+#: cups-lpd.8:37
 #, no-wrap
 msgid "B<-n>"
 msgstr "B<-n>"
 
 # type: Plain text
 #. type: Plain text
-#: cups-lpd.8:41
+#: cups-lpd.8:42
 msgid ""
 "Disables reverse address lookups; normally B<cups-lpd> will try to discover "
 "the hostname of the client via a reverse DNS lookup."
@@ -8278,7 +8326,7 @@ msgstr ""
 
 # type: Plain text
 #. type: Plain text
-#: cups-lpd.8:46
+#: cups-lpd.8:47
 msgid ""
 "Inserts options for all print queues. Most often this is used to disable the "
 "\"l\" filter so that remote print jobs are filtered as needed for printing; "
@@ -8294,7 +8342,7 @@ msgstr ""
 
 # type: Plain text
 #. type: Plain text
-#: cups-lpd.8:50
+#: cups-lpd.8:51
 msgid ""
 "B<cups-lpd> does not enforce the restricted source port number specified in "
 "RFC 1179, as using restricted ports does not prevent users from submitting "
@@ -8309,7 +8357,7 @@ msgstr ""
 
 # type: Plain text
 #. type: Plain text
-#: cups-lpd.8:52
+#: cups-lpd.8:53
 msgid ""
 "The output of the status requests follows RFC 2569, Mapping between LPD and "
 "IPP Protocols. Since many LPD implementations stray from this definition, "
@@ -8321,18 +8369,18 @@ msgstr ""
 "être erronée."
 
 #. type: SH
-#: cups-lpd.8:52
+#: cups-lpd.8:53
 #, no-wrap
 msgid "ERRORS"
 msgstr "ERREURS"
 
 #. type: Plain text
-#: cups-lpd.8:54
+#: cups-lpd.8:55
 msgid "Errors are sent to the system log."
 msgstr "Les erreurs sont envoyées vers le journal système."
 
 #. type: Plain text
-#: cups-lpd.8:59
+#: cups-lpd.8:60
 #, no-wrap
 msgid ""
 "I</etc/inetd.conf>\n"
@@ -8344,7 +8392,7 @@ msgstr ""
 "I</System/Library/LaunchDaemons/org.cups.cups-lpd.plist>\n"
 
 #. type: Plain text
-#: cups-lpd.8:64
+#: cups-lpd.8:65
 #, fuzzy
 msgid ""
 "The B<cups-lpd> program is deprecated and will no longer be supported in a "
@@ -8355,14 +8403,14 @@ msgstr ""
 
 # type: SH
 #. type: SS
-#: cups-lpd.8:64
+#: cups-lpd.8:65
 #, no-wrap
 msgid "PERFORMANCE"
 msgstr "PERFORMANCE"
 
 # type: Plain text
 #. type: Plain text
-#: cups-lpd.8:69
+#: cups-lpd.8:70
 msgid ""
 "B<cups-lpd> performs well with small numbers of clients and printers.  "
 "However, since a new process is created for each connection and since each "
@@ -8380,14 +8428,14 @@ msgstr ""
 
 # type: SH
 #. type: SS
-#: cups-lpd.8:69
+#: cups-lpd.8:70
 #, no-wrap
 msgid "SECURITY"
 msgstr "SÉCURITÉ"
 
 # type: Plain text
 #. type: Plain text
-#: cups-lpd.8:76
+#: cups-lpd.8:77
 msgid ""
 "B<cups-lpd> currently does not perform any access control based on the "
 "settings in I<cupsd.conf(5)> or in the I<hosts.allow(5)> or I<hosts.deny(5)> "
@@ -8403,7 +8451,7 @@ msgstr ""
 
 # type: Plain text
 #. type: Plain text
-#: cups-lpd.8:82
+#: cups-lpd.8:83
 msgid ""
 "While B<xinetd>(8)  has built-in access control support, you should use the "
 "TCP wrappers package with B<inetd>(8)  to limit access to only those "
@@ -8415,7 +8463,7 @@ msgstr ""
 
 # type: Plain text
 #. type: Plain text
-#: cups-lpd.8:86
+#: cups-lpd.8:87
 msgid ""
 "B<cups-lpd> is not enabled by the standard CUPS distribution.  Please "
 "consult with your operating system vendor to determine whether it is enabled "
@@ -8426,7 +8474,7 @@ msgstr ""
 "s'il est activé sur votre système."
 
 #. type: Plain text
-#: cups-lpd.8:92
+#: cups-lpd.8:93
 msgid ""
 "If you are using B<inetd>(8), add the following line to the I<inetd.conf> "
 "file to enable the B<cups-lpd> mini-server:"
@@ -8436,7 +8484,7 @@ msgstr ""
 
 # type: Plain text
 #. type: Plain text
-#: cups-lpd.8:96
+#: cups-lpd.8:97
 #, no-wrap
 msgid ""
 "    printer stream tcp nowait lp /usr/lib/cups/daemon/cups-lpd cups-lpd \\e\n"
@@ -8445,19 +8493,8 @@ msgstr ""
 "    printer stream tcp nowait lp /usr/lib/cups/daemon/cups-lpd cups-lpd \\e\n"
 "        -o document-format=application/octet-stream\n"
 
-# type: Plain text
-#. type: Plain text
-#: cups-lpd.8:102
-msgid ""
-"I<Note:> If you are using Solaris 10 or higher, you must run the "
-"B<inetdconv>(1m)  program to register the changes to the I<inetd.conf> file."
-msgstr ""
-"B<Remarque :> si vous utilisez Solaris 10 ou une version ultérieure, vous "
-"devez exécuter B<inetdconv>(1m) pour enregistrer les changements apportés au "
-"fichier I<inetd.conf>."
-
 #. type: Plain text
-#: cups-lpd.8:111
+#: cups-lpd.8:108
 msgid ""
 "CUPS includes configuration files for B<launchd>(8), B<systemd>(8), and "
 "B<xinetd>(8).  Simply enable the B<cups-lpd> service using the corresponding "
@@ -8468,10 +8505,14 @@ msgstr ""
 "utilisant le programme de contrôle correspondant."
 
 #. type: Plain text
-#: cups-lpd.8:118
+#: cups-lpd.8:116
+#, fuzzy
+#| msgid ""
+#| "B<cupsd>(8), B<inetd>(8), B<launchd>(8), B<xinetd>(8), CUPS Online Help "
+#| "(http://localhost:631/help), RFC 2569"
 msgid ""
-"B<cupsd>(8), B<inetd>(8), B<launchd>(8), B<xinetd>(8), CUPS Online Help "
-"(http://localhost:631/help), RFC 2569"
+"B<cups>(1), B<cupsd>(8), B<inetd>(8), B<launchd>(8), B<xinetd>(8), CUPS "
+"Online Help (http://localhost:631/help), RFC 2569"
 msgstr ""
 "B<cupsd>(8), B<inetd>(8), B<launchd>(8), B<xinetd>(8), aide en ligne de CUPS "
 "E<lt>URL:I<http://localhost:631/help>E<gt>, RFC 2569"
@@ -17487,6 +17528,14 @@ msgstr ""
 msgid "ppdc"
 msgstr "ppdc"
 
+# type: TH
+#. type: TH
+#: ppdc.1:10
+#, fuzzy, no-wrap
+#| msgid "23 October 2008"
+msgid "28 October 2020"
+msgstr "23 octobre 2008"
+
 #. type: Plain text
 #: ppdc.1:13
 msgid "ppdc - cups ppd compiler (deprecated)"
@@ -17612,9 +17661,13 @@ msgstr ""
 # type: Plain text
 #. type: Plain text
 #: ppdc.1:73
+#, fuzzy
+#| msgid ""
+#| "Specifies that the output filename should be based on the ModelName value "
+#| "instead of FileName or PCFilenName."
 msgid ""
 "Specifies that the output filename should be based on the ModelName value "
-"instead of FileName or PCFilenName."
+"instead of FileName or PCFileName."
 msgstr ""
 "Indiquer que le nom du fichier de sortie sera basé sur la valeur ModelName "
 "au lieu de FileName ou PCFilenName."
@@ -18497,6 +18550,24 @@ msgstr ""
 "types>(5), B<printers.conf>(5), aide en ligne de CUPS E<lt>URL:I<http://"
 "localhost:631/help>E<gt>."
 
+# type: Plain text
+#~ msgid ""
+#~ "Specifies that a failed print job should stop the printer unless "
+#~ "otherwise specified for the printer."
+#~ msgstr ""
+#~ "Indiquer qu’une tâche d’impression ayant échoué arrêtera l’imprimante à "
+#~ "moins d’indication contraire pour l’imprimante."
+
+# type: Plain text
+#~ msgid ""
+#~ "I<Note:> If you are using Solaris 10 or higher, you must run the "
+#~ "B<inetdconv>(1m)  program to register the changes to the I<inetd.conf> "
+#~ "file."
+#~ msgstr ""
+#~ "B<Remarque :> si vous utilisez Solaris 10 ou une version ultérieure, vous "
+#~ "devez exécuter B<inetdconv>(1m) pour enregistrer les changements apportés "
+#~ "au fichier I<inetd.conf>."
+
 # type: TH
 #~ msgid "17 May 2019"
 #~ msgstr "17 mai 2019"
@@ -19356,14 +19427,6 @@ msgstr ""
 #~ msgid "Sets a job option."
 #~ msgstr "Définir une option pour le travail d'impression."
 
-# type: Plain text
-#~ msgid ""
-#~ "Specifies that a failed print job should be retried at a later time "
-#~ "unless otherwise specified for the printer."
-#~ msgstr ""
-#~ "Indiquer qu’une tâche d’impression ayant échoué sera recommencée plus "
-#~ "tard à moins d’indication contraire pour l’imprimante."
-
 # type: TH
 #~ msgid "8 July 2014"
 #~ msgstr "8 Juillet 2014"
@@ -19678,10 +19741,6 @@ msgstr ""
 #~ "Récupérer l'ensemble complet des pilotes Windows devrait être plus simple."
 
 # type: TH
-#~ msgid "23 October 2008"
-#~ msgstr "23 octobre 2008"
-
-# type: TH
 #~ msgid "11 January 2013"
 #~ msgstr "11 janvier 2013"
 
@@ -20332,10 +20391,6 @@ msgstr ""
 #~ msgid "LIMITATIONS"
 #~ msgstr "LIMITATIONS"
 
-# type: TH
-#~ msgid "19 November 2009"
-#~ msgstr "19 novembre 2009"
-
 # type: TP
 #~ msgid "-q"
 #~ msgstr "B<-q>"
diff -pruN 2.3.3-3/debian/patches/0001-Fix-hyphen-used-as-minus-sign-manpage-errors.patch 2.3.3op1-3/debian/patches/0001-Fix-hyphen-used-as-minus-sign-manpage-errors.patch
--- 2.3.3-3/debian/patches/0001-Fix-hyphen-used-as-minus-sign-manpage-errors.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0001-Fix-hyphen-used-as-minus-sign-manpage-errors.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,571 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Tue, 9 Aug 2016 18:11:05 +0200
-Subject: Fix hyphen-used-as-minus-sign manpage errors
-
-Automatically generated using sed -i -s 's/^-/\\-/g;s/ -/ \\-/g;s/"-/"\\-/g' man/*.man*
-Also fix a missing backslash escape
-
-Origin: vendor
-Bug-Upstream: https://github.com/apple/cups/issues/4299
-Patch-Name: manpage-hyphen-minus.patch
----
- man/backend.7         |  4 ++--
- man/client.conf.5     |  4 ++--
- man/cups-files.conf.5 |  2 +-
- man/cups-lpd.8        |  6 +++---
- man/cups-snmp.conf.5  |  2 +-
- man/cups.1            |  2 +-
- man/cupsctl.8         |  6 +++---
- man/cupsd-logs.5      | 36 ++++++++++++++++++------------------
- man/cupsd.conf.5      |  2 +-
- man/cupsfilter.8      |  2 +-
- man/filter.7          |  2 +-
- man/ippeveprinter.1   |  6 +++---
- man/ippfind.1         |  6 +++---
- man/ipptoolfile.5     |  8 ++++----
- man/lp.1              | 12 ++++++------
- man/lpadmin.8         |  6 +++---
- man/lpoptions.1       |  4 ++--
- man/lpr.1             |  8 ++++----
- man/mime.convs.5      |  6 +++---
- man/mime.types.5      |  4 ++--
- man/ppdc.1            |  2 +-
- 21 files changed, 65 insertions(+), 65 deletions(-)
-
-diff --git a/man/backend.7 b/man/backend.7
-index 5a70326..3c42631 100644
---- a/man/backend.7
-+++ b/man/backend.7
-@@ -163,7 +163,7 @@ The scheduler will respond to this by canceling the job.
- .TP 5
- .B CUPS_BACKEND_RETRY
- The print file was not successfully transmitted because of a temporary issue.
--The scheduler will retry the job at a future time - other jobs may print before this one.
-+The scheduler will retry the job at a future time \- other jobs may print before this one.
- .TP 5
- .B CUPS_BACKEND_RETRY_CURRENT
- The print file was not successfully transmitted because of a temporary issue.
-@@ -198,7 +198,7 @@ or
- programs to send print jobs or
- .BR lpinfo (8)
- to query for available printers using the backend.
--The one exception is the SNMP backend - see
-+The one exception is the SNMP backend \- see
- .BR cups-snmp (8)
- for more information.
- .SH NOTES
-diff --git a/man/client.conf.5 b/man/client.conf.5
-index 4dbf0c4..f0adb9f 100644
---- a/man/client.conf.5
-+++ b/man/client.conf.5
-@@ -77,7 +77,7 @@ The \fIAllowDH\fR option enables cipher suites using plain Diffie-Hellman key ne
- The \fIAllowRC4\fR option enables the 128-bit RC4 cipher suites, which are required for some older clients.
- The \fIAllowSSL3\fR option enables SSL v3.0, which is required for some older clients that do not support TLS v1.0.
- The \fIDenyCBC\fR option disables all CBC cipher suites.
--The \fIDenyTLS1.0\fR option disables TLS v1.0 support - this sets the minimum protocol version to TLS v1.1.
-+The \fIDenyTLS1.0\fR option disables TLS v1.0 support \- this sets the minimum protocol version to TLS v1.1.
- The \fIMinTLS\fR options set the minimum TLS version to support.
- The \fIMaxTLS\fR options set the maximum TLS version to support.
- Not all operating systems support TLS 1.3 at this time.
-@@ -130,7 +130,7 @@ Configuration settings can instead be viewed or changed using the
- command:
- .nf
- defaults write /Library/Preferences/org.cups.PrintingPrefs.plist Encryption Required
--defaults write /Library/Preferences/org.cups.PrintingPrefs.plist TrustOnFirstUse -bool NO
-+defaults write /Library/Preferences/org.cups.PrintingPrefs.plist TrustOnFirstUse \-bool NO
- 
- defaults read /Library/Preferences/org.cups.PrintingPrefs.plist Encryption
- .fi
-diff --git a/man/cups-files.conf.5 b/man/cups-files.conf.5
-index b451e2f..7249406 100644
---- a/man/cups-files.conf.5
-+++ b/man/cups-files.conf.5
-@@ -236,7 +236,7 @@ The following directives are deprecated and will be removed from a future versio
- \fBFileDevice No\fR
- Specifies whether the file pseudo-device can be used for new printer queues.
- The URI "file:///dev/null" is always allowed.
--File devices cannot be used with "raw" print queues - a PPD file is required.
-+File devices cannot be used with "raw" print queues \- a PPD file is required.
- The specified file is overwritten for every print job.
- Writing to directories is not supported.
- .\"#FontPath
-diff --git a/man/cups-lpd.8 b/man/cups-lpd.8
-index e8ce325..344d2af 100644
---- a/man/cups-lpd.8
-+++ b/man/cups-lpd.8
-@@ -15,9 +15,9 @@ cups-lpd \- receive print jobs and report printer status to lpd clients (depreca
- [
- \fB\-h \fIhostname\fR[\fB:\fIport\fR]
- ] [
--.B -n
-+.B \-n
- ] [
--.B -o
-+.B \-o
- .I option=value
- ]
- .SH DESCRIPTION
-@@ -34,7 +34,7 @@ and
- \fB-h \fIhostname\fR[\fB:\fIport\fR]
- Sets the CUPS server (and port) to use.
- .TP 5
--.B -n
-+.B \-n
- Disables reverse address lookups; normally
- .B cups-lpd
- will try to discover the hostname of the client via a reverse DNS lookup.
-diff --git a/man/cups-snmp.conf.5 b/man/cups-snmp.conf.5
-index 4ca20f2..bb77c73 100644
---- a/man/cups-snmp.conf.5
-+++ b/man/cups-snmp.conf.5
-@@ -16,7 +16,7 @@ The
- file configures how the standard CUPS network backends (http, https, ipp, ipps, lpd, snmp, and socket) access printer information using SNMPv1 and is normally located in the \fI/etc/cups\fR directory.
- Each line in the file can be a configuration directive, a blank line, or a comment. Comment lines start with the # character.
- .LP
--The Community and DebugLevel directives are used by all backends. The remainder apply only to the SNMP backend -
-+The Community and DebugLevel directives are used by all backends. The remainder apply only to the SNMP backend \-
- .BR cups-snmp (8).
- .SH DIRECTIVES
- The following directives are understood by the CUPS network backends:
-diff --git a/man/cups.1 b/man/cups.1
-index 706620d..b0c51a7 100644
---- a/man/cups.1
-+++ b/man/cups.1
-@@ -38,7 +38,7 @@ The easiest way to start is by using the web interface to configure your printer
- .LP
- When you are asked for a username and password, enter your login username and password or the "root" username and password.
- .LP
--After the printer is added you will be asked to set the default printer options (paper size, output mode, etc.) for the printer. Make any changes as needed and then click/press on the Set Default Options button to save them. Some printers also support auto-configuration - click/press on the Query Printer for Default Options button to update the options automatically.
-+After the printer is added you will be asked to set the default printer options (paper size, output mode, etc.) for the printer. Make any changes as needed and then click/press on the Set Default Options button to save them. Some printers also support auto-configuration \- click/press on the Query Printer for Default Options button to update the options automatically.
- .LP
- Once you have added the printer, you can print to it from any application. You can also choose Print Test Page from the maintenance menu to print a simple test page and verify that everything is working properly.
- .LP
-diff --git a/man/cupsctl.8 b/man/cupsctl.8
-index 791954c..c88eb22 100644
---- a/man/cupsctl.8
-+++ b/man/cupsctl.8
-@@ -73,19 +73,19 @@ Display the current settings:
- Enable debug logging:
- .nf
- 
--    cupsctl --debug-logging
-+    cupsctl \--debug-logging
- 
- .fi
- Get the current debug logging state:
- .nf
- 
--    cupsctl | grep '^_debug_logging' | awk -F= '{print $2}'
-+    cupsctl | grep '^_debug_logging' | awk \-F= '{print $2}'
- 
- .fi
- Disable printer sharing:
- .nf
- 
--    cupsctl --no-share-printers
-+    cupsctl \--no-share-printers
- .fi
- .SH KNOWN ISSUES
- You cannot set the Listen or Port directives using \fBcupsctl\fR.
-diff --git a/man/cupsd-logs.5 b/man/cupsd-logs.5
-index 2070be9..a912c46 100644
---- a/man/cupsd-logs.5
-+++ b/man/cupsd-logs.5
-@@ -30,25 +30,25 @@ Each line is in an extended version of the so-called "Common Log Format" used by
- For example:
- .nf
- 
--    10.0.1.2 - - [01/Dec/2005:21:50:28 +0000] "POST / HTTP/1.1" 200 317
-+    10.0.1.2 \- \- [01/Dec/2005:21:50:28 +0000] "POST / HTTP/1.1" 200 317
-       CUPS-Get-Printers successful-ok-ignored-or-substituted-attributes
--    localhost - - [01/Dec/2005:21:50:32 +0000] "GET /admin HTTP/1.1"
--      200 0 - -
--    localhost - - [01/Dec/2005:21:50:32 +0000] "POST / HTTP/1.1"
-+    localhost \- \- [01/Dec/2005:21:50:32 +0000] "GET /admin HTTP/1.1"
-+      200 0 \- \-
-+    localhost \- \- [01/Dec/2005:21:50:32 +0000] "POST / HTTP/1.1"
-       200 157 CUPS-Get-Printers
-       successful-ok-ignored-or-substituted-attributes
--    localhost - - [01/Dec/2005:21:50:32 +0000] "POST / HTTP/1.1"
--      200 1411 CUPS-Get-Devices -
--    localhost - - [01/Dec/2005:21:50:32 +0000] "GET /admin HTTP/1.1"
--      200 6667 - -
-+    localhost \- \- [01/Dec/2005:21:50:32 +0000] "POST / HTTP/1.1"
-+      200 1411 CUPS-Get-Devices \-
-+    localhost \- \- [01/Dec/2005:21:50:32 +0000] "GET /admin HTTP/1.1"
-+      200 6667 \- \-
- 
- .fi
- The \fIhost\fR field will normally only be an IP address unless you have enabled the HostNameLookups directive in the \fIcupsd.conf\fR file or if the IP address corresponds to your local machine.
- .LP
--The \fIgroup\fR field always contains "-".
-+The \fIgroup\fR field always contains "\-".
- .LP
- The \fIuser\fR field is the authenticated username of the requesting user.
--If no username and password is supplied for the request then this field contains "-".
-+If no username and password is supplied for the request then this field contains "\-".
- .LP
- The \fIdate-time\fR field is the date and time of the request in local time and is in the format "[DD/MON/YYYY:HH:MM:SS +ZZZZ]".
- .LP
-@@ -98,7 +98,7 @@ Request too large; typically this means that a client tried to print a file larg
- Upgrading to TLS-encrypted connection.
- .TP 5
- 500
--Server error; typically this happens when the server is unable to open/create a file - consult the error_log file for details.
-+Server error; typically this happens when the server is unable to open/create a file \- consult the error_log file for details.
- .TP 5
- 501
- The client requested encryption but encryption support is not enabled/compiled in.
-@@ -110,11 +110,11 @@ HTTP version number not supported; typically this means that you have a maliciou
- The \fIbytes\fR field contains the number of bytes in the request.
- For POST requests the bytes field contains the number of bytes of non-IPP data that is received from the client.
- .LP
--The \fIipp-operation\fR field contains either "-" for non-IPP requests or the IPP operation name for POST requests containing an IPP request.
-+The \fIipp-operation\fR field contains either "\-" for non-IPP requests or the IPP operation name for POST requests containing an IPP request.
- .LP
--The \fIipp-status\fR field contains either "-" for non-IPP requests or the IPP status code name for POST requests containing an IPP response.
-+The \fIipp-status\fR field contains either "\-" for non-IPP requests or the IPP status code name for POST requests containing an IPP response.
- .SS ERROR LOG FILE FORMAT
--The \fIerror_log\fR file lists messages from the scheduler - errors, warnings, etc. The LogLevel directive in the
-+The \fIerror_log\fR file lists messages from the scheduler \- errors, warnings, etc. The LogLevel directive in the
- .BR cupsd.conf (5)
- file controls which messages are logged:
- .nf
-@@ -204,15 +204,15 @@ The format of this field is identical to the data-time field in the \fIaccess_lo
- .LP
- The \fInum-sheets\fR field provides the total number of pages (sheets) that have been printed on for the job.
- .LP
--The \fIjob-billing\fR field contains a copy of the job-billing or job-account-id attributes provided with the IPP Create-Job or Print-Job requests or "-" if neither was provided.
-+The \fIjob-billing\fR field contains a copy of the job-billing or job-account-id attributes provided with the IPP Create-Job or Print-Job requests or "\-" if neither was provided.
- .LP
- The \fIjob-originating-host-name\fR field contains the hostname or IP address of the client that printed the job.
- .LP
--The \fIjob-name\fR field contains a copy of the job-name attribute provided with the IPP Create-Job or Print-Job requests or "-" if none was provided.
-+The \fIjob-name\fR field contains a copy of the job-name attribute provided with the IPP Create-Job or Print-Job requests or "\-" if none was provided.
- .LP
--The \fImedia\fR field contains a copy of the media or media-col/media-size attribute provided with the IPP Create-Job or Print-Job requests or "-" if none was provided.
-+The \fImedia\fR field contains a copy of the media or media-col/media-size attribute provided with the IPP Create-Job or Print-Job requests or "\-" if none was provided.
- .LP
--The \fIsides\fR field contains a copy of the sides attribute provided with the IPP Create-Job or Print-Job requests or "-" if none was provided.
-+The \fIsides\fR field contains a copy of the sides attribute provided with the IPP Create-Job or Print-Job requests or "\-" if none was provided.
- .SH SEE ALSO
- .BR cupsd (8),
- .BR cupsd.conf (5),
-diff --git a/man/cupsd.conf.5 b/man/cupsd.conf.5
-index 00b1a22..49fdb06 100644
---- a/man/cupsd.conf.5
-+++ b/man/cupsd.conf.5
-@@ -446,7 +446,7 @@ The \fIAllowDH\fR option enables cipher suites using plain Diffie-Hellman key ne
- The \fIAllowRC4\fR option enables the 128-bit RC4 cipher suites, which are required for some older clients.
- The \fIAllowSSL3\fR option enables SSL v3.0, which is required for some older clients that do not support TLS v1.0.
- The \fIDenyCBC\fR option disables all CBC cipher suites.
--The \fIDenyTLS1.0\fR option disables TLS v1.0 support - this sets the minimum protocol version to TLS v1.1.
-+The \fIDenyTLS1.0\fR option disables TLS v1.0 support \- this sets the minimum protocol version to TLS v1.1.
- The \fIMinTLS\fR options set the minimum TLS version to support.
- The \fIMaxTLS\fR options set the maximum TLS version to support.
- Not all operating systems support TLS 1.3 at this time.
-diff --git a/man/cupsfilter.8 b/man/cupsfilter.8
-index c655c21..fe4c5a2 100644
---- a/man/cupsfilter.8
-+++ b/man/cupsfilter.8
-@@ -126,7 +126,7 @@ command use the current user and security session. This may result in different
- The following command will generate a PDF preview of job 42 for a printer named "myprinter" and save it to a file named "preview.pdf":
- .nf
- 
--    cupsfilter -m application/pdf -d myprinter -j 42 >preview.pdf
-+    cupsfilter \-m application/pdf \-d myprinter \-j 42 >preview.pdf
- .fi
- .SH SEE ALSO
- .BR cups (1),
-diff --git a/man/filter.7 b/man/filter.7
-index dbc3150..8cb79bb 100644
---- a/man/filter.7
-+++ b/man/filter.7
-@@ -136,7 +136,7 @@ Sets the named keywords in the printer's PPD file. This is typically used to upd
- .TP 5
- \fBSTATE: +\fI printer-state-reason \fR[ \fI... printer-state-reason\fR ]
- .TP 5
--\fBSTATE: -\fI printer-state-reason \fR[ \fI... printer-state-reason\fR ]
-+\fBSTATE: \-\fI printer-state-reason \fR[ \fI... printer-state-reason\fR ]
- Sets, adds, or removes "printer-state-reason" keywords for the current queue. Typically this is used to indicate media, ink, and toner conditions on a printer.
- .TP 5
- \fBWARNING:\fI message\fR
-diff --git a/man/ippeveprinter.1 b/man/ippeveprinter.1
-index fa32efb..8ab2654 100644
---- a/man/ippeveprinter.1
-+++ b/man/ippeveprinter.1
-@@ -143,8 +143,8 @@ If "command" is not an absolute path ("/path/to/command"),
- looks for the command in the "command" subdirectory of the CUPS binary directory, typically /usr/lib/cups/command or /usr/libexec/cups/command.
- The
- .BR cups-config (1)
--command can be used to discover the correct binary directory ("cups-config --serverbin").
--In addition, the CUPS_SERVERBIN environment variable can be used to override the default location of this directory - see the
-+command can be used to discover the correct binary directory ("cups-config \--serverbin").
-+In addition, the CUPS_SERVERBIN environment variable can be used to override the default location of this directory \- see the
- .BR cups (1)
- man page for more details.
- .TP 5
-@@ -244,7 +244,7 @@ Logs an informational/progress message if \-v has been specified and copies the
- \fBSTATE: \fIkeyword[,keyword,...]\fR
- Sets the printer's "printer-state-reasons" attribute to the listed keywords.
- .TP 5
--\fBSTATE: -\fIkeyword[,keyword,...]\fR
-+\fBSTATE: \-\fIkeyword[,keyword,...]\fR
- Removes the listed keywords from the printer's "printer-state-reasons" attribute.
- .TP 5
- \fBSTATE: +\fIkeyword[,keyword,...]\fR
-diff --git a/man/ippfind.1 b/man/ippfind.1
-index 32f2e6f..d77ef75 100644
---- a/man/ippfind.1
-+++ b/man/ippfind.1
-@@ -75,7 +75,7 @@ True is the hostname matches the given regular expression.
- .B \-l
- .TP 5
- .B \-\-ls
--Lists attributes returned by Get-Printer-Attributes for IPP printers and traditional \fIfind\fR "-ls" output for HTTP URLs.
-+Lists attributes returned by Get-Printer-Attributes for IPP printers and traditional \fIfind\fR "\-ls" output for HTTP URLs.
- The result is true if the URI is accessible, false otherwise.
- .TP 5
- .B \-\-local
-@@ -108,7 +108,7 @@ The result is always true.
- .B \-q
- .TP 5
- .B \-\-quiet
--Quiet mode - just returns the exit codes below.
-+Quiet mode \- just returns the exit codes below.
- .TP 5
- .B \-r
- .TP 5
-@@ -141,7 +141,7 @@ True if the URI matches the given regular expression.
- .TP 5
- \fB\-\-exec \fIutility \fR[ \fIargument \fR... ] \fB;\fR
- Executes the specified program if the current result is true.
--"{foo}" arguments are replaced with the corresponding value - see SUBSTITUTIONS below.
-+"{foo}" arguments are replaced with the corresponding value \- see SUBSTITUTIONS below.
- .PP
- Expressions may also contain modifiers:
- .TP 5
-diff --git a/man/ipptoolfile.5 b/man/ipptoolfile.5
-index 7001017..5763232 100644
---- a/man/ipptoolfile.5
-+++ b/man/ipptoolfile.5
-@@ -166,8 +166,8 @@ The following directives are understood within a \fItest\fR:
- \fBATTR \fItag attribute-name value(s)\fR
- Adds an attribute to the test request.
- Out-of-band tags (admin-define, delete-attribute, no-value, not-settable, unknown, unsupported) have no value.
--Values for other tags are delimited by the comma (",") character - escape commas using the "\\" character.
--Common attributes and values are listed in the IANA IPP registry - see references below.
-+Values for other tags are delimited by the comma (",") character \- escape commas using the "\\" character.
-+Common attributes and values are listed in the IANA IPP registry \- see references below.
- .TP 5
- \fBATTR collection \fIattribute-name \fB{ MEMBER \fItag member-name value(s) ... \fB}\fR [ \fI... \fB,{ \fI... \fB} \fR]
- Adds a collection attribute to the test request.
-@@ -194,7 +194,7 @@ test report.
- \fBEXPECT ?\fIattribute-name predicate(s)\fR
- .TP 5
- \fBEXPECT !\fIattribute-name\fR
--Specifies that the response must/may/must not include the named attribute. Additional requirements can be added as predicates - see the "EXPECT PREDICATES" section for more information on predicates. Attribute names can specify member attributes by separating the attribute and member names with the forward slash, for example "media\-col/media\-size/x\-dimension".
-+Specifies that the response must/may/must not include the named attribute. Additional requirements can be added as predicates \- see the "EXPECT PREDICATES" section for more information on predicates. Attribute names can specify member attributes by separating the attribute and member names with the forward slash, for example "media\-col/media\-size/x\-dimension".
- .TP 5
- \fBEXPECT-ALL \fIattribute-name \fR[ \fIpredicate(s) \fR]
- .TP 5
-@@ -246,7 +246,7 @@ Specifies whether
- will skip the current test if the previous test resulted in an error/failure.
- .TP 5
- \fBSTATUS \fIstatus-code \fR[ \fIpredicate\fR ]
--Specifies an expected response status-code value. Additional requirements can be added as predicates - see the "STATUS PREDICATES" section for more information on predicates.
-+Specifies an expected response status-code value. Additional requirements can be added as predicates \- see the "STATUS PREDICATES" section for more information on predicates.
- .TP 5
- \fBTEST\-ID "\fIidentifier\fR"
- Specifies an identifier string for the current test.
-diff --git a/man/lp.1 b/man/lp.1
-index cbea3b8..839a482 100644
---- a/man/lp.1
-+++ b/man/lp.1
-@@ -83,7 +83,7 @@ lp \- print files
- ]
- .SH DESCRIPTION
- \fBlp\fR submits files for printing or alters a pending job.
--Use a filename of "-" to force printing from the standard input.
-+Use a filename of "\-" to force printing from the standard input.
- .SS THE DEFAULT DESTINATION
- CUPS provides many ways to set the default destination. The \fBLPDEST\fR and \fBPRINTER\fR environment variables are consulted first.
- If neither are set, the current default set using the
-@@ -153,7 +153,7 @@ Use a value of \fIrestart\fR with the \fI-i\fR option to restart a completed job
- \fB\-P \fIpage-list\fR
- Specifies which pages to print in the document.
- The list can contain a list of numbers and ranges (#-#) separated by commas, e.g., "1,3-5,16".
--The page numbers refer to the output pages and not the document's original pages - options like "number-up" can affect the numbering of the pages.
-+The page numbers refer to the output pages and not the document's original pages \- options like "number-up" can affect the numbering of the pages.
- .SS COMMON JOB OPTIONS
- Aside from the printer-specific options reported by the
- .BR lpoptions (1)
-@@ -183,7 +183,7 @@ Prints the job in reverse portrait (rotated 180 degrees).
- \fB\-o print\-quality=4\fR
- .TP 5
- \fB\-o print\-quality=5\fR
--Specifies the output quality - draft (3), normal (4), or best (5).
-+Specifies the output quality \- draft (3), normal (4), or best (5).
- .TP 5
- \fB\-o sides=one\-sided\fR
- Prints on one side of the paper.
-@@ -202,19 +202,19 @@ The \fI-q\fR option accepts a different range of values than the Solaris lp comm
- Print two copies of a document to the default printer:
- .nf
- 
--    lp -n 2 filename
-+    lp \-n 2 filename
- 
- .fi
- Print a double-sided legal document to a printer called "foo":
- .nf
- 
--    lp -d foo -o media=legal -o sides=two-sided-long-edge filename
-+    lp \-d foo \-o media=legal \-o sides=two-sided-long-edge filename
- 
- .fi
- Print a presentation document 2-up to a printer called "bar":
- .nf
- 
--    lp -d bar -o number-up=2 filename
-+    lp \-d bar \-o number-up=2 filename
- .fi
- .SH SEE ALSO
- .BR cancel (1),
-diff --git a/man/lpadmin.8 b/man/lpadmin.8
-index 1b8c91b..ce6a698 100644
---- a/man/lpadmin.8
-+++ b/man/lpadmin.8
-@@ -120,7 +120,7 @@ command.
- .TP 5
- \fB\-o \fIname\fB-default=\fIvalue\fR
- Sets a default server-side option for the destination.
--Any print-time option can be defaulted, e.g., "-o number-up-default=2" to set the default "number-up" option value to 2.
-+Any print-time option can be defaulted, e.g., "\-o number-up-default=2" to set the default "number-up" option value to 2.
- .TP 5
- \fB\-o port\-monitor=\fIname\fR
- Sets the binary communications program to use when printing, "none", "bcp", or "tbcp".
-@@ -162,7 +162,7 @@ If the resulting class becomes empty it is removed.
- Sets user-level access control on a destination.
- Names starting with "@" are interpreted as UNIX groups.
- The latter two forms turn user-level access control off.
--Note: The user 'root' is not granted special access - using "-u allow:foo,bar" will allow users 'foo' and 'bar' to access the printer but NOT 'root'.
-+Note: The user 'root' is not granted special access \- using "\-u allow:foo,bar" will allow users 'foo' and 'bar' to access the printer but NOT 'root'.
- .TP 5
- \fB\-v "\fIdevice-uri\fB"\fR
- Sets the \fIdevice-uri\fR attribute of the printer queue.
-@@ -218,7 +218,7 @@ These files should not be edited directly and are an implementation detail of CU
- Create an IPP Everywhere print queue:
- .nf
- 
--    lpadmin -p myprinter -E -v ipp://myprinter.local/ipp/print -m everywhere
-+    lpadmin \-p myprinter \-E \-v ipp://myprinter.local/ipp/print \-m everywhere
- 
- .fi
- .SH SEE ALSO
-diff --git a/man/lpoptions.1 b/man/lpoptions.1
-index a34fd01..7550d9a 100644
---- a/man/lpoptions.1
-+++ b/man/lpoptions.1
-@@ -102,9 +102,9 @@ Destinations can only be removed using the
- .BR lpadmin (8)
- command.
- .SH FILES
--\fI~/.cups/lpoptions\fR - user defaults and instances created by non-root users.
-+\fI~/.cups/lpoptions\fR \- user defaults and instances created by non-root users.
- .br
--\fI/etc/cups/lpoptions\fR - system-wide defaults and instances created by the root user.
-+\fI/etc/cups/lpoptions\fR \- system-wide defaults and instances created by the root user.
- .SH CONFORMING TO
- The \fBlpoptions\fR command is unique to CUPS.
- .SH SEE ALSO
-diff --git a/man/lpr.1 b/man/lpr.1
-index f367cd9..635d126 100644
---- a/man/lpr.1
-+++ b/man/lpr.1
-@@ -138,7 +138,7 @@ Prints the job in reverse portrait (rotated 180 degrees).
- \fB\-o print\-quality=4\fR
- .TP 5
- \fB\-o print\-quality=5\fR
--Specifies the output quality - draft (3), normal (4), or best (5).
-+Specifies the output quality \- draft (3), normal (4), or best (5).
- .TP 5
- \fB\-o sides=one\-sided\fR
- Prints on one side of the paper.
-@@ -154,19 +154,19 @@ The \fI\-c\fR, \fI\-d\fR, \fI\-f\fR, \fI\-g\fR, \fI\-i\fR, \fI\-n\fR, \fI\-t\fR,
- Print two copies of a document to the default printer:
- .nf
- 
--    lpr -# 2 filename
-+    lpr \-# 2 filename
- 
- .fi
- Print a double-sided legal document to a printer called "foo":
- .nf
- 
--    lpr -P foo -o media=legal -o sides=two-sided-long-edge filename
-+    lpr \-P foo \-o media=legal \-o sides=two-sided-long-edge filename
- 
- .fi
- Print a presentation document 2-up to a printer called "foo":
- .nf
- 
--    lpr -P foo -o number-up=2 filename
-+    lpr \-P foo \-o number-up=2 filename
- .fi
- .SH SEE ALSO
- .BR cancel (1),
-diff --git a/man/mime.convs.5 b/man/mime.convs.5
-index 25a6f76..04ba394 100644
---- a/man/mime.convs.5
-+++ b/man/mime.convs.5
-@@ -35,11 +35,11 @@ A value of 100 means that the filter uses a large amount of resources while a va
- The \fIfilter\fR field specifies the filter program filename.
- Filenames are relative to the CUPS filter directory.
- .SH FILES
--\fI/etc/cups\fR - Typical CUPS configuration directory.
-+\fI/etc/cups\fR \- Typical CUPS configuration directory.
- .br
--\fI/usr/lib/cups/filter\fR - Typical CUPS filter directory.
-+\fI/usr/lib/cups/filter\fR \- Typical CUPS filter directory.
- .br
--\fI/usr/libexec/cups/filter\fR - CUPS filter directory on macOS.
-+\fI/usr/libexec/cups/filter\fR \- CUPS filter directory on macOS.
- .SH EXAMPLES
- Define a filter that converts PostScript documents to CUPS Raster format:
- .nf
-diff --git a/man/mime.types.5 b/man/mime.types.5
-index 7e83de1..3572726 100644
---- a/man/mime.types.5
-+++ b/man/mime.types.5
-@@ -35,7 +35,7 @@ See the "TYPE MATCHING AND PRIORITY" section for more information.
- .LP
- The rules may be grouped using parenthesis, joined using "+" for a logical AND, joined using "," or whitespace for a logical OR, and negated using "!".
- .SS RULES
--Rules take two forms - a filename extension by itself and functions with test
-+Rules take two forms \- a filename extension by itself and functions with test
- values inside parenthesis.
- The following functions are available:
- .TP 5
-@@ -85,7 +85,7 @@ extension "doc", normally the type "text/bar" will be chosen since its name is
- alphanumerically smaller than "text/foo".
- However, if "text/foo" also defines a higher priority than "text/bar", "text/foo" will be chosen instead.
- .SH FILES
--\fI/etc/cups\fR - Typical CUPS configuration directory.
-+\fI/etc/cups\fR \- Typical CUPS configuration directory.
- .SH EXAMPLES
- Define two MIME media types for raster data, with one being a subset with higher priority:
- .nf
-diff --git a/man/ppdc.1 b/man/ppdc.1
-index 44e9d24..38e2669 100644
---- a/man/ppdc.1
-+++ b/man/ppdc.1
-@@ -85,7 +85,7 @@ The default is to generate uncompressed PPD files.
- \fB\-\-crlf\fR
- .TP 5
- \fB\-\-lf\fR
--Specifies the line ending to use - carriage return, carriage return and line feed, or line feed alone.
-+Specifies the line ending to use \- carriage return, carriage return and line feed, or line feed alone.
- The default is to use the line feed character alone.
- .SH NOTES
- PPD files are deprecated and will no longer be supported in a future feature release of CUPS.
diff -pruN 2.3.3-3/debian/patches/0001-Force-a-5-second-sleep-to-wait-for-the-job-control-f.patch 2.3.3op1-3/debian/patches/0001-Force-a-5-second-sleep-to-wait-for-the-job-control-f.patch
--- 2.3.3-3/debian/patches/0001-Force-a-5-second-sleep-to-wait-for-the-job-control-f.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0001-Force-a-5-second-sleep-to-wait-for-the-job-control-f.patch	2020-12-04 09:32:55.000000000 +0000
@@ -0,0 +1,21 @@
+From: Michael R Sweet <msweet@msweet.org>
+Date: Sat, 28 Nov 2020 08:43:46 -0500
+Subject: Force a 5 second sleep to wait for the job control file to be
+ written.
+
+---
+ test/run-stp-tests.sh | 1 +
+ 1 file changed, 1 insertion(+)
+
+diff --git a/test/run-stp-tests.sh b/test/run-stp-tests.sh
+index 1af6d07..0bf95c5 100755
+--- a/test/run-stp-tests.sh
++++ b/test/run-stp-tests.sh
+@@ -844,6 +844,7 @@ else
+ 	echo "PASS"
+ 	echo "    PASSED" >>$strfile
+ 
++	sleep 5
+ 	./waitjobs.sh >>$strfile
+ 
+         echo $ac_n "Verifying that history still exists: $ac_c"
diff -pruN 2.3.3-3/debian/patches/0002-Install-root-backends-world-readable.patch 2.3.3op1-3/debian/patches/0002-Install-root-backends-world-readable.patch
--- 2.3.3-3/debian/patches/0002-Install-root-backends-world-readable.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0002-Install-root-backends-world-readable.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,66 +0,0 @@
-From: Martin Pitt <mpitt@debian.org>
-Date: Tue, 9 Aug 2016 18:11:06 +0200
-Subject: Install root backends world-readable
-
-This is needed:
- - to comply with Debian Policy
- - because it is both nonsensical to not do so
- - it also breaks system checkers, bug reporting, etc
-
-Bug: https://github.com/apple/cups/issues/2935
-Bug-Debian: https://bugs.debian.org/410171
-Patch-Name install-root-backends-world-readable.patch
----
- backend/Makefile         | 4 ++--
- scheduler/cups-deviced.c | 2 +-
- scheduler/job.c          | 2 +-
- 3 files changed, 4 insertions(+), 4 deletions(-)
-
-diff --git a/backend/Makefile b/backend/Makefile
-index e3ce49b..b734458 100644
---- a/backend/Makefile
-+++ b/backend/Makefile
-@@ -13,7 +13,7 @@ include ../Makedefs
- # Object files...
- #
- 
--# RBACKENDS are installed mode 0700 so cupsd will run them as root...
-+# RBACKENDS are installed mode 0744 so cupsd will run them as root...
- #
- # UBACKENDS and ULBACKENDS are installed mode 0755 so cupsd will run them as
- # an unprivileged user...
-@@ -118,7 +118,7 @@ install-exec:	$(INSTALLXPC)
- 	echo Installing backends in $(SERVERBIN)/backend
- 	$(INSTALL_DIR) -m 755 $(SERVERBIN)/backend
- 	for file in $(RBACKENDS); do \
--		$(LIBTOOL) $(INSTALL_BIN) -m 700 $$file $(SERVERBIN)/backend; \
-+		$(LIBTOOL) $(INSTALL_BIN) -m 744 $$file $(SERVERBIN)/backend; \
- 	done
- 	for file in $(UBACKENDS); do \
- 		$(INSTALL_BIN) $$file $(SERVERBIN)/backend; \
-diff --git a/scheduler/cups-deviced.c b/scheduler/cups-deviced.c
-index 77703b9..14478fd 100644
---- a/scheduler/cups-deviced.c
-+++ b/scheduler/cups-deviced.c
-@@ -265,7 +265,7 @@ main(int  argc,				/* I - Number of command-line args */
-     * all others run as the unprivileged user...
-     */
- 
--    start_backend(dent->filename, !(dent->fileinfo.st_mode & (S_IWGRP | S_IRWXO)));
-+    start_backend(dent->filename, !(dent->fileinfo.st_mode & (S_IWGRP | S_IWOTH | S_IXOTH)));
-   }
- 
-   cupsDirClose(dir);
-diff --git a/scheduler/job.c b/scheduler/job.c
-index e20e7c5..eb99b3e 100644
---- a/scheduler/job.c
-+++ b/scheduler/job.c
-@@ -1247,7 +1247,7 @@ cupsdContinueJob(cupsd_job_t *job)	/* I - Job */
-       else if (stat(command, &backinfo))
- 	backroot = 0;
-       else
--        backroot = !(backinfo.st_mode & (S_IWGRP | S_IRWXO));
-+        backroot = !(backinfo.st_mode & (S_IWGRP | S_IWOTH | S_IXOTH));
- 
-       argv[0] = job->printer->sanitized_device_uri;
- 
diff -pruN 2.3.3-3/debian/patches/0002-SERVERBIN-match-host_os_name-on-gnu-first-to-catch-k.patch 2.3.3op1-3/debian/patches/0002-SERVERBIN-match-host_os_name-on-gnu-first-to-catch-k.patch
--- 2.3.3-3/debian/patches/0002-SERVERBIN-match-host_os_name-on-gnu-first-to-catch-k.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0002-SERVERBIN-match-host_os_name-on-gnu-first-to-catch-k.patch	2020-12-04 09:32:55.000000000 +0000
@@ -0,0 +1,28 @@
+From: Didier Raboud <odyx@debian.org>
+Date: Thu, 3 Dec 2020 12:32:54 +0100
+Subject: SERVERBIN: match host_os_name on *-gnu first,
+ to catch kfreebsd-gnu before *bsd*
+
+Debian's kfreebsd-gnu architectures (kfreebsd-amd64 and kfreebsd-i386) work as Debian/GNU systems, hence with a /usr/lib/cups SERVERBIN, not a /usr/libexec/cups.
+
+Bug-Upstream: https://github.com/OpenPrinting/cups/pull/60
+---
+ config-scripts/cups-directories.m4 | 5 +++++
+ 1 file changed, 5 insertions(+)
+
+diff --git a/config-scripts/cups-directories.m4 b/config-scripts/cups-directories.m4
+index b74083a..1430af3 100644
+--- a/config-scripts/cups-directories.m4
++++ b/config-scripts/cups-directories.m4
+@@ -262,6 +262,11 @@ AC_SUBST(CUPS_REQUESTS)
+ 
+ # Server executables...
+ case "$host_os_name" in
++	*-gnu)
++		# GNUs
++		INSTALL_SYSV="install-sysv"
++		CUPS_SERVERBIN="$exec_prefix/lib/cups"
++		;;
+ 	*bsd* | darwin*)
+ 		# *BSD and Darwin (macOS)
+ 		INSTALL_SYSV=""
diff -pruN 2.3.3-3/debian/patches/0003-CUPS_EXE_FILE_PERM-also-match-host_os_name-on-gnu-to.patch 2.3.3op1-3/debian/patches/0003-CUPS_EXE_FILE_PERM-also-match-host_os_name-on-gnu-to.patch
--- 2.3.3-3/debian/patches/0003-CUPS_EXE_FILE_PERM-also-match-host_os_name-on-gnu-to.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0003-CUPS_EXE_FILE_PERM-also-match-host_os_name-on-gnu-to.patch	2020-12-04 09:32:55.000000000 +0000
@@ -0,0 +1,25 @@
+From: Didier Raboud <odyx@debian.org>
+Date: Thu, 3 Dec 2020 18:33:35 +0100
+Subject: CUPS_EXE_FILE_PERM: also match host_os_name on *-gnu,
+ to also catch kfreebsd-gnu
+
+Debian's kfreebsd-gnu architectures (kfreebsd-amd64 and kfreebsd-i386) work as Debian/GNU systems, hence with a 755 CUP_EXE_FILE_PERM, not 555
+
+Bug-Upstream: https://github.com/OpenPrinting/cups/pull/61
+---
+ config-scripts/cups-defaults.m4 | 2 +-
+ 1 file changed, 1 insertion(+), 1 deletion(-)
+
+diff --git a/config-scripts/cups-defaults.m4 b/config-scripts/cups-defaults.m4
+index 7a2d35a..9e05bd4 100644
+--- a/config-scripts/cups-defaults.m4
++++ b/config-scripts/cups-defaults.m4
+@@ -53,7 +53,7 @@ dnl Default executable file permissions
+ AC_ARG_WITH(exe_file_perm, [  --with-exe-file-perm    set default executable permissions value, default=0555],
+ 	CUPS_EXE_FILE_PERM="$withval",
+ 	[case "$host_os_name" in
+-		linux* | gnu*)
++		linux* | gnu* | *-gnu)
+ 			CUPS_EXE_FILE_PERM="755"
+ 			;;
+ 		*)
diff -pruN 2.3.3-3/debian/patches/0003-Fix-jobs-with-multiple-files-or-multiple-formats.patch 2.3.3op1-3/debian/patches/0003-Fix-jobs-with-multiple-files-or-multiple-formats.patch
--- 2.3.3-3/debian/patches/0003-Fix-jobs-with-multiple-files-or-multiple-formats.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0003-Fix-jobs-with-multiple-files-or-multiple-formats.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,27 +0,0 @@
-From: Tim Waugh <twaugh@redhat.com>
-Date: Tue, 9 Aug 2016 18:11:07 +0200
-Subject: Fix jobs with multiple files or multiple formats
-
-Bug-Redhat: https://bugzilla.redhat.com/show_bug.cgi?id=972242
-Bug: https://github.com/apple/cups/issues/4348
-Patch-Name: fixes-for-jobs-with-multiple-files-and-multiple-formats.patch
----
- backend/ipp.c | 5 ++++-
- 1 file changed, 4 insertions(+), 1 deletion(-)
-
-diff --git a/backend/ipp.c b/backend/ipp.c
-index 3f3e186..a99079e 100644
---- a/backend/ipp.c
-+++ b/backend/ipp.c
-@@ -1804,7 +1804,10 @@ main(int  argc,				/* I - Number of command-line args */
- 	ippAddBoolean(request, IPP_TAG_OPERATION, "last-document",
-         	      (i + 1) >= num_files);
- 
--	if (document_format)
-+	if (num_files > 1)
-+	  ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_MIMETYPE,
-+		       "document-format", NULL, "application/octet-stream");
-+	else if (document_format)
- 	  ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_MIMETYPE,
- 		       "document-format", NULL, document_format);
- 
diff -pruN 2.3.3-3/debian/patches/0004-Apple-AirPrint-support.patch 2.3.3op1-3/debian/patches/0004-Apple-AirPrint-support.patch
--- 2.3.3-3/debian/patches/0004-Apple-AirPrint-support.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0004-Apple-AirPrint-support.patch	2020-12-04 09:32:55.000000000 +0000
@@ -0,0 +1,90 @@
+From: Till Kamppeter <till.kamppeter@gmail.com>
+Date: Tue, 9 Aug 2016 18:11:29 +0200
+Subject: Apple AirPrint support
+
+Bug-Ubuntu: https://bugs.launchpad.net/bugs/711779
+Bug-Ubuntu: https://bugs.launchpad.net/bugs/1054495
+Bug-Debian: https://bugs.debian.org/700961
+Bug: https://github.com/apple/cups/issues/4341
+Bug: https://github.com/OpenPrinting/cups/pull/27
+---
+ conf/mime.convs.in   | 3 +++
+ conf/mime.types      | 3 +++
+ scheduler/conf.c     | 2 +-
+ scheduler/dirsvc.c   | 6 ++++++
+ scheduler/printers.c | 4 +++-
+ 5 files changed, 16 insertions(+), 2 deletions(-)
+
+diff --git a/conf/mime.convs.in b/conf/mime.convs.in
+index 57b459d..e042e01 100644
+--- a/conf/mime.convs.in
++++ b/conf/mime.convs.in
+@@ -44,6 +44,9 @@ application/postscript		application/vnd.cups-postscript	66	pstops
+ application/vnd.cups-raster	image/pwg-raster		100	rastertopwg
+ application/vnd.cups-raster	image/urf			100	rastertopwg
+ 
++# Needed for printing from iOS (AirPrint) clients
++image/urf    	      	       application/pdf			100	-
++
+ ########################################################################
+ #
+ # Raw filter...
+diff --git a/conf/mime.types b/conf/mime.types
+index fcd6b6e..ebb0525 100644
+--- a/conf/mime.types
++++ b/conf/mime.types
+@@ -108,6 +108,9 @@ image/x-alias			pix short(8,8) short(8,24)
+ image/x-bitmap			bmp string(0,BM) + !printable(2,14)
+ image/x-icon			ico
+ 
++# Needed for printing from iOS (AirPrint) clients
++image/urf			urf string(0,UNIRAST<00>)
++
+ ########################################################################
+ #
+ # Text files...
+diff --git a/scheduler/conf.c b/scheduler/conf.c
+index 74531a8..bfd1b0b 100644
+--- a/scheduler/conf.c
++++ b/scheduler/conf.c
+@@ -750,7 +750,7 @@ cupsdReadConfiguration(void)
+   DefaultShared            = CUPS_DEFAULT_DEFAULT_SHARED;
+ 
+ #if defined(HAVE_DNSSD) || defined(HAVE_AVAHI)
+-  cupsdSetString(&DNSSDSubTypes, "_cups,_print");
++  cupsdSetString(&DNSSDSubTypes, "_cups,_print,_universal");
+   cupsdClearString(&DNSSDHostName);
+ #endif /* HAVE_DNSSD || HAVE_AVAHI */
+ 
+diff --git a/scheduler/dirsvc.c b/scheduler/dirsvc.c
+index ddd3701..fb2a305 100644
+--- a/scheduler/dirsvc.c
++++ b/scheduler/dirsvc.c
+@@ -440,6 +440,12 @@ dnssdBuildTxtRecord(
+     keyvalue[count  ][0] = "pdl";
+     keyvalue[count++][1] = p->pdl ? p->pdl : "application/postscript";
+ 
++    /* iOS 6 does not accept this printer as AirPrint printer if there is
++       no URF txt record or "URF=none", "DM3" is the minimum needed found
++       by try and error */
++    keyvalue[count  ][0] = "URF";
++    keyvalue[count++][1] = "DM3";
++
+     if (get_auth_info_required(p, air_str, sizeof(air_str)))
+     {
+       keyvalue[count  ][0] = "air";
+diff --git a/scheduler/printers.c b/scheduler/printers.c
+index 7e9a9f2..3e00874 100644
+--- a/scheduler/printers.c
++++ b/scheduler/printers.c
+@@ -3733,7 +3733,9 @@ add_printer_formats(cupsd_printer_t *p)	/* I - Printer */
+       }
+       else if (!_cups_strcasecmp(type->super, "image"))
+       {
+-        if (!_cups_strcasecmp(type->type, "jpeg"))
++        if (!_cups_strcasecmp(type->type, "urf"))
++	  strlcat(pdl, "image/urf,", sizeof(pdl));
++	else if (!_cups_strcasecmp(type->type, "jpeg"))
+ 	  strlcat(pdl, "image/jpeg,", sizeof(pdl));
+ 	else if (!_cups_strcasecmp(type->type, "png"))
+ 	  strlcat(pdl, "image/png,", sizeof(pdl));
diff -pruN 2.3.3-3/debian/patches/0004-Fix-conversion-of-PPD-InputSlot-choice-names.patch 2.3.3op1-3/debian/patches/0004-Fix-conversion-of-PPD-InputSlot-choice-names.patch
--- 2.3.3-3/debian/patches/0004-Fix-conversion-of-PPD-InputSlot-choice-names.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0004-Fix-conversion-of-PPD-InputSlot-choice-names.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,99 +0,0 @@
-From: Till Kamppeter <till.kamppeter@gmail.com>
-Date: Mon, 17 Feb 2020 09:05:58 +0100
-Subject: Fix conversion of PPD InputSlot choice names
-
-When I create a CUPS queue with a PPD file with choice names "Tray-1", "Tray-2",
-... in the InputSlot option CUPS translates these names to double-dashed IPP
-attribute names: "tray--1", "tray--2", ... in the "media-source" attribute, both
-when passing a job to the printer with the IPP backend, making the printer
-ignore the tray choice, and also when answering a get-printer-attributes IPP
-request from a client. This happens when in the PPD a dash is followed by a
-digit, as the pwg_unppdize_name() function in cups/ppd-cache.c inserts a dash
-whenever a non-digit is followed by a digit in the PPD name. As IPP attribute
-names generally never have double-dashes and also no dashes in the beginning or
-the end of the name, I have modified the pwg_unppdize_name() function
-appropriately.
-
-Bug: https://github.com/apple/cups/issues/5740
-Bug-Debian: https://bugs.debian.org/949315
----
- cups/ppd-cache.c | 47 ++++++++++++++++++++++++++++++++++++++---------
- 1 file changed, 38 insertions(+), 9 deletions(-)
-
-diff --git a/cups/ppd-cache.c b/cups/ppd-cache.c
-index 5965e38..6609f53 100644
---- a/cups/ppd-cache.c
-+++ b/cups/ppd-cache.c
-@@ -5140,6 +5140,8 @@ pwg_unppdize_name(const char *ppd,	/* I - PPD keyword */
- {
-   char	*ptr,				/* Pointer into name buffer */
- 	*end;				/* End of name buffer */
-+  int   nodash = 1;                     /* Next char in IPP name cannot be a
-+                                           dash (first char or after a dash) */
- 
- 
-   if (_cups_islower(*ppd))
-@@ -5151,7 +5153,9 @@ pwg_unppdize_name(const char *ppd,	/* I - PPD keyword */
-     const char *ppdptr;			/* Pointer into PPD keyword */
- 
-     for (ppdptr = ppd + 1; *ppdptr; ppdptr ++)
--      if (_cups_isupper(*ppdptr) || strchr(dashchars, *ppdptr))
-+      if (_cups_isupper(*ppdptr) || strchr(dashchars, *ppdptr) ||
-+	  (*ppdptr == '-' && *(ppdptr - 1) == '-') ||
-+	  (*ppdptr == '-' && *(ppdptr + 1) == '\0'))
-         break;
- 
-     if (!*ppdptr)
-@@ -5163,19 +5167,44 @@ pwg_unppdize_name(const char *ppd,	/* I - PPD keyword */
- 
-   for (ptr = name, end = name + namesize - 1; *ppd && ptr < end; ppd ++)
-   {
--    if (_cups_isalnum(*ppd) || *ppd == '-')
-+    if (_cups_isalnum(*ppd))
-+    {
-       *ptr++ = (char)tolower(*ppd & 255);
--    else if (strchr(dashchars, *ppd))
--      *ptr++ = '-';
-+      nodash = 0;
-+    }
-+    else if (*ppd == '-' || strchr(dashchars, *ppd))
-+    {
-+      if (nodash == 0)
-+      {
-+	*ptr++ = '-';
-+	nodash = 1;
-+      }
-+    }
-     else
-+    {
-       *ptr++ = *ppd;
-+      nodash = 0;
-+    }
- 
--    if (!_cups_isupper(*ppd) && _cups_isalnum(*ppd) &&
--	_cups_isupper(ppd[1]) && ptr < end)
--      *ptr++ = '-';
--    else if (!isdigit(*ppd & 255) && isdigit(ppd[1] & 255))
--      *ptr++ = '-';
-+    if (nodash == 0)
-+    {
-+      if (!_cups_isupper(*ppd) && _cups_isalnum(*ppd) &&
-+	  _cups_isupper(ppd[1]) && ptr < end)
-+      {
-+	*ptr++ = '-';
-+	nodash = 1;
-+      }
-+      else if (!isdigit(*ppd & 255) && isdigit(ppd[1] & 255))
-+      {
-+	*ptr++ = '-';
-+	nodash = 1;
-+      }
-+    }
-   }
- 
-+  /* Remove trailing dashes */
-+  while (ptr > name && *(ptr - 1) == '-')
-+    ptr --;
-+
-   *ptr = '\0';
- }
diff -pruN 2.3.3-3/debian/patches/0005-Fix-scheduler-cupsd.conf-load.patch 2.3.3op1-3/debian/patches/0005-Fix-scheduler-cupsd.conf-load.patch
--- 2.3.3-3/debian/patches/0005-Fix-scheduler-cupsd.conf-load.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0005-Fix-scheduler-cupsd.conf-load.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,86 +0,0 @@
-From: Till Kamppeter <till.kamppeter@gmail.com>
-Date: Sat, 22 Feb 2020 14:28:58 +0100
-Subject: Fix scheduler cupsd.conf load
-
-When running it without arguments it is supposed to read the local CUPS's
-cupsd.conf and show a summary of the setting. in CUPS 2.3.1 it shows a mess
-with a lot of HTML inside and this is due to the fact that when loading the
-file via HTTP using the /admin/cups/cupsd.conf path the scheduler calls the
-admin.cgi program which returns the admin front page of the web admin
-interface. cupsctl then tries to interpret that as the config file and displays
-garbage. Even worse is if you run cupsctl with command line argument (one of
-the five switches or a key=value pair) to change a setting. It seems to load
-cupsd.conf again and gets again the HTML code of the web interface page.
-cupsctl tries to interpret this again, producing garbage, adds the
-user-supplied setting and writes all this back into cupsd.conf. Then it tries
-to restart the scheduler which fails due to the broken config file.
-The problem is that in the file scheduler/client.conf, in the function
-get_file() the URI from the client is at first checked whether it begins with
-"/admin/" and in this case the CGI program admin.cgi is responsible. Only after
-that the check for "/admin/conf/cupsd.conf" comes and is never reached.
-I have changed the order now appropriately and this way cupsctl works again.
-Note that the problem only occurs if the web interface is active and the
-cupsctl command is issued by a non-root user.
-This is a regression caused by issue #5652.
-
-Bug: https://github.com/apple/cups/issues/5744
----
- scheduler/client.c | 38 +++++++++++++++++++-------------------
- 1 file changed, 19 insertions(+), 19 deletions(-)
-
-diff --git a/scheduler/client.c b/scheduler/client.c
-index c2ee8f1..54b841b 100644
---- a/scheduler/client.c
-+++ b/scheduler/client.c
-@@ -2789,6 +2789,25 @@ get_file(cupsd_client_t *con,		/* I  - Client connection */
- 
-     perm_check = 0;
-   }
-+  else if (!strcmp(con->uri, "/admin/conf/cupsd.conf"))
-+  {
-+    strlcpy(filename, ConfigurationFile, len);
-+
-+    perm_check = 0;
-+  }
-+  else if (!strncmp(con->uri, "/admin/log/", 11))
-+  {
-+    if (!strncmp(con->uri + 11, "access_log", 10) && AccessLog[0] == '/')
-+      strlcpy(filename, AccessLog, len);
-+    else if (!strncmp(con->uri + 11, "error_log", 9) && ErrorLog[0] == '/')
-+      strlcpy(filename, ErrorLog, len);
-+    else if (!strncmp(con->uri + 11, "page_log", 8) && PageLog[0] == '/')
-+      strlcpy(filename, PageLog, len);
-+    else
-+      return (NULL);
-+
-+    perm_check = 0;
-+  }
-   else if (!strncmp(con->uri, "/admin", 6) || !strncmp(con->uri, "/classes", 8) || !strncmp(con->uri, "/jobs", 5) || !strncmp(con->uri, "/printers", 9))
-   {
-    /*
-@@ -2822,25 +2841,6 @@ get_file(cupsd_client_t *con,		/* I  - Client connection */
- 
-     perm_check = 0;
-   }
--  else if (!strcmp(con->uri, "/admin/conf/cupsd.conf"))
--  {
--    strlcpy(filename, ConfigurationFile, len);
--
--    perm_check = 0;
--  }
--  else if (!strncmp(con->uri, "/admin/log/", 11))
--  {
--    if (!strncmp(con->uri + 11, "access_log", 10) && AccessLog[0] == '/')
--      strlcpy(filename, AccessLog, len);
--    else if (!strncmp(con->uri + 11, "error_log", 9) && ErrorLog[0] == '/')
--      strlcpy(filename, ErrorLog, len);
--    else if (!strncmp(con->uri + 11, "page_log", 8) && PageLog[0] == '/')
--      strlcpy(filename, PageLog, len);
--    else
--      return (NULL);
--
--    perm_check = 0;
--  }
-   else if (con->language)
-   {
-     snprintf(language, sizeof(language), "/%s", con->language->language);
diff -pruN 2.3.3-3/debian/patches/0005-Keep-foomatic-PPDs-recommended-stanzas-in-NickNames.patch 2.3.3op1-3/debian/patches/0005-Keep-foomatic-PPDs-recommended-stanzas-in-NickNames.patch
--- 2.3.3-3/debian/patches/0005-Keep-foomatic-PPDs-recommended-stanzas-in-NickNames.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0005-Keep-foomatic-PPDs-recommended-stanzas-in-NickNames.patch	2020-12-04 09:32:55.000000000 +0000
@@ -0,0 +1,37 @@
+From: Till Kampetter <till.kampetter@gmail.com>
+Date: Tue, 9 Aug 2016 18:11:36 +0200
+Subject: Keep foomatic PPDs "(recommended)" stanzas in NickNames
+
+Bug-Upstream: https://github.com/OpenPrinting/cups/pull/33
+---
+ scheduler/cups-driverd.cxx | 10 ----------
+ 1 file changed, 10 deletions(-)
+
+diff --git a/scheduler/cups-driverd.cxx b/scheduler/cups-driverd.cxx
+index 85516eb..874eb3c 100644
+--- a/scheduler/cups-driverd.cxx
++++ b/scheduler/cups-driverd.cxx
+@@ -240,7 +240,6 @@ add_ppd(const char *filename,		/* I - PPD filename */
+ 	const char *scheme)		/* I - PPD scheme */
+ {
+   ppd_info_t	*ppd;			/* PPD */
+-  char		*recommended;		/* Foomatic driver string */
+ 
+ 
+  /*
+@@ -278,15 +277,6 @@ add_ppd(const char *filename,		/* I - PPD filename */
+   strlcpy(ppd->record.device_id, device_id, sizeof(ppd->record.device_id));
+   strlcpy(ppd->record.scheme, scheme, sizeof(ppd->record.scheme));
+ 
+- /*
+-  * Strip confusing (and often wrong) "recommended" suffix added by
+-  * Foomatic drivers...
+-  */
+-
+-  if ((recommended = strstr(ppd->record.make_and_model,
+-                            " (recommended)")) != NULL)
+-    *recommended = '\0';
+-
+  /*
+   * Add the PPD to the PPD arrays...
+   */
diff -pruN 2.3.3-3/debian/patches/0006-Debian-Set-LogFileGroup-to-adm.patch 2.3.3op1-3/debian/patches/0006-Debian-Set-LogFileGroup-to-adm.patch
--- 2.3.3-3/debian/patches/0006-Debian-Set-LogFileGroup-to-adm.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0006-Debian-Set-LogFileGroup-to-adm.patch	2020-12-04 09:32:55.000000000 +0000
@@ -0,0 +1,23 @@
+From: Martin Pitt <mpitt@debian.org>
+Date: Tue, 9 Aug 2016 18:11:38 +0200
+Subject: Debian: Set LogFileGroup to adm
+
+---
+ conf/cups-files.conf.in | 4 ++++
+ 1 file changed, 4 insertions(+)
+
+diff --git a/conf/cups-files.conf.in b/conf/cups-files.conf.in
+index af11fcc..80ca351 100644
+--- a/conf/cups-files.conf.in
++++ b/conf/cups-files.conf.in
+@@ -29,6 +29,10 @@ SystemGroup @CUPS_SYSTEM_GROUPS@
+ #ConfigFilePerm 0@CUPS_CONFIG_FILE_PERM@
+ #LogFilePerm 0@CUPS_LOG_FILE_PERM@
+ 
++# Specifies the group name or ID that will be used for log files.
++# The default group in Debian is "adm".
++LogFileGroup adm
++
+ # Location of the file logging all access to the scheduler; may be the name
+ # "syslog". If not an absolute path, the value of ServerRoot is used as the
+ # root directory.  Also see the "AccessLogLevel" directive in cupsd.conf.
diff -pruN 2.3.3-3/debian/patches/0006-Fix-leakage-of-ppd.patch 2.3.3op1-3/debian/patches/0006-Fix-leakage-of-ppd.patch
--- 2.3.3-3/debian/patches/0006-Fix-leakage-of-ppd.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0006-Fix-leakage-of-ppd.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,21 +0,0 @@
-From: Zdenek Dohnal <zdohnal@redhat.com>
-Date: Fri, 14 Feb 2020 16:48:49 +0100
-Subject: Fix leakage of ppd
-
----
- ppdc/ppdc-import.cxx | 3 +++
- 1 file changed, 3 insertions(+)
-
-diff --git a/ppdc/ppdc-import.cxx b/ppdc/ppdc-import.cxx
-index 04b587d..b4a8341 100644
---- a/ppdc/ppdc-import.cxx
-+++ b/ppdc/ppdc-import.cxx
-@@ -323,5 +323,8 @@ ppdcSource::import_ppd(const char *f)	// I - Filename
-     }
-   }
- 
-+  if (ppd)
-+    ppdClose(ppd);
-+
-   return (1);
- }
diff -pruN 2.3.3-3/debian/patches/0007-Debian-Move-cupsd.conf.default-from-SERVERROOT-to-DA.patch 2.3.3op1-3/debian/patches/0007-Debian-Move-cupsd.conf.default-from-SERVERROOT-to-DA.patch
--- 2.3.3-3/debian/patches/0007-Debian-Move-cupsd.conf.default-from-SERVERROOT-to-DA.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0007-Debian-Move-cupsd.conf.default-from-SERVERROOT-to-DA.patch	2020-12-04 09:32:55.000000000 +0000
@@ -0,0 +1,62 @@
+From: Didier Raboud <odyx@debian.org>
+Date: Tue, 9 Aug 2016 18:11:24 +0200
+Subject: Debian: Move cupsd.conf.default from SERVERROOT to DATADIR
+
+Origin: vendor
+Bug: https://github.com/apple/cups/issues/4342
+Bug: https://github.com/OpenPrinting/cups/pull/26
+Bug-Debian: https://bugs.debian.org/640124
+---
+ cgi-bin/admin.c | 6 +++++-
+ conf/Makefile   | 5 +++--
+ 2 files changed, 8 insertions(+), 3 deletions(-)
+
+diff --git a/cgi-bin/admin.c b/cgi-bin/admin.c
+index c648938..5ff7501 100644
+--- a/cgi-bin/admin.c
++++ b/cgi-bin/admin.c
+@@ -1636,6 +1636,7 @@ do_config_server(http_t *http)		/* I - HTTP connection */
+     int		ch;			/* Character from file */
+     char	filename[1024];		/* Filename */
+     const char	*server_root;		/* Location of config files */
++    const char	*data_dir;		/* Location of data files */
+ 
+ 
+    /*
+@@ -1719,7 +1720,10 @@ do_config_server(http_t *http)		/* I - HTTP connection */
+     * well...
+     */
+ 
+-    strlcat(filename, ".default", sizeof(filename));
++    if ((data_dir = getenv("CUPS_DATADIR")) == NULL)
++      data_dir = CUPS_DATADIR;
++
++    snprintf(filename, sizeof(filename), "%s/cupsd.conf.default",data_dir);
+ 
+     if (!stat(filename, &info) && info.st_size < (1024 * 1024) &&
+         (cupsd = cupsFileOpen(filename, "r")) != NULL)
+diff --git a/conf/Makefile b/conf/Makefile
+index e249e60..42a123f 100644
+--- a/conf/Makefile
++++ b/conf/Makefile
+@@ -70,7 +70,7 @@ install-data:
+ 		else \
+ 			$(INSTALL_CONFIG) -g $(CUPS_GROUP) $$file $(SERVERROOT) ; \
+ 		fi ; \
+-		$(INSTALL_CONFIG) -g $(CUPS_GROUP) $$file $(SERVERROOT)/$$file.default; \
++		$(INSTALL_CONFIG) -g $(CUPS_GROUP) $$file $(DATADIR)/$$file.default; \
+ 	done
+ 	$(INSTALL_DIR) -m 755 $(DATADIR)/mime
+ 	for file in $(REPLACE); do \
+@@ -118,9 +118,10 @@ install-libs:
+ #
+ 
+ uninstall:
+-	for file in $(KEEP) $(REPLACE) cupsd.conf.default; do \
++	for file in $(KEEP) $(REPLACE); do \
+ 		$(RM) $(SERVERROOT)/$$file; \
+ 	done
++	$(RM) $(DATADIR)/cupsd.conf.default
+ 	-$(RMDIR) $(SERVERROOT)
+ 	for file in $(REPLACE); do \
+ 		$(RM) $(DATADIR)/mime/$$file; \
diff -pruN 2.3.3-3/debian/patches/0007-Tests-Ignore-warnings-from-colord-and-Avahi.patch 2.3.3op1-3/debian/patches/0007-Tests-Ignore-warnings-from-colord-and-Avahi.patch
--- 2.3.3-3/debian/patches/0007-Tests-Ignore-warnings-from-colord-and-Avahi.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0007-Tests-Ignore-warnings-from-colord-and-Avahi.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,28 +0,0 @@
-From: Martin Pitt <mpitt@debian.org>
-Date: Tue, 9 Aug 2016 18:11:09 +0200
-Subject: Tests: Ignore warnings from colord and Avahi
-
-These warnings change the expected number of warnings
-
-Patch-Name: tests-ignore-warnings.patch
----
- test/run-stp-tests.sh | 6 +++++-
- 1 file changed, 5 insertions(+), 1 deletion(-)
-
-diff --git a/test/run-stp-tests.sh b/test/run-stp-tests.sh
-index 2f9630f..a601581 100755
---- a/test/run-stp-tests.sh
-+++ b/test/run-stp-tests.sh
-@@ -1040,7 +1040,11 @@ else
- fi
- 
- # Warning log messages
--count=`$GREP '^W ' $BASE/log/error_log | $GREP -v CreateProfile | wc -l | awk '{print $1}'`
-+count=`$GREP '^W ' $BASE/log/error_log | $GREP -v CreateProfile | \
-+       $GREP -v 'Unable to initialize USB access via libusb, libusb error' | \
-+       $GREP -v 'org.freedesktop.ColorManager' | \
-+       $GREP -v -E 'Avahi client failed: -(1|26)' | \
-+       wc -l | awk '{print $1}'`
- if test $count != 8; then
- 	echo "FAIL: $count warning messages, expected 8."
- 	$GREP '^W ' $BASE/log/error_log
diff -pruN 2.3.3-3/debian/patches/0008-Debian-Do-not-alter-the-permissions-of-cupsd.conf-ev.patch 2.3.3op1-3/debian/patches/0008-Debian-Do-not-alter-the-permissions-of-cupsd.conf-ev.patch
--- 2.3.3-3/debian/patches/0008-Debian-Do-not-alter-the-permissions-of-cupsd.conf-ev.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0008-Debian-Do-not-alter-the-permissions-of-cupsd.conf-ev.patch	2020-12-04 09:32:55.000000000 +0000
@@ -0,0 +1,27 @@
+From: Martin Pitt <mpitt@debian.org>
+Date: Tue, 9 Aug 2016 18:11:41 +0200
+Subject: Debian: Do not alter the permissions of cupsd.conf, ever
+
+Origin: vendor
+Bug: https://github.com/OpenPrinting/cups/pull/36
+---
+ scheduler/conf.c | 2 ++
+ 1 file changed, 2 insertions(+)
+
+diff --git a/scheduler/conf.c b/scheduler/conf.c
+index bfd1b0b..c8cd5ea 100644
+--- a/scheduler/conf.c
++++ b/scheduler/conf.c
+@@ -1140,10 +1140,12 @@ cupsdReadConfiguration(void)
+ 			     Group, 1, 1) < 0 ||
+        cupsdCheckPermissions(ServerRoot, "ssl", 0700, RunUser,
+ 			     Group, 1, 0) < 0 ||
++       /* Never alter permissions of central conffile
+        cupsdCheckPermissions(ConfigurationFile, NULL, ConfigFilePerm, RunUser,
+ 			     Group, 0, 0) < 0 ||
+        cupsdCheckPermissions(CupsFilesFile, NULL, ConfigFilePerm, RunUser,
+ 			     Group, 0, 0) < 0 ||
++       */
+        cupsdCheckPermissions(ServerRoot, "classes.conf", 0600, RunUser,
+ 			     Group, 0, 0) < 0 ||
+        cupsdCheckPermissions(ServerRoot, "printers.conf", 0600, RunUser,
diff -pruN 2.3.3-3/debian/patches/0008-Tests-ignore-usb-dnssd-backend-unexpected-exits.patch 2.3.3op1-3/debian/patches/0008-Tests-ignore-usb-dnssd-backend-unexpected-exits.patch
--- 2.3.3-3/debian/patches/0008-Tests-ignore-usb-dnssd-backend-unexpected-exits.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0008-Tests-ignore-usb-dnssd-backend-unexpected-exits.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,31 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Tue, 9 Aug 2016 18:11:10 +0200
-Subject: Tests: ignore usb & dnssd backend unexpected exits
-
-Ignore the following errors:
- "[cups-deviced] PID * (usb) crashed on signal 11!" and
- "[cups-deviced] PID * (dnssd) stopped with status 1"
-
- They seem to regularly happen on Debian/Ubuntu buildds and break error lines
- counting.
-Patch-Name: tests-ignore-usb-crash.patch
----
- test/run-stp-tests.sh | 5 ++++-
- 1 file changed, 4 insertions(+), 1 deletion(-)
-
-diff --git a/test/run-stp-tests.sh b/test/run-stp-tests.sh
-index a601581..8bde425 100755
---- a/test/run-stp-tests.sh
-+++ b/test/run-stp-tests.sh
-@@ -1025,7 +1025,10 @@ else
- fi
- 
- # Error log messages
--count=`$GREP '^E ' $BASE/log/error_log | $GREP -v 'Unknown default SystemGroup' | wc -l | awk '{print $1}'`
-+count=`$GREP '^E ' $BASE/log/error_log | $GREP -v 'Unknown default SystemGroup' | \
-+       $GREP -v '(usb) crashed on signal 11' | \
-+       $GREP -v '(dnssd) stopped with status 1' | \
-+       wc -l | awk '{print $1}'`
- if test $count != 33; then
- 	echo "FAIL: $count error messages, expected 33."
- 	$GREP '^E ' $BASE/log/error_log
diff -pruN 2.3.3-3/debian/patches/0009-Debian-Show-compile-command-lines.patch 2.3.3op1-3/debian/patches/0009-Debian-Show-compile-command-lines.patch
--- 2.3.3-3/debian/patches/0009-Debian-Show-compile-command-lines.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0009-Debian-Show-compile-command-lines.patch	2020-12-04 09:32:55.000000000 +0000
@@ -0,0 +1,20 @@
+From: Till Kampetter <till.kampetter@gmail.com>
+Date: Tue, 9 Aug 2016 18:11:43 +0200
+Subject: Debian: Show compile command lines
+
+---
+ Makedefs.in | 1 -
+ 1 file changed, 1 deletion(-)
+
+diff --git a/Makedefs.in b/Makedefs.in
+index 9ee7585..038bb94 100644
+--- a/Makedefs.in
++++ b/Makedefs.in
+@@ -263,7 +263,6 @@ USBQUIRKS	=	@USBQUIRKS@
+ # Rules...
+ #
+ 
+-.SILENT:
+ .SUFFIXES:	.a .c .cxx .h .o
+ 
+ .c.o:
diff -pruN 2.3.3-3/debian/patches/0009-Tests-ignore-loadFile-failures.patch 2.3.3op1-3/debian/patches/0009-Tests-ignore-loadFile-failures.patch
--- 2.3.3-3/debian/patches/0009-Tests-ignore-loadFile-failures.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0009-Tests-ignore-loadFile-failures.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,25 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Tue, 9 Aug 2016 18:30:48 +0200
-Subject: Tests: ignore loadFile failures
-
-Ignore the 'loadFile failed: temp file: not a PDF file' error that sometimes
-breaks the errorlines counting on kfreebsd-amd64 for some reason
-Origin: vendor
-Patch-Name: tests-ignore-kfreebsd-amd64-not-a-pdf.patch
----
- test/run-stp-tests.sh | 2 ++
- 1 file changed, 2 insertions(+)
-
-diff --git a/test/run-stp-tests.sh b/test/run-stp-tests.sh
-index 8bde425..f5a98dd 100755
---- a/test/run-stp-tests.sh
-+++ b/test/run-stp-tests.sh
-@@ -1028,6 +1028,8 @@ fi
- count=`$GREP '^E ' $BASE/log/error_log | $GREP -v 'Unknown default SystemGroup' | \
-        $GREP -v '(usb) crashed on signal 11' | \
-        $GREP -v '(dnssd) stopped with status 1' | \
-+       $GREP -v 'loadFile failed: temp file: not a PDF file' | \
-+       $GREP -v 'Failed to connect to system bus' | \
-        wc -l | awk '{print $1}'`
- if test $count != 33; then
- 	echo "FAIL: $count error messages, expected 33."
diff -pruN 2.3.3-3/debian/patches/0010-Debian-Use-dpkg-architecture-in-cups-config-to-make-.patch 2.3.3op1-3/debian/patches/0010-Debian-Use-dpkg-architecture-in-cups-config-to-make-.patch
--- 2.3.3-3/debian/patches/0010-Debian-Use-dpkg-architecture-in-cups-config-to-make-.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0010-Debian-Use-dpkg-architecture-in-cups-config-to-make-.patch	2020-12-04 09:32:55.000000000 +0000
@@ -0,0 +1,49 @@
+From: Didier Raboud <odyx@debian.org>
+Date: Tue, 9 Aug 2016 18:11:49 +0200
+Subject: Debian: Use dpkg-architecture in cups-config to make it
+ architecture-independant
+
+ Also filter -L/usr/lib/(triplet) out of LDFLAGS.
+ Also strip unnecessary libs from --libs.
+ Also launch krb5-config at runtime to avoid getting usr/lib/(triplet) from krb5-config
+
+Bug-Debian: https://bugs.debian.org/741519
+Bug-Debian: https://bugs.debian.org/727058
+Bug-Debian: https://bugs.debian.org/730838
+Bug-Debian: https://bugs.debian.org/751157
+---
+ cups-config.in | 7 ++++---
+ 1 file changed, 4 insertions(+), 3 deletions(-)
+
+diff --git a/cups-config.in b/cups-config.in
+index 9dd094d..b073a07 100755
+--- a/cups-config.in
++++ b/cups-config.in
+@@ -17,7 +17,7 @@ prefix=@prefix@
+ exec_prefix=@exec_prefix@
+ bindir=@bindir@
+ includedir=@includedir@
+-libdir=@libdir@
++libdir=${prefix}/lib/$(dpkg-architecture -qDEB_HOST_MULTIARCH)
+ datarootdir=@datadir@
+ datadir=@datadir@
+ sysconfdir=@sysconfdir@
+@@ -29,7 +29,8 @@ INSTALLSTATIC=@INSTALLSTATIC@
+ # flags for compiler and linker...
+ CFLAGS=""
+ LDFLAGS="@EXPORT_LDFLAGS@"
+-LIBS="@LIBGSSAPI@ @DNSSDLIBS@ @EXPORT_SSLLIBS@ @LIBZ@ @LIBS@"
++LIBGSSAPI=`[ ! -x /usr/bin/krb5-config ] || /usr/bin/krb5-config --libs`
++LIBS="$LIBGSSAPI @DNSSDLIBS@ @EXPORT_SSLLIBS@ @LIBZ@ @LIBS@"
+ 
+ # Check for local invocation...
+ selfdir=`dirname $0`
+@@ -43,7 +44,7 @@ else
+ 	CFLAGS="$CFLAGS -I$includedir"
+     fi
+ 
+-    if test $libdir != /usr/lib -a $libdir != /usr/lib32 -a $libdir != /usr/lib64; then
++    if test $libdir != /usr/lib -a $libdir != /usr/lib32 -a $libdir != /usr/lib64 -a $libdir != /usr/lib/$(dpkg-architecture -qDEB_HOST_MULTIARCH); then
+ 	LDFLAGS="$LDFLAGS -L$libdir"
+     fi
+ fi
diff -pruN 2.3.3-3/debian/patches/0010-Tests-ignore-errors-triggered-on-ipv6-deprived-hosts.patch 2.3.3op1-3/debian/patches/0010-Tests-ignore-errors-triggered-on-ipv6-deprived-hosts.patch
--- 2.3.3-3/debian/patches/0010-Tests-ignore-errors-triggered-on-ipv6-deprived-hosts.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0010-Tests-ignore-errors-triggered-on-ipv6-deprived-hosts.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,24 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Tue, 9 Aug 2016 18:33:56 +0200
-Subject: Tests: ignore errors triggered on ipv6-deprived hosts
-
-Ignore the 'Address family not supported by protocol' error that breaks the
-errorlines counting on buildds without a working IPv6 stack.
-Origin: vendor
-Patch-Name: tests-ignore-ipv6-address-family-not-supported.patch
----
- test/run-stp-tests.sh | 1 +
- 1 file changed, 1 insertion(+)
-
-diff --git a/test/run-stp-tests.sh b/test/run-stp-tests.sh
-index f5a98dd..f3a4321 100755
---- a/test/run-stp-tests.sh
-+++ b/test/run-stp-tests.sh
-@@ -1030,6 +1030,7 @@ count=`$GREP '^E ' $BASE/log/error_log | $GREP -v 'Unknown default SystemGroup'
-        $GREP -v '(dnssd) stopped with status 1' | \
-        $GREP -v 'loadFile failed: temp file: not a PDF file' | \
-        $GREP -v 'Failed to connect to system bus' | \
-+       $GREP -v -E 'Unable to open listen socket for address .* Address family not supported by protocol.' | \
-        wc -l | awk '{print $1}'`
- if test $count != 33; then
- 	echo "FAIL: $count error messages, expected 33."
diff -pruN 2.3.3-3/debian/patches/0011-Debian-Build-mantohtml-with-the-build-architecture-c.patch 2.3.3op1-3/debian/patches/0011-Debian-Build-mantohtml-with-the-build-architecture-c.patch
--- 2.3.3-3/debian/patches/0011-Debian-Build-mantohtml-with-the-build-architecture-c.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0011-Debian-Build-mantohtml-with-the-build-architecture-c.patch	2020-12-04 09:32:55.000000000 +0000
@@ -0,0 +1,110 @@
+From: Helmut Grohne <helmut@subdivi.de>
+Date: Tue, 9 Aug 2016 18:11:49 +0200
+Subject: Debian: Build mantohtml with the build architecture compiler
+
+mantohtml is run during build. Thus it needs to be built with the build
+architecture compiler (or execution fails). The obvious part is switching to
+CC_FOR_BUILD. That also depends on it not requiring any other cups components.
+In particular, removing uses of strlcpy and replacing host architecture-
+specific includes is thus needed.
+
+Bug-Debian: https://bugs.debian.org/837936
+---
+ Makedefs.in     |  1 +
+ configure.ac    |  9 +++++++++
+ man/Makefile    |  5 ++---
+ man/mantohtml.c | 15 ++++++++++-----
+ 4 files changed, 22 insertions(+), 8 deletions(-)
+
+diff --git a/Makedefs.in b/Makedefs.in
+index 038bb94..291099c 100644
+--- a/Makedefs.in
++++ b/Makedefs.in
+@@ -22,6 +22,7 @@ CUPS_VERSION    =       @CUPS_VERSION@
+ AR		=	@AR@
+ AWK		=	@AWK@
+ CC		=	@LIBTOOL_CC@ @CC@
++CC_FOR_BUILD	=	@CC_FOR_BUILD@
+ CHMOD		=	@CHMOD@
+ CXX		=	@LIBTOOL_CXX@ @CXX@
+ DSO		=	@DSO@
+diff --git a/configure.ac b/configure.ac
+index b22e24f..176c44f 100644
+--- a/configure.ac
++++ b/configure.ac
+@@ -20,6 +20,15 @@ sinclude(config-scripts/cups-common.m4)
+ sinclude(config-scripts/cups-directories.m4)
+ sinclude(config-scripts/cups-manpages.m4)
+ 
++AC_MSG_CHECKING([for build system compiler])
++if test "$cross_compiling" = yes; then
++	CC_FOR_BUILD=${CC_FOR_BUILD-cc}
++else
++	CC_FOR_BUILD=${CC}
++fi
++AC_MSG_RESULT(${CC_FOR_BUILD})
++AC_SUBST(CC_FOR_BUILD)
++
+ sinclude(config-scripts/cups-sharedlibs.m4)
+ sinclude(config-scripts/cups-libtool.m4)
+ sinclude(config-scripts/cups-compiler.m4)
+diff --git a/man/Makefile b/man/Makefile
+index 621fe60..e01591a 100644
+--- a/man/Makefile
++++ b/man/Makefile
+@@ -222,6 +222,5 @@ html:	$(MAN1) $(MAN5) $(MAN7) $(MAN8) mantohtml
+ 		./mantohtml $$file >../doc/help/man-`basename $$file .8`.html; \
+ 	done
+ 
+-mantohtml:	mantohtml.o ../cups/$(LIBCUPSSTATIC)
+-	$(LD_CC) $(ARCHFLAGS) $(ALL_LDFLAGS) -o $@ mantohtml.o $(LINKCUPSSTATIC)
+-	$(CODE_SIGN) -s "$(CODE_SIGN_IDENTITY)" $@
++mantohtml:	mantohtml.c
++	$(CC_FOR_BUILD) -o $@ $<
+diff --git a/man/mantohtml.c b/man/mantohtml.c
+index 2a9353a..6223f17 100644
+--- a/man/mantohtml.c
++++ b/man/mantohtml.c
+@@ -11,8 +11,10 @@
+  * Include necessary headers.
+  */
+ 
+-#include <cups/string-private.h>
+-#include <cups/array-private.h>
++#include <ctype.h>
++#include <stdio.h>
++#include <stdlib.h>
++#include <string.h>
+ #include <unistd.h>
+ 
+ 
+@@ -811,7 +813,8 @@ main(int  argc,				/* I - Number of command-line args */
+         * Anchor for HTML output...
+         */
+ 
+-        strlcpy(anchor, line + 4, sizeof(anchor));
++        strncpy(anchor, line + 4, sizeof(anchor) - 1);
++        anchor[sizeof(anchor) - 1] = '\0';
+       }
+       else if (strncmp(line, ".\\\"", 3))
+       {
+@@ -940,7 +943,8 @@ html_alternate(const char *s,		/* I - String */
+ 		manfile[1024],		/* Man page filename */
+ 		manurl[1024];		/* Man page URL */
+ 
+-        strlcpy(name, s, sizeof(name));
++        strncpy(name, s, sizeof(name) - 1);
++        name[sizeof(name) - 1] = '\0';
+         if ((size_t)(end - s) < sizeof(name))
+           name[end - s] = '\0';
+ 
+@@ -1173,7 +1177,8 @@ html_fputs(const char *s,		/* I  - String */
+       if (end[-1] == ',' || end[-1] == '.' || end[-1] == ')')
+         end --;
+ 
+-      strlcpy(temp, s, sizeof(temp));
++      strncpy(temp, s, sizeof(temp) - 1);
++      temp[sizeof(temp) - 1] = '\0';
+       if ((size_t)(end -s) < sizeof(temp))
+         temp[end - s] = '\0';
+ 
diff -pruN 2.3.3-3/debian/patches/0011-Tests-ignore-the-failure-to-write-uncompressed-data.patch 2.3.3op1-3/debian/patches/0011-Tests-ignore-the-failure-to-write-uncompressed-data.patch
--- 2.3.3-3/debian/patches/0011-Tests-ignore-the-failure-to-write-uncompressed-data.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0011-Tests-ignore-the-failure-to-write-uncompressed-data.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,24 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Tue, 9 Aug 2016 18:36:02 +0200
-Subject: Tests: ignore the failure to write uncompressed data
-
-Ignore the 'Unable to write uncompressed print data: Broken pipe'  error that
-sometimes breaks the errorlines counting on kfreebsd for some reason.
-Origin: vendor
-Patch-Name: tests-ignore-kfreebsd-unable-to-write-uncompressed-print-data.patch
----
- test/run-stp-tests.sh | 1 +
- 1 file changed, 1 insertion(+)
-
-diff --git a/test/run-stp-tests.sh b/test/run-stp-tests.sh
-index f3a4321..c072ad8 100755
---- a/test/run-stp-tests.sh
-+++ b/test/run-stp-tests.sh
-@@ -1031,6 +1031,7 @@ count=`$GREP '^E ' $BASE/log/error_log | $GREP -v 'Unknown default SystemGroup'
-        $GREP -v 'loadFile failed: temp file: not a PDF file' | \
-        $GREP -v 'Failed to connect to system bus' | \
-        $GREP -v -E 'Unable to open listen socket for address .* Address family not supported by protocol.' | \
-+       $GREP -v 'Unable to write uncompressed print data: Broken pipe' | \
-        wc -l | awk '{print $1}'`
- if test $count != 33; then
- 	echo "FAIL: $count error messages, expected 33."
diff -pruN 2.3.3-3/debian/patches/0012-Debian-po4a-infrastructure-and-translations-for-manp.patch 2.3.3op1-3/debian/patches/0012-Debian-po4a-infrastructure-and-translations-for-manp.patch
--- 2.3.3-3/debian/patches/0012-Debian-po4a-infrastructure-and-translations-for-manp.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0012-Debian-po4a-infrastructure-and-translations-for-manp.patch	2020-12-04 09:32:55.000000000 +0000
@@ -0,0 +1,341 @@
+From: Didier Raboud <odyx@debian.org>
+Date: Tue, 9 Aug 2016 18:11:50 +0200
+Subject: Debian: po4a infrastructure and translations for manpages
+MIME-Version: 1.0
+Content-Type: text/plain; charset="utf-8"
+Content-Transfer-Encoding: 8bit
+
+Author: Nicolas François <nicolas.francois@centraliens.net>, Helge Kreutzmann <debian@helgefjell.de>
+Origin: vendor
+Bug-Debian: https://bugs.debian.org/478597
+---
+ man/Makefile      |  17 +++-
+ man/Makefile.l10n | 235 ++++++++++++++++++++++++++++++++++++++++++++++++++++++
+ man/de/Makefile   |   7 ++
+ man/fr/Makefile   |   7 ++
+ 4 files changed, 264 insertions(+), 2 deletions(-)
+ create mode 100644 man/Makefile.l10n
+ create mode 100644 man/de/Makefile
+ create mode 100644 man/fr/Makefile
+
+diff --git a/man/Makefile b/man/Makefile
+index e01591a..48f06c4 100644
+--- a/man/Makefile
++++ b/man/Makefile
+@@ -63,12 +63,18 @@ MAN8	=	cupsaccept.8 \
+ 		lpmove.8 \
+ 		lpc.8
+ 
++LANGUAGES=de fr
+ 
+ #
+ # Make everything...
+ #
+ 
+-all:	$(MAN1) $(MAN5) $(MAN7) $(MAN8)
++all:	$(MAN1) $(MAN5) $(MAN7) $(MAN8) translations
++
++translations:
++	# Update the translations and build the translated material
++	po4a --previous ../debian/manpage-po4a/cups.cfg
++	for lang in $(LANGUAGES); do $(MAKE) -C $$lang; done
+ 
+ 
+ #
+@@ -91,6 +97,12 @@ unittests:
+ 
+ clean:
+ 	$(RM) mantohtml mantohtml.o
++	$(RM) $(MAN1) $(MAN5) $(MAN7) $(MAN8)
++	for lang in $(LANGUAGES); do $(MAKE) -C $$lang clean; done
++	# Make sure the PO files are updated and remove generated
++	# translations.
++	po4a --previous --rm-translations ../debian/manpage-po4a/cups.cfg
++	$(RM) ../debian/manpage-po4a/po/cups.pot
+ 
+ 
+ #
+@@ -142,6 +154,7 @@ install-data: all
+ 		$(RM) $(MANDIR)/man8/$$file; \
+ 		$(LN) cupsd-helper.8 $(MANDIR)/man8/$$file; \
+ 	done
++	for lang in $(LANGUAGES); do $(MAKE) -C $$lang install; done
+ 
+ 
+ #
+@@ -189,7 +202,7 @@ uninstall:
+ 	for file in $(MAN8) cupsenable.8 cupsreject.8 cups-deviced.8 cups-driverd.8 cups-exec.8; do \
+ 		$(RM) $(MANDIR)/man8/$$file; \
+ 	done
+-	-$(RMDIR) $(MANDIR)/man8
++	-$(RMDIR) $(AMANDIR)/man$(MAN8DIR)
+ 
+ 
+ #
+diff --git a/man/Makefile.l10n b/man/Makefile.l10n
+new file mode 100644
+index 0000000..08390f5
+--- /dev/null
++++ b/man/Makefile.l10n
+@@ -0,0 +1,235 @@
++#
++# Man page makefile for CUPS.
++#
++# Copyright © 2007-2019 by Apple Inc.
++# Copyright © 1993-2006 by Easy Software Products.
++#
++# Licensed under Apache License v2.0.  See the file "LICENSE" for more
++# information.
++#
++
++include ../../Makedefs
++
++
++#
++# Man pages...
++#
++
++MAN1	=	cancel.1 \
++		cups.1 \
++		cups-config.1 \
++		cupstestppd.1 \
++		ippeveprinter.1 \
++		$(IPPFIND_MAN) \
++		ipptool.1 \
++		lp.1 \
++		lpoptions.1 \
++		lpq.1 \
++		lprm.1 \
++		lpr.1 \
++		lpstat.1 \
++		ppdc.1 \
++		ppdhtml.1 \
++		ppdi.1 \
++		ppdmerge.1 \
++		ppdpo.1
++MAN5	=	classes.conf.5 \
++		client.conf.5 \
++		cups-files.conf.5 \
++		cups-snmp.conf.5 \
++		cupsd.conf.5 \
++		cupsd-logs.5 \
++		ipptoolfile.5 \
++		mailto.conf.5 \
++		mime.convs.5 \
++		mime.types.5 \
++		ppdcfile.5 \
++		printers.conf.5 \
++		subscriptions.conf.5
++MAN7	=	backend.7 \
++		filter.7 \
++		ippevepcl.7 \
++		notifier.7
++MAN8	=	cupsaccept.8 \
++		cupsctl.8 \
++		cupsfilter.8 \
++		cups-lpd.8 \
++		cups-snmp.8 \
++		cupsd.8 \
++		cupsd-helper.8 \
++		cupsenable.8 \
++		lpadmin.8 \
++		lpinfo.8 \
++		lpmove.8 \
++		lpc.8
++
++
++#
++# Make everything...
++#
++
++# Debian-specific patch: Just assume all files are here.
++all:
++
++
++#
++# Make library targets...
++#
++
++libs:
++
++
++#
++# Make unit tests...
++#
++
++unittests:
++
++
++#
++# Clean all config and object files...
++#
++
++clean:
++	$(RM) mantohtml mantohtml.o
++
++
++#
++# Dummy depend target...
++#
++
++depend:
++
++
++#
++# Install all targets...
++#
++
++# Debian-specific patch: directory-based language namespace
++MANDIR := $(MANDIR)/$(LANGUAGE)
++
++install:	all install-data install-headers install-libs install-exec
++
++
++#
++# Install data files...
++#
++
++# Debian-specific patch: skip if doesn't exist
++install-data: all
++	echo Installing man pages in $(MANDIR)/man1...
++	$(INSTALL_DIR) -m 755 $(MANDIR)/man1
++	for file in $(MAN1); do \
++		[ ! -r $$file ] || \
++		$(INSTALL_MAN) $$file $(MANDIR)/man1; \
++	done
++	echo Installing man pages in $(MANDIR)/man5...
++	$(INSTALL_DIR) -m 755 $(MANDIR)/man5
++	for file in $(MAN5); do \
++		[ ! -r $$file ] || \
++		$(INSTALL_MAN) $$file $(MANDIR)/man5; \
++	done
++	echo Installing man pages in $(MANDIR)/man7...
++	$(INSTALL_DIR) -m 755 $(MANDIR)/man7
++	for file in $(MAN7); do \
++		[ ! -r $$file ] || \
++		$(INSTALL_MAN) $$file $(MANDIR)/man7; \
++	done
++	$(RM) $(MANDIR)/man7/ippeveps.7
++	$(LN) ippevepcl.7 $(MANDIR)/man7/ippeveps.7
++	echo Installing man pages in $(MANDIR)/man8...
++	$(INSTALL_DIR) -m 755 $(MANDIR)/man8
++	for file in $(MAN8); do \
++		[ ! -r $$file ] || \
++		$(INSTALL_MAN) $$file $(MANDIR)/man8; \
++	done
++	$(RM) $(MANDIR)/man8/cupsdisable.8
++	$(LN) cupsenable.8 $(MANDIR)/man8/cupsdisable.8
++	$(RM) $(MANDIR)/man8/cupsreject.8
++	$(LN) cupsaccept.8 $(MANDIR)/man8/cupsreject.8
++	for file in cups-deviced.8 cups-driverd.8 cups-exec.8; do \
++		$(RM) $(MANDIR)/man8/$$file; \
++		$(LN) cupsd-helper.8 $(MANDIR)/man8/$$file; \
++	done
++
++
++#
++# Install programs...
++#
++
++install-exec:
++
++
++#
++# Install headers...
++#
++
++install-headers:
++
++
++#
++# Install libraries...
++#
++
++install-libs:
++
++
++#
++# Uninstall files...
++#
++
++uninstall:
++	echo Uninstalling man pages from $(MANDIR)/man1...
++	for file in $(MAN1); do \
++		$(RM) $(MANDIR)/man1/$$file; \
++	done
++	-$(RMDIR) $(MANDIR)/man1
++	echo Uninstalling man pages from $(MANDIR)/man5...
++	for file in $(MAN5); do \
++		$(RM) $(MANDIR)/man5/$$file; \
++	done
++	-$(RMDIR) $(MANDIR)/man5
++	echo Uninstalling man pages from $(MANDIR)/man7...
++	for file in $(MAN7) ippeveps.7; do \
++		$(RM) $(MANDIR)/man7/$$file; \
++	done
++	-$(RMDIR) $(MANDIR)/man7
++	echo Uninstalling man pages from $(MANDIR)/man8...
++	for file in $(MAN8) cupsenable.8 cupsreject.8 cups-deviced.8 cups-driverd.8 cups-exec.8; do \
++		$(RM) $(MANDIR)/man8/$$file; \
++	done
++	-$(RMDIR) $(MANDIR)/man8
++
++
++#
++# Local programs (not built when cross-compiling...)
++#
++
++local:	html
++
++
++#
++# Make html versions of man pages...
++#
++
++html:	$(MAN1) $(MAN5) $(MAN7) $(MAN8) mantohtml
++	echo Converting man pages to HTML...
++	for file in $(MAN1); do \
++		echo "    $$file..."; \
++		./mantohtml $$file >../doc/help/man-`basename $$file .1`.html; \
++	done
++	for file in $(MAN5); do \
++		echo "    $$file..."; \
++		./mantohtml $$file >../doc/help/man-`basename $$file .5`.html; \
++	done
++	for file in $(MAN7); do \
++		echo "    $$file..."; \
++		./mantohtml $$file >../doc/help/man-`basename $$file .7`.html; \
++	done
++	for file in $(MAN8); do \
++		echo "    $$file..."; \
++		./mantohtml $$file >../doc/help/man-`basename $$file .8`.html; \
++	done
++
++mantohtml:	mantohtml.c
++	$(CC_FOR_BUILD) -o $@ $<
+diff --git a/man/de/Makefile b/man/de/Makefile
+new file mode 100644
+index 0000000..7c23784
+--- /dev/null
++++ b/man/de/Makefile
+@@ -0,0 +1,7 @@
++#
++#   Man page makefile for the Common UNIX Printing System (CUPS).
++#
++
++LANGUAGE=de
++
++include ../Makefile.l10n
+diff --git a/man/fr/Makefile b/man/fr/Makefile
+new file mode 100644
+index 0000000..6a50e93
+--- /dev/null
++++ b/man/fr/Makefile
+@@ -0,0 +1,7 @@
++#
++#   Man page makefile for the Common UNIX Printing System (CUPS).
++#
++
++LANGUAGE=fr
++
++include ../Makefile.l10n
diff -pruN 2.3.3-3/debian/patches/0012-Tests-ignore-job-held-message.patch 2.3.3op1-3/debian/patches/0012-Tests-ignore-job-held-message.patch
--- 2.3.3-3/debian/patches/0012-Tests-ignore-job-held-message.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0012-Tests-ignore-job-held-message.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,21 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Sat, 8 Feb 2020 11:49:07 +0100
-Subject: Tests: ignore 'job held' message
-
-Origin: vendor
----
- test/run-stp-tests.sh | 1 +
- 1 file changed, 1 insertion(+)
-
-diff --git a/test/run-stp-tests.sh b/test/run-stp-tests.sh
-index c072ad8..dfa7f6a 100755
---- a/test/run-stp-tests.sh
-+++ b/test/run-stp-tests.sh
-@@ -1032,6 +1032,7 @@ count=`$GREP '^E ' $BASE/log/error_log | $GREP -v 'Unknown default SystemGroup'
-        $GREP -v 'Failed to connect to system bus' | \
-        $GREP -v -E 'Unable to open listen socket for address .* Address family not supported by protocol.' | \
-        $GREP -v 'Unable to write uncompressed print data: Broken pipe' | \
-+       $GREP -v 'Job held by' | \
-        wc -l | awk '{print $1}'`
- if test $count != 33; then
- 	echo "FAIL: $count error messages, expected 33."
diff -pruN 2.3.3-3/debian/patches/0013-Tests-Do-not-run-the-CUPS_EUC_JP-test-case-on-BSD-Hu.patch 2.3.3op1-3/debian/patches/0013-Tests-Do-not-run-the-CUPS_EUC_JP-test-case-on-BSD-Hu.patch
--- 2.3.3-3/debian/patches/0013-Tests-Do-not-run-the-CUPS_EUC_JP-test-case-on-BSD-Hu.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0013-Tests-Do-not-run-the-CUPS_EUC_JP-test-case-on-BSD-Hu.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,24 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Tue, 9 Aug 2016 18:11:16 +0200
-Subject: Tests: Do not run the CUPS_EUC_JP test case on BSD/Hurd either,
- as glibc's iconv behavior is different than what the test expects.
-
-Bug-Debian: https://bugs.debian.org/662996
-Patch-Name: test-i18n-nonlinux.patch
----
- cups/testi18n.c | 2 +-
- 1 file changed, 1 insertion(+), 1 deletion(-)
-
-diff --git a/cups/testi18n.c b/cups/testi18n.c
-index 45e1cab..449670c 100644
---- a/cups/testi18n.c
-+++ b/cups/testi18n.c
-@@ -410,7 +410,7 @@ main(int  argc,				/* I - Argument Count */
-       puts("PASS");
-   }
- 
--#ifndef __linux
-+#if !defined(__linux__) && !defined(__GLIBC__)
-   fputs("cupsCharsetToUTF8(CUPS_EUC_JP): ", stdout);
- 
-   strlcpy(legsrc, legdest, sizeof(legsrc));
diff -pruN 2.3.3-3/debian/patches/0014-Tests-Make-sure-that-all-scheduled-jobs-are-finished.patch 2.3.3op1-3/debian/patches/0014-Tests-Make-sure-that-all-scheduled-jobs-are-finished.patch
--- 2.3.3-3/debian/patches/0014-Tests-Make-sure-that-all-scheduled-jobs-are-finished.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0014-Tests-Make-sure-that-all-scheduled-jobs-are-finished.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,28 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Tue, 9 Aug 2016 18:11:17 +0200
-Subject: Tests: Make sure that all scheduled jobs are finished before
-
- running a new test. Fixes failures on slow architectures like armel and
- mipsel.
-Bug-Debian: https://bugs.debian.org/670878
-Patch-Name: tests-wait-on-unfinished-jobs-everytime.patch
----
- test/run-stp-tests.sh | 5 +++++
- 1 file changed, 5 insertions(+)
-
-diff --git a/test/run-stp-tests.sh b/test/run-stp-tests.sh
-index dfa7f6a..173fc86 100755
---- a/test/run-stp-tests.sh
-+++ b/test/run-stp-tests.sh
-@@ -776,6 +776,11 @@ echo "    $date by $user on `hostname`." >>$strfile
- echo "    <pre>" >>$strfile
- 
- for file in 5*.sh; do
-+	#
-+	# Make sure the past jobs are done before going on.
-+	#
-+	./waitjobs.sh 1800
-+
- 	echo $ac_n "Performing $file: $ac_c"
- 	echo "" >>$strfile
-         echo "`date '+[%d/%b/%Y:%H:%M:%S %z]'` \"$file\":" >>$strfile
diff -pruN 2.3.3-3/debian/patches/0015-Tests-Force-LC_-environment-variables-when-testing-n.patch 2.3.3op1-3/debian/patches/0015-Tests-Force-LC_-environment-variables-when-testing-n.patch
--- 2.3.3-3/debian/patches/0015-Tests-Force-LC_-environment-variables-when-testing-n.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0015-Tests-Force-LC_-environment-variables-when-testing-n.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,31 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Tue, 9 Aug 2016 18:11:18 +0200
-Subject: Tests: Force LC_* environment variables when testing (non)
- l10n'isation.
-
- Permits building in non-"C" environments.
-Origin: vendor
-Patch-Name: tests-fix-ppdLocalize-on-unclean-env.patch
----
- cups/testppd.c | 8 ++++++++
- 1 file changed, 8 insertions(+)
-
-diff --git a/cups/testppd.c b/cups/testppd.c
-index 36707f2..a4ab7bf 100644
---- a/cups/testppd.c
-+++ b/cups/testppd.c
-@@ -658,6 +658,14 @@ main(int  argc,				/* I - Number of command-line arguments */
-     * Test localization...
-     */
- 
-+   /*
-+    * Enforce void localization
-+    */
-+    putenv("LANG=C");
-+    putenv("LC_ALL=C");
-+    putenv("LC_CTYPE=C");
-+    putenv("LC_MESSAGES=C");
-+
-     fputs("ppdLocalizeIPPReason(text): ", stdout);
-     if (ppdLocalizeIPPReason(ppd, "foo", NULL, buffer, sizeof(buffer)) &&
-         !strcmp(buffer, "Foo Reason"))
diff -pruN 2.3.3-3/debian/patches/0016-Tests-Use-127.0.0.1-instead-of-localhost-to-help-pbu.patch 2.3.3op1-3/debian/patches/0016-Tests-Use-127.0.0.1-instead-of-localhost-to-help-pbu.patch
--- 2.3.3-3/debian/patches/0016-Tests-Use-127.0.0.1-instead-of-localhost-to-help-pbu.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0016-Tests-Use-127.0.0.1-instead-of-localhost-to-help-pbu.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,64 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Tue, 9 Aug 2016 18:11:21 +0200
-Subject: Tests: Use 127.0.0.1 instead of localhost to help pbuilder
-
-This should make the test-suite work in pbuilder. It apparently also fixes an
-ipp backend problem in the test-suite.
-
-Origin: vendor
-Patch-Name: tests-use-ipv4-lo-address.patch
----
- test/5.1-lpadmin.sh   | 4 ++--
- test/run-stp-tests.sh | 8 ++++----
- 2 files changed, 6 insertions(+), 6 deletions(-)
-
-diff --git a/test/5.1-lpadmin.sh b/test/5.1-lpadmin.sh
-index 7efc398..08b8c50 100644
---- a/test/5.1-lpadmin.sh
-+++ b/test/5.1-lpadmin.sh
-@@ -52,8 +52,8 @@ echo ""
- 
- echo "Add Shared Printer Test"
- echo ""
--echo "    lpadmin -p Test3 -E -v ipp://localhost:$IPP_PORT/printers/Test2 -m everywhere"
--$runcups $VALGRIND ../systemv/lpadmin -p Test3 -E -v ipp://localhost:$IPP_PORT/printers/Test2 -m everywhere 2>&1
-+echo "    lpadmin -p Test3 -E -v ipp://127.0.0.1:$IPP_PORT/printers/Test2 -m everywhere"
-+$runcups $VALGRIND ../systemv/lpadmin -p Test3 -E -v ipp://127.0.0.1:$IPP_PORT/printers/Test2 -m everywhere 2>&1
- if test $? != 0; then
- 	echo "    FAILED"
- 	exit 1
-diff --git a/test/run-stp-tests.sh b/test/run-stp-tests.sh
-index 173fc86..88bafb1 100755
---- a/test/run-stp-tests.sh
-+++ b/test/run-stp-tests.sh
-@@ -490,7 +490,7 @@ fi
- cat >$BASE/cupsd.conf <<EOF
- StrictConformance Yes
- Browsing Off
--Listen localhost:$port
-+Listen 127.0.0.1:$port
- Listen $BASE/sock
- MaxSubscriptions 3
- MaxLogSize 0
-@@ -617,7 +617,7 @@ fi
- 
- # These get exported because they don't have side-effects...
- CUPS_DISABLE_APPLE_DEFAULT=yes; export CUPS_DISABLE_APPLE_DEFAULT
--CUPS_SERVER=localhost:$port; export CUPS_SERVER
-+CUPS_SERVER=127.0.0.1:$port; export CUPS_SERVER
- CUPS_SERVERROOT=$BASE; export CUPS_SERVERROOT
- CUPS_STATEDIR=$BASE; export CUPS_STATEDIR
- CUPS_DATADIR=$BASE/share; export CUPS_DATADIR
-@@ -743,10 +743,10 @@ for file in 4*.test ../examples/ipp-2.1.test; do
-         echo $ac_n "`date '+[%d/%b/%Y:%H:%M:%S %z]'` $ac_c" >>$strfile
- 
- 	if test $file = ../examples/ipp-2.1.test; then
--		uri="ipp://localhost:$port/printers/Test1"
-+		uri="ipp://127.0.0.1:$port/printers/Test1"
- 		options="-V 2.1 -d NOPRINT=1 -f testfile.ps"
- 	else
--		uri="ipp://localhost:$port/printers"
-+		uri="ipp://127.0.0.1:$port/printers"
- 		options=""
- 	fi
- 	$runcups $VALGRIND ../tools/ipptool -tI $options $uri $file >> $strfile
diff -pruN 2.3.3-3/debian/patches/0017-Tests-Force-LC_ALL-C-environment-variable-when-grepp.patch 2.3.3op1-3/debian/patches/0017-Tests-Force-LC_ALL-C-environment-variable-when-grepp.patch
--- 2.3.3-3/debian/patches/0017-Tests-Force-LC_ALL-C-environment-variable-when-grepp.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0017-Tests-Force-LC_ALL-C-environment-variable-when-grepp.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,24 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Tue, 9 Aug 2016 18:11:22 +0200
-Subject: Tests: Force LC_ALL=C environment variable when grepping the output
- of lpstat
-
-Permits testing in non-"C" environments.
-Origin: vendor
-Patch-Name: tests-make-lpstat-call-reproducible.patch
----
- test/run-stp-tests.sh | 1 +
- 1 file changed, 1 insertion(+)
-
-diff --git a/test/run-stp-tests.sh b/test/run-stp-tests.sh
-index 88bafb1..d9b3985 100755
---- a/test/run-stp-tests.sh
-+++ b/test/run-stp-tests.sh
-@@ -642,6 +642,7 @@ echo "DYLD_LIBRARY_PATH=\"$DYLD_LIBRARY_PATH\"; export DYLD_LIBRARY_PATH" >>$run
- echo "LD_LIBRARY_PATH=\"$LD_LIBRARY_PATH\"; export LD_LIBRARY_PATH" >>$runcups
- echo "LD_PRELOAD=\"$LD_PRELOAD\"; export LD_PRELOAD" >>$runcups
- echo "LOCALEDIR=\"$LOCALEDIR\"; export LOCALEDIR" >>$runcups
-+echo "LC_ALL=\"C\"; export LC_ALL" >>$runcups
- if test "x$CUPS_DEBUG_LEVEL" != x; then
- 	echo "CUPS_DEBUG_FILTER='$CUPS_DEBUG_FILTER'; export CUPS_DEBUG_FILTER" >>$runcups
- 	echo "CUPS_DEBUG_LEVEL=$CUPS_DEBUG_LEVEL; export CUPS_DEBUG_LEVEL" >>$runcups
diff -pruN 2.3.3-3/debian/patches/0018-Tests-Do-not-test-pdftourf.patch 2.3.3op1-3/debian/patches/0018-Tests-Do-not-test-pdftourf.patch
--- 2.3.3-3/debian/patches/0018-Tests-Do-not-test-pdftourf.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0018-Tests-Do-not-test-pdftourf.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,68 +0,0 @@
-From: Michael Sweet <michael.r.sweet@gmail.com>
-Date: Tue, 9 Aug 2016 18:11:23 +0200
-Subject: Tests: Do not test pdftourf
-
- Revert commit 830cfed95a5349b008999eebd34f5233bc35829c
-
- "Update "make test" to include alternate filter."
- .
- This fixes the error lines counting in the test, and is unneeded as pdftourf
- is not shipped in Debian.
-Origin: upstream
-Patch-Name: tests-no-pdftourf.patch
----
- test/run-stp-tests.sh | 4 +---
- test/test.convs       | 1 -
- test/test.types       | 2 --
- 3 files changed, 1 insertion(+), 6 deletions(-)
- delete mode 100644 test/test.types
-
-diff --git a/test/run-stp-tests.sh b/test/run-stp-tests.sh
-index d9b3985..bc332fc 100755
---- a/test/run-stp-tests.sh
-+++ b/test/run-stp-tests.sh
-@@ -268,7 +268,7 @@ case "$usedebugprintfs" in
- 		echo "Enabling debug printfs (level $usedebugprintfs); log files can be found in $BASE/log..."
- 		CUPS_DEBUG_LOG="$BASE/log/debug_printfs.%d"; export CUPS_DEBUG_LOG
- 		CUPS_DEBUG_LEVEL="$usedebugprintfs"; export CUPS_DEBUG_LEVEL
--		CUPS_DEBUG_FILTER='^(http|_http|ipp|_ipp|cups.*Request|cupsGetResponse|cupsSend|mime).*$'; export CUPS_DEBUG_FILTER
-+		CUPS_DEBUG_FILTER='^(http|_http|ipp|_ipp|cups.*Request|cupsGetResponse|cupsSend).*$'; export CUPS_DEBUG_FILTER
- 		;;
- 
- 	*)
-@@ -443,14 +443,12 @@ EOF
- }
- 
- ln -s $root/test/test.convs $BASE/share/mime
--ln -s $root/test/test.types $BASE/share/mime
- 
- if test `uname` = Darwin; then
- 	instfilter cgimagetopdf imagetopdf pdf
- 	instfilter cgpdftopdf pdftopdf passthru
- 	instfilter cgpdftops pdftops ps
- 	instfilter cgpdftoraster pdftoraster raster
--	instfilter cgpdftoraster pdftourf raster
- 	instfilter cgtexttopdf texttopdf pdf
- 	instfilter pstocupsraster pstoraster raster
- else
-diff --git a/test/test.convs b/test/test.convs
-index 77a9ce0..57540aa 100644
---- a/test/test.convs
-+++ b/test/test.convs
-@@ -2,7 +2,6 @@
- application/pdf application/vnd.cups-pdf 100 pdftopdf
- application/pdf application/postscript 100 pdftops
- application/pdf application/vnd.cups-raster 100 pdftoraster
--application/pdf image/urf 100 pdftourf
- application/postscript application/vnd.cups-raster 100 pstoraster
- image/jpeg application/pdf 100 imagetopdf
- text/plain application/pdf 100 texttopdf
-diff --git a/test/test.types b/test/test.types
-deleted file mode 100644
-index 914081c..0000000
---- a/test/test.types
-+++ /dev/null
-@@ -1,2 +0,0 @@
--# Test file listing potential MIME media types that are not in the standard mime.types file
--image/urf
-\ No newline at end of file
diff -pruN 2.3.3-3/debian/patches/0019-Move-cupsd.conf.default-from-SERVERROOT-to-DATADIR.patch 2.3.3op1-3/debian/patches/0019-Move-cupsd.conf.default-from-SERVERROOT-to-DATADIR.patch
--- 2.3.3-3/debian/patches/0019-Move-cupsd.conf.default-from-SERVERROOT-to-DATADIR.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0019-Move-cupsd.conf.default-from-SERVERROOT-to-DATADIR.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,62 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Tue, 9 Aug 2016 18:11:24 +0200
-Subject: Move cupsd.conf.default from SERVERROOT to DATADIR
-
-Origin: vendor
-Bug: https://github.com/apple/cups/issues/4342
-Bug-Debian: https://bugs.debian.org/640124
-Patch-Name: move-cupsd-conf-default-to-share.patch
----
- cgi-bin/admin.c | 6 +++++-
- conf/Makefile   | 5 +++--
- 2 files changed, 8 insertions(+), 3 deletions(-)
-
-diff --git a/cgi-bin/admin.c b/cgi-bin/admin.c
-index f087809..6e9a64a 100644
---- a/cgi-bin/admin.c
-+++ b/cgi-bin/admin.c
-@@ -1629,6 +1629,7 @@ do_config_server(http_t *http)		/* I - HTTP connection */
-     int		ch;			/* Character from file */
-     char	filename[1024];		/* Filename */
-     const char	*server_root;		/* Location of config files */
-+    const char	*data_dir;		/* Location of data files */
- 
- 
-    /*
-@@ -1712,7 +1713,10 @@ do_config_server(http_t *http)		/* I - HTTP connection */
-     * well...
-     */
- 
--    strlcat(filename, ".default", sizeof(filename));
-+    if ((data_dir = getenv("CUPS_DATADIR")) == NULL)
-+      data_dir = CUPS_DATADIR;
-+
-+    snprintf(filename, sizeof(filename), "%s/cupsd.conf.default",data_dir);
- 
-     if (!stat(filename, &info) && info.st_size < (1024 * 1024) &&
-         (cupsd = cupsFileOpen(filename, "r")) != NULL)
-diff --git a/conf/Makefile b/conf/Makefile
-index e249e60..42a123f 100644
---- a/conf/Makefile
-+++ b/conf/Makefile
-@@ -70,7 +70,7 @@ install-data:
- 		else \
- 			$(INSTALL_CONFIG) -g $(CUPS_GROUP) $$file $(SERVERROOT) ; \
- 		fi ; \
--		$(INSTALL_CONFIG) -g $(CUPS_GROUP) $$file $(SERVERROOT)/$$file.default; \
-+		$(INSTALL_CONFIG) -g $(CUPS_GROUP) $$file $(DATADIR)/$$file.default; \
- 	done
- 	$(INSTALL_DIR) -m 755 $(DATADIR)/mime
- 	for file in $(REPLACE); do \
-@@ -118,9 +118,10 @@ install-libs:
- #
- 
- uninstall:
--	for file in $(KEEP) $(REPLACE) cupsd.conf.default; do \
-+	for file in $(KEEP) $(REPLACE); do \
- 		$(RM) $(SERVERROOT)/$$file; \
- 	done
-+	$(RM) $(DATADIR)/cupsd.conf.default
- 	-$(RMDIR) $(SERVERROOT)
- 	for file in $(REPLACE); do \
- 		$(RM) $(DATADIR)/mime/$$file; \
diff -pruN 2.3.3-3/debian/patches/0020-Patch-to-support-Apple-AirPrint-printing-from-iPhone.patch 2.3.3op1-3/debian/patches/0020-Patch-to-support-Apple-AirPrint-printing-from-iPhone.patch
--- 2.3.3-3/debian/patches/0020-Patch-to-support-Apple-AirPrint-printing-from-iPhone.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0020-Patch-to-support-Apple-AirPrint-printing-from-iPhone.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,91 +0,0 @@
-From: Till Kamppeter <till.kamppeter@gmail.com>
-Date: Tue, 9 Aug 2016 18:11:29 +0200
-Subject: Patch to support Apple AirPrint (printing from iPhone, iPad,
- iPod Touch to a CUPS server)
-
-Bug-Ubuntu: https://bugs.launchpad.net/bugs/711779
-Bug-Ubuntu: https://bugs.launchpad.net/bugs/1054495
-Bug-Debian: https://bugs.debian.org/700961
-Bug: https://github.com/apple/cups/issues/4341
-Patch-Name: airprint-support.patch
----
- conf/mime.convs.in   | 3 +++
- conf/mime.types      | 3 +++
- scheduler/conf.c     | 2 +-
- scheduler/dirsvc.c   | 6 ++++++
- scheduler/printers.c | 4 +++-
- 5 files changed, 16 insertions(+), 2 deletions(-)
-
-diff --git a/conf/mime.convs.in b/conf/mime.convs.in
-index 57b459d..e042e01 100644
---- a/conf/mime.convs.in
-+++ b/conf/mime.convs.in
-@@ -44,6 +44,9 @@ application/postscript		application/vnd.cups-postscript	66	pstops
- application/vnd.cups-raster	image/pwg-raster		100	rastertopwg
- application/vnd.cups-raster	image/urf			100	rastertopwg
- 
-+# Needed for printing from iOS (AirPrint) clients
-+image/urf    	      	       application/pdf			100	-
-+
- ########################################################################
- #
- # Raw filter...
-diff --git a/conf/mime.types b/conf/mime.types
-index fcd6b6e..ebb0525 100644
---- a/conf/mime.types
-+++ b/conf/mime.types
-@@ -108,6 +108,9 @@ image/x-alias			pix short(8,8) short(8,24)
- image/x-bitmap			bmp string(0,BM) + !printable(2,14)
- image/x-icon			ico
- 
-+# Needed for printing from iOS (AirPrint) clients
-+image/urf			urf string(0,UNIRAST<00>)
-+
- ########################################################################
- #
- # Text files...
-diff --git a/scheduler/conf.c b/scheduler/conf.c
-index bb6049b..bb4f9d2 100644
---- a/scheduler/conf.c
-+++ b/scheduler/conf.c
-@@ -745,7 +745,7 @@ cupsdReadConfiguration(void)
-   DefaultShared            = CUPS_DEFAULT_DEFAULT_SHARED;
- 
- #if defined(HAVE_DNSSD) || defined(HAVE_AVAHI)
--  cupsdSetString(&DNSSDSubTypes, "_cups,_print");
-+  cupsdSetString(&DNSSDSubTypes, "_cups,_print,_universal");
-   cupsdClearString(&DNSSDHostName);
- #endif /* HAVE_DNSSD || HAVE_AVAHI */
- 
-diff --git a/scheduler/dirsvc.c b/scheduler/dirsvc.c
-index ddd3701..fb2a305 100644
---- a/scheduler/dirsvc.c
-+++ b/scheduler/dirsvc.c
-@@ -440,6 +440,12 @@ dnssdBuildTxtRecord(
-     keyvalue[count  ][0] = "pdl";
-     keyvalue[count++][1] = p->pdl ? p->pdl : "application/postscript";
- 
-+    /* iOS 6 does not accept this printer as AirPrint printer if there is
-+       no URF txt record or "URF=none", "DM3" is the minimum needed found
-+       by try and error */
-+    keyvalue[count  ][0] = "URF";
-+    keyvalue[count++][1] = "DM3";
-+
-     if (get_auth_info_required(p, air_str, sizeof(air_str)))
-     {
-       keyvalue[count  ][0] = "air";
-diff --git a/scheduler/printers.c b/scheduler/printers.c
-index e341bdb..545e0de 100644
---- a/scheduler/printers.c
-+++ b/scheduler/printers.c
-@@ -3731,7 +3731,9 @@ add_printer_formats(cupsd_printer_t *p)	/* I - Printer */
-       }
-       else if (!_cups_strcasecmp(type->super, "image"))
-       {
--        if (!_cups_strcasecmp(type->type, "jpeg"))
-+        if (!_cups_strcasecmp(type->type, "urf"))
-+	  strlcat(pdl, "image/urf,", sizeof(pdl));
-+	else if (!_cups_strcasecmp(type->type, "jpeg"))
- 	  strlcat(pdl, "image/jpeg,", sizeof(pdl));
- 	else if (!_cups_strcasecmp(type->type, "png"))
- 	  strlcat(pdl, "image/png,", sizeof(pdl));
diff -pruN 2.3.3-3/debian/patches/0021-Let-snmp-backend-also-use-manufacturer-specific-MIBs.patch 2.3.3op1-3/debian/patches/0021-Let-snmp-backend-also-use-manufacturer-specific-MIBs.patch
--- 2.3.3-3/debian/patches/0021-Let-snmp-backend-also-use-manufacturer-specific-MIBs.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0021-Let-snmp-backend-also-use-manufacturer-specific-MIBs.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,48 +0,0 @@
-From: Tim Waugh <twaugh@redhat.com>
-Date: Tue, 9 Aug 2016 18:11:30 +0200
-Subject: Let snmp backend also use manufacturer-specific MIBs
-MIME-Version: 1.0
-Content-Type: text/plain; charset="utf-8"
-Content-Transfer-Encoding: 8bit
-
- … of HP and Ricoh to obtain the device IDs of network-connected
- printers. This way we get more reliable information about make and model
- and in addition the supported page description languages, which allows one to
- identify whether an optional PostScript add-on is installed or for an
- unsupported printer which generic PPD is the best choice (requested by
- Ricoh).
-Bug: https://github.com/apple/cups/issues/3552
-Patch-Name: Let-snmp-backend-also-use-manufacturer-specific-MIBs.patch
----
- backend/snmp.c | 8 ++++++++
- 1 file changed, 8 insertions(+)
-
-diff --git a/backend/snmp.c b/backend/snmp.c
-index 66ac884..9572822 100644
---- a/backend/snmp.c
-+++ b/backend/snmp.c
-@@ -154,6 +154,8 @@ static const int	UriOID[] = { CUPS_OID_ppmPortServiceNameOrURI, 1, 1, -1 };
- static const int	LexmarkProductOID[] = { 1,3,6,1,4,1,641,2,1,2,1,2,1,-1 };
- static const int	LexmarkProductOID2[] = { 1,3,6,1,4,1,674,10898,100,2,1,2,1,2,1,-1 };
- static const int	LexmarkDeviceIdOID[] = { 1,3,6,1,4,1,641,2,1,2,1,3,1,-1 };
-+static const int	HPDeviceIdOID[] = { 1,3,6,1,4,1,11,2,3,9,1,1,7,0,-1 };
-+static const int	RicohDeviceIdOID[] = { 1,3,6,1,4,1,367,3,2,1,1,1,11,0,-1 };
- static const int	XeroxProductOID[] = { 1,3,6,1,4,1,128,2,1,3,1,2,0,-1 };
- static cups_array_t	*DeviceURIs = NULL;
- static int		HostNameLookups = 0;
-@@ -969,9 +971,15 @@ read_snmp_response(int fd)		/* I - SNMP socket file descriptor */
- 	_cupsSNMPWrite(fd, &(packet.address), CUPS_SNMP_VERSION_1,
- 	               packet.community, CUPS_ASN1_GET_REQUEST,
- 		       DEVICE_ID, LexmarkDeviceIdOID);
-+	_cupsSNMPWrite(fd, &(packet.address), CUPS_SNMP_VERSION_1,
-+		       packet.community, CUPS_ASN1_GET_REQUEST,
-+		       DEVICE_ID, RicohDeviceIdOID);
- 	_cupsSNMPWrite(fd, &(packet.address), CUPS_SNMP_VERSION_1,
- 	               packet.community, CUPS_ASN1_GET_REQUEST,
- 		       DEVICE_PRODUCT, XeroxProductOID);
-+	_cupsSNMPWrite(fd, &(packet.address), CUPS_SNMP_VERSION_1,
-+		       packet.community, CUPS_ASN1_GET_REQUEST,
-+		       DEVICE_ID, HPDeviceIdOID);
-         break;
- 
-     case DEVICE_DESCRIPTION :
diff -pruN 2.3.3-3/debian/patches/0022-Disable-time-stamps-in-conffiles-to-avoid-ever-chang.patch 2.3.3op1-3/debian/patches/0022-Disable-time-stamps-in-conffiles-to-avoid-ever-chang.patch
--- 2.3.3-3/debian/patches/0022-Disable-time-stamps-in-conffiles-to-avoid-ever-chang.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0022-Disable-time-stamps-in-conffiles-to-avoid-ever-chang.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,67 +0,0 @@
-From: Joey Hess <joeyh@debian.org>
-Date: Tue, 9 Aug 2016 18:11:31 +0200
-Subject: Disable time stamps in conffiles,
- to avoid ever-changing files in /etc.
-
-Bug: https://github.com/apple/cups/issues/3067
-Bug-Debian: https://bugs.debian.org/549673
-Patch-Name: no-conffile-timestamp.patch
----
- scheduler/classes.c       | 2 +-
- scheduler/job.c           | 2 +-
- scheduler/printers.c      | 2 +-
- scheduler/subscriptions.c | 2 +-
- 4 files changed, 4 insertions(+), 4 deletions(-)
-
-diff --git a/scheduler/classes.c b/scheduler/classes.c
-index 14d2558..35d0eb7 100644
---- a/scheduler/classes.c
-+++ b/scheduler/classes.c
-@@ -688,7 +688,7 @@ cupsdSaveAllClasses(void)
-   strftime(temp, sizeof(temp) - 1, "%Y-%m-%d %H:%M", &curdate);
- 
-   cupsFilePuts(fp, "# Class configuration file for " CUPS_SVERSION "\n");
--  cupsFilePrintf(fp, "# Written by cupsd on %s\n", temp);
-+  cupsFilePrintf(fp, "# Written by cupsd\n");
-   cupsFilePuts(fp, "# DO NOT EDIT THIS FILE WHEN CUPSD IS RUNNING\n");
- 
-  /*
-diff --git a/scheduler/job.c b/scheduler/job.c
-index eb99b3e..760e30f 100644
---- a/scheduler/job.c
-+++ b/scheduler/job.c
-@@ -2201,7 +2201,7 @@ cupsdSaveAllJobs(void)
-   strftime(temp, sizeof(temp) - 1, "%Y-%m-%d %H:%M", &curdate);
- 
-   cupsFilePuts(fp, "# Job cache file for " CUPS_SVERSION "\n");
--  cupsFilePrintf(fp, "# Written by cupsd on %s\n", temp);
-+  cupsFilePrintf(fp, "# Written by cupsd\n");
-   cupsFilePrintf(fp, "NextJobId %d\n", NextJobId);
- 
-  /*
-diff --git a/scheduler/printers.c b/scheduler/printers.c
-index 545e0de..f28c64a 100644
---- a/scheduler/printers.c
-+++ b/scheduler/printers.c
-@@ -1503,7 +1503,7 @@ cupsdSaveAllPrinters(void)
-   strftime(temp, sizeof(temp) - 1, "%Y-%m-%d %H:%M", &curdate);
- 
-   cupsFilePuts(fp, "# Printer configuration file for " CUPS_SVERSION "\n");
--  cupsFilePrintf(fp, "# Written by cupsd on %s\n", temp);
-+  cupsFilePrintf(fp, "# Written by cupsd\n");
-   cupsFilePuts(fp, "# DO NOT EDIT THIS FILE WHEN CUPSD IS RUNNING\n");
- 
-   cupsFilePrintf(fp, "NextPrinterId %d\n", NextPrinterId);
-diff --git a/scheduler/subscriptions.c b/scheduler/subscriptions.c
-index 15acedc..eca0bfa 100644
---- a/scheduler/subscriptions.c
-+++ b/scheduler/subscriptions.c
-@@ -1051,7 +1051,7 @@ cupsdSaveAllSubscriptions(void)
-   strftime(temp, sizeof(temp) - 1, "%Y-%m-%d %H:%M", &curdate);
- 
-   cupsFilePuts(fp, "# Subscription configuration file for " CUPS_SVERSION "\n");
--  cupsFilePrintf(fp, "# Written by cupsd on %s\n", temp);
-+  cupsFilePrintf(fp, "# Written by cupsd\n");
- 
-   cupsFilePrintf(fp, "NextSubscriptionId %d\n", NextSubscriptionId);
- 
diff -pruN 2.3.3-3/debian/patches/0023-Do-not-write-VCS-tags-into-installed-conffiles.patch 2.3.3op1-3/debian/patches/0023-Do-not-write-VCS-tags-into-installed-conffiles.patch
--- 2.3.3-3/debian/patches/0023-Do-not-write-VCS-tags-into-installed-conffiles.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0023-Do-not-write-VCS-tags-into-installed-conffiles.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,29 +0,0 @@
-From: Kenshi Muto <kmuto@debian.org>
-Date: Tue, 9 Aug 2016 18:11:33 +0200
-Subject: Do not write VCS tags into installed conffiles
-
-Bug: https://github.com/apple/cups/issues/2369
-Origin: vendor
-Author: Didier Raboud <odyx@debian.org>
-Patch-Name: removecvstag.patch
----
- conf/Makefile | 4 ++++
- 1 file changed, 4 insertions(+)
-
-diff --git a/conf/Makefile b/conf/Makefile
-index 42a123f..db0060d 100644
---- a/conf/Makefile
-+++ b/conf/Makefile
-@@ -69,8 +69,12 @@ install-data:
- 			$(INSTALL_CONFIG) -g $(CUPS_GROUP) $$file $(SERVERROOT)/$$file.N ; \
- 		else \
- 			$(INSTALL_CONFIG) -g $(CUPS_GROUP) $$file $(SERVERROOT) ; \
-+			grep -v "\$$Id[:\$$]" $(SERVERROOT)/$$file > $(SERVERROOT)/$$file.n ; \
-+			mv $(SERVERROOT)/$$file.n $(SERVERROOT)/$$file ; \
- 		fi ; \
- 		$(INSTALL_CONFIG) -g $(CUPS_GROUP) $$file $(DATADIR)/$$file.default; \
-+		grep -v "\$$Id[:\$$]" $(DATADIR)/$$file.default > $(DATADIR)/$$file.default.n ; \
-+		mv $(DATADIR)/$$file.default.n $(DATADIR)/$$file.default ; \
- 	done
- 	$(INSTALL_DIR) -m 755 $(DATADIR)/mime
- 	for file in $(REPLACE); do \
diff -pruN 2.3.3-3/debian/patches/0024-Rename-the-systemd-service-file-from-org.cups.cups.-.patch 2.3.3op1-3/debian/patches/0024-Rename-the-systemd-service-file-from-org.cups.cups.-.patch
--- 2.3.3-3/debian/patches/0024-Rename-the-systemd-service-file-from-org.cups.cups.-.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0024-Rename-the-systemd-service-file-from-org.cups.cups.-.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,59 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Tue, 9 Aug 2016 18:11:34 +0200
-Subject: Rename the systemd service file from org.cups.cups.* to cups.*
-
-Patch-Name: rename-systemd-units.patch
----
- scheduler/org.cups.cups-lpd.socket  | 2 +-
- scheduler/org.cups.cupsd.path.in    | 2 +-
- scheduler/org.cups.cupsd.service.in | 2 +-
- scheduler/org.cups.cupsd.socket.in  | 2 +-
- 4 files changed, 4 insertions(+), 4 deletions(-)
-
-diff --git a/scheduler/org.cups.cups-lpd.socket b/scheduler/org.cups.cups-lpd.socket
-index ed23f9d..eb84459 100644
---- a/scheduler/org.cups.cups-lpd.socket
-+++ b/scheduler/org.cups.cups-lpd.socket
-@@ -1,6 +1,6 @@
- [Unit]
- Description=CUPS LPD Server Socket
--PartOf=org.cups.cups-lpd.service
-+PartOf=cups-lpd.service
- 
- [Socket]
- ListenStream=515
-diff --git a/scheduler/org.cups.cupsd.path.in b/scheduler/org.cups.cupsd.path.in
-index 0f1cc46..7c8509f 100644
---- a/scheduler/org.cups.cupsd.path.in
-+++ b/scheduler/org.cups.cupsd.path.in
-@@ -1,6 +1,6 @@
- [Unit]
- Description=CUPS Scheduler
--PartOf=org.cups.cupsd.service
-+PartOf=cups.service
- 
- [Path]
- PathExists=@CUPS_CACHEDIR@/org.cups.cupsd
-diff --git a/scheduler/org.cups.cupsd.service.in b/scheduler/org.cups.cupsd.service.in
-index 5273762..cd23343 100644
---- a/scheduler/org.cups.cupsd.service.in
-+++ b/scheduler/org.cups.cupsd.service.in
-@@ -9,5 +9,5 @@ Type=simple
- Restart=on-failure
- 
- [Install]
--Also=org.cups.cupsd.socket org.cups.cupsd.path
-+Also=cups.socket cups.path
- WantedBy=printer.target
-diff --git a/scheduler/org.cups.cupsd.socket.in b/scheduler/org.cups.cupsd.socket.in
-index 613b977..3c37d72 100644
---- a/scheduler/org.cups.cupsd.socket.in
-+++ b/scheduler/org.cups.cupsd.socket.in
-@@ -1,6 +1,6 @@
- [Unit]
- Description=CUPS Scheduler
--PartOf=org.cups.cupsd.service
-+PartOf=cups.service
- 
- [Socket]
- ListenStream=@CUPS_DEFAULT_DOMAINSOCKET@
diff -pruN 2.3.3-3/debian/patches/0025-Add-Requires-cups.socket-to-cups.service-to-make-sur.patch 2.3.3op1-3/debian/patches/0025-Add-Requires-cups.socket-to-cups.service-to-make-sur.patch
--- 2.3.3-3/debian/patches/0025-Add-Requires-cups.socket-to-cups.service-to-make-sur.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0025-Add-Requires-cups.socket-to-cups.service-to-make-sur.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,21 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Mon, 24 Feb 2020 11:46:49 +0100
-Subject: Add Requires=cups.socket to cups.service,
- to make sure they start in the right order
-
----
- scheduler/org.cups.cupsd.service.in | 1 +
- 1 file changed, 1 insertion(+)
-
-diff --git a/scheduler/org.cups.cupsd.service.in b/scheduler/org.cups.cupsd.service.in
-index cd23343..79d2c40 100644
---- a/scheduler/org.cups.cupsd.service.in
-+++ b/scheduler/org.cups.cupsd.service.in
-@@ -2,6 +2,7 @@
- Description=CUPS Scheduler
- Documentation=man:cupsd(8)
- After=sssd.service
-+Requires=cups.socket
- 
- [Service]
- ExecStart=@sbindir@/cupsd -l
diff -pruN 2.3.3-3/debian/patches/0026-Do-not-use-host-names-for-broadcasting-print-queues-.patch 2.3.3op1-3/debian/patches/0026-Do-not-use-host-names-for-broadcasting-print-queues-.patch
--- 2.3.3-3/debian/patches/0026-Do-not-use-host-names-for-broadcasting-print-queues-.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0026-Do-not-use-host-names-for-broadcasting-print-queues-.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,25 +0,0 @@
-From: Till Kampetter <till.kampetter@gmail.com>
-Date: Tue, 9 Aug 2016 18:11:35 +0200
-Subject: Do not use host names for broadcasting print queues and
-
- managing print queues broadcasted from other servers by default. Many
- networks do not have valid host names for all machines.
-Bug-Ubuntu: https://bugs.launchpad.net/bugs/449586
-Patch-Name: do-not-broadcast-with-hostnames.patch
----
- scheduler/conf.c | 2 +-
- 1 file changed, 1 insertion(+), 1 deletion(-)
-
-diff --git a/scheduler/conf.c b/scheduler/conf.c
-index bb4f9d2..b73d33f 100644
---- a/scheduler/conf.c
-+++ b/scheduler/conf.c
-@@ -899,7 +899,7 @@ cupsdReadConfiguration(void)
-     cupsdAddAlias(ServerAlias, temp);
-     cupsdLogMessage(CUPSD_LOG_DEBUG, "Added auto ServerAlias %s", temp);
- 
--    if (HostNameLookups || RemotePort)
-+    if (HostNameLookups)
-     {
-       struct hostent	*host;		/* Host entry to get FQDN */
- 
diff -pruN 2.3.3-3/debian/patches/0027-CUPS-removes-the-recommended-comments-of-the-NickNam.patch 2.3.3op1-3/debian/patches/0027-CUPS-removes-the-recommended-comments-of-the-NickNam.patch
--- 2.3.3-3/debian/patches/0027-CUPS-removes-the-recommended-comments-of-the-NickNam.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0027-CUPS-removes-the-recommended-comments-of-the-NickNam.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,39 +0,0 @@
-From: Till Kampetter <till.kampetter@gmail.com>
-Date: Tue, 9 Aug 2016 18:11:36 +0200
-Subject: CUPS removes the "(recommended)" comments of the NickNames of
- Foomatic PPDs when listing available PPDs. This patch removes this removal
- action.
-
-Patch-Name: reactivate_recommended_driver.patch
----
- scheduler/cups-driverd.cxx | 10 ----------
- 1 file changed, 10 deletions(-)
-
-diff --git a/scheduler/cups-driverd.cxx b/scheduler/cups-driverd.cxx
-index 85516eb..874eb3c 100644
---- a/scheduler/cups-driverd.cxx
-+++ b/scheduler/cups-driverd.cxx
-@@ -240,7 +240,6 @@ add_ppd(const char *filename,		/* I - PPD filename */
- 	const char *scheme)		/* I - PPD scheme */
- {
-   ppd_info_t	*ppd;			/* PPD */
--  char		*recommended;		/* Foomatic driver string */
- 
- 
-  /*
-@@ -278,15 +277,6 @@ add_ppd(const char *filename,		/* I - PPD filename */
-   strlcpy(ppd->record.device_id, device_id, sizeof(ppd->record.device_id));
-   strlcpy(ppd->record.scheme, scheme, sizeof(ppd->record.scheme));
- 
-- /*
--  * Strip confusing (and often wrong) "recommended" suffix added by
--  * Foomatic drivers...
--  */
--
--  if ((recommended = strstr(ppd->record.make_and_model,
--                            " (recommended)")) != NULL)
--    *recommended = '\0';
--
-  /*
-   * Add the PPD to the PPD arrays...
-   */
diff -pruN 2.3.3-3/debian/patches/0028-Make-log-files-readable-to-group-adm-if-present.patch 2.3.3op1-3/debian/patches/0028-Make-log-files-readable-to-group-adm-if-present.patch
--- 2.3.3-3/debian/patches/0028-Make-log-files-readable-to-group-adm-if-present.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0028-Make-log-files-readable-to-group-adm-if-present.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,60 +0,0 @@
-From: Martin Pitt <mpitt@debian.org>
-Date: Tue, 9 Aug 2016 18:11:38 +0200
-Subject: Make log files readable to group "adm", if present.
-
-Bug-Ubuntu: https://launchpad.net/bugs/345953
-Patch-Name: logfiles_adm_readable.patch
----
- scheduler/log.c | 11 +++++++++--
- 1 file changed, 9 insertions(+), 2 deletions(-)
-
-diff --git a/scheduler/log.c b/scheduler/log.c
-index 2bd1952..ae0aa55 100644
---- a/scheduler/log.c
-+++ b/scheduler/log.c
-@@ -21,6 +21,7 @@
- #  include <systemd/sd-journal.h>
- #endif /* HAVE_ASL_H */
- #include <syslog.h>
-+#include <grp.h>
- 
- 
- /*
-@@ -110,6 +111,7 @@ cupsdCheckLogFile(cups_file_t **lf,	/* IO - Log file */
- 		filename[1024],		/* Formatted log filename */
- 		*ptr;			/* Pointer into filename */
-   const char	*logptr;		/* Pointer into log filename */
-+  struct group  *loggrp;		/* Group entry of log filename */
- 
- 
-  /*
-@@ -129,6 +131,11 @@ cupsdCheckLogFile(cups_file_t **lf,	/* IO - Log file */
-     return (1);
-   }
- 
-+ /*
-+  * Use adm group if possible, fall back to Group
-+  */
-+ loggrp = getgrnam("adm");
-+
-  /*
-   * Format the filename as needed...
-   */
-@@ -241,7 +248,7 @@ cupsdCheckLogFile(cups_file_t **lf,	/* IO - Log file */
-       * Change ownership and permissions of non-device logs...
-       */
- 
--      fchown(cupsFileNumber(*lf), RunUser, Group);
-+      fchown(cupsFileNumber(*lf), RunUser, loggrp ? loggrp->gr_gid : Group);
-       fchmod(cupsFileNumber(*lf), LogFilePerm);
-     }
-   }
-@@ -284,7 +291,7 @@ cupsdCheckLogFile(cups_file_t **lf,	/* IO - Log file */
-     * Change ownership and permissions of non-device logs...
-     */
- 
--    fchown(cupsFileNumber(*lf), RunUser, Group);
-+    fchown(cupsFileNumber(*lf), RunUser, loggrp ? loggrp->gr_gid : Group);
-     fchmod(cupsFileNumber(*lf), LogFilePerm);
-   }
- 
diff -pruN 2.3.3-3/debian/patches/0029-Deactivate-CUPS-own-log-rotating-as-the-system-alrea.patch 2.3.3op1-3/debian/patches/0029-Deactivate-CUPS-own-log-rotating-as-the-system-alrea.patch
--- 2.3.3-3/debian/patches/0029-Deactivate-CUPS-own-log-rotating-as-the-system-alrea.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0029-Deactivate-CUPS-own-log-rotating-as-the-system-alrea.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,25 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Tue, 9 Aug 2016 18:11:40 +0200
-Subject: Deactivate CUPS' own log rotating as the system already provides a
- more sophisticated log rotating
-
-Patch-Name: default_log_settings.patch
----
- conf/cupsd.conf.in | 4 ++++
- 1 file changed, 4 insertions(+)
-
-diff --git a/conf/cupsd.conf.in b/conf/cupsd.conf.in
-index ab37ca6..78189e5 100644
---- a/conf/cupsd.conf.in
-+++ b/conf/cupsd.conf.in
-@@ -8,6 +8,10 @@
- LogLevel @CUPS_LOG_LEVEL@
- @CUPS_PAGE_LOG_FORMAT@
- 
-+# Deactivate CUPS' internal logrotating, as we provide a better one, especially
-+# LogLevel debug2 gets usable now
-+MaxLogSize 0
-+
- # Only listen for connections from the local machine.
- Listen localhost:@DEFAULT_IPP_PORT@
- @CUPS_LISTEN_DOMAINSOCKET@
diff -pruN 2.3.3-3/debian/patches/0030-Do-not-mess-with-the-permissions-of-cupsd.conf.patch 2.3.3op1-3/debian/patches/0030-Do-not-mess-with-the-permissions-of-cupsd.conf.patch
--- 2.3.3-3/debian/patches/0030-Do-not-mess-with-the-permissions-of-cupsd.conf.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0030-Do-not-mess-with-the-permissions-of-cupsd.conf.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,26 +0,0 @@
-From: Martin Pitt <mpitt@debian.org>
-Date: Tue, 9 Aug 2016 18:11:41 +0200
-Subject: Do not mess with the permissions of cupsd.conf.
-
-Patch-Name: confdirperms.patch
----
- scheduler/conf.c | 2 ++
- 1 file changed, 2 insertions(+)
-
-diff --git a/scheduler/conf.c b/scheduler/conf.c
-index b73d33f..31eedbf 100644
---- a/scheduler/conf.c
-+++ b/scheduler/conf.c
-@@ -1135,10 +1135,12 @@ cupsdReadConfiguration(void)
- 			     Group, 1, 1) < 0 ||
-        cupsdCheckPermissions(ServerRoot, "ssl", 0700, RunUser,
- 			     Group, 1, 0) < 0 ||
-+       /* Never alter permissions of central conffile
-        cupsdCheckPermissions(ConfigurationFile, NULL, ConfigFilePerm, RunUser,
- 			     Group, 0, 0) < 0 ||
-        cupsdCheckPermissions(CupsFilesFile, NULL, ConfigFilePerm, RunUser,
- 			     Group, 0, 0) < 0 ||
-+       */
-        cupsdCheckPermissions(ServerRoot, "classes.conf", 0600, RunUser,
- 			     Group, 0, 0) < 0 ||
-        cupsdCheckPermissions(ServerRoot, "printers.conf", 0600, RunUser,
diff -pruN 2.3.3-3/debian/patches/0031-Show-compile-command-lines.patch 2.3.3op1-3/debian/patches/0031-Show-compile-command-lines.patch
--- 2.3.3-3/debian/patches/0031-Show-compile-command-lines.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0031-Show-compile-command-lines.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-From: Till Kampetter <till.kampetter@gmail.com>
-Date: Tue, 9 Aug 2016 18:11:43 +0200
-Subject: Show compile command lines
-
-Patch-Name: show-compile-command-lines.patch
----
- Makedefs.in | 3 +--
- 1 file changed, 1 insertion(+), 2 deletions(-)
-
-diff --git a/Makedefs.in b/Makedefs.in
-index 9ee7585..511fbf8 100644
---- a/Makedefs.in
-+++ b/Makedefs.in
-@@ -263,8 +263,7 @@ USBQUIRKS	=	@USBQUIRKS@
- # Rules...
- #
- 
--.SILENT:
--.SUFFIXES:	.a .c .cxx .h .o
-+.SUFFIXES:	.1 .1.gz .1m .1m.gz .3 .3.gz .5 .5.gz .7 .7.gz .8 .8.gz .a .c .cxx .h .man .o .gz
- 
- .c.o:
- 	echo Compiling $<...
diff -pruN 2.3.3-3/debian/patches/0032-Set-the-default-for-SyncOnClose-to-Yes.patch 2.3.3op1-3/debian/patches/0032-Set-the-default-for-SyncOnClose-to-Yes.patch
--- 2.3.3-3/debian/patches/0032-Set-the-default-for-SyncOnClose-to-Yes.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0032-Set-the-default-for-SyncOnClose-to-Yes.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,64 +0,0 @@
-From: Tim Waugh <twaugh@redhat.com>
-Date: Tue, 9 Aug 2016 18:11:46 +0200
-Subject: Set the default for SyncOnClose to Yes
-
-Patch-Name: cupsd-set-default-for-SyncOnClose-to-Yes.patch
----
- conf/cups-files.conf.in           | 2 +-
- doc/help/man-cups-files.conf.html | 2 +-
- man/cups-files.conf.5             | 2 +-
- scheduler/conf.c                  | 2 +-
- 4 files changed, 4 insertions(+), 4 deletions(-)
-
-diff --git a/conf/cups-files.conf.in b/conf/cups-files.conf.in
-index 4a78ba6..a3d088d 100644
---- a/conf/cups-files.conf.in
-+++ b/conf/cups-files.conf.in
-@@ -7,7 +7,7 @@
- #FatalErrors @CUPS_FATAL_ERRORS@
- 
- # Do we call fsync() after writing configuration or status files?
--#SyncOnClose No
-+#SyncOnClose Yes
- 
- # Default user and group for filters/backends/helper programs; this cannot be
- # any user or group that resolves to ID 0 for security reasons...
-diff --git a/doc/help/man-cups-files.conf.html b/doc/help/man-cups-files.conf.html
-index c567cbb..f2f6802 100644
---- a/doc/help/man-cups-files.conf.html
-+++ b/doc/help/man-cups-files.conf.html
-@@ -150,7 +150,7 @@ The default is "/var/run/cups" or "/etc/cups" depending on the platform.
- <dd style="margin-left: 5.0em">Specifies whether the scheduler calls
- <b>fsync</b>(2)
- after writing configuration or state files.
--The default is "No".
-+The default is "Yes".
- <dt><a name="SystemGroup"></a><b>SystemGroup </b><i>group-name </i>[ ... <i>group-name</i> ]
- <dd style="margin-left: 5.0em">Specifies the group(s) to use for <i>@SYSTEM</i> group authentication.
- The default contains "admin", "lpadmin", "root", "sys", and/or "system".
-diff --git a/man/cups-files.conf.5 b/man/cups-files.conf.5
-index 7249406..955f47b 100644
---- a/man/cups-files.conf.5
-+++ b/man/cups-files.conf.5
-@@ -211,7 +211,7 @@ The default is "/var/run/cups" or "/etc/cups" depending on the platform.
- Specifies whether the scheduler calls
- .BR fsync (2)
- after writing configuration or state files.
--The default is "No".
-+The default is "Yes".
- .\"#SystemGroup
- .TP 5
- \fBSystemGroup \fIgroup-name \fR[ ... \fIgroup-name\fR ]
-diff --git a/scheduler/conf.c b/scheduler/conf.c
-index 31eedbf..f2924f8 100644
---- a/scheduler/conf.c
-+++ b/scheduler/conf.c
-@@ -735,7 +735,7 @@ cupsdReadConfiguration(void)
-   RootCertDuration         = 300;
-   Sandboxing               = CUPSD_SANDBOXING_STRICT;
-   StrictConformance        = FALSE;
--  SyncOnClose              = FALSE;
-+  SyncOnClose              = TRUE;
-   Timeout                  = 900;
-   WebInterface             = CUPS_DEFAULT_WEBIF;
- 
diff -pruN 2.3.3-3/debian/patches/0033-Set-default-job-error-policy-to-retry-job.patch 2.3.3op1-3/debian/patches/0033-Set-default-job-error-policy-to-retry-job.patch
--- 2.3.3-3/debian/patches/0033-Set-default-job-error-policy-to-retry-job.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0033-Set-default-job-error-policy-to-retry-job.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,73 +0,0 @@
-From: Martin Pitt <martin.pitt@ubuntu.com>
-Date: Tue, 9 Aug 2016 18:11:47 +0200
-Subject: Set default job error policy to "retry-job"
-
-It it is less confusing and a better default on most machines.
-Amend documentation accordingly.
-
-Author: Didier Raboud <odyx@debian.org>
-Origin: vendor
-Patch-Name: cups-set-default-error-policy-retry-job.patch
----
- doc/help/man-cupsd.conf.html | 4 ++--
- man/cupsd.conf.5             | 4 ++--
- scheduler/conf.c             | 6 +++---
- 3 files changed, 7 insertions(+), 7 deletions(-)
-
-diff --git a/doc/help/man-cupsd.conf.html b/doc/help/man-cupsd.conf.html
-index 1668eee..7d161ed 100644
---- a/doc/help/man-cupsd.conf.html
-+++ b/doc/help/man-cupsd.conf.html
-@@ -95,9 +95,9 @@ The default is typically the server's ".local" hostname.
- <dt><b>ErrorPolicy retry-current-job</b>
- <dd style="margin-left: 5.0em">Specifies that a failed print job should be retried immediately unless otherwise specified for the printer.
- <dt><b>ErrorPolicy retry-job</b>
--<dd style="margin-left: 5.0em">Specifies that a failed print job should be retried at a later time unless otherwise specified for the printer.
-+<dd style="margin-left: 5.0em">Specifies that a failed print job should be retried at a later time unless otherwise specified for the printer. The 'retry-job' error policy is the default.
- <dt><b>ErrorPolicy stop-printer</b>
--<dd style="margin-left: 5.0em">Specifies that a failed print job should stop the printer unless otherwise specified for the printer. The 'stop-printer' error policy is the default.
-+<dd style="margin-left: 5.0em">Specifies that a failed print job should stop the printer unless otherwise specified for the printer.
- <dt><a name="FilterLimit"></a><b>FilterLimit </b><i>limit</i>
- <dd style="margin-left: 5.0em">Specifies the maximum cost of filters that are run concurrently, which can be used to minimize disk, memory, and CPU resource problems.
- A limit of 0 disables filter limiting.
-diff --git a/man/cupsd.conf.5 b/man/cupsd.conf.5
-index 49fdb06..6d3d8e3 100644
---- a/man/cupsd.conf.5
-+++ b/man/cupsd.conf.5
-@@ -140,10 +140,10 @@ Specifies that a failed print job should be aborted (discarded) unless otherwise
- Specifies that a failed print job should be retried immediately unless otherwise specified for the printer.
- .TP 5
- \fBErrorPolicy retry-job\fR
--Specifies that a failed print job should be retried at a later time unless otherwise specified for the printer.
-+Specifies that a failed print job should be retried at a later time unless otherwise specified for the printer. The 'retry-job' error policy is the default.
- .TP 5
- \fBErrorPolicy stop-printer\fR
--Specifies that a failed print job should stop the printer unless otherwise specified for the printer. The 'stop-printer' error policy is the default.
-+Specifies that a failed print job should stop the printer unless otherwise specified for the printer.
- .\"#FilterLimit
- .TP 5
- \fBFilterLimit \fIlimit\fR
-diff --git a/scheduler/conf.c b/scheduler/conf.c
-index f2924f8..944655e 100644
---- a/scheduler/conf.c
-+++ b/scheduler/conf.c
-@@ -752,7 +752,7 @@ cupsdReadConfiguration(void)
-   cupsdSetString(&LPDConfigFile, CUPS_DEFAULT_LPD_CONFIG_FILE);
-   cupsdSetString(&SMBConfigFile, CUPS_DEFAULT_SMB_CONFIG_FILE);
- 
--  cupsdSetString(&ErrorPolicy, "stop-printer");
-+  cupsdSetString(&ErrorPolicy, "retry-job");
- 
-   JobHistory          = DEFAULT_HISTORY;
-   JobFiles            = DEFAULT_FILES;
-@@ -1233,8 +1233,8 @@ cupsdReadConfiguration(void)
-       strcmp(ErrorPolicy, "retry-job") &&
-       strcmp(ErrorPolicy, "stop-printer"))
-   {
--    cupsdLogMessage(CUPSD_LOG_ALERT, "Invalid ErrorPolicy \"%s\", resetting to \"stop-printer\".", ErrorPolicy);
--    cupsdSetString(&ErrorPolicy, "stop-printer");
-+    cupsdLogMessage(CUPSD_LOG_ALERT, "Invalid ErrorPolicy \"%s\", resetting to \"retry-job\".", ErrorPolicy);
-+    cupsdSetString(&ErrorPolicy, "retry-job");
-   }
- 
-  /*
diff -pruN 2.3.3-3/debian/patches/0034-Drop-dangling-references-from-cups-lpd.man.patch 2.3.3op1-3/debian/patches/0034-Drop-dangling-references-from-cups-lpd.man.patch
--- 2.3.3-3/debian/patches/0034-Drop-dangling-references-from-cups-lpd.man.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0034-Drop-dangling-references-from-cups-lpd.man.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,24 +0,0 @@
-From: =?utf-8?q?Bastien_ROUCARI=C3=88S?= <bastien.roucaries@u-cergy.fr>
-Date: Tue, 9 Aug 2016 18:11:48 +0200
-Subject: Drop dangling references from cups-lpd.man
-
-Bug-Debian: https://bugs.debian.org/570157
-Patch-Name: man-cups-lpd-drop-dangling-references.patch
----
- man/cups-lpd.8 | 2 --
- 1 file changed, 2 deletions(-)
-
-diff --git a/man/cups-lpd.8 b/man/cups-lpd.8
-index 344d2af..e998df3 100644
---- a/man/cups-lpd.8
-+++ b/man/cups-lpd.8
-@@ -109,9 +109,7 @@ Simply enable the
- .B cups-lpd
- service using the corresponding control program.
- .SH SEE ALSO
--.BR cups (1),
- .BR cupsd (8),
--.BR inetconv (1m),
- .BR inetd (8),
- .BR launchd (8),
- .BR xinetd (8),
diff -pruN 2.3.3-3/debian/patches/0035-Use-dpkg-architecture-in-cups-config-to-make-it-arch.patch 2.3.3op1-3/debian/patches/0035-Use-dpkg-architecture-in-cups-config-to-make-it-arch.patch
--- 2.3.3-3/debian/patches/0035-Use-dpkg-architecture-in-cups-config-to-make-it-arch.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0035-Use-dpkg-architecture-in-cups-config-to-make-it-arch.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,49 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Tue, 9 Aug 2016 18:11:49 +0200
-Subject: Use dpkg-architecture in cups-config to make it
- architecture-independant
-
- Also filter -L/usr/lib/(triplet) out of LDFLAGS.
- Also strip unnecessary libs from --libs.
- Also launch krb5-config at runtime to avoid getting usr/lib/(triplet) from krb5-config
-Bug-Debian: https://bugs.debian.org/741519
-Bug-Debian: https://bugs.debian.org/727058
-Bug-Debian: https://bugs.debian.org/730838
-Bug-Debian: https://bugs.debian.org/751157
-Patch-Name: debianize_cups-config.patch
----
- cups-config.in | 7 ++++---
- 1 file changed, 4 insertions(+), 3 deletions(-)
-
-diff --git a/cups-config.in b/cups-config.in
-index 9dd094d..b073a07 100755
---- a/cups-config.in
-+++ b/cups-config.in
-@@ -17,7 +17,7 @@ prefix=@prefix@
- exec_prefix=@exec_prefix@
- bindir=@bindir@
- includedir=@includedir@
--libdir=@libdir@
-+libdir=${prefix}/lib/$(dpkg-architecture -qDEB_HOST_MULTIARCH)
- datarootdir=@datadir@
- datadir=@datadir@
- sysconfdir=@sysconfdir@
-@@ -29,7 +29,8 @@ INSTALLSTATIC=@INSTALLSTATIC@
- # flags for compiler and linker...
- CFLAGS=""
- LDFLAGS="@EXPORT_LDFLAGS@"
--LIBS="@LIBGSSAPI@ @DNSSDLIBS@ @EXPORT_SSLLIBS@ @LIBZ@ @LIBS@"
-+LIBGSSAPI=`[ ! -x /usr/bin/krb5-config ] || /usr/bin/krb5-config --libs`
-+LIBS="$LIBGSSAPI @DNSSDLIBS@ @EXPORT_SSLLIBS@ @LIBZ@ @LIBS@"
- 
- # Check for local invocation...
- selfdir=`dirname $0`
-@@ -43,7 +44,7 @@ else
- 	CFLAGS="$CFLAGS -I$includedir"
-     fi
- 
--    if test $libdir != /usr/lib -a $libdir != /usr/lib32 -a $libdir != /usr/lib64; then
-+    if test $libdir != /usr/lib -a $libdir != /usr/lib32 -a $libdir != /usr/lib64 -a $libdir != /usr/lib/$(dpkg-architecture -qDEB_HOST_MULTIARCH); then
- 	LDFLAGS="$LDFLAGS -L$libdir"
-     fi
- fi
diff -pruN 2.3.3-3/debian/patches/0036-Build-mantohtml-with-the-build-architecture-compiler.patch 2.3.3op1-3/debian/patches/0036-Build-mantohtml-with-the-build-architecture-compiler.patch
--- 2.3.3-3/debian/patches/0036-Build-mantohtml-with-the-build-architecture-compiler.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0036-Build-mantohtml-with-the-build-architecture-compiler.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,110 +0,0 @@
-From: Helmut Grohne <helmut@subdivi.de>
-Date: Tue, 9 Aug 2016 18:11:49 +0200
-Subject: Build mantohtml with the build architecture compiler
-
-mantohtml is run during build. Thus it needs to be built with the build
-architecture compiler (or execution fails). The obvious part is switching to
-CC_FOR_BUILD. That also depends on it not requiring any other cups components.
-In particular, removing uses of strlcpy and replacing host architecture-
-specific includes is thus needed.
-Bug-Debian: https://bugs.debian.org/837936
-Patch-Name Build-mantohtml-with-the-build-architecture-compiler.patch
----
- Makedefs.in     |  1 +
- configure.ac    |  9 +++++++++
- man/Makefile    |  5 ++---
- man/mantohtml.c | 15 ++++++++++-----
- 4 files changed, 22 insertions(+), 8 deletions(-)
-
-diff --git a/Makedefs.in b/Makedefs.in
-index 511fbf8..fbd16fb 100644
---- a/Makedefs.in
-+++ b/Makedefs.in
-@@ -22,6 +22,7 @@ CUPS_VERSION    =       @CUPS_VERSION@
- AR		=	@AR@
- AWK		=	@AWK@
- CC		=	@LIBTOOL_CC@ @CC@
-+CC_FOR_BUILD	=	@CC_FOR_BUILD@
- CHMOD		=	@CHMOD@
- CXX		=	@LIBTOOL_CXX@ @CXX@
- DSO		=	@DSO@
-diff --git a/configure.ac b/configure.ac
-index dbf3bda..535b0b9 100644
---- a/configure.ac
-+++ b/configure.ac
-@@ -19,6 +19,15 @@ sinclude(config-scripts/cups-common.m4)
- sinclude(config-scripts/cups-directories.m4)
- sinclude(config-scripts/cups-manpages.m4)
- 
-+AC_MSG_CHECKING([for build system compiler])
-+if test "$cross_compiling" = yes; then
-+	CC_FOR_BUILD=${CC_FOR_BUILD-cc}
-+else
-+	CC_FOR_BUILD=${CC}
-+fi
-+AC_MSG_RESULT(${CC_FOR_BUILD})
-+AC_SUBST(CC_FOR_BUILD)
-+
- sinclude(config-scripts/cups-sharedlibs.m4)
- sinclude(config-scripts/cups-libtool.m4)
- sinclude(config-scripts/cups-compiler.m4)
-diff --git a/man/Makefile b/man/Makefile
-index 621fe60..e01591a 100644
---- a/man/Makefile
-+++ b/man/Makefile
-@@ -222,6 +222,5 @@ html:	$(MAN1) $(MAN5) $(MAN7) $(MAN8) mantohtml
- 		./mantohtml $$file >../doc/help/man-`basename $$file .8`.html; \
- 	done
- 
--mantohtml:	mantohtml.o ../cups/$(LIBCUPSSTATIC)
--	$(LD_CC) $(ARCHFLAGS) $(ALL_LDFLAGS) -o $@ mantohtml.o $(LINKCUPSSTATIC)
--	$(CODE_SIGN) -s "$(CODE_SIGN_IDENTITY)" $@
-+mantohtml:	mantohtml.c
-+	$(CC_FOR_BUILD) -o $@ $<
-diff --git a/man/mantohtml.c b/man/mantohtml.c
-index 2a9353a..6223f17 100644
---- a/man/mantohtml.c
-+++ b/man/mantohtml.c
-@@ -11,8 +11,10 @@
-  * Include necessary headers.
-  */
- 
--#include <cups/string-private.h>
--#include <cups/array-private.h>
-+#include <ctype.h>
-+#include <stdio.h>
-+#include <stdlib.h>
-+#include <string.h>
- #include <unistd.h>
- 
- 
-@@ -811,7 +813,8 @@ main(int  argc,				/* I - Number of command-line args */
-         * Anchor for HTML output...
-         */
- 
--        strlcpy(anchor, line + 4, sizeof(anchor));
-+        strncpy(anchor, line + 4, sizeof(anchor) - 1);
-+        anchor[sizeof(anchor) - 1] = '\0';
-       }
-       else if (strncmp(line, ".\\\"", 3))
-       {
-@@ -940,7 +943,8 @@ html_alternate(const char *s,		/* I - String */
- 		manfile[1024],		/* Man page filename */
- 		manurl[1024];		/* Man page URL */
- 
--        strlcpy(name, s, sizeof(name));
-+        strncpy(name, s, sizeof(name) - 1);
-+        name[sizeof(name) - 1] = '\0';
-         if ((size_t)(end - s) < sizeof(name))
-           name[end - s] = '\0';
- 
-@@ -1173,7 +1177,8 @@ html_fputs(const char *s,		/* I  - String */
-       if (end[-1] == ',' || end[-1] == '.' || end[-1] == ')')
-         end --;
- 
--      strlcpy(temp, s, sizeof(temp));
-+      strncpy(temp, s, sizeof(temp) - 1);
-+      temp[sizeof(temp) - 1] = '\0';
-       if ((size_t)(end -s) < sizeof(temp))
-         temp[end - s] = '\0';
- 
diff -pruN 2.3.3-3/debian/patches/0037-po4a-infrastructure-and-translations-for-manpages.patch 2.3.3op1-3/debian/patches/0037-po4a-infrastructure-and-translations-for-manpages.patch
--- 2.3.3-3/debian/patches/0037-po4a-infrastructure-and-translations-for-manpages.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0037-po4a-infrastructure-and-translations-for-manpages.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,342 +0,0 @@
-From: Didier Raboud <odyx@debian.org>
-Date: Tue, 9 Aug 2016 18:11:50 +0200
-Subject: po4a infrastructure and translations for manpages
-MIME-Version: 1.0
-Content-Type: text/plain; charset="utf-8"
-Content-Transfer-Encoding: 8bit
-
-Author: Nicolas François <nicolas.francois@centraliens.net>, Helge Kreutzmann <debian@helgefjell.de>
-Origin: vendor
-Bug-Debian: https://bugs.debian.org/478597
-Patch-Name: manpage-translations.patch
----
- man/Makefile      |  17 +++-
- man/Makefile.l10n | 235 ++++++++++++++++++++++++++++++++++++++++++++++++++++++
- man/de/Makefile   |   7 ++
- man/fr/Makefile   |   7 ++
- 4 files changed, 264 insertions(+), 2 deletions(-)
- create mode 100644 man/Makefile.l10n
- create mode 100644 man/de/Makefile
- create mode 100644 man/fr/Makefile
-
-diff --git a/man/Makefile b/man/Makefile
-index e01591a..48f06c4 100644
---- a/man/Makefile
-+++ b/man/Makefile
-@@ -63,12 +63,18 @@ MAN8	=	cupsaccept.8 \
- 		lpmove.8 \
- 		lpc.8
- 
-+LANGUAGES=de fr
- 
- #
- # Make everything...
- #
- 
--all:	$(MAN1) $(MAN5) $(MAN7) $(MAN8)
-+all:	$(MAN1) $(MAN5) $(MAN7) $(MAN8) translations
-+
-+translations:
-+	# Update the translations and build the translated material
-+	po4a --previous ../debian/manpage-po4a/cups.cfg
-+	for lang in $(LANGUAGES); do $(MAKE) -C $$lang; done
- 
- 
- #
-@@ -91,6 +97,12 @@ unittests:
- 
- clean:
- 	$(RM) mantohtml mantohtml.o
-+	$(RM) $(MAN1) $(MAN5) $(MAN7) $(MAN8)
-+	for lang in $(LANGUAGES); do $(MAKE) -C $$lang clean; done
-+	# Make sure the PO files are updated and remove generated
-+	# translations.
-+	po4a --previous --rm-translations ../debian/manpage-po4a/cups.cfg
-+	$(RM) ../debian/manpage-po4a/po/cups.pot
- 
- 
- #
-@@ -142,6 +154,7 @@ install-data: all
- 		$(RM) $(MANDIR)/man8/$$file; \
- 		$(LN) cupsd-helper.8 $(MANDIR)/man8/$$file; \
- 	done
-+	for lang in $(LANGUAGES); do $(MAKE) -C $$lang install; done
- 
- 
- #
-@@ -189,7 +202,7 @@ uninstall:
- 	for file in $(MAN8) cupsenable.8 cupsreject.8 cups-deviced.8 cups-driverd.8 cups-exec.8; do \
- 		$(RM) $(MANDIR)/man8/$$file; \
- 	done
--	-$(RMDIR) $(MANDIR)/man8
-+	-$(RMDIR) $(AMANDIR)/man$(MAN8DIR)
- 
- 
- #
-diff --git a/man/Makefile.l10n b/man/Makefile.l10n
-new file mode 100644
-index 0000000..08390f5
---- /dev/null
-+++ b/man/Makefile.l10n
-@@ -0,0 +1,235 @@
-+#
-+# Man page makefile for CUPS.
-+#
-+# Copyright © 2007-2019 by Apple Inc.
-+# Copyright © 1993-2006 by Easy Software Products.
-+#
-+# Licensed under Apache License v2.0.  See the file "LICENSE" for more
-+# information.
-+#
-+
-+include ../../Makedefs
-+
-+
-+#
-+# Man pages...
-+#
-+
-+MAN1	=	cancel.1 \
-+		cups.1 \
-+		cups-config.1 \
-+		cupstestppd.1 \
-+		ippeveprinter.1 \
-+		$(IPPFIND_MAN) \
-+		ipptool.1 \
-+		lp.1 \
-+		lpoptions.1 \
-+		lpq.1 \
-+		lprm.1 \
-+		lpr.1 \
-+		lpstat.1 \
-+		ppdc.1 \
-+		ppdhtml.1 \
-+		ppdi.1 \
-+		ppdmerge.1 \
-+		ppdpo.1
-+MAN5	=	classes.conf.5 \
-+		client.conf.5 \
-+		cups-files.conf.5 \
-+		cups-snmp.conf.5 \
-+		cupsd.conf.5 \
-+		cupsd-logs.5 \
-+		ipptoolfile.5 \
-+		mailto.conf.5 \
-+		mime.convs.5 \
-+		mime.types.5 \
-+		ppdcfile.5 \
-+		printers.conf.5 \
-+		subscriptions.conf.5
-+MAN7	=	backend.7 \
-+		filter.7 \
-+		ippevepcl.7 \
-+		notifier.7
-+MAN8	=	cupsaccept.8 \
-+		cupsctl.8 \
-+		cupsfilter.8 \
-+		cups-lpd.8 \
-+		cups-snmp.8 \
-+		cupsd.8 \
-+		cupsd-helper.8 \
-+		cupsenable.8 \
-+		lpadmin.8 \
-+		lpinfo.8 \
-+		lpmove.8 \
-+		lpc.8
-+
-+
-+#
-+# Make everything...
-+#
-+
-+# Debian-specific patch: Just assume all files are here.
-+all:
-+
-+
-+#
-+# Make library targets...
-+#
-+
-+libs:
-+
-+
-+#
-+# Make unit tests...
-+#
-+
-+unittests:
-+
-+
-+#
-+# Clean all config and object files...
-+#
-+
-+clean:
-+	$(RM) mantohtml mantohtml.o
-+
-+
-+#
-+# Dummy depend target...
-+#
-+
-+depend:
-+
-+
-+#
-+# Install all targets...
-+#
-+
-+# Debian-specific patch: directory-based language namespace
-+MANDIR := $(MANDIR)/$(LANGUAGE)
-+
-+install:	all install-data install-headers install-libs install-exec
-+
-+
-+#
-+# Install data files...
-+#
-+
-+# Debian-specific patch: skip if doesn't exist
-+install-data: all
-+	echo Installing man pages in $(MANDIR)/man1...
-+	$(INSTALL_DIR) -m 755 $(MANDIR)/man1
-+	for file in $(MAN1); do \
-+		[ ! -r $$file ] || \
-+		$(INSTALL_MAN) $$file $(MANDIR)/man1; \
-+	done
-+	echo Installing man pages in $(MANDIR)/man5...
-+	$(INSTALL_DIR) -m 755 $(MANDIR)/man5
-+	for file in $(MAN5); do \
-+		[ ! -r $$file ] || \
-+		$(INSTALL_MAN) $$file $(MANDIR)/man5; \
-+	done
-+	echo Installing man pages in $(MANDIR)/man7...
-+	$(INSTALL_DIR) -m 755 $(MANDIR)/man7
-+	for file in $(MAN7); do \
-+		[ ! -r $$file ] || \
-+		$(INSTALL_MAN) $$file $(MANDIR)/man7; \
-+	done
-+	$(RM) $(MANDIR)/man7/ippeveps.7
-+	$(LN) ippevepcl.7 $(MANDIR)/man7/ippeveps.7
-+	echo Installing man pages in $(MANDIR)/man8...
-+	$(INSTALL_DIR) -m 755 $(MANDIR)/man8
-+	for file in $(MAN8); do \
-+		[ ! -r $$file ] || \
-+		$(INSTALL_MAN) $$file $(MANDIR)/man8; \
-+	done
-+	$(RM) $(MANDIR)/man8/cupsdisable.8
-+	$(LN) cupsenable.8 $(MANDIR)/man8/cupsdisable.8
-+	$(RM) $(MANDIR)/man8/cupsreject.8
-+	$(LN) cupsaccept.8 $(MANDIR)/man8/cupsreject.8
-+	for file in cups-deviced.8 cups-driverd.8 cups-exec.8; do \
-+		$(RM) $(MANDIR)/man8/$$file; \
-+		$(LN) cupsd-helper.8 $(MANDIR)/man8/$$file; \
-+	done
-+
-+
-+#
-+# Install programs...
-+#
-+
-+install-exec:
-+
-+
-+#
-+# Install headers...
-+#
-+
-+install-headers:
-+
-+
-+#
-+# Install libraries...
-+#
-+
-+install-libs:
-+
-+
-+#
-+# Uninstall files...
-+#
-+
-+uninstall:
-+	echo Uninstalling man pages from $(MANDIR)/man1...
-+	for file in $(MAN1); do \
-+		$(RM) $(MANDIR)/man1/$$file; \
-+	done
-+	-$(RMDIR) $(MANDIR)/man1
-+	echo Uninstalling man pages from $(MANDIR)/man5...
-+	for file in $(MAN5); do \
-+		$(RM) $(MANDIR)/man5/$$file; \
-+	done
-+	-$(RMDIR) $(MANDIR)/man5
-+	echo Uninstalling man pages from $(MANDIR)/man7...
-+	for file in $(MAN7) ippeveps.7; do \
-+		$(RM) $(MANDIR)/man7/$$file; \
-+	done
-+	-$(RMDIR) $(MANDIR)/man7
-+	echo Uninstalling man pages from $(MANDIR)/man8...
-+	for file in $(MAN8) cupsenable.8 cupsreject.8 cups-deviced.8 cups-driverd.8 cups-exec.8; do \
-+		$(RM) $(MANDIR)/man8/$$file; \
-+	done
-+	-$(RMDIR) $(MANDIR)/man8
-+
-+
-+#
-+# Local programs (not built when cross-compiling...)
-+#
-+
-+local:	html
-+
-+
-+#
-+# Make html versions of man pages...
-+#
-+
-+html:	$(MAN1) $(MAN5) $(MAN7) $(MAN8) mantohtml
-+	echo Converting man pages to HTML...
-+	for file in $(MAN1); do \
-+		echo "    $$file..."; \
-+		./mantohtml $$file >../doc/help/man-`basename $$file .1`.html; \
-+	done
-+	for file in $(MAN5); do \
-+		echo "    $$file..."; \
-+		./mantohtml $$file >../doc/help/man-`basename $$file .5`.html; \
-+	done
-+	for file in $(MAN7); do \
-+		echo "    $$file..."; \
-+		./mantohtml $$file >../doc/help/man-`basename $$file .7`.html; \
-+	done
-+	for file in $(MAN8); do \
-+		echo "    $$file..."; \
-+		./mantohtml $$file >../doc/help/man-`basename $$file .8`.html; \
-+	done
-+
-+mantohtml:	mantohtml.c
-+	$(CC_FOR_BUILD) -o $@ $<
-diff --git a/man/de/Makefile b/man/de/Makefile
-new file mode 100644
-index 0000000..7c23784
---- /dev/null
-+++ b/man/de/Makefile
-@@ -0,0 +1,7 @@
-+#
-+#   Man page makefile for the Common UNIX Printing System (CUPS).
-+#
-+
-+LANGUAGE=de
-+
-+include ../Makefile.l10n
-diff --git a/man/fr/Makefile b/man/fr/Makefile
-new file mode 100644
-index 0000000..6a50e93
---- /dev/null
-+++ b/man/fr/Makefile
-@@ -0,0 +1,7 @@
-+#
-+#   Man page makefile for the Common UNIX Printing System (CUPS).
-+#
-+
-+LANGUAGE=fr
-+
-+include ../Makefile.l10n
diff -pruN 2.3.3-3/debian/patches/0038-Resolve-DNS-SD-service-name-based-URIs-correctly-als.patch 2.3.3op1-3/debian/patches/0038-Resolve-DNS-SD-service-name-based-URIs-correctly-als.patch
--- 2.3.3-3/debian/patches/0038-Resolve-DNS-SD-service-name-based-URIs-correctly-als.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0038-Resolve-DNS-SD-service-name-based-URIs-correctly-als.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,71 +0,0 @@
-From: Till Kamppeter <till.kamppeter@gmail.com>
-Date: Tue, 25 Aug 2020 21:34:00 +0200
-Subject: Resolve DNS-SD-service-name-based URIs correctly also if they are
- from a service from localhost (like IPP-over-USB, Printer Application, ...)
-
----
- cups/http-support.c | 33 +++++++++++++++++++++++++++++----
- 1 file changed, 29 insertions(+), 4 deletions(-)
-
-diff --git a/cups/http-support.c b/cups/http-support.c
-index 6317514..8eabaee 100644
---- a/cups/http-support.c
-+++ b/cups/http-support.c
-@@ -2483,7 +2483,7 @@ http_poll_cb(
- static void
- http_resolve_cb(
-     AvahiServiceResolver   *resolver,	/* I - Resolver (unused) */
--    AvahiIfIndex           interface,	/* I - Interface index (unused) */
-+    AvahiIfIndex           interface,	/* I - Interface index */
-     AvahiProtocol          protocol,	/* I - Network protocol (unused) */
-     AvahiResolverEvent     event,	/* I - Event (found, etc.) */
-     const char             *name,	/* I - Service name */
-@@ -2504,6 +2504,7 @@ http_resolve_cb(
- 			*resdefault;	/* Default path */
-   char			resource[257],	/* Remote path */
- 			fqdn[256];	/* FQDN of the .local name */
-+  char			ifname[IF_NAMESIZE]; /* Interface name */
-   AvahiStringList	*pair;		/* Current TXT record key/value pair */
-   char			*value;		/* Value for "rp" key */
-   size_t		valueLen = 0;	/* Length of "rp" key */
-@@ -2630,13 +2631,37 @@ http_resolve_cb(
-     strlcpy(resource, resdefault, sizeof(resource));
-   }
- 
-+ /*
-+  * Check whether the interface is the loopback interface ("lo"), in this
-+  * case set "localhost" as the host name
-+  */
-+
-+  if (!if_indextoname((unsigned int)interface, ifname))
-+  {
-+    if (uribuf->options & _HTTP_RESOLVE_STDERR)
-+      fprintf(stderr,
-+	      "DEBUG: Unable to find interface name for interface %d: %s\n",
-+	      interface, strerror(errno));
-+    DEBUG_printf(("Unable to find interface name for interface %d: %s\n",
-+		  interface, strerror(errno)));
-+    ifname[0] = '\0';
-+  }
-+
-+  if (!strcmp(ifname, "lo")) {
-+    if (uribuf->options & _HTTP_RESOLVE_STDERR)
-+      fputs("DEBUG: Service comes from loopback interface \"lo\", setting \"localhost\" as host name.\n",
-+	    stderr);
-+    DEBUG_puts("Service comes from loopback interface \"lo\", setting \"localhost\" as host name.");
-+    hostTarget = "localhost";
-+  }
-+
-  /*
-   * Lookup the FQDN if needed...
-   */
- 
--  if ((uribuf->options & _HTTP_RESOLVE_FQDN) &&
--      (hostptr = hostTarget + strlen(hostTarget) - 6) > hostTarget &&
--      !_cups_strcasecmp(hostptr, ".local"))
-+  else if ((uribuf->options & _HTTP_RESOLVE_FQDN) &&
-+	   (hostptr = hostTarget + strlen(hostTarget) - 6) > hostTarget &&
-+	   !_cups_strcasecmp(hostptr, ".local"))
-   {
-    /*
-     * OK, we got a .local name but the caller needs a real domain.  Start by
diff -pruN 2.3.3-3/debian/patches/0039-Make-lpoptions-list-a-printer-s-options-correctly-al.patch 2.3.3op1-3/debian/patches/0039-Make-lpoptions-list-a-printer-s-options-correctly-al.patch
--- 2.3.3-3/debian/patches/0039-Make-lpoptions-list-a-printer-s-options-correctly-al.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0039-Make-lpoptions-list-a-printer-s-options-correctly-al.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,29 +0,0 @@
-From: Till Kamppeter <till.kamppeter@gmail.com>
-Date: Tue, 25 Aug 2020 21:34:00 +0200
-Subject: Make lpoptions list a printer's options correctly also when CUPS is
- running on an alternative port
-
----
- systemv/lpoptions.c | 3 +--
- 1 file changed, 1 insertion(+), 2 deletions(-)
-
-diff --git a/systemv/lpoptions.c b/systemv/lpoptions.c
-index 08746c0..c55f281 100644
---- a/systemv/lpoptions.c
-+++ b/systemv/lpoptions.c
-@@ -480,14 +480,13 @@ static void
- list_options(cups_dest_t *dest)		/* I - Destination to list */
- {
-   http_t	*http;			/* Connection to destination */
--  char		resource[1024];		/* Resource path */
-   int		i;			/* Looping var */
-   const char	*filename;		/* PPD filename */
-   ppd_file_t	*ppd;			/* PPD data */
-   ppd_group_t	*group;			/* Current group */
- 
- 
--  if ((http = cupsConnectDest(dest, CUPS_DEST_FLAGS_NONE, 30000, NULL, resource, sizeof(resource), NULL, NULL)) == NULL)
-+  if ((http = _cupsConnect()) == NULL)
-   {
-     _cupsLangPrintf(stderr, _("lpoptions: Unable to get PPD file for %s: %s"),
- 		    dest->name, cupsLastErrorString());
diff -pruN 2.3.3-3/debian/patches/0040-Fix-fax-numbers-supplied-via-GTK-print-dialog-removi.patch 2.3.3op1-3/debian/patches/0040-Fix-fax-numbers-supplied-via-GTK-print-dialog-removi.patch
--- 2.3.3-3/debian/patches/0040-Fix-fax-numbers-supplied-via-GTK-print-dialog-removi.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0040-Fix-fax-numbers-supplied-via-GTK-print-dialog-removi.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,92 +0,0 @@
-From: Till Kamppeter <till.kamppeter@gmail.com>
-Date: Wed, 26 Aug 2020 13:03:00 +0200
-Subject: Fix fax numbers supplied via GTK print dialog,
- removing a "Custom." prefix;
- do not choke if the GTK dialog sends "None" as phone number or pre-dial
- prefix
-
----
- backend/ipp.c | 61 ++++++++++++++++++++++++++++++++++++++++++++++-------------
- 1 file changed, 48 insertions(+), 13 deletions(-)
-
-diff --git a/backend/ipp.c b/backend/ipp.c
-index a99079e..d80d650 100644
---- a/backend/ipp.c
-+++ b/backend/ipp.c
-@@ -2828,7 +2828,19 @@ new_request(
-         */
- 
-         _httpDecodeURI(phone, keyword, sizeof(phone));
--        for (ptr = phone; *ptr;)
-+	ptr = phone;
-+
-+	/* Weed out "Custom." in the beginning, this allows to put the
-+	   "phone" option as custom string option into the PPD so that
-+	   print dialogs not supporting fax display the option and
-+	   allow entering the phone number. Print dialogs also send "None"
-+	   if no phone number got entered, filter this, too. */
-+	if (!_cups_strcasecmp(phone, "None"))
-+	  *ptr = '\0';
-+	if (!_cups_strncasecmp(phone, "Custom.", 7))
-+	  _cups_strcpy(ptr, ptr + 7);
-+
-+        for (; *ptr;)
- 	{
- 	  if (*ptr == ',')
- 	    *ptr = 'p';
-@@ -2838,20 +2850,43 @@ new_request(
- 	    ptr ++;
-         }
- 
--        httpAssembleURI(HTTP_URI_CODING_ALL, tel_uri, sizeof(tel_uri), "tel", NULL, NULL, 0, phone);
--        ippAddString(destination, IPP_TAG_JOB, IPP_TAG_URI, "destination-uri", NULL, tel_uri);
--
--	if ((keyword = cupsGetOption("faxPrefix", num_options,
--	                             options)) != NULL && *keyword)
--        {
--	  char	predial[1024];		/* Pre-dial string */
-+	if (strlen(phone) > 0)
-+	{
-+	  httpAssembleURI(HTTP_URI_CODING_ALL, tel_uri, sizeof(tel_uri),
-+			  "tel", NULL, NULL, 0, phone);
-+	  ippAddString(destination, IPP_TAG_JOB, IPP_TAG_URI,
-+		       "destination-uri", NULL, tel_uri);
-+	  fprintf(stderr, "DEBUG: Faxing to phone %s; destination-uri: %s\n",
-+		  phone, tel_uri);
-+
-+	  if ((keyword = cupsGetOption("faxPrefix", num_options,
-+				       options)) != NULL && *keyword)
-+	  {
-+	    char	predial[1024];		/* Pre-dial string */
-+
-+	    _httpDecodeURI(predial, keyword, sizeof(predial));
-+	    ptr = predial;
-+	    if (!_cups_strcasecmp(ptr, "None"))
-+	      *ptr = '\0';
-+	    if (!_cups_strncasecmp(ptr, "Custom.", 7))
-+	      ptr += 7;
-+	    if (strlen(ptr) > 0)
-+	    {
-+	      ippAddString(destination, IPP_TAG_JOB, IPP_TAG_TEXT,
-+			   "pre-dial-string", NULL, ptr);
-+	      fprintf(stderr, "DEBUG: Pre-dialing %s; pre-dial-string: %s\n",
-+		      ptr, ptr);
-+	    }
-+	    else
-+	      fprintf(stderr, "WARNING: Pre-dial number for fax not valid! Sending fax without pre-dial number.\n");
-+	  }
- 
--	  _httpDecodeURI(predial, keyword, sizeof(predial));
--	  ippAddString(destination, IPP_TAG_JOB, IPP_TAG_TEXT, "pre-dial-string", NULL, predial);
-+	  ippAddCollection(request, IPP_TAG_JOB, "destination-uris",
-+			   destination);
-+	  ippDelete(destination);
- 	}
--
--        ippAddCollection(request, IPP_TAG_JOB, "destination-uris", destination);
--        ippDelete(destination);
-+	else
-+	  fprintf(stderr, "ERROR: Phone number for fax not valid! Fax cannot be sent.\n");
-       }
-     }
-     else
diff -pruN 2.3.3-3/debian/patches/0041-Let-the-rastertopwg-filter-check-rounding-errors-whe.patch 2.3.3op1-3/debian/patches/0041-Let-the-rastertopwg-filter-check-rounding-errors-whe.patch
--- 2.3.3-3/debian/patches/0041-Let-the-rastertopwg-filter-check-rounding-errors-whe.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/0041-Let-the-rastertopwg-filter-check-rounding-errors-whe.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,77 +0,0 @@
-From: Till Kamppeter <till.kamppeter@gmail.com>
-Date: Thu, 27 Aug 2020 10:22:00 +0200
-Subject: Let the rastertopwg filter check rounding errors when calculating
- the page geometry
-
----
- filter/rastertopwg.c | 28 ++++++++++++++++++++++------
- 1 file changed, 22 insertions(+), 6 deletions(-)
-
-diff --git a/filter/rastertopwg.c b/filter/rastertopwg.c
-index 1e63e4e..bffd89a 100644
---- a/filter/rastertopwg.c
-+++ b/filter/rastertopwg.c
-@@ -41,8 +41,10 @@ main(int  argc,				/* I - Number of command-line args */
- 			page_top,	/* Top margin */
- 			page_bottom,	/* Bottom margin */
- 			page_left,	/* Left margin */
-+			page_right,	/* Right margin */
- 			linesize,	/* Bytes per line */
- 			lineoffset;	/* Offset into line */
-+  int			tmp;
-   unsigned char		white;		/* White pixel */
-   ppd_file_t		*ppd;		/* PPD file */
-   ppd_attr_t		*back;		/* cupsBackSide attribute */
-@@ -120,14 +122,30 @@ main(int  argc,				/* I - Number of command-line args */
-     fprintf(stderr, "PAGE: %d %d\n", page, inheader.NumCopies);
- 
-     page_width  = (unsigned)(inheader.cupsPageSize[0] * inheader.HWResolution[0] / 72.0);
-+    if (page_width < inheader.cupsWidth &&
-+	page_width >= inheader.cupsWidth - 2)
-+      page_width = (unsigned)inheader.cupsWidth;
-     page_height = (unsigned)(inheader.cupsPageSize[1] * inheader.HWResolution[1] / 72.0);
-+    if (page_height < inheader.cupsHeight &&
-+	page_height >= inheader.cupsHeight - 2)
-+      page_height = (unsigned)inheader.cupsHeight;
-     page_left   = (unsigned)(inheader.cupsImagingBBox[0] * inheader.HWResolution[0] / 72.0);
-     page_bottom = (unsigned)(inheader.cupsImagingBBox[1] * inheader.HWResolution[1] / 72.0);
--    page_top    = page_height - page_bottom - inheader.cupsHeight;
-+    tmp        = (int)(page_height - page_bottom - inheader.cupsHeight);
-+    if (tmp < 0 && tmp >= -2) /* Rounding error */
-+      page_top = 0;
-+    else
-+      page_top = (unsigned)tmp;
-+    tmp        = (int)(page_width - page_left - inheader.cupsWidth);
-+    if (tmp < 0 && tmp >= -2) /* Rounding error */
-+      page_right = 0;
-+    else
-+      page_right = (unsigned)tmp;
-     linesize    = (page_width * inheader.cupsBitsPerPixel + 7) / 8;
-     lineoffset  = page_left * inheader.cupsBitsPerPixel / 8; /* Round down */
- 
--    if (page_left > page_width || page_top > page_height || page_bottom > page_height)
-+    fprintf(stderr, "DEBUG: In pixels: Width: %u  Height: %u  Left: %u  Right:  %u  Top: %u  Bottom: %u\n", page_width, page_height, page_left, page_right, page_top, page_bottom);
-+    if (page_left > page_width || page_top > page_height || page_bottom > page_height || page_right > page_width)
-     {
-       _cupsLangPrintFilter(stderr, "ERROR", _("Unsupported raster data."));
-       fprintf(stderr, "DEBUG: Bad bottom/left/top margin on page %d.\n", page);
-@@ -291,8 +309,7 @@ main(int  argc,				/* I - Number of command-line args */
- 	  outheader.cupsInteger[1] = ~0U;/* CrossFeedTransform */
- 	  outheader.cupsInteger[2] = 1;	/* FeedTransform */
- 
--	  outheader.cupsInteger[3] = page_width - page_left -
--	                             inheader.cupsWidth;
-+	  outheader.cupsInteger[3] = page_right;
- 					/* ImageBoxLeft */
- 	  outheader.cupsInteger[4] = page_top;
- 					/* ImageBoxTop */
-@@ -355,8 +372,7 @@ main(int  argc,				/* I - Number of command-line args */
- 	  outheader.cupsInteger[1] = ~0U;/* CrossFeedTransform */
- 	  outheader.cupsInteger[2] = ~0U;/* FeedTransform */
- 
--	  outheader.cupsInteger[3] = page_width - page_left -
--	                             inheader.cupsWidth;
-+	  outheader.cupsInteger[3] = page_right;
- 					/* ImageBoxLeft */
- 	  outheader.cupsInteger[4] = page_bottom;
- 					/* ImageBoxTop */
diff -pruN 2.3.3-3/debian/patches/series 2.3.3op1-3/debian/patches/series
--- 2.3.3-3/debian/patches/series	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches/series	2020-12-04 09:32:55.000000000 +0000
@@ -1,41 +1,12 @@
-0001-Fix-hyphen-used-as-minus-sign-manpage-errors.patch
-0002-Install-root-backends-world-readable.patch
-0003-Fix-jobs-with-multiple-files-or-multiple-formats.patch
-0004-Fix-conversion-of-PPD-InputSlot-choice-names.patch
-0005-Fix-scheduler-cupsd.conf-load.patch
-0006-Fix-leakage-of-ppd.patch
-0007-Tests-Ignore-warnings-from-colord-and-Avahi.patch
-0008-Tests-ignore-usb-dnssd-backend-unexpected-exits.patch
-0009-Tests-ignore-loadFile-failures.patch
-0010-Tests-ignore-errors-triggered-on-ipv6-deprived-hosts.patch
-0011-Tests-ignore-the-failure-to-write-uncompressed-data.patch
-0012-Tests-ignore-job-held-message.patch
-0013-Tests-Do-not-run-the-CUPS_EUC_JP-test-case-on-BSD-Hu.patch
-0014-Tests-Make-sure-that-all-scheduled-jobs-are-finished.patch
-0015-Tests-Force-LC_-environment-variables-when-testing-n.patch
-0016-Tests-Use-127.0.0.1-instead-of-localhost-to-help-pbu.patch
-0017-Tests-Force-LC_ALL-C-environment-variable-when-grepp.patch
-0018-Tests-Do-not-test-pdftourf.patch
-0019-Move-cupsd.conf.default-from-SERVERROOT-to-DATADIR.patch
-0020-Patch-to-support-Apple-AirPrint-printing-from-iPhone.patch
-0021-Let-snmp-backend-also-use-manufacturer-specific-MIBs.patch
-0022-Disable-time-stamps-in-conffiles-to-avoid-ever-chang.patch
-0023-Do-not-write-VCS-tags-into-installed-conffiles.patch
-0024-Rename-the-systemd-service-file-from-org.cups.cups.-.patch
-0025-Add-Requires-cups.socket-to-cups.service-to-make-sur.patch
-0026-Do-not-use-host-names-for-broadcasting-print-queues-.patch
-0027-CUPS-removes-the-recommended-comments-of-the-NickNam.patch
-0028-Make-log-files-readable-to-group-adm-if-present.patch
-0029-Deactivate-CUPS-own-log-rotating-as-the-system-alrea.patch
-0030-Do-not-mess-with-the-permissions-of-cupsd.conf.patch
-0031-Show-compile-command-lines.patch
-0032-Set-the-default-for-SyncOnClose-to-Yes.patch
-0033-Set-default-job-error-policy-to-retry-job.patch
-0034-Drop-dangling-references-from-cups-lpd.man.patch
-0035-Use-dpkg-architecture-in-cups-config-to-make-it-arch.patch
-0036-Build-mantohtml-with-the-build-architecture-compiler.patch
-0037-po4a-infrastructure-and-translations-for-manpages.patch
-0038-Resolve-DNS-SD-service-name-based-URIs-correctly-als.patch
-0039-Make-lpoptions-list-a-printer-s-options-correctly-al.patch
-0040-Fix-fax-numbers-supplied-via-GTK-print-dialog-removi.patch
-0041-Let-the-rastertopwg-filter-check-rounding-errors-whe.patch
+0001-Force-a-5-second-sleep-to-wait-for-the-job-control-f.patch
+0002-SERVERBIN-match-host_os_name-on-gnu-first-to-catch-k.patch
+0003-CUPS_EXE_FILE_PERM-also-match-host_os_name-on-gnu-to.patch
+0004-Apple-AirPrint-support.patch
+0005-Keep-foomatic-PPDs-recommended-stanzas-in-NickNames.patch
+0006-Debian-Set-LogFileGroup-to-adm.patch
+0007-Debian-Move-cupsd.conf.default-from-SERVERROOT-to-DA.patch
+0008-Debian-Do-not-alter-the-permissions-of-cupsd.conf-ev.patch
+0009-Debian-Show-compile-command-lines.patch
+0010-Debian-Use-dpkg-architecture-in-cups-config-to-make-.patch
+0011-Debian-Build-mantohtml-with-the-build-architecture-c.patch
+0012-Debian-po4a-infrastructure-and-translations-for-manp.patch
diff -pruN 2.3.3-3/debian/patches-ubuntu/ubuntu-disable-browsing.patch 2.3.3op1-3/debian/patches-ubuntu/ubuntu-disable-browsing.patch
--- 2.3.3-3/debian/patches-ubuntu/ubuntu-disable-browsing.patch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/patches-ubuntu/ubuntu-disable-browsing.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,16 +0,0 @@
-Description: Disable Browsing by default on Ubuntu (not sanctioned yet by https://wiki.ubuntu.com/DefaultNetworkServices). This is only applied when building on Ubuntu.
-Author: Martin Pitt <martin.pitt@ubuntu.com>
-
-diff --git a/conf/cupsd.conf.in b/conf/cupsd.conf.in
-index 42e24a2..4282368 100644
---- a/conf/cupsd.conf.in
-+++ b/conf/cupsd.conf.in
-@@ -17,7 +17,7 @@ Listen localhost:@DEFAULT_IPP_PORT@
- @CUPS_LISTEN_DOMAINSOCKET@
- 
- # Show shared printers on the local network.
--Browsing On
-+Browsing Off
- BrowseLocalProtocols @CUPS_BROWSE_LOCAL_PROTOCOLS@
- 
- # Default authentication type, when authentication is required...
diff -pruN 2.3.3-3/debian/po/da.po 2.3.3op1-3/debian/po/da.po
--- 2.3.3-3/debian/po/da.po	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/po/da.po	2020-12-04 09:32:55.000000000 +0000
@@ -14,7 +14,7 @@ msgstr ""
 "Language-Team: Danish\n"
 "Language: \n"
 "MIME-Version: 1.0\n"
-"Content-Type: text/plain; charset=ISO-8859-1\n"
+"Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "X-Generator: KBabel 1.11.4\n"
 "Plural-Forms:  nplurals=2; plural=(n != 1);\n"
@@ -23,7 +23,7 @@ msgstr ""
 #. Description
 #: ../cups-bsd.templates:2001
 msgid "Do you want to set up the BSD lpd compatibility server?"
-msgstr "nsker du at stte BSD lpd-kompatibilitetsserveren op?"
+msgstr "Ønsker du at sætte BSD lpd-kompatibilitetsserveren op?"
 
 #. Type: boolean
 #. Description
@@ -34,17 +34,17 @@ msgid ""
 "to submit jobs over the network via the \"BSD\" or \"LPR\" services, and "
 "these computers cannot be converted to use the IPP protocol that CUPS uses."
 msgstr ""
-"CUPS-pakken indeholder en server, der kan modtage print-jobs p BSD-form og "
-"sende dem videre til CUPS. Den br kun sttes op, hvis det er muligt, at "
-"andre computere sender jobs over netvrket via servicerne \"BSD\" eller \"LPR"
-"\", og disse computere ikke kan overg til at benytte den IPP-protokol, som "
+"CUPS-pakken indeholder en server, der kan modtage print-jobs på BSD-form og "
+"sende dem videre til CUPS. Den bør kun sættes op, hvis det er muligt, at "
+"andre computere sender jobs over netværket via servicerne \"BSD\" eller \"LPR"
+"\", og disse computere ikke kan overgå til at benytte den IPP-protokol, som "
 "CUPS benytter."
 
 #. Type: boolean
 #. Description
 #: ../cups.templates:2001
 msgid "Do you want CUPS to print unknown jobs as raw jobs?"
-msgstr "nsker du at CUPS skal udskrive ukendte jobs som r jobs?"
+msgstr "Ønsker du at CUPS skal udskrive ukendte jobs som rå jobs?"
 
 #. Type: boolean
 #. Description
@@ -55,10 +55,10 @@ msgid ""
 "many jobs get submitted as the MIME type application/octet-stream and could "
 "be rejected if CUPS cannot guess the job's format."
 msgstr ""
-"Internet Printing Protocol IPP krver, at der angives MIME-type for alle "
+"Internet Printing Protocol IPP kræver, at der angives MIME-type for alle "
 "printjobs. Da ikke alle printjob-kilder kan medsende den relevante type, vil "
 "mange jobs blive sendt med MIME-typen \"application/octet-stream\", og kunne "
-"blive afvist, sfremt CUPS ikke kan gtte jobbets format."
+"blive afvist, såfremt CUPS ikke kan gætte jobbets format."
 
 #. Type: boolean
 #. Description
@@ -67,7 +67,7 @@ msgid ""
 "CUPS can handle all such jobs as \"raw\" jobs, which causes them to be sent "
 "directly to the printer without processing."
 msgstr ""
-"CUPS kan hndtere sdanne jobs som \"r\" jobs, hvilket betyder, at de "
+"CUPS kan håndtere sådanne jobs som \"rå\" jobs, hvilket betyder, at de "
 "sendes direkte til printeren uden yderligere behandling."
 
 #. Type: boolean
@@ -77,7 +77,7 @@ msgid ""
 "It is recommended to choose this option if the server will be accepting "
 "print jobs from Windows computers or Samba servers."
 msgstr ""
-"Det anbefales at vlge denne indstilling, hvis serveren kommer til at "
+"Det anbefales at vælge denne indstilling, hvis serveren kommer til at "
 "modtage printjobs fra Windows-computere eller Samba-servere."
 
 #. Type: multiselect
@@ -132,15 +132,15 @@ msgid ""
 "Please choose the backend program to be used by CUPS. The default choice "
 "should fit the most common environments."
 msgstr ""
-"Vlg det bagvedliggende program, CUPS skal bruge. Det forvalgte burde vre "
+"Vælg det bagvedliggende program, CUPS skal bruge. Det forvalgte burde være "
 "passende under de mest almindelige forhold."
 
 #~ msgid ""
 #~ "Unfortunately, some backend programs are likely to cause some trouble. "
 #~ "For example, some PPC kernels crash with the parallel backend."
 #~ msgstr ""
-#~ "Desvrre giver nogle af disse bagvedliggende programmer ofte visse "
-#~ "problemer (f.eks. bryder kernen sammen p nogle PPC-maskiner med parallel-"
+#~ "Desværre giver nogle af disse bagvedliggende programmer ofte visse "
+#~ "problemer (f.eks. bryder kernen sammen på nogle PPC-maskiner med parallel-"
 #~ "programmet)."
 
 #~ msgid "ipp"
@@ -155,19 +155,19 @@ msgstr ""
 #~ "local driver the MIME type application/octet-stream. Samba also submits "
 #~ "its print jobs this way."
 #~ msgstr ""
-#~ "Hvis du vil acceptere printjobs fra Windows-computere, br du acceptere "
-#~ "denne funktion, da Windows giver alle IPP-printjobs, som hndteres af en "
+#~ "Hvis du vil acceptere printjobs fra Windows-computere, bør du acceptere "
+#~ "denne funktion, da Windows giver alle IPP-printjobs, som håndteres af en "
 #~ "lokal driver MIME-typen \"application/octet-stream\". Samba sender sine "
-#~ "jobs p samme mde."
+#~ "jobs på samme måde."
 
 #~ msgid "Port or/and host name where CUPS will listen to:"
-#~ msgstr "Port og/eller vrtsnavn, CUPS skal lytte p:"
+#~ msgstr "Port og/eller værtsnavn, CUPS skal lytte på:"
 
 #~ msgid ""
 #~ "Please specify the port or the host name CUPS daemon will listen to. The "
 #~ "following formats are allowed:"
 #~ msgstr ""
-#~ "Angiv port eller vrtsnavn, CUPS-dmonen skal lytte p. Flgende formater "
+#~ "Angiv port eller værtsnavn, CUPS-dæmonen skal lytte på. Følgende formater "
 #~ "er gyldige:"
 
 #~ msgid ""
@@ -177,9 +177,9 @@ msgstr ""
 #~ " - File domain socket (/var/run/cups/cups.sock)."
 #~ msgstr ""
 #~ " - Portnummer  (631);\n"
-#~ " - vrtsnavn   (debian.eksempel.dk);\n"
-#~ " - Vrt:Port   (debian.eksempel.dk:631);\n"
-#~ " - Fildomnesokkel (/var/run/cups/cups.sock)."
+#~ " - værtsnavn   (debian.eksempel.dk);\n"
+#~ " - Vært:Port   (debian.eksempel.dk:631);\n"
+#~ " - Fildomænesokkel (/var/run/cups/cups.sock)."
 
 #~ msgid ""
 #~ "You can combine any of these by delimiting in a space-separated list."
@@ -191,31 +191,31 @@ msgstr ""
 #~ "for security reasons."
 #~ msgstr ""
 #~ "Standardporten 631 er reserveret til Internet-PrinterProtokollen (IPP). "
-#~ "\"localhost:631\" anbefales af sikkerhedsgrunde for at stte et "
-#~ "selvstndigt milj op."
+#~ "\"localhost:631\" anbefales af sikkerhedsgrunde for at sætte et "
+#~ "selvstændigt miljø op."
 
 #~ msgid "Broadcast and/or listen for CUPS printer information on the network?"
-#~ msgstr "Rundsend og/eller lyt efter CUPS-printeroplysninger p netvrket?"
+#~ msgstr "Rundsend og/eller lyt efter CUPS-printeroplysninger på netværket?"
 
 #~ msgid ""
 #~ "CUPS daemon can broadcast printer information for clients on the network, "
 #~ "and detect printers on the network automatically."
 #~ msgstr ""
-#~ "CUPS-dmonen kan rundsende printeroplysninger til klienter p netvrket "
-#~ "og detektere printere p netvrket automatisk."
+#~ "CUPS-dæmonen kan rundsende printeroplysninger til klienter på netværket "
+#~ "og detektere printere på netværket automatisk."
 
 #~ msgid ""
 #~ "If you choose this option, the CUPS daemon will periodically send UDP "
 #~ "broadcasts to detect printers."
 #~ msgstr ""
-#~ "Hvis du vlger denne indstilling, vil CUPS-dmonen periodisk sende UDP-"
+#~ "Hvis du vælger denne indstilling, vil CUPS-dæmonen periodisk sende UDP-"
 #~ "rundsendinger for at detektere printere."
 
 #~ msgid "Incorrect value entered"
-#~ msgstr "Ugyldig vrdi indtastet"
+#~ msgstr "Ugyldig værdi indtastet"
 
 #~ msgid "an error occurred while parsing the port number or the host name."
-#~ msgstr "der opstod en fejl under tolkningaf portnummer eller vrtsnavn."
+#~ msgstr "der opstod en fejl under tolkningaf portnummer eller værtsnavn."
 
 #~ msgid "Please correct your input."
 #~ msgstr "Ret venligst din indtastning."
@@ -224,4 +224,4 @@ msgstr ""
 #~ msgstr "ipp, lpd, parallel, scsi, seriel, sokkel, usb"
 
 #~ msgid "Select the backends you want."
-#~ msgstr "Vlg det bagvedliggende program, du nsker."
+#~ msgstr "Vælg det bagvedliggende program, du ønsker."
diff -pruN 2.3.3-3/debian/po/es.po 2.3.3op1-3/debian/po/es.po
--- 2.3.3-3/debian/po/es.po	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/po/es.po	2020-12-04 09:32:55.000000000 +0000
@@ -4,7 +4,7 @@
 #
 # Changes:
 # - Initial translation
-#        Carlos Valdivia Yage <valyag@dat.etsit.upm.es>, 2003, 2004, 2006
+#        Carlos Valdivia Yagüe <valyag@dat.etsit.upm.es>, 2003, 2004, 2006
 # - Translation update
 #        Javier Fernandez-Sanguino <jfs@debian.org>, 2007
 #
@@ -26,19 +26,19 @@ msgstr ""
 "Report-Msgid-Bugs-To: cups@packages.debian.org\n"
 "POT-Creation-Date: 2016-12-20 08:55+0100\n"
 "PO-Revision-Date: 2007-06-21 18:51+0200\n"
-"Last-Translator: Carlos Valdivia Yage <valyag@dat.etsit.upm.es>\n"
+"Last-Translator: Carlos Valdivia Yagüe <valyag@dat.etsit.upm.es>\n"
 "Language-Team: Debian L10n Spanish Team <debian-l10n-spanish@lists.debian."
 "org>\n"
 "Language: \n"
 "MIME-Version: 1.0\n"
-"Content-Type: text/plain; charset=ISO-8859-15\n"
+"Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
 #. Type: boolean
 #. Description
 #: ../cups-bsd.templates:2001
 msgid "Do you want to set up the BSD lpd compatibility server?"
-msgstr "Desea configurar el servidor de compatibilidad lpd de BSD?"
+msgstr "¿Desea configurar el servidor de compatibilidad lpd de BSD?"
 
 #. Type: boolean
 #. Description
@@ -49,9 +49,9 @@ msgid ""
 "to submit jobs over the network via the \"BSD\" or \"LPR\" services, and "
 "these computers cannot be converted to use the IPP protocol that CUPS uses."
 msgstr ""
-"Este paquete incluye un servidor que acepta trabajos de impresin al estilo "
-"BSD y se los enva a CUPS. Configrelo nicamente en el caso de que haya "
-"otras mquinas que enven trabajos de impresin mediante la red, usando los "
+"Este paquete incluye un servidor que acepta trabajos de impresión al estilo "
+"BSD y se los envía a CUPS. Configúrelo únicamente en el caso de que haya "
+"otras máquinas que envíen trabajos de impresión mediante la red, usando los "
 "servicios \"BSD\" o \"LPR\" y no se puede hacer que estos utilice el "
 "protocolo IPP que utiliza CUPS."
 
@@ -59,7 +59,7 @@ msgstr ""
 #. Description
 #: ../cups.templates:2001
 msgid "Do you want CUPS to print unknown jobs as raw jobs?"
-msgstr "Quiere que CUPS imprima en bruto los trabajos desconocidos?"
+msgstr "¿Quiere que CUPS imprima en bruto los trabajos desconocidos?"
 
 #. Type: boolean
 #. Description
@@ -70,9 +70,9 @@ msgid ""
 "many jobs get submitted as the MIME type application/octet-stream and could "
 "be rejected if CUPS cannot guess the job's format."
 msgstr ""
-"En IPP todos los trabajos de impresin tienen un tipo MIME. Puesto que no "
-"todas las fuentes de trabajos de impresin asignan correctamente algn tipo "
-"MIME, muchos llegan con el tipo application/octet-stream y podran "
+"En IPP todos los trabajos de impresión tienen un tipo MIME. Puesto que no "
+"todas las fuentes de trabajos de impresión asignan correctamente algún tipo "
+"MIME, muchos llegan con el tipo «application/octet-stream» y podrían "
 "rechazarse si CUPS no puede adivinar el formato del trabajo."
 
 #. Type: boolean
@@ -82,8 +82,8 @@ msgid ""
 "CUPS can handle all such jobs as \"raw\" jobs, which causes them to be sent "
 "directly to the printer without processing."
 msgstr ""
-"Es posible hacer que CUPS trate todos estos trabajos como trabajos en "
-"crudo, con lo que se mandan directamente a la impresora sin procesar."
+"Es posible hacer que CUPS trate todos estos trabajos como trabajos «en "
+"crudo», con lo que se mandan directamente a la impresora sin procesar."
 
 #. Type: boolean
 #. Description
@@ -92,8 +92,8 @@ msgid ""
 "It is recommended to choose this option if the server will be accepting "
 "print jobs from Windows computers or Samba servers."
 msgstr ""
-"Se recomienda que escoga esta opcin si el servidor va a aceptar trabajos de "
-"impresin de ordenadores con Windows o servidores Samba."
+"Se recomienda que escoga esta opción si el servidor va a aceptar trabajos de "
+"impresión de ordenadores con Windows o servidores Samba."
 
 #. Type: multiselect
 #. Choices
@@ -129,7 +129,7 @@ msgstr "dnssd"
 #. Description
 #: ../cups.templates:3002
 msgid "Printer communication backends:"
-msgstr "Motores de comunicacin con la impresora:"
+msgstr "Motores de comunicación con la impresora:"
 
 #. Type: multiselect
 #. Description
@@ -147,15 +147,15 @@ msgid ""
 "Please choose the backend program to be used by CUPS. The default choice "
 "should fit the most common environments."
 msgstr ""
-"Por favor, elija el motor que utilizar CUPS. La opcin predeterminada "
-"debera ser apta para los entornos ms comunes."
+"Por favor, elija el motor que utilizará CUPS. La opción predeterminada "
+"debería ser apta para los entornos más comunes."
 
 #~ msgid ""
 #~ "Unfortunately, some backend programs are likely to cause some trouble. "
 #~ "For example, some PPC kernels crash with the parallel backend."
 #~ msgstr ""
 #~ "Desafortunadamente, ciertos motores pueden causar problemas. Por ejemplo, "
-#~ "con el motor del puerto paralelo se producen algunas cadas del ncleo en "
+#~ "con el motor del puerto paralelo se producen algunas caídas del núcleo en "
 #~ "la arquitectura PPC."
 
 #~ msgid "ipp"
@@ -170,7 +170,7 @@ msgstr ""
 #~ "local driver the MIME type application/octet-stream. Samba also submits "
 #~ "its print jobs this way."
 #~ msgstr ""
-#~ "Si va a recibir trabajos de impresin desde sistemas Windows es muy "
-#~ "probable que desee activar esta opcin, ya que Windows da a los trabajos "
-#~ "de impresin IPP que procesa localmente el tipo application/octet-stream. "
-#~ "Samba tambin enva los trabajos de impresin de esta manera."
+#~ "Si va a recibir trabajos de impresión desde sistemas Windows es muy "
+#~ "probable que desee activar esta opción, ya que Windows da a los trabajos "
+#~ "de impresión IPP que procesa localmente el tipo application/octet-stream. "
+#~ "Samba también envía los trabajos de impresión de esta manera."
diff -pruN 2.3.3-3/debian/po/it.po 2.3.3op1-3/debian/po/it.po
--- 2.3.3-3/debian/po/it.po	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/po/it.po	2020-12-04 09:32:55.000000000 +0000
@@ -13,14 +13,14 @@ msgstr ""
 "Language-Team: Italian <tp@lists.linux.it>\n"
 "Language: it\n"
 "MIME-Version: 1.0\n"
-"Content-Type: text/plain; charset=ISO-8859-1\n"
+"Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
 #. Type: boolean
 #. Description
 #: ../cups-bsd.templates:2001
 msgid "Do you want to set up the BSD lpd compatibility server?"
-msgstr "Si vuole configurare il server di compatibilit con lpd di BSD?"
+msgstr "Si vuole configurare il server di compatibilità con lpd di BSD?"
 
 #. Type: boolean
 #. Description
@@ -31,11 +31,11 @@ msgid ""
 "to submit jobs over the network via the \"BSD\" or \"LPR\" services, and "
 "these computers cannot be converted to use the IPP protocol that CUPS uses."
 msgstr ""
-"Il pacchetto CUPS contiene un server che pu accettare job di stampa in "
+"Il pacchetto CUPS contiene un server che può accettare job di stampa in "
 "formato BSD per poi girarli a CUPS. Questo server dovrebbe essere attivato "
 "solo se in rete ci sono altri computer che potrebbero inviare job tramite i "
 "servizi \"BSD\" o \"LPR\" e che non possono essere configurati per usare il "
-"protocollo IPP, cio quello usato da CUPS."
+"protocollo IPP, cioè quello usato da CUPS."
 
 #. Type: boolean
 #. Description
@@ -64,7 +64,7 @@ msgid ""
 "CUPS can handle all such jobs as \"raw\" jobs, which causes them to be sent "
 "directly to the printer without processing."
 msgstr ""
-"CUPS pu trattare tutti questi job come job \"raw\", ci comporta l'invio "
+"CUPS può trattare tutti questi job come job \"raw\", ciò comporta l'invio "
 "diretto alla stampante, senza ulteriori elaborazioni."
 
 #. Type: boolean
diff -pruN 2.3.3-3/debian/po/sv.po 2.3.3op1-3/debian/po/sv.po
--- 2.3.3-3/debian/po/sv.po	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/po/sv.po	2020-12-04 09:32:55.000000000 +0000
@@ -21,7 +21,7 @@ msgstr ""
 "Language-Team: Swedish <tp-sv@listor.tp-sv.se>\n"
 "Language: sv\n"
 "MIME-Version: 1.0\n"
-"Content-Type: text/plain; charset=iso-8859-1\n"
+"Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
 #. Type: boolean
@@ -39,17 +39,17 @@ msgid ""
 "to submit jobs over the network via the \"BSD\" or \"LPR\" services, and "
 "these computers cannot be converted to use the IPP protocol that CUPS uses."
 msgstr ""
-"CUPS-paketet innehller en server som kan acceptera utskriftsjobb av BSD-"
-"stil och skicka dem till CUPS. Den br endast konfigureras om du har andra "
-"datorer som kommer att skicka jobb ver ntverket via \"BSD\" eller \"LPR\"-"
-"tjnster och dessa datorer inte kan konverteras till att anvnda IPP-"
-"protokollet som CUPS anvnder."
+"CUPS-paketet innehåller en server som kan acceptera utskriftsjobb av BSD-"
+"stil och skicka dem till CUPS. Den bör endast konfigureras om du har andra "
+"datorer som kommer att skicka jobb över nätverket via \"BSD\" eller \"LPR\"-"
+"tjänster och dessa datorer inte kan konverteras till att använda IPP-"
+"protokollet som CUPS använder."
 
 #. Type: boolean
 #. Description
 #: ../cups.templates:2001
 msgid "Do you want CUPS to print unknown jobs as raw jobs?"
-msgstr "Vill du att CUPS ska skriva ut oknda jobb som rjobb?"
+msgstr "Vill du att CUPS ska skriva ut okända jobb som råjobb?"
 
 #. Type: boolean
 #. Description
@@ -60,9 +60,9 @@ msgid ""
 "many jobs get submitted as the MIME type application/octet-stream and could "
 "be rejected if CUPS cannot guess the job's format."
 msgstr ""
-"Internet Printing Protocol (IPP) anvnder en MIME-typ fr alla sorters "
-"utskriftsjobb. Eftersom inte alla kllor fr utskriftsjobb kan skicka med en "
-"lmplig typ blir mnga jobb skickade som MIME-typen \"application/octet-"
+"Internet Printing Protocol (IPP) använder en MIME-typ för alla sorters "
+"utskriftsjobb. Eftersom inte alla källor för utskriftsjobb kan skicka med en "
+"lämplig typ blir många jobb skickade som MIME-typen \"application/octet-"
 "stream\" och kan bli nekade om CUPS inte kan gissa jobbtypen."
 
 #. Type: boolean
@@ -72,8 +72,8 @@ msgid ""
 "CUPS can handle all such jobs as \"raw\" jobs, which causes them to be sent "
 "directly to the printer without processing."
 msgstr ""
-"CUPS kan hantera alla sdan jobb som \"raw\"-jobb vilket orsakar att de "
-"skickas direkt till skrivaren utan att frst behandlas."
+"CUPS kan hantera alla sådan jobb som \"raw\"-jobb vilket orsakar att de "
+"skickas direkt till skrivaren utan att först behandlas."
 
 #. Type: boolean
 #. Description
@@ -82,8 +82,8 @@ msgid ""
 "It is recommended to choose this option if the server will be accepting "
 "print jobs from Windows computers or Samba servers."
 msgstr ""
-"Det r rekommenderat att vlja det hr alternativet om servern ska acceptera "
-"utskriftsjobb frn Windows-datorer eller Samba-servrar."
+"Det är rekommenderat att välja det här alternativet om servern ska acceptera "
+"utskriftsjobb från Windows-datorer eller Samba-servrar."
 
 #. Type: multiselect
 #. Choices
@@ -119,7 +119,7 @@ msgstr "dnssd"
 #. Description
 #: ../cups.templates:3002
 msgid "Printer communication backends:"
-msgstr "Bakndar fr skrivarkommunikation:"
+msgstr "Bakändar för skrivarkommunikation:"
 
 #. Type: multiselect
 #. Description
@@ -127,7 +127,7 @@ msgstr "Bakndar fr skrivarkommunikatio
 msgid ""
 "CUPS uses backend programs to communicate with the printer device or port."
 msgstr ""
-"CUPS anvnder bakndesprogram fr att kommunicera med skrivarenheten eller "
+"CUPS använder bakändesprogram för att kommunicera med skrivarenheten eller "
 "porten."
 
 #. Type: multiselect
@@ -137,15 +137,15 @@ msgid ""
 "Please choose the backend program to be used by CUPS. The default choice "
 "should fit the most common environments."
 msgstr ""
-"Vlj det bakndesprogram som ska anvndas av CUPS. Standardvalet br passa "
-"de flesta vanliga miljer."
+"Välj det bakändesprogram som ska användas av CUPS. Standardvalet bör passa "
+"de flesta vanliga miljöer."
 
 #~ msgid ""
 #~ "Unfortunately, some backend programs are likely to cause some trouble. "
 #~ "For example, some PPC kernels crash with the parallel backend."
 #~ msgstr ""
-#~ "Tyvrr kan vissa bakndesprogram orsaka en del problem. Till exempel kan "
-#~ "vissa PPC-krnor krascha nr den parallella baknden anvnds."
+#~ "Tyvärr kan vissa bakändesprogram orsaka en del problem. Till exempel kan "
+#~ "vissa PPC-kärnor krascha när den parallella bakänden används."
 
 #~ msgid "ipp"
 #~ msgstr "ipp"
@@ -159,21 +159,21 @@ msgstr ""
 #~ "local driver the MIME type application/octet-stream. Samba also submits "
 #~ "its print jobs this way."
 #~ msgstr ""
-#~ "Om du vill att utskriftsjobb ska accepteras frn Windows-datorer br du "
-#~ "antagligen vlja denna funktion eftersom Windows stter alla IPP-"
+#~ "Om du vill att utskriftsjobb ska accepteras från Windows-datorer bör du "
+#~ "antagligen välja denna funktion eftersom Windows sätter alla IPP-"
 #~ "utskriftsjobb som hanteras av en lokal drivare till MIME-typen "
-#~ "\"application/octet-stream\". Samba skickar ocks sina utskriftsjobb p "
-#~ "detta stt."
+#~ "\"application/octet-stream\". Samba skickar också sina utskriftsjobb på "
+#~ "detta sätt."
 
 #~ msgid "Port or/and host name where CUPS will listen to:"
-#~ msgstr "Port och/eller vrdnamn som CUPS lyssnar p:"
+#~ msgstr "Port och/eller värdnamn som CUPS lyssnar på:"
 
 #~ msgid ""
 #~ "Please specify the port or the host name CUPS daemon will listen to. The "
 #~ "following formats are allowed:"
 #~ msgstr ""
-#~ "Vnligen ange porten eller vrdnamnet som CUPS-demonen ska lyssna p. "
-#~ "Fljande format r tilltna:"
+#~ "Vänligen ange porten eller värdnamnet som CUPS-demonen ska lyssna på. "
+#~ "Följande format är tillåtna:"
 
 #, fuzzy
 #~ msgid ""
@@ -183,79 +183,79 @@ msgstr ""
 #~ " - File domain socket (/var/run/cups/cups.sock)."
 #~ msgstr ""
 #~ " - Portnummer (631);\n"
-#~ " - Vrdnamn   (debian.exempel.se);\n"
-#~ " - Vrd:Port   (debian.exempel.se:631)."
+#~ " - Värdnamn   (debian.exempel.se);\n"
+#~ " - Värd:Port   (debian.exempel.se:631)."
 
 #~ msgid ""
 #~ "You can combine any of these by delimiting in a space-separated list."
-#~ msgstr "Du kan kombinera flera av dessa genom att avgrnsa med mellanslag."
+#~ msgstr "Du kan kombinera flera av dessa genom att avgränsa med mellanslag."
 
 #~ msgid ""
 #~ "The default port 631 is reserved for the Internet Printing Protocol "
 #~ "(IPP). \"localhost:631\" is recommended to setup a standalone environment "
 #~ "for security reasons."
 #~ msgstr ""
-#~ "Standardport 631 r reserverad fr Internet Printing Protocol (IPP). "
-#~ "\"localhost:631\" r rekommenderad fr att stlla in en fristende milj "
-#~ "av skerhetsskl."
+#~ "Standardport 631 är reserverad för Internet Printing Protocol (IPP). "
+#~ "\"localhost:631\" är rekommenderad för att ställa in en fristående miljö "
+#~ "av säkerhetsskäl."
 
 #~ msgid "Broadcast and/or listen for CUPS printer information on the network?"
 #~ msgstr ""
-#~ "Vill du snda ut och/eller lyssna efter skrivarinformation fr CUPS p "
-#~ "ntverket?"
+#~ "Vill du sända ut och/eller lyssna efter skrivarinformation för CUPS på "
+#~ "nätverket?"
 
 #~ msgid ""
 #~ "CUPS daemon can broadcast printer information for clients on the network, "
 #~ "and detect printers on the network automatically."
 #~ msgstr ""
-#~ "CUPS-demonen kan snda ut skrivarinformation fr klienter p ntverket "
-#~ "och automatiskt identifiera skrivare p ntverket."
+#~ "CUPS-demonen kan sända ut skrivarinformation för klienter på nätverket "
+#~ "och automatiskt identifiera skrivare på nätverket."
 
 #~ msgid ""
 #~ "If you choose this option, the CUPS daemon will periodically send UDP "
 #~ "broadcasts to detect printers."
 #~ msgstr ""
-#~ "Om du valde detta alternativ kommer CUPS-demonen att med jmna mellanrum "
-#~ "snda UDP-broadcast fr att identifiera skrivare."
+#~ "Om du valde detta alternativ kommer CUPS-demonen att med jämna mellanrum "
+#~ "sända UDP-broadcast för att identifiera skrivare."
 
 #~ msgid "Incorrect value entered"
-#~ msgstr "Felaktigt vrde angivet"
+#~ msgstr "Felaktigt värde angivet"
 
 #~ msgid "an error occurred while parsing the port number or the host name."
-#~ msgstr "ett fel intrffade vid tolkning av portnumret eller vrdnamnet."
+#~ msgstr "ett fel inträffade vid tolkning av portnumret eller värdnamnet."
 
 #~ msgid "Please correct your input."
-#~ msgstr "Vnligen rtt till det."
+#~ msgstr "Vänligen rätt till det."
 
 #~ msgid "ipp, lpd, parallel, scsi, serial, socket, usb"
 #~ msgstr "ipp, lpd, parallell, scsi, seriell, socket, usb"
 
 #~ msgid "Select the backends you want."
-#~ msgstr "Vlj det baksystem du vill anvnda."
+#~ msgstr "Välj det baksystem du vill använda."
 
 #~ msgid "Specify the port or/and host name that wants to be listened."
-#~ msgstr "Ange port och/eller vrdnamn som ska lyssnas p."
+#~ msgstr "Ange port och/eller värdnamn som ska lyssnas på."
 
 #~ msgid "- Port number (631)"
 #~ msgstr "- Portnummer (631)"
 
 #~ msgid "- Host name   (debian.example.com)"
-#~ msgstr "- Vrdnamn   (debian.exempel.se)"
+#~ msgstr "- Värdnamn   (debian.exempel.se)"
 
 #~ msgid "- Host:Port   (debian.example.com:631)"
-#~ msgstr "- Vrd:Port   (debian.exempel.se:631)"
+#~ msgstr "- Värd:Port   (debian.exempel.se:631)"
 
 #~ msgid "It is possible to combine by delimiting two or more values in space."
 #~ msgstr ""
-#~ "Det r mjligt att kombinera genom att avgrnsa tv eller fler vrden med "
+#~ "Det är möjligt att kombinera genom att avgränsa två eller fler värden med "
 #~ "mellanslag."
 
 #~ msgid ""
 #~ "When this option is accepted, CUPS daemon will broadcast and detect by "
 #~ "using UDP periodically."
 #~ msgstr ""
-#~ "Nr denna funktion accepteras kommer CUPS-demonen att snda ut och "
-#~ "identifiera genom att anvnda UDP med jmna mellanrum."
+#~ "När denna funktion accepteras kommer CUPS-demonen att sända ut och "
+#~ "identifiera genom att använda UDP med jämna mellanrum."
 
 #~ msgid "The wrong value is found in the input."
-#~ msgstr "Fel vrde matades in."
+#~ msgstr "Fel värde matades in."
diff -pruN 2.3.3-3/debian/rules 2.3.3op1-3/debian/rules
--- 2.3.3-3/debian/rules	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/rules	2020-12-04 09:32:55.000000000 +0000
@@ -5,7 +5,6 @@ derives_from_ubuntu := $(shell (dpkg-ven
 # Enabling PIE globally doesn't work, but ./configure already enables PIE
 # where necessary.
 export DEB_BUILD_MAINT_OPTIONS = hardening=+all,-pie
-export DEB_LDFLAGS_MAINT_APPEND = -Wl,--as-needed
 
 ifeq ($(shell dpkg-vendor --is Ubuntu && echo yes) $(DEB_HOST_ARCH), yes i386)
    skip_packages = -Ncups -Ncups-core-drivers
@@ -26,20 +25,21 @@ else
 CONFIG_LIBUSB=--enable-libusb
 endif
 
-override_dh_auto_configure:
 ifeq ($(derives_from_ubuntu),yes)
-	set -e; if ! [ -e debian/patches-ubuntu/stamp-applied ]; then \
-	    echo '---- Applying Ubuntu specific patches'; \
-	    for p in debian/patches-ubuntu/*; do \
-	        patch -p1 --no-backup-if-mismatch < $$p; \
-	    done; \
-	    touch debian/patches-ubuntu/stamp-applied; \
-	fi
+CUPS_CONFIGURE_DISTRO_OPTIONS=--disable-browsing
+else
+CUPS_CONFIGURE_DISTRO_OPTIONS=
 endif
+
+override_dh_auto_configure:
 	# Rebuild ./configure to get build system patches working
 	aclocal
 	autoconf
+	# --with-error-policy=retry-job # Set default job error policy to "retry-job", since it is less confusing and a better default on most machines
+	# --enable-sync-on-close # Set SyncOnClose to yes; considered saner on Linux
+	# --with-max-log-size=0 # Deactivate CUPS' internal logrotating, as we provide a better one, especially LogLevel debug2 gets usable now
 	dh_auto_configure -- \
+		$(CUPS_CONFIGURE_DISTRO_OPTIONS) \
 		--with-docdir=/usr/share/cups/doc-root \
 		--localedir=/usr/share/cups/locale \
 		--enable-libpaper \
@@ -60,6 +60,9 @@ endif
 		--with-log-file-perm=0640 \
 		--with-local_protocols='dnssd' \
 		--with-systemd=/lib/systemd/system \
+		--with-error-policy=retry-job \
+		--enable-sync-on-close \
+		--with-max-log-size=0 \
 		$(CONFIG_LIBUSB)
 
 override_dh_auto_install:
@@ -162,10 +165,6 @@ endif
 
 
 override_dh_install:
-	# Rename the systemd service units to cups.* instead of org.cups.cupsd.*
-	set -e; for type in socket path service; do \
-	    mv debian/tmp/lib/systemd/system/org.cups.cupsd.$$type debian/tmp/lib/systemd/system/cups.$$type ;\
-	done
 	dh_install
 
 ifneq (,$(filter cups-server-common,$(shell dh_listpackages)))
@@ -214,7 +213,7 @@ override_dh_strip_nondeterminism: overri
 
 override_dh_auto_test:
 ifeq (,$(findstring nocheck,$(DEB_BUILD_OPTIONS)))
-	CUPS_TESTBASE=$(shell mktemp -d /tmp/cups.XXXXXX) make check
+	CUPS_TESTBASE=$(shell mktemp -d /tmp/cups.XXXXXX) dh_auto_test
 	# Check that cups-config is not architecture-specific
 	[ -r cups-config ] && grep -vq $(shell dpkg-architecture -qDEB_HOST_MULTIARCH) cups-config
 endif
@@ -224,16 +223,6 @@ override_dh_makeshlibs:
 	dh_makeshlibs -- -c4
 endif
 
-override_dh_clean:
-	dh_clean
-	if [ -e debian/patches-ubuntu/stamp-applied ]; then \
-	    echo '---- Unapplying Ubuntu specific patches'; \
-	    for p in debian/patches-ubuntu/*; do \
-	        patch -Rp1 --no-backup-if-mismatch < $$p; \
-	    done; \
-	    rm debian/patches-ubuntu/stamp-applied; \
-	fi
-
 override_dh_auto_clean:
 	[ ! -f Makedefs ] || dh_auto_clean
 	rm -f man/client.conf.man packaging/cups.list
diff -pruN 2.3.3-3/debian/source/options 2.3.3op1-3/debian/source/options
--- 2.3.3-3/debian/source/options	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/source/options	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-extend-diff-ignore = "(^|/)testrpm$"
diff -pruN 2.3.3-3/debian/upstream/metadata 2.3.3op1-3/debian/upstream/metadata
--- 2.3.3-3/debian/upstream/metadata	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/upstream/metadata	2020-12-04 09:32:55.000000000 +0000
@@ -1,4 +1,4 @@
-Bug-Database: https://github.com/apple/cups/issues
-Bug-Submit: https://github.com/apple/cups/issues
-Repository: https://github.com/apple/cups.git
-Repository-Browse: https://github.com/apple/cups
+Bug-Database: https://github.com/OpenPrinting/cups/issues
+Bug-Submit: https://github.com/OpenPrinting/cups/issues
+Repository: https://github.com/OpenPrinting/cups.git
+Repository-Browse: https://github.com/OpenPrinting/cups
diff -pruN 2.3.3-3/debian/upstream/signing-key.asc 2.3.3op1-3/debian/upstream/signing-key.asc
--- 2.3.3-3/debian/upstream/signing-key.asc	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/upstream/signing-key.asc	2020-12-04 09:32:55.000000000 +0000
@@ -1,52 +1,52 @@
 -----BEGIN PGP PUBLIC KEY BLOCK-----
 
-mQINBFo5hCYBEAD7WeR8qWUuD4Z3spmcjwIIcFsjF5V7MpqCZrGRcFiTH+MRiomQ
-Ylr652+9JlQjS9e/6Gtist6ydADvHqELmg42wQX7MrOCTDfKpM/mP2InMIDkel16
-SZbtBORR44LOzsZ9Cm7739M4hZWp2PVn+ElWJr6t3l9NXVZDXaPWugHlxUYYGz7O
-UxfYdkFQ3ND5ST60+Ir8P7YoSfCvxi2dus6/One7dhuTGdm/8+EtwrFPJWgbVxah
-FQHD8TKht3poGm6+mqgDley6soo4vUlUnYRbrEe+oXRnTx4Yih3FsXNez7IHFtJv
-MzHPSLE+2KsWp1gylp4hgLc5NGUD67nRO8GDqkhLK+PgJERx1NozLXqBa4XaoC6F
-rq4i3C+JSsWqWUUs85tpZHwEnZmfYMV+cWcUkuHRwhls2PIVzm2b2BALXV8MY9yO
-w8EBTrPo1ae1AplCZnLQX7gBdgBhX6ou+UKXqrAlaqiXlaxY2psajrmY+IqUXJL9
-H9IPMmzHz+apfAvIc4WY2APUI9BDT11gh8ko3ZWVUNxlL1rUwbCBjtwKdmVLLNmr
-mU1JbKY9L1PAXElEbpyJ6KrXk49KrFE8lnhTE4g2rUZ0wdmzjbAL0oaBL5qdNupd
-MjW20Y+PyYgvIrXNPTk/mhx79rAMlUIhNRYQhyATywr9/ubimhkNgYbcfQARAQAB
-tBxDVVBTLm9yZyA8c2VjdXJpdHlAY3Vwcy5vcmc+iQJUBBMBCgA+FiEERdCDlG4w
-NSgrPMqa9DQQQjXal+sFAlo5hCYCGwMFCQeGH4AFCwkIBwMFFQoJCAsFFgIDAQAC
-HgECF4AACgkQ9DQQQjXal+v1Fg//YlAD/woMIwumfTIBGdc7oye+JLRKTXOnIDxb
-VATpcSZOS6LMHy0x7k6kQ+G81r7NkfbQFHZRhvmf62qkg46JhPVJqWBqwVgrbQbk
-RRFbo38NkZ37WW2xhImt8iGC8XjfpbfraVYaZQuU7Jbn4vrAppOZbzgVI1T2FIh/
-+GXWbv4WV7hNaNvjREZl1UrzzCTpxrSBgoyx+1P6SwDHYWrC/gp4CMLEj6zf2Hwz
-KyIU+FmW54LIZafnswgNpoW1taZx7iSWfvqoyySomtL0PwhYWpKAyIZDf+6cffjx
-Fwp5UufEkLjyui0b/6DbCjyWiNHh8BT7niLZ54VXcO8IWr/kQH61s41xp0xU9/Pr
-N7Mn22Qd5SCFcDmbFvSI8m7Gn61G8mUfCL2zeAMUkNuzZgc+p2VhRCr+/9gk2eEg
-BOqxrrsKDa0g5mWLA0y8a5oohlXKM6SoyRcujCfQxO3rCD1+qM48Zm+4l/6NBg8w
-wRJNKoARnR2c9wGvHRbJY3kXllnd/3Fk/EzXwilFK4Fk0uIk8AtMSTh0Se1KNEum
-/AbUxRG50dq9pyrfYxsjhNmzu92NIR5sR5PyRQRbGDJkIlNEEbh87TBCrYqnKaPU
-lev+476zFE/raaum/DL0ANOUQCtX5ftWEK2Xo1s28DEo2DzyJWmYSmr/wnf8wrp7
-lNWA/F25Ag0EWjmEJgEQAPZvzo1nX/F4+9BGE9o0OSPZt/BLkusiyz6fd46k5vj7
-LGPFpjtMxUxbPNhMJi3QVBhtb8yiNugRmE0sWaA7b2COsXT8jaHZ2EBV0XnTr4Tv
-hSxNbdXu9fiDRFQ9x3D/LhDvDRgq0lKQw5cRBLCZw4as9Ytxn1WnS8evwhHRMMYL
-/lCyviyyj8zczXPmdWLVlMbhD02Yf5DpteSyhjMTvZFJWZiIUupnM1WXppDo4/Id
-nr2Sc5awhuFxdrSYFpaB5+hOdsjhDENcm+GY10iUNCqklCP5BZOeDprap7XwMElW
-/chdrwovPYn54Sugl9oHjUOfiJLi/e4J+ey86+2sWY0rZvmOViR1w4NldB+GbEQW
-/HOyTwo1Og36+7Ci9m2yothSC0wJAb5Bvg2tc1u4AsG2ylaxMFmwX226d2jJlFNl
-2crNFaIE/Uuo7YqH8pcm9kVZ+0apLHoxtZFnZF5QzLmcA83YFFWkqjEfmdLobWXX
-pZ+jPkHZDEhj21D+6LYCtUjDwnICySLoIawoMpkV+tdRyHuzxdYX1Nkh74mC2A7d
-koxMw86CgXP4UHJwCYunN+rUi7oC8oI1isqtMK8MZhcPdlvE721+fpdAdBIo8KVs
-RxQJ3vzhTuugZl5w3E8Jt7lC/q6CC6VI7V74fCNJjXiytrcpYg+FYCyfvxJ/4GH/
-ABEBAAGJAjwEGAEKACYWIQRF0IOUbjA1KCs8ypr0NBBCNdqX6wUCWjmEJgIbDAUJ
-B4YfgAAKCRD0NBBCNdqX65zoEACdIsOlto5FQtv2Yx/ayYklEsPgrx1IDnudvVUZ
-C+vsDoF9aOUBjUvpHjdBWOBnc/ThOw8ARvOcZLT06HNyzvkJNjj05N+hy1hiSY5B
-kL+TGCVkE/wUIDf69lt+KEG89EjpRDSTLDw8t05bEiaZ1XKfDmcIXbao38zhI2CD
-r+h1eQotY8bGA7hC7knwQv4VRnN8zBgZhQZdapjC8fBoaY00YZ4wBvd4Yz13/HGi
-gXssFNd35n+K+mnUaqulLIwjVfN1/luOubTpqCGVtSEVvHiq7XVRR6cSc345vFMa
-3AtRtHKQpZutEz08gZqrXXwALom+HWNbPqdHXEE/mZxvpEVMQr325KLKSPQGZSCq
-s8AFeYLYf66gn7T50VX5ws9sGANVvq1CHbouSbfc+UJkibeKG4/jSlqUwWNktEEJ
-hI+yGJP5xitfA4IGPaipfVHsxP1z37oht6BTj0zUlfEg9YoPmuHEAhxP7CGOatMM
-QkRQ7l0W3F05XL1HzynDnKkEigAUlwhq8Z5oO3Vf9b0MJg/V6T2+jzGIcy0PmliX
-rR6FQB5SMRaGCrJxSaPeadnSkJOpFM0dRqKDB049IAIbSxz5ZuqCpbB8tH17ezqu
-J3b3cDsSI2TOkacnMo01+IUcrgySKwl/4eUHd92FSq/m085HOQnlae4fjjJ/7qDd
-/yDo+w==
-=padA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+=YD80
 -----END PGP PUBLIC KEY BLOCK-----
diff -pruN 2.3.3-3/debian/watch 2.3.3op1-3/debian/watch
--- 2.3.3-3/debian/watch	2020-09-03 07:27:04.000000000 +0000
+++ 2.3.3op1-3/debian/watch	2020-12-04 09:32:55.000000000 +0000
@@ -1,3 +1,3 @@
 version=4
 opts="uversionmangle=s/^(release|v)?\.//;s/(rc|b)/~$1/,pgpsigurlmangle=s/$/\.sig/" \
-  https://github.com/apple/cups/releases .*/cups-(release|v)?@ANY_VERSION@-source@ARCHIVE_EXT@
+  https://github.com/OpenPrinting/cups/releases .*/cups-(release|v)?@ANY_VERSION@-source@ARCHIVE_EXT@
diff -pruN 2.3.3-3/doc/cups.css 2.3.3op1-3/doc/cups.css
--- 2.3.3-3/doc/cups.css	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/doc/cups.css	2020-11-27 14:25:26.000000000 +0000
@@ -1,11 +1,11 @@
 /* Layout CSS */
 .header {
   background: rgba(46,46,46,.9);
-  box-shadow: 0px 2px 5px rgba(0,0,0,0.25);
+  box-shadow: 0 2px 5px rgba(0,0,0,0.25);
   color: white;
   left: 0;
   margin-bottom: 20px;
-  padding: 0px;
+  padding: 0;
   position: fixed;
   right: 0;
   top: 0;
@@ -13,7 +13,7 @@
 }
 .header ul {
   list-style: none;
-  margin: 0px;
+  margin: 0;
   -webkit-margin-before: 0;
   -webkit-margin-after: 0;
   -webkit-margin-start: 0;
@@ -38,7 +38,7 @@
 }
 .header a.active {
   background: white !important;
-  box-shadow: rgba(0,0,0,0.1) 0px 0px 10px 0px inset;
+  box-shadow: rgba(0,0,0,0.1) 0 0 10px 0 inset;
   color: black !important;
   text-decoration: none !important;
 }
@@ -47,13 +47,13 @@
   padding: 40px 20px;
 }
 .row .body {
-  padding: 0px;
+  padding: 0;
 }
 
 .footer {
   background: rgba(46,46,46,.9);
   bottom: 0;
-  box-shadow: 0px -2px 5px rgba(0,0,0,0.25);
+  box-shadow: 0 -2px 5px rgba(0,0,0,0.25);
   color: #cccccc;
   font-size: 10px;
   height: 20px;
@@ -104,54 +104,54 @@
 }
 
 /* Appearance CSS */
-BODY {
+body {
   background: white;
   color: black;
   font-family: lucida grande, geneva, helvetica, arial, sans-serif;
   margin: 0;
 }
 
-H1, H2, H3, H4, H5, H6, P, TD, TH {
+h1, h2, h3, h4, h5, h6, p, td, th {
   font-family: lucida grande, geneva, helvetica, arial, sans-serif;
 }
 
-H1 { font-size: 2em; }
-H2 { font-size: 1.75em; }
-H3 { font-size: 1.5em; }
-H4 { font-size: 1.25em; }
+h1 { font-size: 2em; }
+h2 { font-size: 1.75em; }
+h3 { font-size: 1.5em; }
+h4 { font-size: 1.25em; }
 
-KBD {
+kbd {
   color: #006600;
   font-family: monaco, courier, monospace;
   font-weight: bold;
 }
 
-PRE {
+pre {
   font-family: monaco, courier, monospace;
 }
 
-BLOCKQUOTE {
+blockquote {
   border-left: solid 2px #777;
   margin: 1em 0;
   padding: 10px;
 }
 
-BLOCKQUOTE OL LI {
+blockquote ol li {
   margin-left: -1em;
 }
 
-PRE.command, PRE.example {
+pre.command, pre.example {
   background: #eee;
   margin: 0 36pt;
   padding: 10px;
 }
 
-P.example {
+p.example {
   font-style: italic;
   margin-left: 36pt;
 }
 
-DL.man DD {
+dl.man dd {
   margin-left: 5em;
 }
 
@@ -159,48 +159,48 @@ DL.man DT {
   margin-left: 0;
 }
 
-PRE.man {
+pre.man {
   margin: 0;
 }
 
-PRE.command EM, PRE.example EM {
+pre.command EM, pre.example EM {
   color: #3f0000;
   font-family: lucida grande, geneva, helvetica, arial, sans-serif;
 }
 
-P.command {
+p.command {
   color: #7f0000;
   font-family: monaco, courier, monospace;
   margin-left: 36pt;
 }
 
-P.formula {
+p.formula {
   font-style: italic;
   margin-left: 36pt;
 }
 
-A IMG {
+a img {
   border: none;
 }
 
-A:link:hover IMG {
+a:link:hover img {
   background: #f0f0f0;
   border-radius: 10px;
   -moz-border-radius: 10px;
 }
 
-A:link, A:visited {
+a:link, a:visited {
   font-weight: inherit;
   text-decoration: none;
   color: #000099;
 }
 
-A:link:hover, A:visited:hover, A:active {
+a:link:hover, a:visited:hover, a:active {
   text-decoration: underline;
   color: #990099;
 }
 
-TABLE.page {
+table.page {
   border: none;
   border-collapse: collapse;
   height: 100%;
@@ -209,29 +209,29 @@ TABLE.page {
   width: 100%;
 }
 
-TD.body {
+td.body {
   height: 100%;
   vertical-align: top;
 }
 
-TD.sel, TD.unsel {
+td.sel, td.unsel {
   border-left: thin solid #cccccc;
-  padding: 0px 5px;
+  padding: 0 5px;
   text-align: center;
   vertical-align: middle;
   width: 14%;
 }
 
-TD.sel {
+td.sel {
   background: url(images/sel.gif);
 }
 
-TD.unsel {
+td.unsel {
   background: url(images/unsel.gif);
 }
 
-TD.sel A, TD.sel A:hover, TD.unsel A:link:hover, TD.unsel A:visited:hover,
-TD.unsel A:active, TD.unsel A, TD.unsel A:visited {
+td.sel a, td.sel a:hover, td.unsel a:link:hover, td.unsel a:visited:hover,
+td.unsel a:active, td.unsel a, td.unsel a:visited {
   color: #666666;
   display: block;
   font-weight: normal;
@@ -239,7 +239,7 @@ TD.unsel A:active, TD.unsel A, TD.unsel
   text-decoration: none;
 }
 
-TD.trailer {
+td.trailer {
   background: #f0f0f0;
   border: solid thin #e0e0e0;
   color: #666666;
@@ -247,42 +247,42 @@ TD.trailer {
   padding: 5px;
 }
 
-TD.trailer A {
+td.trailer a {
   color: #666699;
 }
 
-FORM {
+form {
   display: inline;
 }
 
-INPUT[TYPE="TEXT"], TEXTAREA {
+input[type="text"], textarea {
   font-family: monaco, courier, monospace;
 }
 
-INPUT[TYPE="IMAGE"] {
+input[type="image"] {
   border: none;
   padding: 2pt;
   vertical-align: bottom;
 }
 
-SUB, SUP {
+sub, sup {
   font-size: 50%;
 }
 
-TR.data, TD.data, TR.data TD {
+tr.data, td.data, tr.data td {
   margin-top: 10pt;
   padding: 5pt;
   border-bottom: solid 1pt #999999;
 }
 
-TR.data TH {
+tr.data th {
   border-bottom: solid 1pt #999999;
   padding-top: 10pt;
   padding-left: 5pt;
   text-align: left;
 }
 
-DIV.table TABLE {
+div.table table {
   border: solid thin #999999;
   border-collapse: collapse;
   border-spacing: 0;
@@ -290,7 +290,7 @@ DIV.table TABLE {
   margin-right: auto;
 }
 
-DIV.table CAPTION {
+div.table caption {
   caption-side: top;
   font-size: 120%;
   font-style: italic;
@@ -299,24 +299,24 @@ DIV.table CAPTION {
   margin-right: auto;
 }
 
-DIV.table TABLE TD {
+div.table table td {
   background: white;
   border: solid thin #bbbbbb;
   padding: 5pt 10pt 0;
 }
 
-DIV.table TABLE TH {
+div.table table th {
   background: #f0f0f0;
   border: none;
   border-bottom: solid thin #999999;
 }
 
-DIV.figure TABLE {
+div.figure table {
   margin-left: auto;
   margin-right: auto;
 }
 
-DIV.figure CAPTION {
+div.figure caption {
   caption-side: bottom;
   font-size: 120%;
   font-style: italic;
@@ -325,21 +325,21 @@ DIV.figure CAPTION {
   margin-right: auto;
 }
 
-TH.label {
+th.label {
   text-align: right;
   vertical-align: top;
 }
 
-TH.sublabel {
+th.sublabel {
   text-align: right;
   font-weight: normal;
 }
 
-HR {
+hr {
   border: solid thin;
 }
 
-SPAN.info {
+span.info {
   background: black;
   border: thin solid black;
   color: white;
@@ -349,7 +349,7 @@ SPAN.info {
   white-space: nowrap;
 }
 
-H2 SPAN.info, H3 SPAN.info, H4 SPAN.info {
+h2 span.info, h3 span.info, h4 span.info {
   float: right;
   font-size: 100%;
 }
@@ -359,41 +359,41 @@ H2 SPAN.info, H3 SPAN.info, H4 SPAN.info
   color: white;
 }
 
-TH.conflict {
+th.conflict {
   text-align: right;
 }
 
-H1.title {
+h1.title {
   display: none;
 }
 
-H2.title, H3.title, .row .body H2, .row .body H3 {
+h2.title, h3.title, .row .body h2, .row .body h3 {
   border-bottom: solid 2pt black;
 }
 
-TABLE.indent {
+table.indent {
   margin-top: 2em;
   margin-left: auto;
   margin-right: auto;
   width: 90%;
 }
 
-TABLE.indent {
+table.indent {
   border-collapse: collapse;
 }
 
-TABLE.indent TD, TABLE.indent TH {
+table.indent td, table.indent th {
   padding: 0;
 }
 
-TABLE.list {
+table.list {
   border-collapse: collapse;
   margin-left: auto;
   margin-right: auto;
   width: 90%;
 }
 
-TABLE.list TH {
+table.list th {
   background: white;
   border-bottom: solid thin #cccccc;
   color: #444444;
@@ -404,39 +404,39 @@ TABLE.list TH {
   white-space: nowrap;
 }
 
-TABLE.list TH A {
+table.list th a {
   color: #4444cc;
 }
 
-TABLE.list TD {
+table.list td {
   border-bottom: solid thin #eeeeee;
   padding-top: 5pt;
   padding-left: 5pt;
 }
 
-TABLE.list TR:nth-child(even) {
+table.list tr:nth-child(even) {
   background: #f8f8f8;
 }
 
-TABLE.list TR:nth-child(odd) {
+table.list tr:nth-child(odd) {
   background: #f4f4f4;
 }
 
-DIV.sidebar {
+div.sidebar {
   float: right;
   min-width: 25%;
   margin-left: 10px;
   max-width: 33%;
 }
 
-DIV.sidebar P.l0 {
+div.sidebar p.l0 {
   margin-bottom: 0;
   margin-left: 0;
   margin-right: 0;
   margin-top: 12pt;
 }
 
-DIV.sidebar P.l1 {
+div.sidebar p.l1 {
   margin-bottom: 0;
   margin-left: 36pt;
   margin-right: 0;
@@ -444,7 +444,7 @@ DIV.sidebar P.l1 {
   text-indent: -18pt;
 }
 
-DIV.sidebar P.l2 {
+div.sidebar p.l2 {
   font-style: italic;
   margin-bottom: 0;
   margin-left: 54pt;
@@ -453,18 +453,18 @@ DIV.sidebar P.l2 {
   text-indent: -18pt;
 }
 
-TABLE.inset {
+table.inset {
   background: #f0f0f0;
   border: thin solid #e0e0e0;
   margin-top: 1em;
   padding: 0;
   width: 100%;
-  /* These are not implemented by all browsers, but that's OK */
+  /* these are not implemented by all browsers, but that's ok */
   border-radius: 5px;
   -moz-border-radius: 5px;
 }
 
-TABLE.inset CAPTION {
+table.inset caption {
   caption-side: top;
   color: #666666;
   font-size: 80%;
@@ -473,36 +473,36 @@ TABLE.inset CAPTION {
   text-align: left;
 }
 
-TABLE.inset TD {
+table.inset td {
   padding: 2px;
 }
 
-DT {
+dt {
   margin-left: 36pt;
   margin-top: 12pt;
 }
 
-DD {
+dd {
   margin-left: 54pt;
 }
 
-DL.category DT {
+dl.category dt {
   font-weight: bold;
 }
 
-P.summary {
+p.summary {
   margin-left: 36pt;
   font-family: monaco, courier, monospace;
 }
 
-DIV.summary TABLE {
+div.summary table {
   border: solid thin #999999;
   border-collapse: collapse;
   border-spacing: 0;
   margin: 10px;
 }
 
-DIV.summary TABLE TD, DIV.summary TABLE TH {
+div.summary table td, div.summary table th {
   background: white;
   border: solid thin #999999;
   border-spacing: 0;
@@ -511,16 +511,16 @@ DIV.summary TABLE TD, DIV.summary TABLE
   vertical-align: top;
 }
 
-DIV.summary TABLE THEAD TH {
+div.summary table thead th {
   background: #f0f0f0;
 }
 
-DIV.tabs {
+div.tabs {
   height: 480px;
   overflow: hidden;
 }
 
-DIV.tab {
+div.tab {
   float: left;
   height: 100%;
   overflow-y: auto;
@@ -641,7 +641,8 @@ table.list {
   width: 100%;
 }
 table.list tr:nth-child(even) {
-  background: rgba(127,127,127,0.1);]n}
+  background: rgba(127,127,127,0.1);
+}
 table.list th {
   border-right: 2px solid gray;
   font-family: monospace;
@@ -674,7 +675,7 @@ table.list td {
   }
 
   .body {
-    paddng: 0px;
+    padding: 0;
   }
 
   .footer {
@@ -689,7 +690,7 @@ table.list td {
     width: 100%;
   }
 
-  DIV.sidebar {
+  div.sidebar {
     float: none;
     margin-left: 0;
     max-width: 100%;
@@ -697,15 +698,15 @@ table.list td {
     width: 100%;
   }
 
-  BLOCKQUOTE {
+  blockquote {
     margin: 0;
   }
 
-  P.example {
+  p.example {
     margin-left: 0;
   }
 
-  PRE.command, PRE.example, PRE.man {
+  pre.command, pre.example, pre.man {
     margin-left: 0;
     white-space: pre-wrap;
   }
@@ -713,7 +714,6 @@ table.list td {
 
 /* iPad overrides */
 @media only screen and (min-device-width: 768px) and (max-device-width: 1024px) {
-
   .mobile {
     display: inherit;
   }
diff -pruN 2.3.3-3/doc/cups-printable.css 2.3.3op1-3/doc/cups-printable.css
--- 2.3.3-3/doc/cups-printable.css	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/doc/cups-printable.css	2020-11-27 14:25:26.000000000 +0000
@@ -1,113 +1,113 @@
-BODY {
+body {
   font-family: lucida grande, geneva, helvetica, arial, sans-serif;
 }
 
-H1, H2, H3, H4, H5, H6, P, TD, TH {
+h1, h2, h3, h4, h5, h6, p, td, th {
   font-family: lucida grande, geneva, helvetica, arial, sans-serif;
 }
 
-H1 { font-size: 2em; }
-H2 { font-size: 1.75em; }
-H3 { font-size: 1.5em; }
-H4 { font-size: 1.25em; }
+h1 { font-size: 2em; }
+h2 { font-size: 1.75em; }
+h3 { font-size: 1.5em; }
+h4 { font-size: 1.25em; }
 
-KBD {
+kbd {
   font-family: monaco, courier, monospace;
   font-weight: bold;
 }
 
-PRE {
+pre {
   font-family: monaco, courier, monospace;
 }
 
-BLOCKQUOTE {
+blockquote {
   border-left: solid 2px #777;
   margin: 1em 0;
   padding: 10px;
 }
 
-BLOCKQUOTE OL LI {
+blockquote ol li {
   margin-left: -1em;
 }
 
-PRE.command, PRE.example {
+pre.command, pre.example {
   background: #eee;
   margin: 0 36pt;
   padding: 10px;
 }
 
-P.compact {
+p.compact {
   margin: 0;
 }
 
-P.example {
+p.example {
   font-style: italic;
   margin-left: 36pt;
 }
 
-DL.man DD {
+dl.man dd {
   margin-left: 5em;
 }
 
-DL.man DT {
+dl.man dt {
   margin-left: 0;
 }
 
-PRE.man {
+pre.man {
   margin: 0;
 }
 
-PRE.command EM, PRE.example EM {
+pre.command em, pre.example em {
   font-family: lucida grande, geneva, helvetica, arial, sans-serif;
 }
 
-P.command {
+p.command {
   font-family: monaco, courier, monospace;
   margin-left: 36pt;
 }
 
-P.formula {
+p.formula {
   font-style: italic;
   margin-left: 36pt;
 }
 
-A IMG {
+a img {
   border: none;
 }
 
-A:link:hover IMG {
+a:link:hover img {
   background: #f0f0f0;
   border-radius: 10px;
   -moz-border-radius: 10px;
 }
 
-A:link, A:visited {
+a:link, a:visited {
   font-weight: inherit;
   text-decoration: none;
 }
 
-A:link:hover, A:visited:hover, A:active {
+a:link:hover, a:visited:hover, a:active {
   text-decoration: underline;
 }
 
-SUB, SUP {
+sub, sup {
   font-size: 50%;
 }
 
-TR.data, TD.data, TR.data TD {
+tr.data, td.data, tr.data td {
   margin-top: 10pt;
   padding: 5pt;
   border-bottom: solid 1pt #999999;
 }
 
-TR.data TH {
+tr.data th {
   border-bottom: solid 1pt #999999;
   padding-top: 10pt;
   padding-left: 5pt;
   text-align: left;
 }
 
-DIV.table TABLE {
+div.table table {
   border: solid thin #999999;
   border-collapse: collapse;
   border-spacing: 0;
@@ -115,7 +115,7 @@ DIV.table TABLE {
   margin-right: auto;
 }
 
-DIV.table CAPTION {
+div.table caption {
   caption-side: top;
   font-size: 120%;
   font-style: italic;
@@ -124,23 +124,23 @@ DIV.table CAPTION {
   margin-right: auto;
 }
 
-DIV.table TABLE TD {
+div.table table td {
   border: solid thin #cccccc;
   padding: 5pt 10pt 0;
 }
 
-DIV.table TABLE TH {
+div.table table th {
   background: #cccccc;
   border: none;
   border-bottom: solid thin #999999;
 }
 
-DIV.figure TABLE {
+div.figure table {
   margin-left: auto;
   margin-right: auto;
 }
 
-DIV.figure CAPTION {
+div.figure caption {
   caption-side: bottom;
   font-size: 120%;
   font-style: italic;
@@ -149,21 +149,21 @@ DIV.figure CAPTION {
   margin-right: auto;
 }
 
-TH.label {
+th.label {
   text-align: right;
   vertical-align: top;
 }
 
-TH.sublabel {
+th.sublabel {
   text-align: right;
   font-weight: normal;
 }
 
-HR {
+hr {
   border: solid thin;
 }
 
-SPAN.info {
+span.info {
   background: black;
   border: thin solid black;
   color: white;
@@ -173,41 +173,41 @@ SPAN.info {
   white-space: nowrap;
 }
 
-H2 SPAN.info, H3 SPAN.info, H4 SPAN.info {
+h2 span.info, h3 span.info, h4 span.info {
   float: right;
   font-size: 100%;
 }
 
-H1.title {
+h1.title {
 }
 
-H2.title, H3.title {
+h2.title, h3.title {
   border-bottom: solid 2pt #000000;
 }
 
-DIV.indent, TABLE.indent {
+div.indent, table.indent {
   margin-top: 2em;
   margin-left: auto;
   margin-right: auto;
   width: 90%;
 }
 
-TABLE.indent {
+table.indent {
   border-collapse: collapse;
 }
 
-TABLE.indent TD, TABLE.indent TH {
+table.indent td, table.indent th {
   padding: 0;
 }
 
-TABLE.list {
+table.list {
   border-collapse: collapse;
   margin-left: auto;
   margin-right: auto;
   width: 90%;
 }
 
-TABLE.list TH {
+table.list th {
   background: white;
   border-bottom: solid thin #cccccc;
   color: #444444;
@@ -218,57 +218,57 @@ TABLE.list TH {
   white-space: nowrap;
 }
 
-TABLE.list TH A {
+table.list th a {
   color: #4444cc;
 }
 
-TABLE.list TD {
+table.list td {
   border-bottom: solid thin #eeeeee;
   padding-top: 5pt;
   padding-left: 5pt;
 }
 
-TABLE.list TR:nth-child(even) {
+table.list tr:nth-child(even) {
   background: #f8f8f8;
 }
 
-TABLE.list TR:nth-child(odd) {
+table.list tr:nth-child(odd) {
   background: #f4f4f4;
 }
 
-DT {
+dt {
   margin-left: 36pt;
   margin-top: 12pt;
 }
 
-DD {
+dd {
   margin-left: 54pt;
 }
 
-DL.category DT {
+dl.category dt {
   font-weight: bold;
 }
 
-P.summary {
+p.summary {
   margin-left: 36pt;
   font-family: monaco, courier, monospace;
 }
 
-DIV.summary TABLE {
+div.summary table {
   border: solid thin #999999;
   border-collapse: collapse;
   border-spacing: 0;
   margin: 10px;
 }
 
-DIV.summary TABLE TD, DIV.summary TABLE TH {
+div.summary table td, div.summary table th {
   border: solid thin #999999;
   padding: 5px;
   text-align: left;
   vertical-align: top;
 }
 
-DIV.summary TABLE THEAD TH {
+div.summary table thead th {
   background: #eeeeee;
 }
 
@@ -353,7 +353,7 @@ h1, h2, h3, h4, h5, h6 {
 blockquote {
   border: solid thin gray;
   box-shadow: 3px 3px 5px rgba(0,0,0,0.5);
-  padding: 10px 10px 0px;
+  padding: 10px 10px 0;
   page-break-inside: avoid;
 }
 p code, li code, p.code, pre, ul.code li {
@@ -389,8 +389,8 @@ h2 span.info, h3 span.info, h4 span.info
   padding: 3px 6px;
 }
 h2.title span.info, h3.title span.info, h4.title span.info {
-  border-bottom-left-radius: 0px;
-  border-bottom-right-radius: 0px;
+  border-bottom-left-radius: 0;
+  border-bottom-right-radius: 0;
 }
 h2.title span.info {
   padding: 4px 6px;
@@ -414,7 +414,8 @@ table.list {
   width: 100%;
 }
 table.list tr:nth-child(even) {
-  background: rgba(127,127,127,0.1);]n}
+  background: rgba(127,127,127,0.1);
+}
 table.list th {
   border-right: 2px solid gray;
   font-family: monospace;
diff -pruN 2.3.3-3/doc/help/man-cups-files.conf.html 2.3.3op1-3/doc/help/man-cups-files.conf.html
--- 2.3.3-3/doc/help/man-cups-files.conf.html	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/doc/help/man-cups-files.conf.html	2020-11-27 14:25:26.000000000 +0000
@@ -98,6 +98,10 @@ The <i>kind</i> strings are:
 <dt><a name="Group"></a><b>Group </b><i>group-name-or-number</i>
 <dd style="margin-left: 5.0em">Specifies the group name or ID that will be used when executing external programs.
 The default group is operating system specific but is usually "lp" or "nobody".
+</div>
+<dt><a name="LogFileGroup"></a><b>LogFileGroup </b><i>group-name-or-number</i>
+<dd style="margin-left: 5.0em">Specifies the group name or ID that will be used for log files.
+The default group is operating system specific but is usually "lp" or "nobody".
 <dt><a name="LogFilePerm"></a><b>LogFilePerm </b><i>mode</i>
 <dd style="margin-left: 5.0em">Specifies the permissions of all log files that the scheduler writes.
 The default is "0644".
@@ -150,7 +154,6 @@ The default is "/var/run/cups" or "/etc/
 <dd style="margin-left: 5.0em">Specifies whether the scheduler calls
 <b>fsync</b>(2)
 after writing configuration or state files.
-The default is "No".
 <dt><a name="SystemGroup"></a><b>SystemGroup </b><i>group-name </i>[ ... <i>group-name</i> ]
 <dd style="margin-left: 5.0em">Specifies the group(s) to use for <i>@SYSTEM</i> group authentication.
 The default contains "admin", "lpadmin", "root", "sys", and/or "system".
@@ -209,6 +212,7 @@ command is used instead.
 <b>subscriptions.conf</b>(5),
 CUPS Online Help (<a href="http://localhost:631/help">http://localhost:631/help</a>)
 <h2 class="title"><a name="COPYRIGHT">Copyright</a></h2>
+Copyright &copy; 2020 by Michael R Sweet
 Copyright &copy; 2007-2019 by Apple Inc.
 
 </body>
diff -pruN 2.3.3-3/doc/help/man-cups-lpd.html 2.3.3op1-3/doc/help/man-cups-lpd.html
--- 2.3.3-3/doc/help/man-cups-lpd.html	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/doc/help/man-cups-lpd.html	2020-11-27 14:25:26.000000000 +0000
@@ -90,9 +90,6 @@ mini-server:
         -o document-format=application/octet-stream
 
 </pre>
-<p><i>Note:</i> If you are using Solaris 10 or higher, you must run the
-<b>inetdconv</b>(1m)
-program to register the changes to the <i>inetd.conf</i> file.
 <p>CUPS includes configuration files for
 <b>launchd</b>(8),
 <b>systemd</b>(8),
@@ -104,13 +101,13 @@ service using the corresponding control
 <h2 class="title"><a name="SEE_ALSO">See Also</a></h2>
 <b>cups</b>(1),
 <b>cupsd</b>(8),
-<b>inetconv</b>(1m),
 <b>inetd</b>(8),
 <b>launchd</b>(8),
 <b>xinetd</b>(8),
 CUPS Online Help (<a href="http://localhost:631/help)">http://localhost:631/help)</a>,
 RFC 2569
 <h2 class="title"><a name="COPYRIGHT">Copyright</a></h2>
+Copyright &copy; 2020 by Michael R Sweet
 Copyright &copy; 2007-2019 by Apple Inc.
 
 </body>
diff -pruN 2.3.3-3/doc/help/man-ppdc.html 2.3.3op1-3/doc/help/man-ppdc.html
--- 2.3.3-3/doc/help/man-ppdc.html	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/doc/help/man-ppdc.html	2020-11-27 14:25:26.000000000 +0000
@@ -63,7 +63,7 @@ The default output directory is "ppd".
 The default language is "en" (English).
 Separate multiple languages with commas, for example "de_DE,en_UK,es_ES,es_MX,es_US,fr_CA,fr_FR,it_IT" will create PPD files with German, UK English, Spanish (Spain, Mexico, and US), French (France and Canada), and Italian languages in each file.
 <dt><b>-m</b>
-<dd style="margin-left: 5.0em">Specifies that the output filename should be based on the ModelName value instead of FileName or PCFilenName.
+<dd style="margin-left: 5.0em">Specifies that the output filename should be based on the ModelName value instead of FileName or PCFileName.
 <dt><b>-t</b>
 <dd style="margin-left: 5.0em">Specifies that PPD files should be tested instead of generated.
 <dt><b>-v</b>
diff -pruN 2.3.3-3/filter/rastertoepson.c 2.3.3op1-3/filter/rastertoepson.c
--- 2.3.3-3/filter/rastertoepson.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/filter/rastertoepson.c	2020-11-27 14:25:26.000000000 +0000
@@ -955,7 +955,7 @@ OutputRows(
   * Clear the buffer...
   */
 
-  memset(LineBuffers[row], 0, header->cupsWidth * DotBytes);
+  memset(LineBuffers[row], 0, (size_t)header->cupsWidth * (size_t)DotBytes);
 }
 
 
diff -pruN 2.3.3-3/filter/rastertohp.c 2.3.3op1-3/filter/rastertohp.c
--- 2.3.3-3/filter/rastertohp.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/filter/rastertohp.c	2020-11-27 14:25:26.000000000 +0000
@@ -332,7 +332,7 @@ StartPage(ppd_file_t         *ppd,	/* I
     Planes[plane] = Planes[0] + plane * header->cupsBytesPerLine / NumPlanes;
 
   if (ColorBits > 1)
-    BitBuffer = malloc(ColorBits * ((header->cupsWidth + 7) / 8));
+    BitBuffer = malloc((size_t)ColorBits * (((size_t)header->cupsWidth + 7) / 8));
   else
     BitBuffer = NULL;
 
diff -pruN 2.3.3-3/filter/rastertopwg.c 2.3.3op1-3/filter/rastertopwg.c
--- 2.3.3-3/filter/rastertopwg.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/filter/rastertopwg.c	2020-11-27 14:25:26.000000000 +0000
@@ -41,8 +41,10 @@ main(int  argc,				/* I - Number of comm
 			page_top,	/* Top margin */
 			page_bottom,	/* Bottom margin */
 			page_left,	/* Left margin */
+			page_right,	/* Right margin */
 			linesize,	/* Bytes per line */
 			lineoffset;	/* Offset into line */
+  int			tmp;
   unsigned char		white;		/* White pixel */
   ppd_file_t		*ppd;		/* PPD file */
   ppd_attr_t		*back;		/* cupsBackSide attribute */
@@ -120,14 +122,30 @@ main(int  argc,				/* I - Number of comm
     fprintf(stderr, "PAGE: %d %d\n", page, inheader.NumCopies);
 
     page_width  = (unsigned)(inheader.cupsPageSize[0] * inheader.HWResolution[0] / 72.0);
+    if (page_width < inheader.cupsWidth &&
+	page_width >= inheader.cupsWidth - 1)
+      page_width = (unsigned)inheader.cupsWidth;
     page_height = (unsigned)(inheader.cupsPageSize[1] * inheader.HWResolution[1] / 72.0);
+    if (page_height < inheader.cupsHeight &&
+	page_height >= inheader.cupsHeight - 1)
+      page_height = (unsigned)inheader.cupsHeight;
     page_left   = (unsigned)(inheader.cupsImagingBBox[0] * inheader.HWResolution[0] / 72.0);
     page_bottom = (unsigned)(inheader.cupsImagingBBox[1] * inheader.HWResolution[1] / 72.0);
-    page_top    = page_height - page_bottom - inheader.cupsHeight;
+    tmp        = (int)(page_height - page_bottom - inheader.cupsHeight);
+    if (tmp < 0 && tmp >= -1) /* Rounding error */
+      page_top = 0;
+    else
+      page_top = (unsigned)tmp;
+    tmp        = (int)(page_width - page_left - inheader.cupsWidth);
+    if (tmp < 0 && tmp >= -1) /* Rounding error */
+      page_right = 0;
+    else
+      page_right = (unsigned)tmp;
     linesize    = (page_width * inheader.cupsBitsPerPixel + 7) / 8;
     lineoffset  = page_left * inheader.cupsBitsPerPixel / 8; /* Round down */
 
-    if (page_left > page_width || page_top > page_height || page_bottom > page_height)
+    fprintf(stderr, "DEBUG: In pixels: Width: %u  Height: %u  Left: %u  Right:  %u  Top: %u  Bottom: %u\n", page_width, page_height, page_left, page_right, page_top, page_bottom);
+    if (page_left > page_width || page_top > page_height || page_bottom > page_height || page_right > page_width)
     {
       _cupsLangPrintFilter(stderr, "ERROR", _("Unsupported raster data."));
       fprintf(stderr, "DEBUG: Bad bottom/left/top margin on page %d.\n", page);
@@ -259,8 +277,7 @@ main(int  argc,				/* I - Number of comm
       }
     }
 
-    if (inheader.cupsPageSizeName[0] &&
-        (pwg_size = _ppdCacheGetSize(cache, inheader.cupsPageSizeName)) != NULL)
+    if (inheader.cupsPageSizeName[0] && (pwg_size = _ppdCacheGetSize(cache, inheader.cupsPageSizeName)) != NULL && pwg_size->map.pwg)
     {
       strlcpy(outheader.cupsPageSizeName, pwg_size->map.pwg,
 	      sizeof(outheader.cupsPageSizeName));
@@ -291,8 +308,7 @@ main(int  argc,				/* I - Number of comm
 	  outheader.cupsInteger[1] = ~0U;/* CrossFeedTransform */
 	  outheader.cupsInteger[2] = 1;	/* FeedTransform */
 
-	  outheader.cupsInteger[3] = page_width - page_left -
-	                             inheader.cupsWidth;
+	  outheader.cupsInteger[3] = page_right;
 					/* ImageBoxLeft */
 	  outheader.cupsInteger[4] = page_top;
 					/* ImageBoxTop */
@@ -355,8 +371,7 @@ main(int  argc,				/* I - Number of comm
 	  outheader.cupsInteger[1] = ~0U;/* CrossFeedTransform */
 	  outheader.cupsInteger[2] = ~0U;/* FeedTransform */
 
-	  outheader.cupsInteger[3] = page_width - page_left -
-	                             inheader.cupsWidth;
+	  outheader.cupsInteger[3] = page_right;
 					/* ImageBoxLeft */
 	  outheader.cupsInteger[4] = page_bottom;
 					/* ImageBoxTop */
diff -pruN 2.3.3-3/INSTALL.md 2.3.3op1-3/INSTALL.md
--- 2.3.3-3/INSTALL.md	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/INSTALL.md	2020-11-27 14:25:26.000000000 +0000
@@ -1,5 +1,5 @@
-INSTALL - CUPS v2.3.3 - 2020-04-24
-==================================
+INSTALL - CUPS v2.3.3op1 - 2020-11-27
+=====================================
 
 This file describes how to compile and install CUPS from source code. For more
 information on CUPS see the file called "README.md".  A complete change log can
@@ -130,11 +130,11 @@ TESTING THE SOFTWARE
 Aside from the built-in unit tests, CUPS includes an automated test framework
 for testing the entire printing system.  To run the tests, just type:
 
-    make check ENTER
+    make test ENTER
 
 or if you have FreeBSD, NetBSD, or OpenBSD type:
 
-    gmake check ENTER
+    gmake test ENTER
 
 The test framework runs a copy of the CUPS scheduler (cupsd) on port 8631 in
 /tmp/cups-$USER and produces a nice HTML report of the results.
diff -pruN 2.3.3-3/locale/checkpo.c 2.3.3op1-3/locale/checkpo.c
--- 2.3.3-3/locale/checkpo.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/locale/checkpo.c	2020-11-27 14:25:26.000000000 +0000
@@ -321,7 +321,7 @@ abbreviate(const char *s,		/* I - String
       if (bufsize < 4)
         break;
 
-      sprintf(bufptr, "\\%03o", *s);
+      snprintf(bufptr, bufsize, "\\%03o", *s);
       bufptr += 4;
       bufsize -= 4;
     }
diff -pruN 2.3.3-3/Makefile 2.3.3op1-3/Makefile
--- 2.3.3-3/Makefile	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/Makefile	2020-11-27 14:25:26.000000000 +0000
@@ -1,6 +1,7 @@
 #
 # Top-level Makefile for CUPS.
 #
+# Copyright © 2020 by Michael R Sweet
 # Copyright © 2007-2019 by Apple Inc.
 # Copyright © 1997-2007 by Easy Software Products, all rights reserved.
 #
@@ -230,16 +231,16 @@ uninstall:
 # Run the test suite...
 #
 
-test:	all unittests
-	echo Running CUPS test suite...
+testserver:	all unittests
+	echo Running CUPS test server...
 	cd test; ./run-stp-tests.sh $(TESTOPTIONS)
 
 
-check:	all unittests
-	echo Running CUPS test suite with defaults...
+check test:	all unittests
+	echo Running CUPS test suite...
 	cd test; ./run-stp-tests.sh 1 0 n n
 
-debugcheck:	all unittests
+debugcheck debugtest:	all unittests
 	echo Running CUPS test suite with debug printfs...
 	cd test; ./run-stp-tests.sh 1 0 n y
 
diff -pruN 2.3.3-3/man/cups-files.conf.5 2.3.3op1-3/man/cups-files.conf.5
--- 2.3.3-3/man/cups-files.conf.5	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/man/cups-files.conf.5	2020-11-27 14:25:26.000000000 +0000
@@ -1,13 +1,14 @@
 .\"
 .\" cups-files.conf man page for CUPS.
 .\"
+.\" Copyright © 2020 by Michael R Sweet
 .\" Copyright © 2007-2019 by Apple Inc.
 .\" Copyright © 1997-2006 by Easy Software Products.
 .\"
 .\" Licensed under Apache License v2.0.  See the file "LICENSE" for more
 .\" information.
 .\"
-.TH cups-files.conf 5 "CUPS" "26 April 2019" "Apple Inc."
+.TH cups-files.conf 5 "CUPS" "14 November 2020" "Apple Inc."
 .SH NAME
 cups\-files.conf \- file and directory configuration file for cups
 .SH DESCRIPTION
@@ -131,6 +132,12 @@ Bad startup file permissions are fatal,
 \fBGroup \fIgroup-name-or-number\fR
 Specifies the group name or ID that will be used when executing external programs.
 The default group is operating system specific but is usually "lp" or "nobody".
+.RE
+.\"#LogFileGroup
+.TP 5
+\fBLogFileGroup \fIgroup-name-or-number\fR
+Specifies the group name or ID that will be used for log files.
+The default group is operating system specific but is usually "lp" or "nobody".
 .\"#LogFilePerm
 .TP 5
 \fBLogFilePerm \fImode\fR
@@ -211,7 +218,6 @@ The default is "/var/run/cups" or "/etc/
 Specifies whether the scheduler calls
 .BR fsync (2)
 after writing configuration or state files.
-The default is "No".
 .\"#SystemGroup
 .TP 5
 \fBSystemGroup \fIgroup-name \fR[ ... \fIgroup-name\fR ]
@@ -288,4 +294,5 @@ command is used instead.
 .BR subscriptions.conf (5),
 CUPS Online Help (http://localhost:631/help)
 .SH COPYRIGHT
+Copyright \[co] 2020 by Michael R Sweet
 Copyright \[co] 2007-2019 by Apple Inc.
diff -pruN 2.3.3-3/man/cups-lpd.8 2.3.3op1-3/man/cups-lpd.8
--- 2.3.3-3/man/cups-lpd.8	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/man/cups-lpd.8	2020-11-27 14:25:26.000000000 +0000
@@ -1,13 +1,14 @@
 .\"
 .\" cups-lpd man page for CUPS.
 .\"
+.\" Copyright © 2020 by Michael R Sweet
 .\" Copyright © 2007-2019 by Apple Inc.
 .\" Copyright © 1997-2006 by Easy Software Products.
 .\"
 .\" Licensed under Apache License v2.0.  See the file "LICENSE" for more
 .\" information.
 .\"
-.TH cups-lpd 8 "CUPS" "26 April 2019" "Apple Inc."
+.TH cups-lpd 8 "CUPS" "14 November 2020" "Apple Inc."
 .SH NAME
 cups-lpd \- receive print jobs and report printer status to lpd clients (deprecated)
 .SH SYNOPSIS
@@ -96,10 +97,6 @@ mini-server:
 
 .fi
 .LP
-\fINote:\fR If you are using Solaris 10 or higher, you must run the
-.BR inetdconv (1m)
-program to register the changes to the \fIinetd.conf\fR file.
-.LP
 CUPS includes configuration files for
 .BR launchd (8),
 .BR systemd (8),
@@ -111,11 +108,11 @@ service using the corresponding control
 .SH SEE ALSO
 .BR cups (1),
 .BR cupsd (8),
-.BR inetconv (1m),
 .BR inetd (8),
 .BR launchd (8),
 .BR xinetd (8),
 CUPS Online Help (http://localhost:631/help),
 RFC 2569
 .SH COPYRIGHT
+Copyright \[co] 2020 by Michael R Sweet
 Copyright \[co] 2007-2019 by Apple Inc.
diff -pruN 2.3.3-3/man/ppdc.1 2.3.3op1-3/man/ppdc.1
--- 2.3.3-3/man/ppdc.1	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/man/ppdc.1	2020-11-27 14:25:26.000000000 +0000
@@ -7,7 +7,7 @@
 .\" Licensed under Apache License v2.0.  See the file "LICENSE" for more
 .\" information.
 .\"
-.TH ppdc 1 "CUPS" "26 April 2019" "Apple Inc."
+.TH ppdc 1 "CUPS" "28 October 2020" "Apple Inc."
 .SH NAME
 ppdc \- cups ppd compiler (deprecated)
 .SH SYNOPSIS
@@ -69,7 +69,7 @@ The default language is "en" (English).
 Separate multiple languages with commas, for example "de_DE,en_UK,es_ES,es_MX,es_US,fr_CA,fr_FR,it_IT" will create PPD files with German, UK English, Spanish (Spain, Mexico, and US), French (France and Canada), and Italian languages in each file.
 .TP 5
 .B \-m
-Specifies that the output filename should be based on the ModelName value instead of FileName or PCFilenName.
+Specifies that the output filename should be based on the ModelName value instead of FileName or PCFileName.
 .TP 5
 .B \-t
 Specifies that PPD files should be tested instead of generated.
diff -pruN 2.3.3-3/packaging/cups.list.in 2.3.3op1-3/packaging/cups.list.in
--- 2.3.3-3/packaging/cups.list.in	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/packaging/cups.list.in	2020-11-27 14:25:26.000000000 +0000
@@ -1,6 +1,7 @@
 #
 # ESP Package Manager (EPM) file list for CUPS.
 #
+# Copyright © 2020 by Michael R Sweet
 # Copyright © 2007-2019 by Apple Inc.
 # Copyright © 1997-2007 by Easy Software Products, all rights reserved.
 #
@@ -10,8 +11,8 @@
 
 # Product information
 %product CUPS
-%copyright 2007-2019 by Apple Inc.
-%vendor Apple Inc.
+%copyright 2020 by Michael R Sweet, 2007-2019 by Apple Inc.
+%vendor OpenPrinting
 #%license LICENSE
 %readme LICENSE
 %format rpm
@@ -20,8 +21,9 @@
 %format !rpm
 %version @CUPS_VERSION@
 %format all
-%description CUPS is the standards-based, open source printing system developed by
-%description Apple Inc. for macOS® and other UNIX®-like operating systems.
+%description CUPS is the standards-based, open source printing system developed
+%description by Apple Inc. and maintained by OpenPrinting for macOS® and other
+%description UNIX®-like operating systems.
 
 %format rpm
 %provides lpd
diff -pruN 2.3.3-3/packaging/cups.spec 2.3.3op1-3/packaging/cups.spec
--- 2.3.3-3/packaging/cups.spec	2020-04-27 23:18:04.000000000 +0000
+++ 2.3.3op1-3/packaging/cups.spec	2020-11-27 14:25:35.000000000 +0000
@@ -3,6 +3,7 @@
 #
 # Original version by Jason McMullan <jmcc@ontv.com>.
 #
+# Copyright © 2020 by Michael R Sweet
 # Copyright © 2007-2019 by Apple Inc.
 # Copyright © 1999-2007 by Easy Software Products, all rights reserved.
 #
@@ -40,15 +41,15 @@
 
 Summary: CUPS
 Name: cups
-Version: 2.3.3
+Version: 2.3.3op1
 Release: 0
 Epoch: 1
 License: GPL
 Group: System Environment/Daemons
-Source: https://github.com/apple/cups/releases/download/v2.3.3/cups-2.3.3-source.tar.gz
+Source: https://github.com/openprinting/cups/releases/download/v2.3.3op1/cups-2.3.3op1-source.tar.gz
 Url: http://www.cups.org
 Packager: Anonymous <anonymous@example.com>
-Vendor: Example Corp
+Vendor: OpenPrinting
 
 # Package names are as defined for Red Hat (and clone) distributions
 BuildRequires: gnutls-devel, pam-devel
@@ -97,7 +98,8 @@ Requires: %{name} = %{epoch}:%{version}
 
 %description
 CUPS is the standards-based, open source printing system developed by
-Apple Inc. for macOS® and other UNIX®-like operating systems.
+Apple Inc. and maintained by OpenPrinting for macOS® and other UNIX®-like
+operating systems.
 
 %description devel
 This package provides the CUPS headers and development environment.
@@ -126,11 +128,11 @@ rm -rf $RPM_BUILD_ROOT/usr/share/cups/ba
 
 %post
 %if %{?_with_systemd:1}%{!?_with_systemd:0}
-/bin/systemctl enable org.cups.cupsd.service
+/bin/systemctl enable cups.service
 
 if test $1 -ge 1; then
-	/bin/systemctl stop org.cups.cupsd.service
-	/bin/systemctl start org.cups.cupsd.service
+	/bin/systemctl stop cups.service
+	/bin/systemctl start cups.service
 fi
 
 %else
@@ -150,8 +152,8 @@ fi
 %preun
 %if %{?_with_systemd:1}%{!?_with_systemd:0}
 if test $1 -ge 1; then
-	/bin/systemctl stop org.cups.cupsd.service
-	/bin/systemctl disable org.cups.cupsd.service
+	/bin/systemctl stop cups.service
+	/bin/systemctl disable cups.service
 fi
 
 %else
@@ -164,8 +166,8 @@ fi
 %postun
 %if %{?_with_systemd:1}%{!?_with_systemd:0}
 if test $1 -ge 1; then
-	/bin/systemctl stop org.cups.cupsd.service
-	/bin/systemctl start org.cups.cupsd.service
+	/bin/systemctl stop cups.service
+	/bin/systemctl start cups.service
 fi
 
 %else
@@ -203,7 +205,7 @@ rm -rf $RPM_BUILD_ROOT
 
 %if %{?_with_systemd:1}%{!?_with_systemd:0}
 # SystemD
-/usr/lib/systemd/system/org.cups.cupsd.*
+/usr/lib/systemd/system/cups.*
 
 %else
 # Legacy init support on Linux
@@ -425,7 +427,7 @@ rm -rf $RPM_BUILD_ROOT
 %defattr(-,root,root)
 %if %{?_with_systemd:1}%{!?_with_systemd:0}
 # SystemD
-/usr/lib/systemd/system/org.cups.cups-lpd*
+/usr/lib/systemd/system/cups-lpd*
 %else
 # Legacy xinetd
 /etc/xinetd.d/cups-lpd
diff -pruN 2.3.3-3/packaging/cups.spec.in 2.3.3op1-3/packaging/cups.spec.in
--- 2.3.3-3/packaging/cups.spec.in	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/packaging/cups.spec.in	2020-11-27 14:25:26.000000000 +0000
@@ -3,6 +3,7 @@
 #
 # Original version by Jason McMullan <jmcc@ontv.com>.
 #
+# Copyright © 2020 by Michael R Sweet
 # Copyright © 2007-2019 by Apple Inc.
 # Copyright © 1999-2007 by Easy Software Products, all rights reserved.
 #
@@ -48,7 +49,7 @@ Group: System Environment/Daemons
 Source: https://github.com/apple/cups/releases/download/v%{version}/cups-%{version}-source.tar.gz
 Url: http://www.cups.org
 Packager: Anonymous <anonymous@example.com>
-Vendor: Example Corp
+Vendor: OpenPrinting
 
 # Package names are as defined for Red Hat (and clone) distributions
 BuildRequires: gnutls-devel, pam-devel
@@ -97,7 +98,8 @@ Requires: %{name} = %{epoch}:%{version}
 
 %description
 CUPS is the standards-based, open source printing system developed by
-Apple Inc. for macOS® and other UNIX®-like operating systems.
+Apple Inc. and maintained by OpenPrinting for macOS® and other UNIX®-like
+operating systems.
 
 %description devel
 This package provides the CUPS headers and development environment.
@@ -126,11 +128,11 @@ rm -rf $RPM_BUILD_ROOT/usr/share/cups/ba
 
 %post
 %if %{?_with_systemd:1}%{!?_with_systemd:0}
-/bin/systemctl enable org.cups.cupsd.service
+/bin/systemctl enable cups.service
 
 if test $1 -ge 1; then
-	/bin/systemctl stop org.cups.cupsd.service
-	/bin/systemctl start org.cups.cupsd.service
+	/bin/systemctl stop cups.service
+	/bin/systemctl start cups.service
 fi
 
 %else
@@ -150,8 +152,8 @@ fi
 %preun
 %if %{?_with_systemd:1}%{!?_with_systemd:0}
 if test $1 -ge 1; then
-	/bin/systemctl stop org.cups.cupsd.service
-	/bin/systemctl disable org.cups.cupsd.service
+	/bin/systemctl stop cups.service
+	/bin/systemctl disable cups.service
 fi
 
 %else
@@ -164,8 +166,8 @@ fi
 %postun
 %if %{?_with_systemd:1}%{!?_with_systemd:0}
 if test $1 -ge 1; then
-	/bin/systemctl stop org.cups.cupsd.service
-	/bin/systemctl start org.cups.cupsd.service
+	/bin/systemctl stop cups.service
+	/bin/systemctl start cups.service
 fi
 
 %else
@@ -203,7 +205,7 @@ rm -rf $RPM_BUILD_ROOT
 
 %if %{?_with_systemd:1}%{!?_with_systemd:0}
 # SystemD
-/usr/lib/systemd/system/org.cups.cupsd.*
+/usr/lib/systemd/system/cups.*
 
 %else
 # Legacy init support on Linux
@@ -425,7 +427,7 @@ rm -rf $RPM_BUILD_ROOT
 %defattr(-,root,root)
 %if %{?_with_systemd:1}%{!?_with_systemd:0}
 # SystemD
-/usr/lib/systemd/system/org.cups.cups-lpd*
+/usr/lib/systemd/system/cups-lpd*
 %else
 # Legacy xinetd
 /etc/xinetd.d/cups-lpd
diff -pruN 2.3.3-3/ppdc/ppdc-import.cxx 2.3.3op1-3/ppdc/ppdc-import.cxx
--- 2.3.3-3/ppdc/ppdc-import.cxx	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/ppdc/ppdc-import.cxx	2020-11-27 14:25:26.000000000 +0000
@@ -323,5 +323,8 @@ ppdcSource::import_ppd(const char *f)	//
     }
   }
 
+  if (ppd)
+    ppdClose(ppd);
+
   return (1);
 }
diff -pruN 2.3.3-3/README.md 2.3.3op1-3/README.md
--- 2.3.3-3/README.md	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/README.md	2020-11-27 14:25:26.000000000 +0000
@@ -1,5 +1,15 @@
-README - CUPS v2.3.3 - 2020-04-24
-=================================
+README - CUPS v2.3.3op1 - 2020-11-27
+====================================
+
+![Version](https://img.shields.io/github/v/release/openprinting/cups?include_prereleases)
+![Apache 2.0](https://img.shields.io/github/license/openprinting/cups)
+[![Build Status](https://travis-ci.org/openprinting/cups.svg?branch=master)](https://travis-ci.org/github/openprinting/cups)
+
+> *Note:* This version of CUPS is being maintained by the OpenPrinting
+> organization.  It tracks the current Apple CUPS sources and includes common
+> changes and bug fixes for the various Linux distributions and other UNIX®-like
+> operating systems.
+
 
 INTRODUCTION
 ------------
diff -pruN 2.3.3-3/scheduler/classes.c 2.3.3op1-3/scheduler/classes.c
--- 2.3.3-3/scheduler/classes.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/scheduler/classes.c	2020-11-27 14:25:26.000000000 +0000
@@ -688,7 +688,7 @@ cupsdSaveAllClasses(void)
   strftime(temp, sizeof(temp) - 1, "%Y-%m-%d %H:%M", &curdate);
 
   cupsFilePuts(fp, "# Class configuration file for " CUPS_SVERSION "\n");
-  cupsFilePrintf(fp, "# Written by cupsd on %s\n", temp);
+  cupsFilePrintf(fp, "# Written by cupsd\n");
   cupsFilePuts(fp, "# DO NOT EDIT THIS FILE WHEN CUPSD IS RUNNING\n");
 
  /*
diff -pruN 2.3.3-3/scheduler/client.c 2.3.3op1-3/scheduler/client.c
--- 2.3.3-3/scheduler/client.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/scheduler/client.c	2020-11-27 14:25:26.000000000 +0000
@@ -2789,6 +2789,25 @@ get_file(cupsd_client_t *con,		/* I  - C
 
     perm_check = 0;
   }
+  else if (!strcmp(con->uri, "/admin/conf/cupsd.conf"))
+  {
+    strlcpy(filename, ConfigurationFile, len);
+
+    perm_check = 0;
+  }
+  else if (!strncmp(con->uri, "/admin/log/", 11))
+  {
+    if (!strncmp(con->uri + 11, "access_log", 10) && AccessLog[0] == '/')
+      strlcpy(filename, AccessLog, len);
+    else if (!strncmp(con->uri + 11, "error_log", 9) && ErrorLog[0] == '/')
+      strlcpy(filename, ErrorLog, len);
+    else if (!strncmp(con->uri + 11, "page_log", 8) && PageLog[0] == '/')
+      strlcpy(filename, PageLog, len);
+    else
+      return (NULL);
+
+    perm_check = 0;
+  }
   else if (!strncmp(con->uri, "/admin", 6) || !strncmp(con->uri, "/classes", 8) || !strncmp(con->uri, "/jobs", 5) || !strncmp(con->uri, "/printers", 9))
   {
    /*
@@ -2822,25 +2841,6 @@ get_file(cupsd_client_t *con,		/* I  - C
 
     perm_check = 0;
   }
-  else if (!strcmp(con->uri, "/admin/conf/cupsd.conf"))
-  {
-    strlcpy(filename, ConfigurationFile, len);
-
-    perm_check = 0;
-  }
-  else if (!strncmp(con->uri, "/admin/log/", 11))
-  {
-    if (!strncmp(con->uri + 11, "access_log", 10) && AccessLog[0] == '/')
-      strlcpy(filename, AccessLog, len);
-    else if (!strncmp(con->uri + 11, "error_log", 9) && ErrorLog[0] == '/')
-      strlcpy(filename, ErrorLog, len);
-    else if (!strncmp(con->uri + 11, "page_log", 8) && PageLog[0] == '/')
-      strlcpy(filename, PageLog, len);
-    else
-      return (NULL);
-
-    perm_check = 0;
-  }
   else if (con->language)
   {
     snprintf(language, sizeof(language), "/%s", con->language->language);
@@ -3471,8 +3471,7 @@ pipe_command(cupsd_client_t *con,	/* I -
   }
   else
   {
-    sprintf(content_length, "CONTENT_LENGTH=" CUPS_LLFMT,
-            CUPS_LLCAST con->bytes);
+    snprintf(content_length, sizeof(content_length), "CONTENT_LENGTH=" CUPS_LLFMT, CUPS_LLCAST con->bytes);
     snprintf(content_type, sizeof(content_type), "CONTENT_TYPE=%s",
              httpGetField(con->http, HTTP_FIELD_CONTENT_TYPE));
 
diff -pruN 2.3.3-3/scheduler/conf.c 2.3.3op1-3/scheduler/conf.c
--- 2.3.3-3/scheduler/conf.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/scheduler/conf.c	2020-11-27 14:25:26.000000000 +0000
@@ -723,6 +723,7 @@ cupsdReadConfiguration(void)
   ListenBackLog            = SOMAXCONN;
   LogDebugHistory          = 200;
   LogFilePerm              = CUPS_DEFAULT_LOG_FILE_PERM;
+  LogFileGroup             = Group;
   LogLevel                 = CUPSD_LOG_WARN;
   LogTimeFormat            = CUPSD_TIME_STANDARD;
   MaxClients               = 100;
@@ -735,7 +736,11 @@ cupsdReadConfiguration(void)
   RootCertDuration         = 300;
   Sandboxing               = CUPSD_SANDBOXING_STRICT;
   StrictConformance        = FALSE;
+#ifdef CUPS_DEFAULT_SYNC_ON_CLOSE
+  SyncOnClose              = TRUE;
+#else
   SyncOnClose              = FALSE;
+#endif /* CUPS_DEFAULT_SYNC_ON_CLOSE */
   Timeout                  = 900;
   WebInterface             = CUPS_DEFAULT_WEBIF;
 
@@ -752,7 +757,7 @@ cupsdReadConfiguration(void)
   cupsdSetString(&LPDConfigFile, CUPS_DEFAULT_LPD_CONFIG_FILE);
   cupsdSetString(&SMBConfigFile, CUPS_DEFAULT_SMB_CONFIG_FILE);
 
-  cupsdSetString(&ErrorPolicy, "stop-printer");
+  cupsdSetString(&ErrorPolicy, CUPS_DEFAULT_ERROR_POLICY);
 
   JobHistory          = DEFAULT_HISTORY;
   JobFiles            = DEFAULT_FILES;
@@ -899,7 +904,7 @@ cupsdReadConfiguration(void)
     cupsdAddAlias(ServerAlias, temp);
     cupsdLogMessage(CUPSD_LOG_DEBUG, "Added auto ServerAlias %s", temp);
 
-    if (HostNameLookups || RemotePort)
+    if (HostNameLookups)
     {
       struct hostent	*host;		/* Host entry to get FQDN */
 
@@ -1245,7 +1250,10 @@ cupsdReadConfiguration(void)
     char	*paper_result;		/* Paper size name from libpaper */
 
     if ((paper_result = systempapername()) != NULL)
+    {
       cupsdSetString(&DefaultPaperSize, paper_result);
+      free(paper_result);
+    }
     else
 #endif /* HAVE_LIBPAPER */
     if (!DefaultLanguage ||
@@ -1742,7 +1750,7 @@ get_address(const char  *value,		/* I -
       * Use the default port...
       */
 
-      sprintf(defpname, "%d", defport);
+      snprintf(defpname, sizeof(defpname), "%d", defport);
       portname = defpname;
       hostname = buffer;
     }
@@ -3501,6 +3509,31 @@ read_cups_files_conf(cups_file_t *fp)	/*
 	                  linenum, CupsFilesFile);
 	  if (FatalErrors & CUPSD_FATAL_CONFIG)
 	    return (0);
+	}
+      }
+    }
+    else if (!_cups_strcasecmp(line, "LogFileGroup") && value)
+    {
+     /*
+      * Group ID to log as...
+      */
+
+      if (isdigit(value[0]))
+        LogFileGroup = (gid_t)atoi(value);
+      else
+      {
+        endgrent();
+	group = getgrnam(value);
+
+	if (group != NULL)
+	  LogFileGroup = group->gr_gid;
+	else
+	{
+	  cupsdLogMessage(CUPSD_LOG_ERROR,
+	                  "Unknown LogFileGroup \"%s\" on line %d of %s.", value,
+	                  linenum, CupsFilesFile);
+	  if (FatalErrors & CUPSD_FATAL_CONFIG)
+	    return (0);
 	}
       }
     }
diff -pruN 2.3.3-3/scheduler/conf.h 2.3.3op1-3/scheduler/conf.h
--- 2.3.3-3/scheduler/conf.h	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/scheduler/conf.h	2020-11-27 14:25:26.000000000 +0000
@@ -173,6 +173,8 @@ VAR mode_t		ConfigFilePerm		VALUE(0640U)
 					/* Permissions for config files */
 			LogFilePerm		VALUE(0644U);
 					/* Permissions for log files */
+VAR gid_t		LogFileGroup		VALUE(0);
+					/* Group ID for log files */
 VAR cupsd_loglevel_t	LogLevel		VALUE(CUPSD_LOG_WARN);
 					/* Error log level */
 VAR cupsd_time_t	LogTimeFormat		VALUE(CUPSD_TIME_STANDARD);
diff -pruN 2.3.3-3/scheduler/cups-deviced.c 2.3.3op1-3/scheduler/cups-deviced.c
--- 2.3.3-3/scheduler/cups-deviced.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/scheduler/cups-deviced.c	2020-11-27 14:25:26.000000000 +0000
@@ -265,7 +265,7 @@ main(int  argc,				/* I - Number of comm
     * all others run as the unprivileged user...
     */
 
-    start_backend(dent->filename, !(dent->fileinfo.st_mode & (S_IWGRP | S_IRWXO)));
+    start_backend(dent->filename, !(dent->fileinfo.st_mode & (S_IWGRP | S_IWOTH | S_IXOTH)));
   }
 
   cupsDirClose(dir);
diff -pruN 2.3.3-3/scheduler/cups-lpdAT.service.in 2.3.3op1-3/scheduler/cups-lpdAT.service.in
--- 2.3.3-3/scheduler/cups-lpdAT.service.in	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/scheduler/cups-lpdAT.service.in	2020-11-27 14:25:26.000000000 +0000
@@ -0,0 +1,9 @@
+[Unit]
+Description=CUPS LPD server
+Documentation=man:cups-lpd(8)
+
+[Service]
+ExecStart=-@CUPS_SERVERBIN@/daemon/cups-lpd
+StandardInput=socket
+User=@CUPS_USER@
+
diff -pruN 2.3.3-3/scheduler/cups-lpd.c 2.3.3op1-3/scheduler/cups-lpd.c
--- 2.3.3-3/scheduler/cups-lpd.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/scheduler/cups-lpd.c	2020-11-27 14:25:26.000000000 +0000
@@ -1268,7 +1268,7 @@ remove_jobs(const char *dest,		/* I - De
 
     request = ippNewRequest(IPP_OP_CANCEL_JOB);
 
-    sprintf(uri, "ipp://localhost/jobs/%d", id);
+    snprintf(uri, sizeof(uri), "ipp://localhost/jobs/%d", id);
     ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_URI, "job-uri", NULL, uri);
 
     ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_NAME,
diff -pruN 2.3.3-3/scheduler/cups-lpd.socket 2.3.3op1-3/scheduler/cups-lpd.socket
--- 2.3.3-3/scheduler/cups-lpd.socket	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/scheduler/cups-lpd.socket	2020-11-27 14:25:26.000000000 +0000
@@ -0,0 +1,10 @@
+[Unit]
+Description=CUPS LPD Server Socket
+PartOf=cups-lpd.service
+
+[Socket]
+ListenStream=515
+Accept=yes
+
+[Install]
+WantedBy=sockets.target
diff -pruN 2.3.3-3/scheduler/cups.path.in 2.3.3op1-3/scheduler/cups.path.in
--- 2.3.3-3/scheduler/cups.path.in	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/scheduler/cups.path.in	2020-11-27 14:25:26.000000000 +0000
@@ -0,0 +1,9 @@
+[Unit]
+Description=CUPS Scheduler
+PartOf=cups.service
+
+[Path]
+PathExists=@CUPS_CACHEDIR@/org.cups.cupsd
+
+[Install]
+WantedBy=multi-user.target
diff -pruN 2.3.3-3/scheduler/cups.service.in 2.3.3op1-3/scheduler/cups.service.in
--- 2.3.3-3/scheduler/cups.service.in	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/scheduler/cups.service.in	2020-11-27 14:25:26.000000000 +0000
@@ -0,0 +1,14 @@
+[Unit]
+Description=CUPS Scheduler
+Documentation=man:cupsd(8)
+After=network.target sssd.service ypbind.service
+Requires=cups.socket
+
+[Service]
+ExecStart=@sbindir@/cupsd -l
+Type=notify
+Restart=on-failure
+
+[Install]
+Also=cups.socket cups.path
+WantedBy=printer.target
diff -pruN 2.3.3-3/scheduler/cups.socket.in 2.3.3op1-3/scheduler/cups.socket.in
--- 2.3.3-3/scheduler/cups.socket.in	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/scheduler/cups.socket.in	2020-11-27 14:25:26.000000000 +0000
@@ -0,0 +1,9 @@
+[Unit]
+Description=CUPS Scheduler
+PartOf=cups.service
+
+[Socket]
+ListenStream=@CUPS_DEFAULT_DOMAINSOCKET@
+
+[Install]
+WantedBy=sockets.target
diff -pruN 2.3.3-3/scheduler/ipp.c 2.3.3op1-3/scheduler/ipp.c
--- 2.3.3-3/scheduler/ipp.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/scheduler/ipp.c	2020-11-27 14:25:26.000000000 +0000
@@ -1,6 +1,7 @@
 /*
  * IPP routines for the CUPS scheduler.
  *
+ * Copyright © 2020 by Michael R Sweet
  * Copyright © 2007-2019 by Apple Inc.
  * Copyright © 1997-2007 by Easy Software Products, all rights reserved.
  *
@@ -4891,7 +4892,7 @@ copy_printer_attrs(
   }
 
   if (printer->alert && (!ra || cupsArrayFind(ra, "printer-alert")))
-    ippAddString(con->response, IPP_TAG_PRINTER, IPP_TAG_STRING, "printer-alert", NULL, printer->alert);
+    ippAddOctetString(con->response, IPP_TAG_PRINTER, "printer-alert", printer->alert, (int)strlen(printer->alert));
 
   if (printer->alert_description && (!ra || cupsArrayFind(ra, "printer-alert-description")))
     ippAddString(con->response, IPP_TAG_PRINTER, IPP_TAG_TEXT, "printer-alert-description", NULL, printer->alert_description);
@@ -5016,6 +5017,9 @@ copy_printer_attrs(
   if (!ra || cupsArrayFind(ra, "queued-job-count"))
     add_queued_job_count(con, printer);
 
+  if (!ra || cupsArrayFind(ra, "uri-security-supported"))
+    ippAddString(con->response, IPP_TAG_PRINTER, IPP_TAG_KEYWORD, "uri-security-supported", NULL, is_encrypted ? "tls" : "none");
+
   copy_attrs(con->response, printer->attrs, ra, IPP_TAG_ZERO, 0, NULL);
   if (printer->ppd_attrs)
     copy_attrs(con->response, printer->ppd_attrs, ra, IPP_TAG_ZERO, 0, NULL);
@@ -10866,17 +10870,13 @@ set_printer_defaults(
 
       case IPP_TAG_INTEGER :
       case IPP_TAG_ENUM :
-          sprintf(value, "%d", attr->values[0].integer);
-          printer->num_options = cupsAddOption(name, value,
-					       printer->num_options,
-					       &(printer->options));
+          printer->num_options = cupsAddIntegerOption(name, attr->values[0].integer, printer->num_options, &(printer->options));
           cupsdLogMessage(CUPSD_LOG_DEBUG,
 	                  "Setting %s to %s...", attr->name, value);
           break;
 
       case IPP_TAG_RANGE :
-          sprintf(value, "%d-%d", attr->values[0].range.lower,
-	          attr->values[0].range.upper);
+          snprintf(value, sizeof(value), "%d-%d", attr->values[0].range.lower, attr->values[0].range.upper);
           printer->num_options = cupsAddOption(name, value,
 					       printer->num_options,
 					       &(printer->options));
@@ -10885,10 +10885,7 @@ set_printer_defaults(
           break;
 
       case IPP_TAG_RESOLUTION :
-          sprintf(value, "%dx%d%s", attr->values[0].resolution.xres,
-	          attr->values[0].resolution.yres,
-		  attr->values[0].resolution.units == IPP_RES_PER_INCH ?
-		      "dpi" : "dpcm");
+          snprintf(value, sizeof(value), "%dx%d%s", attr->values[0].resolution.xres, attr->values[0].resolution.yres, attr->values[0].resolution.units == IPP_RES_PER_INCH ? "dpi" : "dpcm");
           printer->num_options = cupsAddOption(name, value,
 					       printer->num_options,
 					       &(printer->options));
diff -pruN 2.3.3-3/scheduler/job.c 2.3.3op1-3/scheduler/job.c
--- 2.3.3-3/scheduler/job.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/scheduler/job.c	2020-11-27 14:25:26.000000000 +0000
@@ -893,7 +893,7 @@ cupsdContinueJob(cupsd_job_t *job)	/* I
     goto abort_job;
   }
 
-  sprintf(jobid, "%d", job->id);
+  snprintf(jobid, sizeof(jobid), "%d", job->id);
 
   argv[0] = job->printer->name;
   argv[1] = jobid;
@@ -1247,7 +1247,7 @@ cupsdContinueJob(cupsd_job_t *job)	/* I
       else if (stat(command, &backinfo))
 	backroot = 0;
       else
-        backroot = !(backinfo.st_mode & (S_IWGRP | S_IRWXO));
+        backroot = !(backinfo.st_mode & (S_IWGRP | S_IWOTH | S_IXOTH));
 
       argv[0] = job->printer->sanitized_device_uri;
 
@@ -2201,7 +2201,7 @@ cupsdSaveAllJobs(void)
   strftime(temp, sizeof(temp) - 1, "%Y-%m-%d %H:%M", &curdate);
 
   cupsFilePuts(fp, "# Job cache file for " CUPS_SVERSION "\n");
-  cupsFilePrintf(fp, "# Written by cupsd on %s\n", temp);
+  cupsFilePrintf(fp, "# Written by cupsd\n");
   cupsFilePrintf(fp, "NextJobId %d\n", NextJobId);
 
  /*
@@ -2625,7 +2625,7 @@ cupsdSetJobState(
     else
       cupsdAddEvent(CUPSD_EVENT_JOB_STATE, job->printer, job, "%s", buffer);
 
-    if (newstate == IPP_JOB_STOPPED || newstate == IPP_JOB_ABORTED || newstate == IPP_JOB_HELD)
+    if (newstate == IPP_JOB_STOPPED || newstate == IPP_JOB_ABORTED)
       cupsdLogJob(job, CUPSD_LOG_ERROR, "%s", buffer);
     else
       cupsdLogJob(job, CUPSD_LOG_INFO, "%s", buffer);
@@ -3229,7 +3229,7 @@ finalize_job(cupsd_job_t *job,		/* I - J
       exit_code = job->status;
     }
 
-    cupsdLogJob(job, CUPSD_LOG_INFO, "Backend returned status %d (%s)",
+    cupsdLogJob(job, CUPSD_LOG_WARN, "Backend returned status %d (%s)",
 		exit_code,
 		exit_code == CUPS_BACKEND_FAILED ? "failed" :
 		    exit_code == CUPS_BACKEND_AUTH_REQUIRED ?
diff -pruN 2.3.3-3/scheduler/listen.c 2.3.3op1-3/scheduler/listen.c
--- 2.3.3-3/scheduler/listen.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/scheduler/listen.c	2020-11-27 14:25:26.000000000 +0000
@@ -160,7 +160,7 @@ cupsdStartListening(void)
 
       if (lis->fd == -1)
       {
-	cupsdLogMessage(CUPSD_LOG_ERROR,
+	cupsdLogMessage(errno == EAFNOSUPPORT ? CUPSD_LOG_INFO : CUPSD_LOG_ERROR,
 			"Unable to open listen socket for address %s:%d - %s.",
 			s, p, strerror(errno));
 
diff -pruN 2.3.3-3/scheduler/log.c 2.3.3op1-3/scheduler/log.c
--- 2.3.3-3/scheduler/log.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/scheduler/log.c	2020-11-27 14:25:26.000000000 +0000
@@ -241,7 +241,7 @@ cupsdCheckLogFile(cups_file_t **lf,	/* I
       * Change ownership and permissions of non-device logs...
       */
 
-      fchown(cupsFileNumber(*lf), RunUser, Group);
+      fchown(cupsFileNumber(*lf), RunUser, LogFileGroup);
       fchmod(cupsFileNumber(*lf), LogFilePerm);
     }
   }
@@ -284,7 +284,7 @@ cupsdCheckLogFile(cups_file_t **lf,	/* I
     * Change ownership and permissions of non-device logs...
     */
 
-    fchown(cupsFileNumber(*lf), RunUser, Group);
+    fchown(cupsFileNumber(*lf), RunUser, LogFileGroup);
     fchmod(cupsFileNumber(*lf), LogFilePerm);
   }
 
diff -pruN 2.3.3-3/scheduler/main.c 2.3.3op1-3/scheduler/main.c
--- 2.3.3-3/scheduler/main.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/scheduler/main.c	2020-11-27 14:25:26.000000000 +0000
@@ -681,8 +681,17 @@ main(int  argc,				/* I - Number of comm
 
 #ifdef HAVE_ONDEMAND
   if (OnDemand)
+  {
     cupsdAddEvent(CUPSD_EVENT_SERVER_STARTED, NULL, NULL, "Scheduler started on demand.");
+
+#  ifdef HAVE_SYSTEMD
+    sd_notifyf(0, "READY=1\n"
+		  "STATUS=Scheduler is running...\n"
+		  "MAINPID=%lu", (unsigned long)getpid());
+#  endif /* HAVE_SYSTEMD */
+  }
   else
+
 #endif /* HAVE_ONDEMAND */
   if (fg)
     cupsdAddEvent(CUPSD_EVENT_SERVER_STARTED, NULL, NULL, "Scheduler started in foreground.");
diff -pruN 2.3.3-3/scheduler/Makefile 2.3.3op1-3/scheduler/Makefile
--- 2.3.3-3/scheduler/Makefile	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/scheduler/Makefile	2020-11-27 14:25:26.000000000 +0000
@@ -1,6 +1,7 @@
 #
 # Scheduler Makefile for CUPS.
 #
+# Copyright © 2020 by Michael R Sweet
 # Copyright © 2007-2019 by Apple Inc.
 # Copyright © 1997-2007 by Easy Software Products, all rights reserved.
 #
@@ -194,12 +195,13 @@ install-data:
 	if test "x$(SYSTEMD_DIR)" != x; then \
 		echo Installing systemd configuration files...; \
 		$(INSTALL_DIR) $(BUILDROOT)$(SYSTEMD_DIR); \
-		$(INSTALL_DATA) org.cups.cupsd.path $(BUILDROOT)$(SYSTEMD_DIR); \
-		$(INSTALL_DATA) org.cups.cupsd.service $(BUILDROOT)$(SYSTEMD_DIR); \
-		$(INSTALL_DATA) org.cups.cupsd.socket $(BUILDROOT)$(SYSTEMD_DIR); \
-		$(INSTALL_DATA) org.cups.cups-lpdAT.service $(BUILDROOT)$(SYSTEMD_DIR)/org.cups.cups-lpd@.service; \
-		$(INSTALL_DATA) org.cups.cups-lpd.socket $(BUILDROOT)$(SYSTEMD_DIR); \
-	elif test "x$(XINETD)" != x; then \
+		$(INSTALL_DATA) cups.path $(BUILDROOT)$(SYSTEMD_DIR); \
+		$(INSTALL_DATA) cups.service $(BUILDROOT)$(SYSTEMD_DIR); \
+		$(INSTALL_DATA) cups.socket $(BUILDROOT)$(SYSTEMD_DIR); \
+		$(INSTALL_DATA) cups-lpdAT.service $(BUILDROOT)$(SYSTEMD_DIR)/cups-lpd@.service; \
+		$(INSTALL_DATA) cups-lpd.socket $(BUILDROOT)$(SYSTEMD_DIR); \
+	fi
+	if test "x$(XINETD)" != x; then \
 		echo Installing xinetd configuration file for cups-lpd...; \
 		$(INSTALL_DIR) -m 755 $(BUILDROOT)$(XINETD); \
 		$(INSTALL_DATA) cups-lpd.xinetd $(BUILDROOT)$(XINETD)/cups-lpd; \
@@ -294,9 +296,9 @@ uninstall:
 	fi
 	if test "x$SYSTEMD_DIR" != x; then \
 		echo Uninstalling systemd files...; \
-		$(RM) $(BUILDROOT)$(SYSTEMD_DIR)/org.cups.cupsd.path; \
-		$(RM) $(BUILDROOT)$(SYSTEMD_DIR)/org.cups.cupsd.service; \
-		$(RM) $(BUILDROOT)$(SYSTEMD_DIR)/org.cups.cupsd.socket; \
+		$(RM) $(BUILDROOT)$(SYSTEMD_DIR)/cups.path; \
+		$(RM) $(BUILDROOT)$(SYSTEMD_DIR)/cups.service; \
+		$(RM) $(BUILDROOT)$(SYSTEMD_DIR)/cups.socket; \
 	fi
 	if test "x$(SMFMANIFESTDIR)" != x; then \
 		echo Uninstalling SMF manifest file...;\
diff -pruN 2.3.3-3/scheduler/org.cups.cupsd.path.in 2.3.3op1-3/scheduler/org.cups.cupsd.path.in
--- 2.3.3-3/scheduler/org.cups.cupsd.path.in	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/scheduler/org.cups.cupsd.path.in	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-[Unit]
-Description=CUPS Scheduler
-PartOf=org.cups.cupsd.service
-
-[Path]
-PathExists=@CUPS_CACHEDIR@/org.cups.cupsd
-
-[Install]
-WantedBy=multi-user.target
diff -pruN 2.3.3-3/scheduler/org.cups.cupsd.service.in 2.3.3op1-3/scheduler/org.cups.cupsd.service.in
--- 2.3.3-3/scheduler/org.cups.cupsd.service.in	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/scheduler/org.cups.cupsd.service.in	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-[Unit]
-Description=CUPS Scheduler
-Documentation=man:cupsd(8)
-After=sssd.service
-
-[Service]
-ExecStart=@sbindir@/cupsd -l
-Type=simple
-Restart=on-failure
-
-[Install]
-Also=org.cups.cupsd.socket org.cups.cupsd.path
-WantedBy=printer.target
diff -pruN 2.3.3-3/scheduler/org.cups.cupsd.socket.in 2.3.3op1-3/scheduler/org.cups.cupsd.socket.in
--- 2.3.3-3/scheduler/org.cups.cupsd.socket.in	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/scheduler/org.cups.cupsd.socket.in	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-[Unit]
-Description=CUPS Scheduler
-PartOf=org.cups.cupsd.service
-
-[Socket]
-ListenStream=@CUPS_DEFAULT_DOMAINSOCKET@
-
-[Install]
-WantedBy=sockets.target
diff -pruN 2.3.3-3/scheduler/org.cups.cups-lpdAT.service.in 2.3.3op1-3/scheduler/org.cups.cups-lpdAT.service.in
--- 2.3.3-3/scheduler/org.cups.cups-lpdAT.service.in	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/scheduler/org.cups.cups-lpdAT.service.in	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-[Unit]
-Description=CUPS LPD server
-Documentation=man:cups-lpd(8)
-
-[Service]
-ExecStart=-@CUPS_SERVERBIN@/daemon/cups-lpd
-StandardInput=socket
-User=@CUPS_USER@
-
diff -pruN 2.3.3-3/scheduler/org.cups.cups-lpd.socket 2.3.3op1-3/scheduler/org.cups.cups-lpd.socket
--- 2.3.3-3/scheduler/org.cups.cups-lpd.socket	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/scheduler/org.cups.cups-lpd.socket	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-[Unit]
-Description=CUPS LPD Server Socket
-PartOf=org.cups.cups-lpd.service
-
-[Socket]
-ListenStream=515
-Accept=yes
-
-[Install]
-WantedBy=sockets.target
diff -pruN 2.3.3-3/scheduler/printers.c 2.3.3op1-3/scheduler/printers.c
--- 2.3.3-3/scheduler/printers.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/scheduler/printers.c	2020-11-27 14:25:26.000000000 +0000
@@ -1,6 +1,7 @@
 /*
  * Printer routines for the CUPS scheduler.
  *
+ * Copyright © 2020 by Michael R Sweet
  * Copyright © 2007-2019 by Apple Inc.
  * Copyright © 1997-2007 by Easy Software Products, all rights reserved.
  *
@@ -822,12 +823,15 @@ cupsdDeletePrinter(
   ippDelete(p->attrs);
   ippDelete(p->ppd_attrs);
 
+  _ppdCacheDestroy(p->pc);
+
   mimeDeleteType(MimeDatabase, p->filetype);
   mimeDeleteType(MimeDatabase, p->prefiltertype);
 
   cupsdFreeStrings(&(p->users));
   cupsdFreeQuotas(p);
 
+  cupsdClearString(&p->uuid);
   cupsdClearString(&p->uri);
   cupsdClearString(&p->hostname);
   cupsdClearString(&p->name);
@@ -1503,7 +1507,7 @@ cupsdSaveAllPrinters(void)
   strftime(temp, sizeof(temp) - 1, "%Y-%m-%d %H:%M", &curdate);
 
   cupsFilePuts(fp, "# Printer configuration file for " CUPS_SVERSION "\n");
-  cupsFilePrintf(fp, "# Written by cupsd on %s\n", temp);
+  cupsFilePrintf(fp, "# Written by cupsd\n");
   cupsFilePuts(fp, "# DO NOT EDIT THIS FILE WHEN CUPSD IS RUNNING\n");
 
   cupsFilePrintf(fp, "NextPrinterId %d\n", NextPrinterId);
@@ -2316,8 +2320,6 @@ cupsdSetPrinterAttrs(cupsd_printer_t *p)
 
   ippAddString(p->attrs, IPP_TAG_PRINTER, IPP_TAG_KEYWORD,
                "uri-authentication-supported", NULL, auth_supported);
-  ippAddString(p->attrs, IPP_TAG_PRINTER, IPP_TAG_KEYWORD,
-               "uri-security-supported", NULL, "none");
   if (p->printer_id)
     ippAddInteger(p->attrs, IPP_TAG_PRINTER, IPP_TAG_INTEGER, "printer-id", p->printer_id);
   ippAddString(p->attrs, IPP_TAG_PRINTER, IPP_TAG_NAME, "printer-name", NULL,
@@ -4016,7 +4018,8 @@ load_ppd(cupsd_printer_t *p)		/* I - Pri
 
     num_qualities = 0;
 
-    if ((output_mode = ppdFindOption(ppd, "OutputMode")) != NULL)
+    if ((output_mode = ppdFindOption(ppd, "OutputMode")) ||
+        (output_mode = ppdFindOption(ppd, "cupsPrintQuality")))
     {
       if (ppdFindChoice(output_mode, "draft") ||
           ppdFindChoice(output_mode, "fast"))
diff -pruN 2.3.3-3/scheduler/subscriptions.c 2.3.3op1-3/scheduler/subscriptions.c
--- 2.3.3-3/scheduler/subscriptions.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/scheduler/subscriptions.c	2020-11-27 14:25:26.000000000 +0000
@@ -1051,7 +1051,7 @@ cupsdSaveAllSubscriptions(void)
   strftime(temp, sizeof(temp) - 1, "%Y-%m-%d %H:%M", &curdate);
 
   cupsFilePuts(fp, "# Subscription configuration file for " CUPS_SVERSION "\n");
-  cupsFilePrintf(fp, "# Written by cupsd on %s\n", temp);
+  cupsFilePrintf(fp, "# Written by cupsd\n");
 
   cupsFilePrintf(fp, "NextSubscriptionId %d\n", NextSubscriptionId);
 
diff -pruN 2.3.3-3/systemv/cancel.c 2.3.3op1-3/systemv/cancel.c
--- 2.3.3-3/systemv/cancel.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/systemv/cancel.c	2020-11-27 14:25:26.000000000 +0000
@@ -274,7 +274,7 @@ main(int  argc,				/* I - Number of comm
       }
       else
       {
-        sprintf(uri, "ipp://localhost/jobs/%d", job_id);
+        snprintf(uri, sizeof(uri), "ipp://localhost/jobs/%d", job_id);
 	ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_URI, "job-uri", NULL,
 	             uri);
       }
diff -pruN 2.3.3-3/systemv/lp.c 2.3.3op1-3/systemv/lp.c
--- 2.3.3-3/systemv/lp.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/systemv/lp.c	2020-11-27 14:25:26.000000000 +0000
@@ -161,6 +161,12 @@ main(int  argc,				/* I - Number of comm
 				  "name."), argv[0]);
 		return (1);
 	      }
+	      else if (cupsLastError() == IPP_STATUS_ERROR_NOT_FOUND)
+	      {
+		_cupsLangPrintf(stderr,
+				_("%s: Error - The printer or class does not exist."), argv[0]);
+		return (1);
+	      }
 	      break;
 
 	  case 'f' : /* Form */
@@ -280,9 +286,7 @@ main(int  argc,				/* I - Number of comm
 		return (1);
 	      }
 
-	      sprintf(buffer, "%d", num_copies);
-	      num_options = cupsAddOption("copies", buffer, num_options,
-					  &options);
+	      num_options = cupsAddIntegerOption("copies", num_copies, num_options, &options);
 	      break;
 
 	  case 'o' : /* Option */
@@ -342,9 +346,7 @@ main(int  argc,				/* I - Number of comm
 		return (1);
 	      }
 
-	      sprintf(buffer, "%d", priority);
-	      num_options = cupsAddOption("job-priority", buffer, num_options,
-					  &options);
+	      num_options = cupsAddIntegerOption("job-priority", priority, num_options, &options);
 	      break;
 
 	  case 's' : /* Silent */
@@ -660,7 +662,7 @@ restart_job(const char *command,	/* I -
 
   request = ippNewRequest(IPP_RESTART_JOB);
 
-  sprintf(uri, "ipp://localhost/jobs/%d", job_id);
+  snprintf(uri, sizeof(uri), "ipp://localhost/jobs/%d", job_id);
 
   ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_URI,
                "job-uri", NULL, uri);
@@ -708,7 +710,7 @@ set_job_attrs(
 
   request = ippNewRequest(IPP_SET_JOB_ATTRIBUTES);
 
-  sprintf(uri, "ipp://localhost/jobs/%d", job_id);
+  snprintf(uri, sizeof(uri), "ipp://localhost/jobs/%d", job_id);
 
   ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_URI,
                "job-uri", NULL, uri);
diff -pruN 2.3.3-3/test/run-stp-tests.sh 2.3.3op1-3/test/run-stp-tests.sh
--- 2.3.3-3/test/run-stp-tests.sh	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/test/run-stp-tests.sh	2020-11-27 14:25:26.000000000 +0000
@@ -268,7 +268,7 @@ case "$usedebugprintfs" in
 		echo "Enabling debug printfs (level $usedebugprintfs); log files can be found in $BASE/log..."
 		CUPS_DEBUG_LOG="$BASE/log/debug_printfs.%d"; export CUPS_DEBUG_LOG
 		CUPS_DEBUG_LEVEL="$usedebugprintfs"; export CUPS_DEBUG_LEVEL
-		CUPS_DEBUG_FILTER='^(http|_http|ipp|_ipp|cups.*Request|cupsGetResponse|cupsSend|mime).*$'; export CUPS_DEBUG_FILTER
+		CUPS_DEBUG_FILTER='^(http|_http|ipp|_ipp|cups.*Request|cupsGetResponse|cupsSend).*$'; export CUPS_DEBUG_FILTER
 		;;
 
 	*)
@@ -443,14 +443,12 @@ EOF
 }
 
 ln -s $root/test/test.convs $BASE/share/mime
-ln -s $root/test/test.types $BASE/share/mime
 
 if test `uname` = Darwin; then
 	instfilter cgimagetopdf imagetopdf pdf
 	instfilter cgpdftopdf pdftopdf passthru
 	instfilter cgpdftops pdftops ps
 	instfilter cgpdftoraster pdftoraster raster
-	instfilter cgpdftoraster pdftourf raster
 	instfilter cgtexttopdf texttopdf pdf
 	instfilter pstocupsraster pstoraster raster
 else
@@ -458,7 +456,6 @@ else
 	instfilter pdftopdf pdftopdf passthru
 	instfilter pdftops pdftops ps
 	instfilter pdftoraster pdftoraster raster
-	instfilter pdftoraster pdftourf raster
 	instfilter pstoraster pstoraster raster
 	instfilter texttopdf texttopdf pdf
 
@@ -776,6 +773,13 @@ echo "    $date by $user on `hostname`."
 echo "    <pre>" >>$strfile
 
 for file in 5*.sh; do
+	# Wait for jobs from the previous test to complete before running the
+	# next test...
+	if test $file != 5.1-lpadmin.sh; then
+		./waitjobs.sh 1800
+	fi
+
+	# Run the test...
 	echo $ac_n "Performing $file: $ac_c"
 	echo "" >>$strfile
         echo "`date '+[%d/%b/%Y:%H:%M:%S %z]'` \"$file\":" >>$strfile
@@ -1040,7 +1044,7 @@ else
 fi
 
 # Warning log messages
-count=`$GREP '^W ' $BASE/log/error_log | $GREP -v CreateProfile | wc -l | awk '{print $1}'`
+count=`$GREP '^W ' $BASE/log/error_log | $GREP -v CreateProfile | $GREP -v 'libusb error' | $GREP -v ColorManager | $GREP -v 'Avahi client failed' | wc -l | awk '{print $1}'`
 if test $count != 8; then
 	echo "FAIL: $count warning messages, expected 8."
 	$GREP '^W ' $BASE/log/error_log
diff -pruN 2.3.3-3/test/test.convs 2.3.3op1-3/test/test.convs
--- 2.3.3-3/test/test.convs	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/test/test.convs	2020-11-27 14:25:26.000000000 +0000
@@ -2,7 +2,6 @@
 application/pdf application/vnd.cups-pdf 100 pdftopdf
 application/pdf application/postscript 100 pdftops
 application/pdf application/vnd.cups-raster 100 pdftoraster
-application/pdf image/urf 100 pdftourf
 application/postscript application/vnd.cups-raster 100 pstoraster
 image/jpeg application/pdf 100 imagetopdf
 text/plain application/pdf 100 texttopdf
diff -pruN 2.3.3-3/test/test.types 2.3.3op1-3/test/test.types
--- 2.3.3-3/test/test.types	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/test/test.types	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-# Test file listing potential MIME media types that are not in the standard mime.types file
-image/urf
\ No newline at end of file
diff -pruN 2.3.3-3/test/waitjobs.sh 2.3.3op1-3/test/waitjobs.sh
--- 2.3.3-3/test/waitjobs.sh	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/test/waitjobs.sh	2020-11-27 14:25:26.000000000 +0000
@@ -30,6 +30,19 @@ else
         ac_c='\c'
 fi
 
+#
+# Check whether we have any jobs to wait for...
+#
+
+jobs=`$runcups ../systemv/lpstat 2>/dev/null | wc -l | tr -d ' '`
+if test $jobs = 0; then
+	exit 0
+fi
+
+#
+# We do, let the tester know what is going on...
+#
+
 echo $ac_n "Waiting for jobs to complete...$ac_c"
 oldjobs=0
 
diff -pruN 2.3.3-3/tools/Dependencies 2.3.3op1-3/tools/Dependencies
--- 2.3.3-3/tools/Dependencies	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/tools/Dependencies	2020-11-27 14:25:26.000000000 +0000
@@ -8,8 +8,9 @@ ippeveprinter.o: ippeveprinter.c ../cups
   ../cups/cups.h ../cups/file.h ../cups/ipp.h ../cups/http.h \
   ../cups/language.h ../cups/pwg.h ../cups/http-private.h \
   ../cups/language-private.h ../cups/transcode.h ../cups/pwg-private.h \
-  ../cups/thread-private.h ../cups/ppd-private.h ../cups/ppd.h \
-  ../cups/raster.h printer-png.h
+  ../cups/thread-private.h ../cups/debug-private.h ../cups/ppd-private.h \
+  ../cups/ppd.h ../cups/raster.h printer-png.h printer-lg-png.h \
+  printer-sm-png.h
 ippeveps.o: ippeveps.c ippevecommon.h ../cups/cups.h ../cups/file.h \
   ../cups/versioning.h ../cups/ipp.h ../cups/http.h ../cups/array.h \
   ../cups/language.h ../cups/pwg.h ../cups/raster.h \
diff -pruN 2.3.3-3/tools/ippeveprinter.c 2.3.3op1-3/tools/ippeveprinter.c
--- 2.3.3-3/tools/ippeveprinter.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/tools/ippeveprinter.c	2020-11-27 14:25:26.000000000 +0000
@@ -1,10 +1,11 @@
 /*
  * IPP Everywhere printer application for CUPS.
  *
+ * Copyright © 2020 by the IEEE-ISTO Printer Working Group.
  * Copyright © 2010-2019 by Apple Inc.
  *
  * Licensed under Apache License v2.0.  See the file "LICENSE" for more
- * information.º
+ * information.
  *
  * Note: This program began life as the "ippserver" sample code that first
  * appeared in CUPS 1.4.  The name has been changed in order to distinguish it
@@ -38,6 +39,7 @@ typedef ULONG nfds_t;
 #else
 extern char **environ;
 
+#  include <spawn.h>
 #  include <sys/fcntl.h>
 #  include <sys/wait.h>
 #  include <poll.h>
@@ -48,7 +50,9 @@ extern char **environ;
 #elif defined(HAVE_AVAHI)
 #  include <avahi-client/client.h>
 #  include <avahi-client/publish.h>
+#  include <avahi-common/alternative.h>
 #  include <avahi-common/error.h>
+#  include <avahi-common/malloc.h>
 #  include <avahi-common/thread-watch.h>
 #endif /* HAVE_DNSSD */
 
@@ -74,6 +78,8 @@ extern char **environ;
 #endif /* HAVE_LIBPAM */
 
 #include "printer-png.h"
+#include "printer-lg-png.h"
+#include "printer-sm-png.h"
 
 
 /*
@@ -178,16 +184,22 @@ typedef struct ippeve_printer_s		/**** P
   /* TODO: One IPv4 and one IPv6 listener are really not sufficient */
   int			ipv4,		/* IPv4 listener */
 			ipv6;		/* IPv6 listener */
-  ippeve_srv_t		ipp_ref,	/* Bonjour IPP service */
-			ipps_ref,	/* Bonjour IPPS service */
-			http_ref,	/* Bonjour HTTP service */
-			printer_ref;	/* Bonjour LPD service */
-  char			*dnssd_name,	/* printer-dnssd-name */
+#ifdef HAVE_DNSSD
+  ippeve_srv_t		ipp_ref,	/* DNS-SD IPP service */
+			ipps_ref,	/* DNS-SD IPPS service */
+			http_ref,	/* DNS-SD HTTP service */
+			printer_ref;	/* DNS-SD LPD service */
+#elif defined(HAVE_AVAHI)
+  ippeve_srv_t		dnssd_ref;	/* DNS-SD services */
+#endif /* HAVE_DNSSD */
+  char			*dnssd_subtypes;/* DNS-SD subtypes */
+  int			dnssd_collision;/* Name collision? */
+  char			*dnssd_name,	/* printer-dns-sd-name */
 			*name,		/* printer-name */
-			*icon,		/* Icon filename */
+			*icons[3],	/* Icon filenames */
+			*strings,	/* Strings filename */
 			*directory,	/* Spool directory */
 			*hostname,	/* Hostname */
-			*uri,		/* printer-uri-supported */
 			*device_uri,	/* Device URI (if any) */
 			*output_format,	/* Output format */
 #if !CUPS_LITE
@@ -239,7 +251,10 @@ typedef struct ippeve_client_s		/**** Cl
   http_state_t		operation;	/* Request operation */
   ipp_op_t		operation_id;	/* IPP operation-id */
   char			uri[1024],	/* Request URI */
-			*options;	/* URI options */
+			*options,	/* URI options */
+			host_field[HTTP_MAX_VALUE];
+					/* Host: header */
+  int			host_port;	/* Port number from Host: header */
   http_addr_t		addr;		/* Client address */
   char			hostname[256],	/* Client hostname */
 			username[HTTP_MAX_VALUE];
@@ -264,7 +279,7 @@ static int		create_job_file(ippeve_job_t
 static int		create_listener(const char *name, int port, int family);
 static ipp_t		*create_media_col(const char *media, const char *source, const char *type, int width, int length, int bottom, int left, int right, int top);
 static ipp_t		*create_media_size(int width, int length);
-static ippeve_printer_t	*create_printer(const char *servername, int serverport, const char *name, const char *location, const char *icon, cups_array_t *docformats, const char *subtypes, const char *directory, const char *command, const char *device_uri, const char *output_format, ipp_t *attrs);
+static ippeve_printer_t	*create_printer(const char *servername, int serverport, const char *name, const char *location, const char *icons, const char *strings, cups_array_t *docformats, const char *subtypes, const char *directory, const char *command, const char *device_uri, const char *output_format, ipp_t *attrs);
 static void		debug_attributes(const char *title, ipp_t *ipp, int response);
 static void		delete_client(ippeve_client_t *client);
 static void		delete_job(ippeve_job_t *job);
@@ -280,11 +295,14 @@ static int		filter_cb(ippeve_filter_t *f
 static ippeve_job_t	*find_job(ippeve_client_t *client);
 static void		finish_document_data(ippeve_client_t *client, ippeve_job_t *job);
 static void		finish_document_uri(ippeve_client_t *client, ippeve_job_t *job);
+static void		flush_document_data(ippeve_client_t *client);
+static int		have_document_data(ippeve_client_t *client);
 static void		html_escape(ippeve_client_t *client, const char *s, size_t slen);
 static void		html_footer(ippeve_client_t *client);
 static void		html_header(ippeve_client_t *client, const char *title, int refresh);
 static void		html_printf(ippeve_client_t *client, const char *format, ...) _CUPS_FORMAT(2, 3);
 static void		ipp_cancel_job(ippeve_client_t *client);
+static void		ipp_cancel_my_jobs(ippeve_client_t *client);
 static void		ipp_close_job(ippeve_client_t *client);
 static void		ipp_create_job(ippeve_client_t *client);
 static void		ipp_get_job_attributes(ippeve_client_t *client);
@@ -311,7 +329,7 @@ static int		process_http(ippeve_client_t
 static int		process_ipp(ippeve_client_t *client);
 static void		*process_job(ippeve_job_t *job);
 static void		process_state_message(ippeve_job_t *job, char *message);
-static int		register_printer(ippeve_printer_t *printer, const char *subtypes);
+static int		register_printer(ippeve_printer_t *printer);
 static int		respond_http(ippeve_client_t *client, http_status_t code, const char *content_coding, const char *type, size_t length);
 static void		respond_ipp(ippeve_client_t *client, ipp_status_t status, const char *message, ...) _CUPS_FORMAT(3, 4);
 static void		respond_unsupported(ippeve_client_t *client, ipp_attribute_t *attr);
@@ -368,6 +386,7 @@ main(int  argc,				/* I - Number of comm
 #if !CUPS_LITE
 		*ppdfile = NULL,	/* PPD file */
 #endif /* !CUPS_LITE */
+		*strings = NULL,	/* Strings file */
 		*subtypes = "_print";	/* DNS-SD service subtype */
   int		legacy = 0,		/* Legacy mode? */
 		duplex = 0,		/* Duplex mode */
@@ -475,6 +494,14 @@ main(int  argc,				/* I - Number of comm
               break;
 #endif /* !CUPS_LITE */
 
+	  case 'S' : /* -S filename.strings */
+	      i ++;
+	      if (i >= argc)
+	        usage(1);
+
+	      strings = argv[i];
+	      break;
+
           case 'V' : /* -V max-version */
 	      i ++;
 	      if (i >= argc)
@@ -699,7 +726,7 @@ main(int  argc,				/* I - Number of comm
   else
     attrs = load_legacy_attributes(make, model, ppm, ppm_color, duplex, docformats);
 
-  if ((printer = create_printer(servername, serverport, name, location, icon, docformats, subtypes, directory, command, device_uri, output_format, attrs)) == NULL)
+  if ((printer = create_printer(servername, serverport, name, location, icon, strings, docformats, subtypes, directory, command, device_uri, output_format, attrs)) == NULL)
     return (1);
 
   printer->web_forms = web_forms;
@@ -1177,7 +1204,11 @@ create_job(ippeve_client_t *client)	/* I
 
   job->id = client->printer->next_job_id ++;
 
-  snprintf(uri, sizeof(uri), "%s/%d", client->printer->uri, job->id);
+  if ((attr = ippFindAttribute(client->request, "printer-uri", IPP_TAG_URI)) != NULL)
+    snprintf(uri, sizeof(uri), "%s/%d", ippGetString(attr, 0, NULL), job->id);
+  else
+    httpAssembleURIf(HTTP_URI_CODING_ALL, uri, sizeof(uri), "ipp", NULL, client->printer->hostname, client->printer->port, "/ipp/print/%d", job->id);
+
   httpAssembleUUID(client->printer->hostname, client->printer->port, client->printer->name, job->id, uuid, sizeof(uuid));
 
   ippAddDate(job->attrs, IPP_TAG_JOB, "date-time-at-creation", ippTimeToDate(time(&job->created)));
@@ -1185,9 +1216,17 @@ create_job(ippeve_client_t *client)	/* I
   ippAddString(job->attrs, IPP_TAG_JOB, IPP_TAG_URI, "job-uri", NULL, uri);
   ippAddString(job->attrs, IPP_TAG_JOB, IPP_TAG_URI, "job-uuid", NULL, uuid);
   if ((attr = ippFindAttribute(client->request, "printer-uri", IPP_TAG_URI)) != NULL)
+  {
     ippAddString(job->attrs, IPP_TAG_JOB, IPP_TAG_URI, "job-printer-uri", NULL, ippGetString(attr, 0, NULL));
+  }
   else
-    ippAddString(job->attrs, IPP_TAG_JOB, IPP_TAG_URI, "job-printer-uri", NULL, client->printer->uri);
+  {
+    char printer_uri[1024];		/* job-printer-uri value */
+
+    httpAssembleURI(HTTP_URI_CODING_ALL, printer_uri, sizeof(printer_uri), "ipp", NULL, client->printer->hostname, client->printer->port, "/ipp/print");
+    ippAddString(job->attrs, IPP_TAG_JOB, IPP_TAG_URI, "job-printer-uri", NULL, printer_uri);
+  }
+
   ippAddInteger(job->attrs, IPP_TAG_JOB, IPP_TAG_INTEGER, "time-at-creation", (int)(job->created - client->printer->start_time));
 
   cupsArrayAdd(client->printer->jobs, job);
@@ -1385,9 +1424,10 @@ create_printer(
     int          serverport,		/* I - Server port */
     const char   *name,			/* I - printer-name */
     const char   *location,		/* I - printer-location */
-    const char   *icon,			/* I - printer-icons */
+    const char   *icons,		/* I - printer-icons */
+    const char   *strings,		/* I - printer-strings-uri */
     cups_array_t *docformats,		/* I - document-format-supported */
-    const char   *subtypes,		/* I - Bonjour service subtype(s) */
+    const char   *subtypes,		/* I - DNS-SD service subtype(s) */
     const char   *directory,		/* I - Spool directory */
     const char   *command,		/* I - Command to run on job files, if any */
     const char   *device_uri,		/* I - Output device, if any */
@@ -1399,15 +1439,10 @@ create_printer(
 #ifndef _WIN32
   char			path[1024];	/* Full path to command */
 #endif /* !_WIN32 */
-  char			uri[1024],	/* Printer URI */
-#ifdef HAVE_SSL
-			securi[1024],	/* Secure printer URI */
-			*uris[2],	/* All URIs */
-#endif /* HAVE_SSL */
-			icons[1024],	/* printer-icons URI */
-			adminurl[1024],	/* printer-more-info URI */
-			supplyurl[1024],/* printer-supply-info-uri URI */
-			uuid[128];	/* printer-uuid */
+  unsigned char		sha256[32];	/* SHA-256 digest/sum */
+  char			uuid_data[1024],/* Data to hash for printer-uuid */
+			uuid[128],	/* printer-uuid */
+			*iconsptr;	/* Pointer into icons string */
   int			k_supported;	/* Maximum file size supported */
   int			num_formats;	/* Number of supported document formats */
   const char		*formats[100],	/* Supported document formats */
@@ -1629,23 +1664,47 @@ create_printer(
     return (NULL);
   }
 
-  printer->ipv4          = -1;
-  printer->ipv6          = -1;
-  printer->name          = strdup(name);
-  printer->dnssd_name    = strdup(name);
-  printer->command       = command ? strdup(command) : NULL;
-  printer->device_uri    = device_uri ? strdup(device_uri) : NULL;
-  printer->output_format = output_format ? strdup(output_format) : NULL;
-  printer->directory     = strdup(directory);
-  printer->icon          = icon ? strdup(icon) : NULL;
-  printer->port          = serverport;
-  printer->start_time    = time(NULL);
-  printer->config_time   = printer->start_time;
-  printer->state         = IPP_PSTATE_IDLE;
-  printer->state_reasons = IPPEVE_PREASON_NONE;
-  printer->state_time    = printer->start_time;
-  printer->jobs          = cupsArrayNew((cups_array_func_t)compare_jobs, NULL);
-  printer->next_job_id   = 1;
+  printer->ipv4           = -1;
+  printer->ipv6           = -1;
+  printer->name           = strdup(name);
+  printer->dnssd_name     = strdup(name);
+  printer->dnssd_subtypes = subtypes ? strdup(subtypes) : NULL;
+  printer->command        = command ? strdup(command) : NULL;
+  printer->device_uri     = device_uri ? strdup(device_uri) : NULL;
+  printer->output_format  = output_format ? strdup(output_format) : NULL;
+  printer->directory      = strdup(directory);
+  printer->icons[0]       = icons ? strdup(icons) : NULL;
+  printer->strings        = strings ? strdup(strings) : NULL;
+  printer->port           = serverport;
+  printer->start_time     = time(NULL);
+  printer->config_time    = printer->start_time;
+  printer->state          = IPP_PSTATE_IDLE;
+  printer->state_reasons  = IPPEVE_PREASON_NONE;
+  printer->state_time     = printer->start_time;
+  printer->jobs           = cupsArrayNew((cups_array_func_t)compare_jobs, NULL);
+  printer->next_job_id    = 1;
+
+  if (printer->icons[0])
+  {
+   /*
+    * Extract up to 3 icons...
+    */
+
+    for (i = 1, iconsptr = strchr(icons, ','); iconsptr && i < 3; i ++, iconsptr = strchr(iconsptr, ','))
+    {
+      *iconsptr++ = '\0';
+      printer->icons[i] = iconsptr;
+    }
+
+    if (iconsptr)
+      *iconsptr = '\0';			/* Strip any icons after the third... */
+
+    while (i < 3)
+    {
+      printer->icons[i] = printer->icons[i - 1];
+      i ++;
+    }
+  }
 
   if (servername)
   {
@@ -1653,9 +1712,21 @@ create_printer(
   }
   else
   {
-    char	temp[1024];		/* Temporary string */
+    char	temp[1024],		/* Temporary string */
+		*tempptr;		/* Pointer into temporary string */
+
+#ifdef HAVE_AVAHI
+    const char *avahi_name = avahi_client_get_host_name_fqdn(DNSSDClient);
 
-    printer->hostname = strdup(httpGetHostname(NULL, temp, sizeof(temp)));
+    if (avahi_name)
+      strlcpy(temp, avahi_name, sizeof(temp));
+    else
+#endif /* HAVE_AVAHI */
+
+    if ((tempptr = strstr(httpGetHostname(NULL, temp, sizeof(temp)), ".lan")) != NULL && !tempptr[5])
+      strlcpy(tempptr, ".local", sizeof(temp) - (size_t)(tempptr - temp));
+
+    printer->hostname = strdup(temp);
   }
 
   _cupsRWInit(&(printer->rwlock));
@@ -1677,31 +1748,21 @@ create_printer(
   }
 
  /*
-  * Prepare URI values for the printer attributes...
+  * Prepare values for the printer attributes...
   */
 
-  httpAssembleURI(HTTP_URI_CODING_ALL, uri, sizeof(uri), "ipp", NULL, printer->hostname, printer->port, "/ipp/print");
-  printer->uri    = strdup(uri);
-  printer->urilen = strlen(uri);
-
-#ifdef HAVE_SSL
-  httpAssembleURI(HTTP_URI_CODING_ALL, securi, sizeof(securi), "ipps", NULL, printer->hostname, printer->port, "/ipp/print");
-#endif /* HAVE_SSL */
-
-  httpAssembleURI(HTTP_URI_CODING_ALL, icons, sizeof(icons), WEB_SCHEME, NULL, printer->hostname, printer->port, "/icon.png");
-  httpAssembleURI(HTTP_URI_CODING_ALL, adminurl, sizeof(adminurl), WEB_SCHEME, NULL, printer->hostname, printer->port, "/");
-  httpAssembleURI(HTTP_URI_CODING_ALL, supplyurl, sizeof(supplyurl), WEB_SCHEME, NULL, printer->hostname, printer->port, "/supplies");
-  httpAssembleUUID(printer->hostname, serverport, name, 0, uuid, sizeof(uuid));
+  snprintf(uuid_data, sizeof(uuid_data), "_IPPEVEPRINTER_:%s:%d:%s", printer->hostname, printer->port, printer->name);
+  cupsHashData("sha2-256", (unsigned char *)uuid_data, strlen(uuid_data), sha256, sizeof(sha256));
+  snprintf(uuid, sizeof(uuid), "urn:uuid:%02x%02x%02x%02x-%02x%02x-%02x%02x-%02x%02x-%02x%02x%02x%02x%02x%02x", sha256[0], sha256[1], sha256[3], sha256[4], sha256[5], sha256[6], (sha256[10] & 15) | 0x30, sha256[11], (sha256[15] & 0x3f) | 0x40, sha256[16], sha256[20], sha256[21], sha256[25], sha256[26], sha256[30], sha256[31]);
 
   if (Verbosity)
   {
-    fprintf(stderr, "printer-more-info=\"%s\"\n", adminurl);
-    fprintf(stderr, "printer-supply-info-uri=\"%s\"\n", supplyurl);
 #ifdef HAVE_SSL
-    fprintf(stderr, "printer-uri=\"%s\",\"%s\"\n", uri, securi);
+    fprintf(stderr, "printer-uri-supported=\"ipp://%s:%d/ipp/print\",\"ipps://%s:%d/ipp/print\"\n", printer->hostname, printer->port, printer->hostname, printer->port);
 #else
-    fprintf(stderr, "printer-uri=\"%s\"\n", uri);
+    fprintf(stderr, "printer-uri-supported=\"ipp://%s:%d/ipp/print\"\n", printer->hostname, printer->port);
 #endif /* HAVE_SSL */
+    fprintf(stderr, "printer-uuid=\"%s\"\n", uuid);
   }
 
  /*
@@ -1859,9 +1920,6 @@ create_printer(
   /* printer-geo-location */
   ippAddOutOfBand(printer->attrs, IPP_TAG_PRINTER, IPP_TAG_UNKNOWN, "printer-geo-location");
 
-  /* printer-icons */
-  ippAddString(printer->attrs, IPP_TAG_PRINTER, IPP_TAG_URI, "printer-icons", NULL, icons);
-
   /* printer-is-accepting-jobs */
   ippAddBoolean(printer->attrs, IPP_TAG_PRINTER, "printer-is-accepting-jobs", 1);
 
@@ -1871,9 +1929,6 @@ create_printer(
   /* printer-location */
   ippAddString(printer->attrs, IPP_TAG_PRINTER, IPP_TAG_TEXT, "printer-location", NULL, location);
 
-  /* printer-more-info */
-  ippAddString(printer->attrs, IPP_TAG_PRINTER, IPP_TAG_URI, "printer-more-info", NULL, adminurl);
-
   /* printer-name */
   ippAddString(printer->attrs, IPP_TAG_PRINTER, IPP_TAG_NAME, "printer-name", NULL, name);
 
@@ -1883,19 +1938,8 @@ create_printer(
   /* printer-organizational-unit */
   ippAddString(printer->attrs, IPP_TAG_PRINTER, IPP_CONST_TAG(IPP_TAG_TEXT), "printer-organizational-unit", NULL, "");
 
-  /* printer-supply-info-uri */
-  ippAddString(printer->attrs, IPP_TAG_PRINTER, IPP_TAG_URI, "printer-supply-info-uri", NULL, supplyurl);
-
-  /* printer-uri-supported */
-#ifdef HAVE_SSL
-  uris[0] = uri;
-  uris[1] = securi;
-
-  ippAddStrings(printer->attrs, IPP_TAG_PRINTER, IPP_TAG_URI, "printer-uri-supported", 2, NULL, (const char **)uris);
-
-#else
-  ippAddString(printer->attrs, IPP_TAG_PRINTER, IPP_TAG_URI, "printer-uri-supported", NULL, uri);
-#endif /* HAVE_SSL */
+  /* printer-strings-languages-supported */
+  ippAddString(printer->attrs, IPP_TAG_PRINTER, IPP_TAG_LANGUAGE, "printer-strings-languages-supported", NULL, "en");
 
   /* printer-uuid */
   ippAddString(printer->attrs, IPP_TAG_PRINTER, IPP_TAG_URI, "printer-uuid", NULL, uuid);
@@ -1929,10 +1973,10 @@ create_printer(
   debug_attributes("Printer", printer->attrs, 0);
 
  /*
-  * Register the printer with Bonjour...
+  * Register the printer with DNS-SD...
   */
 
-  if (!register_printer(printer, subtypes))
+  if (!register_printer(printer))
     goto bad_printer;
 
  /*
@@ -2088,14 +2132,8 @@ delete_printer(ippeve_printer_t *printer
 #elif defined(HAVE_AVAHI)
   avahi_threaded_poll_lock(DNSSDMaster);
 
-  if (printer->printer_ref)
-    avahi_entry_group_free(printer->printer_ref);
-  if (printer->ipp_ref)
-    avahi_entry_group_free(printer->ipp_ref);
-  if (printer->ipps_ref)
-    avahi_entry_group_free(printer->ipps_ref);
-  if (printer->http_ref)
-    avahi_entry_group_free(printer->http_ref);
+  if (printer->dnssd_ref)
+    avahi_entry_group_free(printer->dnssd_ref);
 
   avahi_threaded_poll_unlock(DNSSDMaster);
 #endif /* HAVE_DNSSD */
@@ -2104,8 +2142,10 @@ delete_printer(ippeve_printer_t *printer
     free(printer->dnssd_name);
   if (printer->name)
     free(printer->name);
-  if (printer->icon)
-    free(printer->icon);
+  if (printer->icons[0])
+    free(printer->icons[0]);
+  if (printer->strings)
+    free(printer->strings);
   if (printer->command)
     free(printer->command);
   if (printer->device_uri)
@@ -2118,8 +2158,6 @@ delete_printer(ippeve_printer_t *printer
     free(printer->directory);
   if (printer->hostname)
     free(printer->hostname);
-  if (printer->uri)
-    free(printer->uri);
 
   ippDelete(printer->attrs);
   cupsArrayDelete(printer->jobs);
@@ -2130,7 +2168,7 @@ delete_printer(ippeve_printer_t *printer
 
 #ifdef HAVE_DNSSD
 /*
- * 'dnssd_callback()' - Handle Bonjour registration events.
+ * 'dnssd_callback()' - Handle DNS-SD registration events.
  */
 
 static void DNSSD_API
@@ -2141,32 +2179,29 @@ dnssd_callback(
     const char          *name,		/* I - Service name */
     const char          *regtype,	/* I - Service type */
     const char          *domain,	/* I - Domain for service */
-    ippeve_printer_t      *printer)	/* I - Printer */
+    ippeve_printer_t    *printer)	/* I - Printer */
 {
   (void)sdRef;
   (void)flags;
   (void)domain;
+  (void)name;
 
-  if (errorCode)
+  if (errorCode == kDNSServiceErr_NameConflict)
   {
-    fprintf(stderr, "DNSServiceRegister for %s failed with error %d.\n", regtype, (int)errorCode);
-    return;
+    fputs("DNS-SD service name collision detected.\n", stderr);
+    printer->dnssd_collision = 1;
   }
-  else if (strcasecmp(name, printer->dnssd_name))
+  else if (errorCode)
   {
-    if (Verbosity)
-      fprintf(stderr, "Now using DNS-SD service name \"%s\".\n", name);
-
-    /* No lock needed since only the main thread accesses/changes this */
-    free(printer->dnssd_name);
-    printer->dnssd_name = strdup(name);
+    fprintf(stderr, "DNSServiceRegister for %s failed with error %d.\n", regtype, (int)errorCode);
+    return;
   }
 }
 
 
 #elif defined(HAVE_AVAHI)
 /*
- * 'dnssd_callback()' - Handle Bonjour registration events.
+ * 'dnssd_callback()' - Handle DNS-SD registration events.
  */
 
 static void
@@ -2175,9 +2210,17 @@ dnssd_callback(
     AvahiEntryGroupState state,		/* I - Registration state */
     void                 *context)	/* I - Printer */
 {
+  ippeve_printer_t *printer = (ippeve_printer_t *)context;
+ 					/* Printer */
+
+
   (void)srv;
-  (void)state;
-  (void)context;
+
+  if (state == AVAHI_ENTRY_GROUP_COLLISION)
+  {
+    fputs("DNS-SD service name collision detected.\n", stderr);
+    printer->dnssd_collision = 1;
+  }
 }
 
 
@@ -2191,10 +2234,8 @@ static void
 dnssd_client_cb(
     AvahiClient      *c,		/* I - Client */
     AvahiClientState state,		/* I - Current state */
-    void             *userdata)		/* I - User data (unused) */
+    void             *userdata)		/* I - User data (printer) */
 {
-  (void)userdata;
-
   if (!c)
     return;
 
@@ -2226,7 +2267,7 @@ dnssd_init(void)
 #ifdef HAVE_DNSSD
   if (DNSServiceCreateConnection(&DNSSDMaster) != kDNSServiceErr_NoError)
   {
-    fputs("Error: Unable to initialize Bonjour.\n", stderr);
+    fputs("Error: Unable to initialize DNS-SD.\n", stderr);
     exit(1);
   }
 
@@ -2235,13 +2276,13 @@ dnssd_init(void)
 
   if ((DNSSDMaster = avahi_threaded_poll_new()) == NULL)
   {
-    fputs("Error: Unable to initialize Bonjour.\n", stderr);
+    fputs("Error: Unable to initialize DNS-SD.\n", stderr);
     exit(1);
   }
 
   if ((DNSSDClient = avahi_client_new(avahi_threaded_poll_get(DNSSDMaster), AVAHI_CLIENT_NO_FAIL, dnssd_client_cb, NULL, &error)) == NULL)
   {
-    fputs("Error: Unable to initialize Bonjour.\n", stderr);
+    fputs("Error: Unable to initialize DNS-SD.\n", stderr);
     exit(1);
   }
 
@@ -2292,10 +2333,12 @@ find_job(ippeve_client_t *client)		/* I
   if ((attr = ippFindAttribute(client->request, "job-uri", IPP_TAG_URI)) != NULL)
   {
     const char *uri = ippGetString(attr, 0, NULL);
+					/* URI value */
+    const char *uriptr = strrchr(uri, '/');
+					/* Pointer to the last slash in the URI */
 
-    if (!strncmp(uri, client->printer->uri, client->printer->urilen) &&
-        uri[client->printer->urilen] == '/')
-      key.id = atoi(uri + client->printer->urilen + 1);
+    if (uriptr && isdigit(uriptr[1] & 255))
+      key.id = atoi(uriptr + 1);
     else
       return (NULL);
   }
@@ -2476,8 +2519,9 @@ finish_document_uri(
   * Do we have a file to print?
   */
 
-  if (httpGetState(client->http) == HTTP_STATE_POST_RECV)
+  if (have_document_data(client))
   {
+    flush_document_data(client);
     respond_ipp(client, IPP_STATUS_ERROR_BAD_REQUEST, "Unexpected document data following request.");
 
     goto abort_job;
@@ -2728,6 +2772,42 @@ finish_document_uri(
 
 
 /*
+ * 'flush_document_data()' - Safely flush remaining document data.
+ */
+
+static void
+flush_document_data(
+    ippeve_client_t *client)		/* I - Client */
+{
+  char	buffer[8192];			/* Read buffer */
+
+
+  if (httpGetState(client->http) == HTTP_STATE_POST_RECV)
+  {
+    while (httpRead2(client->http, buffer, sizeof(buffer)) > 0);
+  }
+}
+
+
+/*
+ * 'have_document_data()' - Determine whether we have more document data.
+ */
+
+static int				/* O - 1 if data is present, 0 otherwise */
+have_document_data(
+    ippeve_client_t *client)		/* I - Client */
+{
+  char temp;				/* Data */
+
+
+  if (httpGetState(client->http) != HTTP_STATE_POST_RECV)
+    return (0);
+  else
+    return (httpPeek(client->http, &temp, 1) > 0);
+}
+
+
+/*
  * 'html_escape()' - Write a HTML-safe string.
  */
 
@@ -2989,7 +3069,7 @@ html_printf(ippeve_client_t *client,	/*
 	    if ((size_t)(width + 2) > sizeof(temp))
 	      break;
 
-	    sprintf(temp, tformat, va_arg(ap, double));
+	    snprintf(temp, sizeof(temp), tformat, va_arg(ap, double));
 
             httpWrite2(client->http, temp, strlen(temp));
 	    break;
@@ -3007,13 +3087,13 @@ html_printf(ippeve_client_t *client,	/*
 
 #  ifdef HAVE_LONG_LONG
             if (size == 'L')
-	      sprintf(temp, tformat, va_arg(ap, long long));
+	      snprintf(temp, sizeof(temp), tformat, va_arg(ap, long long));
 	    else
 #  endif /* HAVE_LONG_LONG */
             if (size == 'l')
-	      sprintf(temp, tformat, va_arg(ap, long));
+	      snprintf(temp, sizeof(temp), tformat, va_arg(ap, long));
 	    else
-	      sprintf(temp, tformat, va_arg(ap, int));
+	      snprintf(temp, sizeof(temp), tformat, va_arg(ap, int));
 
             httpWrite2(client->http, temp, strlen(temp));
 	    break;
@@ -3022,7 +3102,7 @@ html_printf(ippeve_client_t *client,	/*
 	    if ((size_t)(width + 2) > sizeof(temp))
 	      break;
 
-	    sprintf(temp, tformat, va_arg(ap, void *));
+	    snprintf(temp, sizeof(temp), tformat, va_arg(ap, void *));
 
             httpWrite2(client->http, temp, strlen(temp));
 	    break;
@@ -3124,6 +3204,53 @@ ipp_cancel_job(ippeve_client_t *client)
 
 
 /*
+ * 'ipp_cancel_my_jobs()' - Cancel all jobs.
+ *
+ * Note: Since ippeveprinter doesn't do spooling, this really just cancels the
+ * current job.
+ */
+
+static void
+ipp_cancel_my_jobs(
+    ippeve_client_t *client)		/* I - Client */
+{
+  ippeve_job_t		*job;		/* Job information */
+
+
+  _cupsRWLockWrite(&client->printer->rwlock);
+
+  if ((job = client->printer->active_job) != NULL)
+  {
+   /*
+    * See if the job is already completed, canceled, or aborted; if so,
+    * we can't cancel...
+    */
+
+    if (job->state < IPP_JSTATE_CANCELED)
+    {
+     /*
+      * Cancel the job...
+      */
+
+      if (job->state == IPP_JSTATE_PROCESSING || (job->state == IPP_JSTATE_HELD && job->fd >= 0))
+      {
+	job->cancel = 1;
+      }
+      else
+      {
+	job->state     = IPP_JSTATE_CANCELED;
+	job->completed = time(NULL);
+      }
+    }
+  }
+
+  respond_ipp(client, IPP_STATUS_OK, NULL);
+
+  _cupsRWUnlock(&client->printer->rwlock);
+}
+
+
+/*
  * 'ipp_close_job()' - Close an open job.
  */
 
@@ -3190,25 +3317,23 @@ ipp_create_job(ippeve_client_t *client)
 
 
  /*
-  * Validate print job attributes...
+  * Do we have a file to print?
   */
 
-  if (!valid_job_attributes(client))
+  if (have_document_data(client))
   {
-    httpFlush(client->http);
+    flush_document_data(client);
+    respond_ipp(client, IPP_STATUS_ERROR_BAD_REQUEST,
+                "Unexpected document data following request.");
     return;
   }
 
  /*
-  * Do we have a file to print?
+  * Validate print job attributes...
   */
 
-  if (httpGetState(client->http) == HTTP_STATE_POST_RECV)
-  {
-    respond_ipp(client, IPP_STATUS_ERROR_BAD_REQUEST,
-                "Unexpected document data following request.");
+  if (!valid_job_attributes(client))
     return;
-  }
 
  /*
   * Create the job...
@@ -3477,6 +3602,29 @@ ipp_get_printer_attributes(
   if (!ra || cupsArrayFind(ra, "printer-current-time"))
     ippAddDate(client->response, IPP_TAG_PRINTER, "printer-current-time", ippTimeToDate(time(NULL)));
 
+  if (!ra || cupsArrayFind(ra, "printer-icons"))
+  {
+    char	uris[3][1024];		/* Buffers for URIs */
+    const char	*values[3];		/* Values for attribute */
+
+    httpAssembleURI(HTTP_URI_CODING_ALL, uris[0], sizeof(uris[0]), WEB_SCHEME, NULL, client->host_field, client->host_port, "/icon-sm.png");
+    httpAssembleURI(HTTP_URI_CODING_ALL, uris[1], sizeof(uris[1]), WEB_SCHEME, NULL, client->host_field, client->host_port, "/icon.png");
+    httpAssembleURI(HTTP_URI_CODING_ALL, uris[2], sizeof(uris[2]), WEB_SCHEME, NULL, client->host_field, client->host_port, "/icon-lg.png");
+
+    values[0] = uris[0];
+    values[1] = uris[1];
+    values[2] = uris[2];
+
+    ippAddStrings(client->response, IPP_TAG_PRINTER, IPP_TAG_URI, "printer-icons", 3, NULL, values);
+  }
+
+  if (!ra || cupsArrayFind(ra, "printer-more-info"))
+  {
+    char	uri[1024];		/* URI value */
+
+    httpAssembleURI(HTTP_URI_CODING_ALL, uri, sizeof(uri), WEB_SCHEME, NULL, client->host_field, client->host_port, "/");
+    ippAddString(client->response, IPP_TAG_PRINTER, IPP_TAG_URI, "printer-more-info", NULL, uri);
+  }
 
   if (!ra || cupsArrayFind(ra, "printer-state"))
     ippAddInteger(client->response, IPP_TAG_PRINTER, IPP_TAG_ENUM, "printer-state", (int)printer->state);
@@ -3521,9 +3669,42 @@ ipp_get_printer_attributes(
     }
   }
 
+  if (!ra || cupsArrayFind(ra, "printer-strings-uri"))
+  {
+    char	uri[1024];		/* URI value */
+
+    httpAssembleURI(HTTP_URI_CODING_ALL, uri, sizeof(uri), WEB_SCHEME, NULL, client->host_field, client->host_port, "/en.strings");
+    ippAddString(client->response, IPP_TAG_PRINTER, IPP_TAG_URI, "printer-strings-uri", NULL, uri);
+  }
+
+  if (!ra || cupsArrayFind(ra, "printer-supply-info-uri"))
+  {
+    char	uri[1024];		/* URI value */
+
+    httpAssembleURI(HTTP_URI_CODING_ALL, uri, sizeof(uri), WEB_SCHEME, NULL, client->host_field, client->host_port, "/supplies");
+    ippAddString(client->response, IPP_TAG_PRINTER, IPP_TAG_URI, "printer-supply-info-uri", NULL, uri);
+  }
+
   if (!ra || cupsArrayFind(ra, "printer-up-time"))
     ippAddInteger(client->response, IPP_TAG_PRINTER, IPP_TAG_INTEGER, "printer-up-time", (int)(time(NULL) - printer->start_time));
 
+  if (!ra || cupsArrayFind(ra, "printer-uri-supported"))
+  {
+    char	uris[2][1024];		/* Buffers for URIs */
+    const char	*values[2];		/* Values for attribute */
+    int		num_values = 0;		/* Number of values */
+
+    httpAssembleURI(HTTP_URI_CODING_ALL, uris[0], sizeof(uris[0]), "ipp", NULL, client->host_field, client->host_port, "/ipp/print");
+    values[num_values ++] = uris[0];
+
+#ifdef HAVE_SSL
+    httpAssembleURI(HTTP_URI_CODING_ALL, uris[1], sizeof(uris[1]), "ipps", NULL, client->host_field, client->host_port, "/ipp/print");
+    values[num_values ++] = uris[1];
+#endif /* HAVE_SSL */
+
+    ippAddStrings(client->response, IPP_TAG_PRINTER, IPP_TAG_URI, "printer-uri-supported", num_values, NULL, values);
+  }
+
   if (!ra || cupsArrayFind(ra, "queued-job-count"))
     ippAddInteger(client->response, IPP_TAG_PRINTER, IPP_TAG_INTEGER, "queued-job-count", printer->active_job && printer->active_job->state < IPP_JSTATE_CANCELED);
 
@@ -3550,8 +3731,21 @@ ipp_identify_printer(
 
   if (!actions || ippContainsString(actions, "sound"))
   {
+#ifdef __APPLE__
+    pid_t	pid;			/* Process ID for "afplay" utility */
+    static const char * const afplay[3] =
+    {					/* Arguments for "afplay" utility */
+      "/usr/bin/afplay",
+      "/System/Library/Sounds/Ping.aiff",
+      NULL
+    };
+
+    posix_spawn(&pid, afplay[0], NULL, NULL, (char **)afplay, NULL);
+
+#else
     putchar(0x07);
     fflush(stdout);
+#endif /* __APPLE__ */
   }
 
   if (ippContainsString(actions, "display"))
@@ -3577,7 +3771,7 @@ ipp_print_job(ippeve_client_t *client)	/
 
   if (!valid_job_attributes(client))
   {
-    httpFlush(client->http);
+    flush_document_data(client);
     return;
   }
 
@@ -3585,7 +3779,7 @@ ipp_print_job(ippeve_client_t *client)	/
   * Do we have a file to print?
   */
 
-  if (httpGetState(client->http) == HTTP_STATE_POST_SEND)
+  if (!have_document_data(client))
   {
     respond_ipp(client, IPP_STATUS_ERROR_BAD_REQUEST, "No file in request.");
     return;
@@ -3625,7 +3819,7 @@ ipp_print_uri(ippeve_client_t *client)	/
 
   if (!valid_job_attributes(client))
   {
-    httpFlush(client->http);
+    flush_document_data(client);
     return;
   }
 
@@ -3658,6 +3852,7 @@ ipp_send_document(
 {
   ippeve_job_t		*job;		/* Job information */
   ipp_attribute_t	*attr;		/* Current attribute */
+  int			have_data;	/* Have document data? */
 
 
  /*
@@ -3666,26 +3861,28 @@ ipp_send_document(
 
   if ((job = find_job(client)) == NULL)
   {
+    flush_document_data(client);
     respond_ipp(client, IPP_STATUS_ERROR_NOT_FOUND, "Job does not exist.");
-    httpFlush(client->http);
     return;
   }
 
  /*
   * See if we already have a document for this job or the job has already
-  * in a non-pending state...
+  * in a terminating state...
   */
 
-  if (job->state > IPP_JSTATE_HELD)
+  have_data = have_document_data(client);
+
+  if ((job->filename || job->fd >= 0) && have_data)
   {
-    respond_ipp(client, IPP_STATUS_ERROR_NOT_POSSIBLE, "Job is not in a pending state.");
-    httpFlush(client->http);
+    flush_document_data(client);
+    respond_ipp(client, IPP_STATUS_ERROR_MULTIPLE_JOBS_NOT_SUPPORTED, "Multiple document jobs are not supported.");
     return;
   }
-  else if (job->filename || job->fd >= 0)
+  else if (job->state > IPP_JSTATE_HELD && have_data)
   {
-    respond_ipp(client, IPP_STATUS_ERROR_MULTIPLE_JOBS_NOT_SUPPORTED, "Multiple document jobs are not supported.");
-    httpFlush(client->http);
+    flush_document_data(client);
+    respond_ipp(client, IPP_STATUS_ERROR_NOT_POSSIBLE, "Job is not in a pending state.");
     return;
   }
 
@@ -3695,20 +3892,20 @@ ipp_send_document(
 
   if ((attr = ippFindAttribute(client->request, "last-document", IPP_TAG_ZERO)) == NULL)
   {
+    flush_document_data(client);
     respond_ipp(client, IPP_STATUS_ERROR_BAD_REQUEST, "Missing required last-document attribute.");
-    httpFlush(client->http);
     return;
   }
   else if (ippGetGroupTag(attr) != IPP_TAG_OPERATION)
   {
+    flush_document_data(client);
     respond_ipp(client, IPP_STATUS_ERROR_BAD_REQUEST, "The last-document attribute is not in the operation group.");
-    httpFlush(client->http);
     return;
   }
-  else if (ippGetValueTag(attr) != IPP_TAG_BOOLEAN || ippGetCount(attr) != 1 || !ippGetBoolean(attr, 0))
+  else if (ippGetValueTag(attr) != IPP_TAG_BOOLEAN || ippGetCount(attr) != 1)
   {
+    flush_document_data(client);
     respond_unsupported(client, attr);
-    httpFlush(client->http);
     return;
   }
 
@@ -3716,12 +3913,15 @@ ipp_send_document(
   * Validate document attributes...
   */
 
-  if (!valid_doc_attributes(client))
+  if (have_data && !valid_doc_attributes(client))
   {
-    httpFlush(client->http);
+    flush_document_data(client);
     return;
   }
 
+  if (!have_data && !job->filename)
+    job->state = IPP_JSTATE_ABORTED;
+
  /*
   * Then finish getting the document data and process things...
   */
@@ -3739,7 +3939,8 @@ ipp_send_document(
 
   _cupsRWUnlock(&(client->printer->rwlock));
 
-  finish_document_data(client, job);
+  if (have_data)
+    finish_document_data(client, job);
 }
 
 
@@ -3762,44 +3963,39 @@ ipp_send_uri(ippeve_client_t *client)	/*
   if ((job = find_job(client)) == NULL)
   {
     respond_ipp(client, IPP_STATUS_ERROR_NOT_FOUND, "Job does not exist.");
-    httpFlush(client->http);
     return;
   }
 
  /*
   * See if we already have a document for this job or the job has already
-  * in a non-pending state...
+  * in a non-terminating state...
   */
 
-  if (job->state > IPP_JSTATE_HELD)
+  if (job->filename || job->fd >= 0)
   {
-    respond_ipp(client, IPP_STATUS_ERROR_NOT_POSSIBLE, "Job is not in a pending state.");
-    httpFlush(client->http);
+    respond_ipp(client, IPP_STATUS_ERROR_MULTIPLE_JOBS_NOT_SUPPORTED, "Multiple document jobs are not supported.");
     return;
   }
-  else if (job->filename || job->fd >= 0)
+  else if (job->state > IPP_JSTATE_HELD)
   {
-    respond_ipp(client, IPP_STATUS_ERROR_MULTIPLE_JOBS_NOT_SUPPORTED, "Multiple document jobs are not supported.");
-    httpFlush(client->http);
+    flush_document_data(client);
+    respond_ipp(client, IPP_STATUS_ERROR_NOT_POSSIBLE, "Job is not in a pending state.");
     return;
   }
 
   if ((attr = ippFindAttribute(client->request, "last-document", IPP_TAG_ZERO)) == NULL)
   {
     respond_ipp(client, IPP_STATUS_ERROR_BAD_REQUEST, "Missing required last-document attribute.");
-    httpFlush(client->http);
     return;
   }
   else if (ippGetGroupTag(attr) != IPP_TAG_OPERATION)
   {
     respond_ipp(client, IPP_STATUS_ERROR_BAD_REQUEST, "The last-document attribute is not in the operation group.");
-    httpFlush(client->http);
     return;
   }
-  else if (ippGetValueTag(attr) != IPP_TAG_BOOLEAN || ippGetCount(attr) != 1 || !ippGetBoolean(attr, 0))
+  else if (ippGetValueTag(attr) != IPP_TAG_BOOLEAN || ippGetCount(attr) != 1)
   {
     respond_unsupported(client, attr);
-    httpFlush(client->http);
     return;
   }
 
@@ -3809,7 +4005,7 @@ ipp_send_uri(ippeve_client_t *client)	/*
 
   if (!valid_doc_attributes(client))
   {
-    httpFlush(client->http);
+    flush_document_data(client);
     return;
   }
 
@@ -4359,9 +4555,36 @@ load_legacy_attributes(
   if (cupsArrayFind(docformats, (void *)"application/pdf"))
     ippAddInteger(attrs, IPP_TAG_PRINTER, IPP_TAG_INTEGER, "document-password-supported", 1023);
 
+  /* finishing-template-supported */
+  ippAddString(attrs, IPP_TAG_PRINTER, IPP_CONST_TAG(IPP_TAG_KEYWORD), "finishing-template-supported", NULL, "none");
+
+  /* finishings-col-database */
+  col = ippNew();
+  ippAddString(col, IPP_TAG_PRINTER, IPP_CONST_TAG(IPP_TAG_KEYWORD), "finishing-template", NULL, "none");
+  ippAddCollection(attrs, IPP_TAG_PRINTER, "finishings-col-database", col);
+  ippDelete(col);
+
+  /* finishings-col-default */
+  col = ippNew();
+  ippAddString(col, IPP_TAG_PRINTER, IPP_CONST_TAG(IPP_TAG_KEYWORD), "finishing-template", NULL, "none");
+  ippAddCollection(attrs, IPP_TAG_PRINTER, "finishings-col-default", col);
+  ippDelete(col);
+
+  /* finishings-col-ready */
+  col = ippNew();
+  ippAddString(col, IPP_TAG_PRINTER, IPP_CONST_TAG(IPP_TAG_KEYWORD), "finishing-template", NULL, "none");
+  ippAddCollection(attrs, IPP_TAG_PRINTER, "finishings-col-ready", col);
+  ippDelete(col);
+
+  /* finishings-col-supported */
+  ippAddString(attrs, IPP_TAG_PRINTER, IPP_CONST_TAG(IPP_TAG_KEYWORD), "finishings-col-supported", NULL, "finishing-template");
+
   /* finishings-default */
   ippAddInteger(attrs, IPP_TAG_PRINTER, IPP_TAG_ENUM, "finishings-default", IPP_FINISHINGS_NONE);
 
+  /* finishings-ready */
+  ippAddInteger(attrs, IPP_TAG_PRINTER, IPP_TAG_ENUM, "finishings-ready", IPP_FINISHINGS_NONE);
+
   /* finishings-supported */
   ippAddInteger(attrs, IPP_TAG_PRINTER, IPP_TAG_ENUM, "finishings-supported", IPP_FINISHINGS_NONE);
 
@@ -5000,7 +5223,7 @@ load_ppd_attributes(
   }
 
   /* finishings-col-supported */
-  ippAddString(attrs, IPP_TAG_PRINTER, IPP_TAG_KEYWORD, "finishings-col-supported", NULL, "finishing-template");
+  ippAddString(attrs, IPP_TAG_PRINTER, IPP_CONST_TAG(IPP_TAG_KEYWORD), "finishings-col-supported", NULL, "finishing-template");
 
   /* finishings-default */
   ippAddInteger(attrs, IPP_TAG_PRINTER, IPP_TAG_ENUM, "finishings-default", IPP_FINISHINGS_NONE);
@@ -5623,8 +5846,9 @@ process_http(ippeve_client_t *client)	/*
   ipp_state_t		ipp_state;	/* State of IPP transfer */
   char			scheme[32],	/* Method/scheme */
 			userpass[128],	/* Username:password */
-			hostname[HTTP_MAX_HOST];
+			hostname[HTTP_MAX_HOST],
 					/* Hostname */
+			*ptr;		/* Pointer into value */
   int			port;		/* Port number */
   static const char * const http_states[] =
   {					/* Strings for logging HTTP method */
@@ -5733,6 +5957,10 @@ process_http(ippeve_client_t *client)	/*
     return (0);
   }
 
+ /*
+  * Validate the host header...
+  */
+
   if (!httpGetField(client->http, HTTP_FIELD_HOST)[0] &&
       httpGetVersion(client->http) >= HTTP_VERSION_1_1)
   {
@@ -5740,6 +5968,36 @@ process_http(ippeve_client_t *client)	/*
     * HTTP/1.1 and higher require the "Host:" field...
     */
 
+    fprintf(stderr, "%s Missing Host: header.\n", client->hostname);
+    respond_http(client, HTTP_STATUS_BAD_REQUEST, NULL, NULL, 0);
+    return (0);
+  }
+
+  strlcpy(client->host_field, httpGetField(client->http, HTTP_FIELD_HOST), sizeof(client->host_field));
+  if ((ptr = strrchr(client->host_field, ':')) != NULL)
+  {
+   /*
+    * Grab port number from Host: header...
+    */
+
+    *ptr++ = '\0';
+    client->host_port = atoi(ptr);
+  }
+  else
+  {
+   /*
+    * Use the default port number...
+    */
+
+    client->host_port = client->printer->port;
+  }
+
+  ptr = strrchr(client->host_field, '.');
+
+  if (!isdigit(client->host_field[0] & 255) && client->host_field[0] != '[' && strcmp(client->host_field, client->printer->hostname) && strcmp(client->host_field, "localhost") &&
+      (!ptr || (strcmp(ptr, ".local") && strcmp(ptr, ".local."))))
+  {
+    fprintf(stderr, "%s Bad Host: header '%s'.\n", client->hostname, client->host_field);
     respond_http(client, HTTP_STATUS_BAD_REQUEST, NULL, NULL, 0);
     return (0);
   }
@@ -5787,7 +6045,9 @@ process_http(ippeve_client_t *client)	/*
 	return (respond_http(client, HTTP_STATUS_OK, NULL, NULL, 0));
 
     case HTTP_STATE_HEAD :
-        if (!strcmp(client->uri, "/icon.png"))
+        if (!strcmp(client->uri, "/en.strings"))
+	  return (respond_http(client, HTTP_STATUS_OK, NULL, "text/strings", 0));
+        else if (!strcmp(client->uri, "/icon.png") || !strcmp(client->uri, "/icon-lg.png") || !strcmp(client->uri, "/icon-sm.png"))
 	  return (respond_http(client, HTTP_STATUS_OK, NULL, "image/png", 0));
 	else if (!strcmp(client->uri, "/") || !strcmp(client->uri, "/media") || !strcmp(client->uri, "/supplies"))
 	  return (respond_http(client, HTTP_STATUS_OK, NULL, "text/html", 0));
@@ -5795,22 +6055,54 @@ process_http(ippeve_client_t *client)	/*
 	  return (respond_http(client, HTTP_STATUS_NOT_FOUND, NULL, NULL, 0));
 
     case HTTP_STATE_GET :
-        if (!strcmp(client->uri, "/icon.png"))
+        if (!strcmp(client->uri, "/en.strings"))
 	{
 	 /*
-	  * Send PNG icon file.
+	  * Send strings file.
 	  */
 
-          if (client->printer->icon)
+          if (client->printer->strings)
           {
 	    int		fd;		/* Icon file */
 	    struct stat	fileinfo;	/* Icon file information */
 	    char	buffer[4096];	/* Copy buffer */
 	    ssize_t	bytes;		/* Bytes */
 
-	    fprintf(stderr, "Icon file is \"%s\".\n", client->printer->icon);
+	    if (!stat(client->printer->strings, &fileinfo) && (fd = open(client->printer->strings, O_RDONLY)) >= 0)
+	    {
+	      if (!respond_http(client, HTTP_STATUS_OK, NULL, "text/strings", (size_t)fileinfo.st_size))
+	      {
+		close(fd);
+		return (0);
+	      }
+
+	      while ((bytes = read(fd, buffer, sizeof(buffer))) > 0)
+		httpWrite2(client->http, buffer, (size_t)bytes);
+
+	      httpFlushWrite(client->http);
 
-	    if (!stat(client->printer->icon, &fileinfo) && (fd = open(client->printer->icon, O_RDONLY)) >= 0)
+	      close(fd);
+	    }
+	    else
+	      return (respond_http(client, HTTP_STATUS_NOT_FOUND, NULL, NULL, 0));
+	  }
+	  else
+	    return (respond_http(client, HTTP_STATUS_NOT_FOUND, NULL, NULL, 0));
+        }
+        else if (!strcmp(client->uri, "/icon.png"))
+	{
+	 /*
+	  * Send medium PNG icon file.
+	  */
+
+          if (client->printer->icons[1])
+          {
+	    int		fd;		/* Icon file */
+	    struct stat	fileinfo;	/* Icon file information */
+	    char	buffer[4096];	/* Copy buffer */
+	    ssize_t	bytes;		/* Bytes */
+
+	    if (!stat(client->printer->icons[1], &fileinfo) && (fd = open(client->printer->icons[1], O_RDONLY)) >= 0)
 	    {
 	      if (!respond_http(client, HTTP_STATUS_OK, NULL, "image/png", (size_t)fileinfo.st_size))
 	      {
@@ -5839,6 +6131,90 @@ process_http(ippeve_client_t *client)	/*
 	    httpFlushWrite(client->http);
 	  }
 	}
+        else if (!strcmp(client->uri, "/icon-lg.png"))
+	{
+	 /*
+	  * Send large PNG icon file.
+	  */
+
+          if (client->printer->icons[2])
+          {
+	    int		fd;		/* Icon file */
+	    struct stat	fileinfo;	/* Icon file information */
+	    char	buffer[4096];	/* Copy buffer */
+	    ssize_t	bytes;		/* Bytes */
+
+	    if (!stat(client->printer->icons[2], &fileinfo) && (fd = open(client->printer->icons[2], O_RDONLY)) >= 0)
+	    {
+	      if (!respond_http(client, HTTP_STATUS_OK, NULL, "image/png", (size_t)fileinfo.st_size))
+	      {
+		close(fd);
+		return (0);
+	      }
+
+	      while ((bytes = read(fd, buffer, sizeof(buffer))) > 0)
+		httpWrite2(client->http, buffer, (size_t)bytes);
+
+	      httpFlushWrite(client->http);
+
+	      close(fd);
+	    }
+	    else
+	      return (respond_http(client, HTTP_STATUS_NOT_FOUND, NULL, NULL, 0));
+	  }
+	  else
+	  {
+	    fputs("Icon file is internal printer-lg.png.\n", stderr);
+
+	    if (!respond_http(client, HTTP_STATUS_OK, NULL, "image/png", sizeof(printer_lg_png)))
+	      return (0);
+
+            httpWrite2(client->http, (const char *)printer_lg_png, sizeof(printer_lg_png));
+	    httpFlushWrite(client->http);
+	  }
+	}
+        else if (!strcmp(client->uri, "/icon-sm.png"))
+	{
+	 /*
+	  * Send small PNG icon file.
+	  */
+
+          if (client->printer->icons[0])
+          {
+	    int		fd;		/* Icon file */
+	    struct stat	fileinfo;	/* Icon file information */
+	    char	buffer[4096];	/* Copy buffer */
+	    ssize_t	bytes;		/* Bytes */
+
+	    if (!stat(client->printer->icons[0], &fileinfo) && (fd = open(client->printer->icons[0], O_RDONLY)) >= 0)
+	    {
+	      if (!respond_http(client, HTTP_STATUS_OK, NULL, "image/png", (size_t)fileinfo.st_size))
+	      {
+		close(fd);
+		return (0);
+	      }
+
+	      while ((bytes = read(fd, buffer, sizeof(buffer))) > 0)
+		httpWrite2(client->http, buffer, (size_t)bytes);
+
+	      httpFlushWrite(client->http);
+
+	      close(fd);
+	    }
+	    else
+	      return (respond_http(client, HTTP_STATUS_NOT_FOUND, NULL, NULL, 0));
+	  }
+	  else
+	  {
+	    fputs("Icon file is internal printer-sm.png.\n", stderr);
+
+	    if (!respond_http(client, HTTP_STATUS_OK, NULL, "image/png", sizeof(printer_sm_png)))
+	      return (0);
+
+            httpWrite2(client->http, (const char *)printer_sm_png, sizeof(printer_sm_png));
+	    httpFlushWrite(client->http);
+	  }
+	}
 	else
 	{
 	 /*
@@ -6083,12 +6459,13 @@ process_ipp(ippeve_client_t *client)	/*
         else if ((!strcmp(name, "job-uri") &&
                   strncmp(resource, "/ipp/print/", 11)) ||
                  (!strcmp(name, "printer-uri") &&
-                  strcmp(resource, "/ipp/print")))
+                  strcmp(resource, "/ipp/print") &&
+                  (strcmp(resource, "/") || ippGetOperation(client->request) != IPP_OP_GET_PRINTER_ATTRIBUTES)))
 	  respond_ipp(client, IPP_STATUS_ERROR_NOT_FOUND, "%s %s not found.",
 		      name, ippGetString(uri, 0, NULL));
 	else if (client->operation_id != IPP_OP_GET_PRINTER_ATTRIBUTES && (status = authenticate_request(client)) != HTTP_STATUS_CONTINUE)
         {
-          httpFlush(client->http);
+          flush_document_data(client);
 
           return (respond_http(client, status, NULL, NULL, 0));
         }
@@ -6118,7 +6495,7 @@ process_ipp(ippeve_client_t *client)	/*
 	      if (!respond_http(client, HTTP_STATUS_EXPECTATION_FAILED, NULL, NULL, 0))
 		return (0);
 
-	      httpFlush(client->http);
+	      flush_document_data(client);
 	      return (1);
 	    }
 	  }
@@ -6157,6 +6534,10 @@ process_ipp(ippeve_client_t *client)	/*
 		ipp_cancel_job(client);
 		break;
 
+	    case IPP_OP_CANCEL_MY_JOBS :
+		ipp_cancel_my_jobs(client);
+		break;
+
 	    case IPP_OP_GET_JOB_ATTRIBUTES :
 		ipp_get_job_attributes(client);
 		break;
@@ -6745,44 +7126,44 @@ process_state_message(
 
 
 /*
- * 'register_printer()' - Register a printer object via Bonjour.
+ * 'register_printer()' - Register a printer object via DNS-SD.
  */
 
 static int				/* O - 1 on success, 0 on error */
 register_printer(
-    ippeve_printer_t *printer,		/* I - Printer */
-    const char       *subtypes)		/* I - Service subtype(s) */
+    ippeve_printer_t *printer)		/* I - Printer */
 {
 #if defined(HAVE_DNSSD) || defined(HAVE_AVAHI)
-  ippeve_txt_t		ipp_txt;	/* Bonjour IPP TXT record */
+  ippeve_txt_t		ipp_txt;	/* DNS-SD IPP TXT record */
   int			i,		/* Looping var */
 			count;		/* Number of values */
   ipp_attribute_t	*color_supported,
 			*document_format_supported,
 			*printer_location,
 			*printer_make_and_model,
-			*printer_more_info,
 			*printer_uuid,
 			*sides_supported,
 			*urf_supported;	/* Printer attributes */
   const char		*value;		/* Value string */
-  char			formats[252],	/* List of supported formats */
+  char			adminurl[247],	/* adminurl value */
+			formats[252],	/* List of supported formats */
 			urf[252],	/* List of supported URF values */
 			*ptr;		/* Pointer into string */
 
 
-  if (!strcmp(subtypes, "off"))
+  if (printer->dnssd_subtypes && !strcmp(printer->dnssd_subtypes, "off"))
     return (1);
 
   color_supported           = ippFindAttribute(printer->attrs, "color-supported", IPP_TAG_BOOLEAN);
   document_format_supported = ippFindAttribute(printer->attrs, "document-format-supported", IPP_TAG_MIMETYPE);
   printer_location          = ippFindAttribute(printer->attrs, "printer-location", IPP_TAG_TEXT);
   printer_make_and_model    = ippFindAttribute(printer->attrs, "printer-make-and-model", IPP_TAG_TEXT);
-  printer_more_info         = ippFindAttribute(printer->attrs, "printer-more-info", IPP_TAG_URI);
   printer_uuid              = ippFindAttribute(printer->attrs, "printer-uuid", IPP_TAG_URI);
   sides_supported           = ippFindAttribute(printer->attrs, "sides-supported", IPP_TAG_KEYWORD);
   urf_supported             = ippFindAttribute(printer->attrs, "urf-supported", IPP_TAG_KEYWORD);
 
+  httpAssembleURI(HTTP_URI_CODING_ALL, adminurl, sizeof(adminurl), WEB_SCHEME, NULL, printer->hostname, printer->port, "/");
+
   for (i = 0, count = ippGetCount(document_format_supported), ptr = formats; i < count; i ++)
   {
     value = ippGetString(document_format_supported, i, NULL);
@@ -6815,11 +7196,35 @@ register_printer(
       break;
   }
 
+ /*
+  * Rename the service as needed...
+  */
+
+  if (printer->dnssd_collision)
+  {
+    char	new_dnssd_name[256];	/* New DNS-SD name */
+    const char	*uuid = ippGetString(printer_uuid, 0, NULL);
+					/* "printer-uuid" value */
+
+    _cupsRWLockWrite(&printer->rwlock);
+
+    snprintf(new_dnssd_name, sizeof(new_dnssd_name), "%s (%c%c%c%c%c%c)", printer->dnssd_name, toupper(uuid[39]), toupper(uuid[40]), toupper(uuid[41]), toupper(uuid[42]), toupper(uuid[43]), toupper(uuid[44]));
+
+    free(printer->dnssd_name);
+    printer->dnssd_name = strdup(new_dnssd_name);
+
+    fprintf(stderr, "DNS-SD name collision, trying new DNS-SD service name '%s'.\n", printer->dnssd_name);
+
+    _cupsRWUnlock(&printer->rwlock);
+
+    printer->dnssd_collision = 0;
+  }
 #endif /* HAVE_DNSSD || HAVE_AVAHI */
+
 #ifdef HAVE_DNSSD
-  DNSServiceErrorType	error;		/* Error from Bonjour */
-  char			regtype[256];	/* Bonjour service type */
-  uint32_t		interface;	/* Interface index */
+  DNSServiceErrorType	error;		/* Error from DNS-SD */
+  char			regtype[256];	/* DNS-SD service type */
+  uint32_t		ifindex;	/* Interface index */
 
 
  /*
@@ -6830,8 +7235,7 @@ register_printer(
   TXTRecordSetValue(&ipp_txt, "rp", 9, "ipp/print");
   if ((value = ippGetString(printer_make_and_model, 0, NULL)) != NULL)
     TXTRecordSetValue(&ipp_txt, "ty", (uint8_t)strlen(value), value);
-  if ((value = ippGetString(printer_more_info, 0, NULL)) != NULL)
-    TXTRecordSetValue(&ipp_txt, "adminurl", (uint8_t)strlen(value), value);
+  TXTRecordSetValue(&ipp_txt, "adminurl", (uint8_t)strlen(adminurl), adminurl);
   if ((value = ippGetString(printer_location, 0, NULL)) != NULL)
     TXTRecordSetValue(&ipp_txt, "note", (uint8_t)strlen(value), value);
   TXTRecordSetValue(&ipp_txt, "pdl", (uint8_t)strlen(formats), formats);
@@ -6852,11 +7256,14 @@ register_printer(
   * defend our service name but not actually support LPD...
   */
 
-  interface = !strcmp(printer->hostname, "localhost") ? kDNSServiceInterfaceIndexLocalOnly : kDNSServiceInterfaceIndexAny;
+  ifindex = !strcmp(printer->hostname, "localhost") ? kDNSServiceInterfaceIndexLocalOnly : kDNSServiceInterfaceIndexAny;
+
+  if (printer->printer_ref)
+    DNSServiceRefDeallocate(printer->printer_ref);
 
   printer->printer_ref = DNSSDMaster;
 
-  if ((error = DNSServiceRegister(&(printer->printer_ref), kDNSServiceFlagsShareConnection, interface, printer->dnssd_name, "_printer._tcp", NULL /* domain */, NULL /* host */, 0 /* port */, 0 /* txtLen */, NULL /* txtRecord */, (DNSServiceRegisterReply)dnssd_callback, printer)) != kDNSServiceErr_NoError)
+  if ((error = DNSServiceRegister(&(printer->printer_ref), kDNSServiceFlagsShareConnection | kDNSServiceFlagsNoAutoRename, ifindex, printer->dnssd_name, "_printer._tcp", NULL /* domain */, NULL /* host */, 0 /* port */, 0 /* txtLen */, NULL /* txtRecord */, (DNSServiceRegisterReply)dnssd_callback, printer)) != kDNSServiceErr_NoError)
   {
     _cupsLangPrintf(stderr, _("Unable to register \"%s.%s\": %d"), printer->dnssd_name, "_printer._tcp", error);
     return (0);
@@ -6867,14 +7274,17 @@ register_printer(
   * advertise our IPP printer...
   */
 
+  if (printer->ipp_ref)
+    DNSServiceRefDeallocate(printer->ipp_ref);
+
   printer->ipp_ref = DNSSDMaster;
 
-  if (subtypes && *subtypes)
-    snprintf(regtype, sizeof(regtype), "_ipp._tcp,%s", subtypes);
+  if (printer->dnssd_subtypes && *(printer->dnssd_subtypes))
+    snprintf(regtype, sizeof(regtype), "_ipp._tcp,%s", printer->dnssd_subtypes);
   else
     strlcpy(regtype, "_ipp._tcp", sizeof(regtype));
 
-  if ((error = DNSServiceRegister(&(printer->ipp_ref), kDNSServiceFlagsShareConnection, interface, printer->dnssd_name, regtype, NULL /* domain */, NULL /* host */, htons(printer->port), TXTRecordGetLength(&ipp_txt), TXTRecordGetBytesPtr(&ipp_txt), (DNSServiceRegisterReply)dnssd_callback, printer)) != kDNSServiceErr_NoError)
+  if ((error = DNSServiceRegister(&(printer->ipp_ref), kDNSServiceFlagsShareConnection | kDNSServiceFlagsNoAutoRename, ifindex, printer->dnssd_name, regtype, NULL /* domain */, NULL /* host */, htons(printer->port), TXTRecordGetLength(&ipp_txt), TXTRecordGetBytesPtr(&ipp_txt), (DNSServiceRegisterReply)dnssd_callback, printer)) != kDNSServiceErr_NoError)
   {
     _cupsLangPrintf(stderr, _("Unable to register \"%s.%s\": %d"), printer->dnssd_name, regtype, error);
     return (0);
@@ -6886,14 +7296,17 @@ register_printer(
   * advertise our IPPS printer...
   */
 
+  if (printer->ipps_ref)
+    DNSServiceRefDeallocate(printer->ipps_ref);
+
   printer->ipps_ref = DNSSDMaster;
 
-  if (subtypes && *subtypes)
-    snprintf(regtype, sizeof(regtype), "_ipps._tcp,%s", subtypes);
+  if (printer->dnssd_subtypes && *(printer->dnssd_subtypes))
+    snprintf(regtype, sizeof(regtype), "_ipps._tcp,%s", printer->dnssd_subtypes);
   else
     strlcpy(regtype, "_ipps._tcp", sizeof(regtype));
 
-  if ((error = DNSServiceRegister(&(printer->ipps_ref), kDNSServiceFlagsShareConnection, interface, printer->dnssd_name, regtype, NULL /* domain */, NULL /* host */, htons(printer->port), TXTRecordGetLength(&ipp_txt), TXTRecordGetBytesPtr(&ipp_txt), (DNSServiceRegisterReply)dnssd_callback, printer)) != kDNSServiceErr_NoError)
+  if ((error = DNSServiceRegister(&(printer->ipps_ref), kDNSServiceFlagsShareConnection | kDNSServiceFlagsNoAutoRename, ifindex, printer->dnssd_name, regtype, NULL /* domain */, NULL /* host */, htons(printer->port), TXTRecordGetLength(&ipp_txt), TXTRecordGetBytesPtr(&ipp_txt), (DNSServiceRegisterReply)dnssd_callback, printer)) != kDNSServiceErr_NoError)
   {
     _cupsLangPrintf(stderr, _("Unable to register \"%s.%s\": %d"), printer->dnssd_name, regtype, error);
     return (0);
@@ -6905,9 +7318,12 @@ register_printer(
   * real port number to advertise our IPP printer...
   */
 
+  if (printer->http_ref)
+    DNSServiceRefDeallocate(printer->http_ref);
+
   printer->http_ref = DNSSDMaster;
 
-  if ((error = DNSServiceRegister(&(printer->http_ref), kDNSServiceFlagsShareConnection, interface, printer->dnssd_name, "_http._tcp,_printer", NULL /* domain */, NULL /* host */, htons(printer->port), 0 /* txtLen */, NULL /* txtRecord */, (DNSServiceRegisterReply)dnssd_callback, printer)) != kDNSServiceErr_NoError)
+  if ((error = DNSServiceRegister(&(printer->http_ref), kDNSServiceFlagsShareConnection | kDNSServiceFlagsNoAutoRename, ifindex, printer->dnssd_name, "_http._tcp,_printer", NULL /* domain */, NULL /* host */, htons(printer->port), 0 /* txtLen */, NULL /* txtRecord */, (DNSServiceRegisterReply)dnssd_callback, printer)) != kDNSServiceErr_NoError)
   {
     _cupsLangPrintf(stderr, _("Unable to register \"%s.%s\": %d"), printer->dnssd_name, "_http._tcp,_printer", error);
     return (0);
@@ -6926,8 +7342,7 @@ register_printer(
   ipp_txt = avahi_string_list_add_printf(ipp_txt, "rp=ipp/print");
   if ((value = ippGetString(printer_make_and_model, 0, NULL)) != NULL)
     ipp_txt = avahi_string_list_add_printf(ipp_txt, "ty=%s", value);
-  if ((value = ippGetString(printer_more_info, 0, NULL)) != NULL)
-    ipp_txt = avahi_string_list_add_printf(ipp_txt, "adminurl=%s", value);
+  ipp_txt = avahi_string_list_add_printf(ipp_txt, "adminurl=%s", adminurl);
   if ((value = ippGetString(printer_location, 0, NULL)) != NULL)
     ipp_txt = avahi_string_list_add_printf(ipp_txt, "note=%s", value);
   ipp_txt = avahi_string_list_add_printf(ipp_txt, "pdl=%s", formats);
@@ -6949,18 +7364,21 @@ register_printer(
 
   avahi_threaded_poll_lock(DNSSDMaster);
 
-  printer->ipp_ref = avahi_entry_group_new(DNSSDClient, dnssd_callback, NULL);
+  if (printer->dnssd_ref)
+    avahi_entry_group_free(printer->dnssd_ref);
 
-  avahi_entry_group_add_service_strlst(printer->ipp_ref, AVAHI_IF_UNSPEC, AVAHI_PROTO_UNSPEC, 0, printer->dnssd_name, "_printer._tcp", NULL, NULL, 0, NULL);
+  printer->dnssd_ref = avahi_entry_group_new(DNSSDClient, dnssd_callback, printer);
+
+  avahi_entry_group_add_service_strlst(printer->dnssd_ref, AVAHI_IF_UNSPEC, AVAHI_PROTO_UNSPEC, 0, printer->dnssd_name, "_printer._tcp", NULL, NULL, 0, NULL);
 
  /*
   * Then register the _ipp._tcp (IPP)...
   */
 
-  avahi_entry_group_add_service_strlst(printer->ipp_ref, AVAHI_IF_UNSPEC, AVAHI_PROTO_UNSPEC, 0, printer->dnssd_name, "_ipp._tcp", NULL, NULL, printer->port, ipp_txt);
-  if (subtypes && *subtypes)
+  avahi_entry_group_add_service_strlst(printer->dnssd_ref, AVAHI_IF_UNSPEC, AVAHI_PROTO_UNSPEC, 0, printer->dnssd_name, "_ipp._tcp", NULL, NULL, printer->port, ipp_txt);
+  if (printer->dnssd_subtypes && *(printer->dnssd_subtypes))
   {
-    char *temptypes = strdup(subtypes), *start, *end;
+    char *temptypes = strdup(printer->dnssd_subtypes), *start, *end;
 
     for (start = temptypes; *start; start = end)
     {
@@ -6970,7 +7388,7 @@ register_printer(
         end = start + strlen(start);
 
       snprintf(temp, sizeof(temp), "%s._sub._ipp._tcp", start);
-      avahi_entry_group_add_service_subtype(printer->ipp_ref, AVAHI_IF_UNSPEC, AVAHI_PROTO_UNSPEC, 0, printer->dnssd_name, "_ipp._tcp", NULL, temp);
+      avahi_entry_group_add_service_subtype(printer->dnssd_ref, AVAHI_IF_UNSPEC, AVAHI_PROTO_UNSPEC, 0, printer->dnssd_name, "_ipp._tcp", NULL, temp);
     }
 
     free(temptypes);
@@ -6981,10 +7399,10 @@ register_printer(
   * _ipps._tcp (IPPS) for secure printing...
   */
 
-  avahi_entry_group_add_service_strlst(printer->ipp_ref, AVAHI_IF_UNSPEC, AVAHI_PROTO_UNSPEC, 0, printer->dnssd_name, "_ipps._tcp", NULL, NULL, printer->port, ipp_txt);
-  if (subtypes && *subtypes)
+  avahi_entry_group_add_service_strlst(printer->dnssd_ref, AVAHI_IF_UNSPEC, AVAHI_PROTO_UNSPEC, 0, printer->dnssd_name, "_ipps._tcp", NULL, NULL, printer->port, ipp_txt);
+  if (printer->dnssd_subtypes && *(printer->dnssd_subtypes))
   {
-    char *temptypes = strdup(subtypes), *start, *end;
+    char *temptypes = strdup(printer->dnssd_subtypes), *start, *end;
 
     for (start = temptypes; *start; start = end)
     {
@@ -6994,7 +7412,7 @@ register_printer(
         end = start + strlen(start);
 
       snprintf(temp, sizeof(temp), "%s._sub._ipps._tcp", start);
-      avahi_entry_group_add_service_subtype(printer->ipp_ref, AVAHI_IF_UNSPEC, AVAHI_PROTO_UNSPEC, 0, printer->dnssd_name, "_ipps._tcp", NULL, temp);
+      avahi_entry_group_add_service_subtype(printer->dnssd_ref, AVAHI_IF_UNSPEC, AVAHI_PROTO_UNSPEC, 0, printer->dnssd_name, "_ipps._tcp", NULL, temp);
     }
 
     free(temptypes);
@@ -7005,14 +7423,14 @@ register_printer(
   * Finally _http.tcp (HTTP) for the web interface...
   */
 
-  avahi_entry_group_add_service_strlst(printer->ipp_ref, AVAHI_IF_UNSPEC, AVAHI_PROTO_UNSPEC, 0, printer->dnssd_name, "_http._tcp", NULL, NULL, printer->port, NULL);
-  avahi_entry_group_add_service_subtype(printer->ipp_ref, AVAHI_IF_UNSPEC, AVAHI_PROTO_UNSPEC, 0, printer->dnssd_name, "_http._tcp", NULL, "_printer._sub._http._tcp");
+  avahi_entry_group_add_service_strlst(printer->dnssd_ref, AVAHI_IF_UNSPEC, AVAHI_PROTO_UNSPEC, 0, printer->dnssd_name, "_http._tcp", NULL, NULL, printer->port, NULL);
+  avahi_entry_group_add_service_subtype(printer->dnssd_ref, AVAHI_IF_UNSPEC, AVAHI_PROTO_UNSPEC, 0, printer->dnssd_name, "_http._tcp", NULL, "_printer._sub._http._tcp");
 
  /*
   * Commit it...
   */
 
-  avahi_entry_group_commit(printer->ipp_ref);
+  avahi_entry_group_commit(printer->dnssd_ref);
   avahi_threaded_poll_unlock(DNSSDMaster);
 
   avahi_string_list_free(ipp_txt);
@@ -7194,14 +7612,13 @@ respond_unsupported(
 static void
 run_printer(ippeve_printer_t *printer)	/* I - Printer */
 {
-  int		num_fds;		/* Number of file descriptors */
-  struct pollfd	polldata[3];		/* poll() data */
-  int		timeout;		/* Timeout for poll() */
-  ippeve_client_t	*client;		/* New client */
+  int			num_fds;	/* Number of file descriptors */
+  struct pollfd		polldata[3];	/* poll() data */
+  ippeve_client_t	*client;	/* New client */
 
 
  /*
-  * Setup poll() data for the Bonjour service socket and IPv4/6 listeners...
+  * Setup poll() data for the DNS-SD service socket and IPv4/6 listeners...
   */
 
   polldata[0].fd     = printer->ipv4;
@@ -7223,12 +7640,7 @@ run_printer(ippeve_printer_t *printer)	/
 
   for (;;)
   {
-    if (cupsArrayCount(printer->jobs))
-      timeout = 10;
-    else
-      timeout = -1;
-
-    if (poll(polldata, (nfds_t)num_fds, timeout) < 0 && errno != EINTR)
+    if (poll(polldata, (nfds_t)num_fds, 1000) < 0 && errno != EINTR)
     {
       perror("poll() failed");
       break;
@@ -7270,11 +7682,20 @@ run_printer(ippeve_printer_t *printer)	/
       }
     }
 
+   /*
+    * Process DNS-SD messages...
+    */
+
 #ifdef HAVE_DNSSD
     if (polldata[2].revents & POLLIN)
       DNSServiceProcessResult(DNSSDMaster);
 #endif /* HAVE_DNSSD */
 
+#if defined(HAVE_DNSSD) || defined(HAVE_AVAHI)
+    if (printer->dnssd_collision)
+      register_printer(printer);
+#endif /* HAVE_DNSSD || HAVE_AVAHI */
+
    /*
     * Clean out old jobs...
     */
@@ -7932,13 +8353,16 @@ usage(int status)			/* O - Exit status *
   _cupsLangPuts(stdout, _("-K keypath              Set location of server X.509 certificates and keys."));
 #endif /* HAVE_SSL */
   _cupsLangPuts(stdout, _("-M manufacturer         Set manufacturer name (default=Test)"));
+#if !CUPS_LITE
   _cupsLangPuts(stdout, _("-P filename.ppd         Load printer attributes from PPD file"));
+#endif /* !CUPS_LITE */
+  _cupsLangPuts(stdout, _("-S filename.strings     Set strings file"));
   _cupsLangPuts(stdout, _("-V version              Set default IPP version"));
   _cupsLangPuts(stdout, _("-a filename.conf        Load printer attributes from conf file"));
   _cupsLangPuts(stdout, _("-c command              Set print command"));
   _cupsLangPuts(stdout, _("-d spool-directory      Set spool directory"));
   _cupsLangPuts(stdout, _("-f type/subtype[,...]   Set supported file types"));
-  _cupsLangPuts(stdout, _("-i iconfile.png         Set icon file"));
+  _cupsLangPuts(stdout, _("-i iconfile.png[,...]   Set icon file(s)"));
   _cupsLangPuts(stdout, _("-k                      Keep job spool files"));
   _cupsLangPuts(stdout, _("-l location             Set location of printer"));
   _cupsLangPuts(stdout, _("-m model                Set model name (default=Printer)"));
@@ -8056,6 +8480,7 @@ valid_doc_attributes(
     memset(header, 0, sizeof(header));
     httpPeek(client->http, (char *)header, sizeof(header));
 
+    fprintf(stderr, "%s %s Auto-type header: %02X%02X%02X%02X%02X%02X%02X%02X\n", client->hostname, op_name, header[0], header[1], header[2], header[3], header[4], header[5], header[6], header[7]);
     if (!memcmp(header, "%PDF", 4))
       format = "application/pdf";
     else if (!memcmp(header, "%!", 2))
@@ -8064,7 +8489,7 @@ valid_doc_attributes(
       format = "image/jpeg";
     else if (!memcmp(header, "\211PNG", 4))
       format = "image/png";
-    else if (!memcmp(header, "RAS2", 4))
+    else if (!memcmp(header, "RaS2PwgR", 8))
       format = "image/pwg-raster";
     else if (!memcmp(header, "UNIRAST", 8))
       format = "image/urf";
diff -pruN 2.3.3-3/tools/ippfind.c 2.3.3op1-3/tools/ippfind.c
--- 2.3.3-3/tools/ippfind.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/tools/ippfind.c	2020-11-27 14:25:26.000000000 +0000
@@ -3,6 +3,7 @@
  * commands such as IPP and Bonjour conformance tests.  This tool is
  * inspired by the UNIX "find" command, thus its name.
  *
+ * Copyright © 2020 by the IEEE-ISTO Printer Working Group
  * Copyright © 2008-2018 by Apple Inc.
  *
  * Licensed under Apache License v2.0.  See the file "LICENSE" for more
@@ -1273,6 +1274,16 @@ main(int  argc,				/* I - Number of comm
       }
 
 #elif defined(HAVE_AVAHI)
+      char	*subtype,		/* Sub-type, if any */
+		subtype_buf[256];	/* Sub-type buffer */
+
+      if ((subtype = strstr(regtype, ",_")) != NULL)
+      {
+        *subtype++ = '\0';
+        snprintf(subtype_buf, sizeof(subtype_buf), "%s._sub.%s", subtype, regtype);
+        regtype = subtype_buf;
+      }
+
       if (avahi_service_browser_new(avahi_client, AVAHI_IF_UNSPEC,
                                     AVAHI_PROTO_UNSPEC, regtype, domain, 0,
                                     browse_callback, services))
@@ -2774,6 +2785,7 @@ show_usage(void)
   _cupsLangPuts(stderr, _("-h regex                Match hostname to regular expression"));
   _cupsLangPuts(stderr, _("-l                      List attributes"));
   _cupsLangPuts(stderr, _("-n regex                Match service name to regular expression"));
+  _cupsLangPuts(stderr, _("-N name                 Match service name to literal name value"));
   _cupsLangPuts(stderr, _("-p                      Print URI if true"));
   _cupsLangPuts(stderr, _("-q                      Quietly report match via exit code"));
   _cupsLangPuts(stderr, _("-r                      True if service is remote"));
@@ -2786,8 +2798,9 @@ show_usage(void)
   _cupsLangPuts(stderr, _("--exec utility [argument ...] ;\n"
                           "                        Execute program if true"));
   _cupsLangPuts(stderr, _("--host regex            Match hostname to regular expression"));
-  _cupsLangPuts(stderr, _("--ls                    List attributes"));
+  _cupsLangPuts(stderr, _("--literal-name name     Match service name to literal name value"));
   _cupsLangPuts(stderr, _("--local                 True if service is local"));
+  _cupsLangPuts(stderr, _("--ls                    List attributes"));
   _cupsLangPuts(stderr, _("--name regex            Match service name to regular expression"));
   _cupsLangPuts(stderr, _("--path regex            Match resource path to regular expression"));
   _cupsLangPuts(stderr, _("--port number[-number]  Match port to number or range"));
diff -pruN 2.3.3-3/tools/ipptool.c 2.3.3op1-3/tools/ipptool.c
--- 2.3.3-3/tools/ipptool.c	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/tools/ipptool.c	2020-11-27 14:25:26.000000000 +0000
@@ -1,6 +1,7 @@
 /*
  * ipptool command for CUPS.
  *
+ * Copyright @ 2020 by The Printer Working Group.
  * Copyright © 2007-2019 by Apple Inc.
  * Copyright © 1997-2007 by Easy Software Products.
  *
@@ -140,6 +141,7 @@ typedef struct _cups_testdata_s		/**** T
 		file_id[1024];		/* File identifier */
   int		ignore_errors;		/* Ignore test failures? */
   char		name[1024];		/* Test name */
+  char		pause[1024];		/* PAUSE value */
   useconds_t	repeat_interval;	/* Repeat interval (delay) */
   int		request_id;		/* Current request ID */
   char		resource[512];		/* Resource for request */
@@ -709,7 +711,7 @@ main(int  argc,				/* I - Number of comm
 
   cupsFileClose(data.outfile);
 
-/*
+ /*
   * Exit...
   */
 
@@ -916,6 +918,18 @@ do_test(_ipp_file_t      *f,		/* I - IPP
     return (0);
 
  /*
+  * Show any PAUSE message, as needed...
+  */
+
+  if (data->pause[0])
+  {
+    if (!data->skip_test)
+      pause_message(data->pause);
+
+    data->pause[0] = '\0';
+  }
+
+ /*
   * Take over control of the attributes in the request...
   */
 
@@ -2047,6 +2061,21 @@ get_filename(const char *testfile,	/* I
       dstptr = dst; /* Should never happen */
 
     strlcpy(dstptr, src, dstsize - (size_t)(dstptr - dst));
+
+#if _WIN32
+    if (_access(dst, 0))
+    {
+     /*
+      * Not available relative to the testfile, see if it can be found on the
+      * desktop...
+      */
+      const char *userprofile = getenv("USERPROFILE");
+					/* User home directory */
+
+      if (userprofile)
+        snprintf(dst, dstsize, "%s/Desktop/%s", userprofile, src);
+    }
+#endif /* _WIN32 */
   }
 
   return (dst);
@@ -3132,7 +3161,7 @@ token_cb(_ipp_file_t      *f,		/* I - IP
 
       if (_ippFileReadToken(f, temp, sizeof(temp)))
       {
-        pause_message(temp);
+        strlcpy(data->pause, temp, sizeof(data->pause));
       }
       else
       {
Binary files 2.3.3-3/tools/printer-lg.png and 2.3.3op1-3/tools/printer-lg.png differ
diff -pruN 2.3.3-3/tools/printer-lg-png.h 2.3.3op1-3/tools/printer-lg-png.h
--- 2.3.3-3/tools/printer-lg-png.h	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/tools/printer-lg-png.h	2020-11-27 14:25:26.000000000 +0000
@@ -0,0 +1,1850 @@
+static const unsigned char printer_lg_png[] =
+{
+  0x89,0x50,0x4e,0x47,0x0d,0x0a,0x1a,0x0a,0x00,0x00,0x00,0x0d,0x49,0x48,0x44,0x52,
+  0x00,0x00,0x02,0x00,0x00,0x00,0x02,0x00,0x08,0x06,0x00,0x00,0x00,0xf4,0x78,0xd4,
+  0xfa,0x00,0x00,0x04,0x19,0x69,0x43,0x43,0x50,0x6b,0x43,0x47,0x43,0x6f,0x6c,0x6f,
+  0x72,0x53,0x70,0x61,0x63,0x65,0x47,0x65,0x6e,0x65,0x72,0x69,0x63,0x52,0x47,0x42,
+  0x00,0x00,0x38,0x8d,0x8d,0x55,0x5d,0x68,0x1c,0x55,0x14,0x3e,0xbb,0x73,0x67,0x23,
+  0x24,0xce,0x53,0x6c,0x34,0x85,0x74,0xa8,0x3f,0x0d,0x25,0x0d,0x93,0x56,0x34,0xa1,
+  0xb4,0xba,0x7f,0xdd,0xdd,0x36,0x6e,0x96,0x49,0x36,0xda,0x22,0xe8,0x64,0xf6,0xee,
+  0xce,0x98,0xc9,0xce,0x38,0x33,0xbb,0xfd,0xa1,0x4f,0x45,0x50,0x7c,0x31,0xea,0x9b,
+  0x14,0xc4,0xbf,0xb7,0x80,0x20,0x28,0xf5,0x0f,0xdb,0x3e,0xb4,0x2f,0x95,0x0a,0x25,
+  0xda,0xd4,0x20,0x28,0x3e,0xb4,0xf8,0x83,0x50,0xe8,0x8b,0xa6,0xeb,0x99,0x3b,0x33,
+  0x99,0x69,0xba,0xb1,0xde,0x65,0xee,0x7c,0xf3,0x9d,0xef,0x9e,0x7b,0xee,0xb9,0x67,
+  0xef,0x05,0xe8,0xb9,0xaa,0x58,0x96,0x91,0x14,0x01,0x16,0x9a,0xae,0x2d,0x17,0x32,
+  0xe2,0x73,0x87,0x8f,0x88,0x3d,0x2b,0x90,0x84,0x87,0xa0,0x17,0x06,0xa1,0x57,0x51,
+  0x1d,0x2b,0x5d,0xa9,0x4c,0x02,0x36,0x4f,0x0b,0x77,0xb5,0x5b,0xdf,0x43,0xc2,0x7b,
+  0x5f,0xd9,0xd5,0xdd,0xfe,0x9f,0xad,0xb7,0x46,0x1d,0x15,0x20,0x71,0x1f,0x62,0xb3,
+  0xe6,0xa8,0x0b,0x88,0x8f,0x01,0xf0,0xa7,0x55,0xcb,0x76,0x01,0x7a,0xfa,0x91,0x1f,
+  0x3f,0xea,0x5a,0x1e,0xf6,0x62,0xe8,0xb7,0x31,0x40,0xc4,0x2f,0x7a,0xb8,0xe1,0x63,
+  0xd7,0xc3,0x73,0x3e,0x7e,0x8d,0x69,0x66,0xe4,0x2c,0xe2,0xd3,0x88,0x05,0x55,0x53,
+  0x6a,0x88,0x97,0x10,0x8f,0xcc,0xc5,0xf8,0x46,0x0c,0xfb,0x31,0xb0,0xd6,0x5f,0xa0,
+  0x4d,0x6a,0xeb,0xaa,0xe8,0xe5,0xa2,0x62,0x9b,0x75,0xdd,0xa0,0xb1,0x70,0xef,0x61,
+  0xfe,0x9f,0x6d,0xc1,0x68,0x85,0xf3,0x6d,0xc3,0xa7,0xcf,0x99,0x9f,0x3e,0x84,0xef,
+  0x61,0x5c,0xfb,0x2b,0x35,0x25,0xe7,0xe1,0x51,0xc4,0x4b,0xaa,0x92,0x9f,0x46,0xfc,
+  0x08,0xe2,0x6b,0x6d,0x7d,0xb6,0x1c,0xe0,0xdb,0x96,0x9b,0x91,0x11,0x3f,0x06,0x90,
+  0xdc,0xde,0x9a,0xaf,0xa6,0x11,0xef,0x44,0x5c,0xac,0xdb,0x07,0xaa,0xbe,0x9f,0xa4,
+  0xad,0xb5,0x8a,0x21,0x7e,0xe7,0x84,0x36,0xf3,0x2c,0xe2,0x2d,0x88,0xcf,0x37,0xe7,
+  0xca,0x53,0xc1,0xd8,0xab,0xaa,0x93,0xc5,0x9c,0xc1,0x76,0xc4,0xb7,0x35,0x5a,0xf2,
+  0xf2,0x3b,0x04,0xc0,0x89,0xba,0x5b,0x9a,0xf1,0xc7,0x72,0xfb,0x6d,0x53,0x9e,0xf2,
+  0xe7,0xe5,0xea,0x35,0x9a,0xcb,0x7b,0x79,0x44,0xfc,0xfa,0xbc,0x79,0x48,0xf6,0x7d,
+  0x72,0x9f,0x39,0xed,0xe9,0x7c,0xe8,0xf3,0x84,0x96,0x2d,0x07,0xfc,0xa5,0x97,0x94,
+  0x83,0x15,0xc4,0x83,0x88,0x7f,0xa1,0x46,0x41,0xf6,0xe7,0xe2,0xfe,0xb1,0xdc,0x4a,
+  0x10,0x03,0x19,0x6a,0x1a,0xe5,0x49,0x7f,0x2e,0x92,0xa3,0x0e,0x5b,0x2f,0xe3,0x5d,
+  0x6d,0xa6,0xe8,0xcf,0x4b,0x0c,0x17,0x37,0xd4,0x1f,0x4b,0x16,0xeb,0xfa,0x81,0x52,
+  0xa0,0xff,0x44,0xb3,0x8b,0x72,0x80,0xaf,0x59,0x06,0xab,0x51,0x8c,0x8d,0x4f,0xda,
+  0x2d,0xb9,0xea,0xeb,0xf9,0x51,0xc5,0xce,0x17,0x7c,0x9f,0x7c,0x85,0x36,0xab,0x81,
+  0x7f,0xbe,0x0d,0xb3,0x09,0x05,0x28,0x98,0x30,0x87,0xbd,0x0a,0x4d,0x58,0x03,0x11,
+  0x64,0x28,0x40,0x06,0xdf,0x16,0xd8,0x68,0xa9,0x83,0x0e,0x06,0x32,0x14,0xad,0x14,
+  0x19,0x8a,0x5f,0xa1,0x66,0x17,0x1b,0xe7,0xc0,0x3c,0xf2,0x3a,0xb4,0x99,0xcd,0xc1,
+  0xbe,0xc2,0x94,0xfe,0xc8,0xc8,0x5f,0x83,0xf9,0xb8,0xce,0xb4,0x2a,0x64,0x87,0x3e,
+  0x82,0x16,0xb2,0x1a,0xfc,0x8e,0xac,0x16,0xd3,0x65,0xf1,0xab,0x85,0x5c,0x63,0x13,
+  0x3f,0x7e,0x2c,0x37,0x02,0x3f,0x26,0x19,0x20,0x12,0xd9,0x83,0xcf,0x5e,0x32,0x49,
+  0xf6,0x91,0x71,0x32,0x01,0x22,0x79,0x8a,0x3c,0x4d,0xf6,0x93,0x1c,0xb2,0x13,0x64,
+  0xef,0xfa,0xd8,0x4a,0x6c,0x45,0x5e,0x3c,0x37,0xd6,0xfd,0xbc,0x8c,0x33,0x52,0xa6,
+  0x9b,0x45,0xdd,0x39,0xb4,0xbb,0xa0,0x60,0xff,0x33,0x2a,0x4c,0x5c,0x53,0xd7,0xac,
+  0x2c,0x0e,0xb6,0x86,0x23,0xcb,0x29,0xfb,0x05,0x5d,0xbd,0xfc,0xc6,0x5f,0xb1,0x5c,
+  0xe9,0x2c,0x37,0x51,0xb6,0xe2,0x19,0x9d,0xba,0x57,0xce,0xf9,0x5f,0xf9,0xeb,0xfc,
+  0x32,0xf6,0x2b,0xfc,0x6a,0xa4,0xe0,0x7f,0xe4,0x57,0xf1,0xb7,0x72,0xc7,0x5a,0xcc,
+  0xbb,0xb2,0x4c,0xc3,0xec,0x6c,0x58,0x73,0x77,0x55,0x1a,0x6d,0x06,0xe3,0x16,0xf0,
+  0xd1,0x99,0xc5,0x89,0xc5,0x1d,0xf3,0x71,0xf1,0xe4,0x57,0x0f,0x46,0x7e,0x96,0xc9,
+  0x99,0xe7,0xaf,0xf4,0x5d,0x3c,0x59,0x6f,0x2e,0x0e,0x46,0xac,0x97,0x05,0xfa,0x6a,
+  0xf9,0x56,0x19,0x4e,0x8d,0x44,0xac,0xf4,0x83,0xf4,0x87,0xb4,0x2c,0xbd,0x27,0x7d,
+  0x28,0xfd,0xc6,0xbd,0xcd,0x7d,0xca,0x7d,0xcd,0x7d,0xce,0x7d,0xc1,0x5d,0x02,0x91,
+  0x3b,0xcb,0x9d,0xe3,0xbe,0xe1,0x2e,0x70,0x1f,0x73,0x5f,0xc6,0xf6,0x6a,0xf3,0x1a,
+  0x5a,0xdf,0x7b,0x16,0x79,0x18,0xb7,0x67,0xe9,0x96,0x6b,0xac,0x4a,0x21,0x23,0x6c,
+  0x15,0x1e,0x16,0x72,0xc2,0x36,0xe1,0x51,0x61,0x32,0xf2,0x27,0x0c,0x08,0x63,0x42,
+  0x51,0xd8,0x81,0x96,0xad,0xeb,0xfb,0x16,0x9f,0x2f,0x9e,0x3d,0x1d,0x0e,0x63,0x1f,
+  0xe6,0xa7,0xfb,0x5c,0xbe,0x2e,0x56,0x01,0x89,0xfb,0xb1,0x02,0xf4,0x4d,0xfe,0x55,
+  0x55,0x54,0xe9,0x70,0x94,0x29,0x1d,0x56,0x6f,0x4d,0x38,0xbe,0x41,0x13,0x8c,0x24,
+  0x43,0x64,0x8c,0x94,0x36,0x54,0xf7,0xb8,0x57,0xf3,0xa1,0x22,0x95,0x4f,0xe5,0x52,
+  0x69,0x10,0x53,0x3b,0x53,0x13,0xa9,0xb1,0xd4,0x41,0x0f,0x87,0xb3,0xa6,0x76,0xa0,
+  0x6d,0x02,0xfb,0xfc,0x1d,0xd5,0xa9,0x6e,0xb2,0x52,0xea,0xd2,0x63,0xde,0x7d,0x02,
+  0x59,0xd3,0x3a,0x6e,0xeb,0x0d,0xcd,0x15,0x77,0x4b,0xd2,0x93,0x62,0x1a,0xaf,0x36,
+  0x2a,0x96,0x9a,0xea,0xe8,0x88,0xa8,0x18,0x86,0xc8,0x4c,0x8e,0x68,0x53,0x87,0xda,
+  0x6d,0x5a,0x1b,0x05,0xef,0xde,0xf4,0x8f,0xf4,0x9b,0x32,0xbb,0x0f,0x13,0x5b,0x2e,
+  0x47,0x9c,0xfb,0x0c,0xc0,0xbe,0x3f,0xf1,0xec,0xfb,0x2e,0xe2,0x8e,0xb4,0x00,0x96,
+  0x1c,0x80,0x81,0xc7,0x23,0x6e,0x18,0xcf,0xca,0x07,0xde,0x05,0x38,0xf3,0x84,0xda,
+  0xb2,0xdb,0xc1,0x1d,0x91,0x48,0x7c,0x0b,0xe0,0xd4,0xf7,0xec,0xf6,0xbf,0xfa,0x32,
+  0x78,0x7e,0xfd,0xd4,0xe9,0xdc,0xc4,0x73,0xac,0xe7,0x2d,0x80,0xb5,0x37,0x3b,0x9d,
+  0xbf,0xdf,0xef,0x74,0xd6,0x3e,0x40,0xff,0xab,0x00,0x67,0x8d,0x7f,0x01,0xa0,0x9f,
+  0x7c,0x55,0x03,0x5c,0x0b,0xef,0x00,0x00,0x00,0x38,0x65,0x58,0x49,0x66,0x4d,0x4d,
+  0x00,0x2a,0x00,0x00,0x00,0x08,0x00,0x01,0x87,0x69,0x00,0x04,0x00,0x00,0x00,0x01,
+  0x00,0x00,0x00,0x1a,0x00,0x00,0x00,0x00,0x00,0x02,0xa0,0x02,0x00,0x04,0x00,0x00,
+  0x00,0x01,0x00,0x00,0x02,0x00,0xa0,0x03,0x00,0x04,0x00,0x00,0x00,0x01,0x00,0x00,
+  0x02,0x00,0x00,0x00,0x00,0x00,0x28,0x30,0x97,0xbf,0x00,0x00,0x03,0x62,0x69,0x54,
+  0x58,0x74,0x58,0x4d,0x4c,0x3a,0x63,0x6f,0x6d,0x2e,0x61,0x64,0x6f,0x62,0x65,0x2e,
+  0x78,0x6d,0x70,0x00,0x00,0x00,0x00,0x00,0x3c,0x78,0x3a,0x78,0x6d,0x70,0x6d,0x65,
+  0x74,0x61,0x20,0x78,0x6d,0x6c,0x6e,0x73,0x3a,0x78,0x3d,0x22,0x61,0x64,0x6f,0x62,
+  0x65,0x3a,0x6e,0x73,0x3a,0x6d,0x65,0x74,0x61,0x2f,0x22,0x20,0x78,0x3a,0x78,0x6d,
+  0x70,0x74,0x6b,0x3d,0x22,0x58,0x4d,0x50,0x20,0x43,0x6f,0x72,0x65,0x20,0x35,0x2e,
+  0x34,0x2e,0x30,0x22,0x3e,0x0a,0x20,0x20,0x20,0x3c,0x72,0x64,0x66,0x3a,0x52,0x44,
+  0x46,0x20,0x78,0x6d,0x6c,0x6e,0x73,0x3a,0x72,0x64,0x66,0x3d,0x22,0x68,0x74,0x74,
+  0x70,0x3a,0x2f,0x2f,0x77,0x77,0x77,0x2e,0x77,0x33,0x2e,0x6f,0x72,0x67,0x2f,0x31,
+  0x39,0x39,0x39,0x2f,0x30,0x32,0x2f,0x32,0x32,0x2d,0x72,0x64,0x66,0x2d,0x73,0x79,
+  0x6e,0x74,0x61,0x78,0x2d,0x6e,0x73,0x23,0x22,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,
+  0x20,0x3c,0x72,0x64,0x66,0x3a,0x44,0x65,0x73,0x63,0x72,0x69,0x70,0x74,0x69,0x6f,
+  0x6e,0x20,0x72,0x64,0x66,0x3a,0x61,0x62,0x6f,0x75,0x74,0x3d,0x22,0x22,0x0a,0x20,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x78,0x6d,0x6c,0x6e,0x73,
+  0x3a,0x64,0x63,0x3d,0x22,0x68,0x74,0x74,0x70,0x3a,0x2f,0x2f,0x70,0x75,0x72,0x6c,
+  0x2e,0x6f,0x72,0x67,0x2f,0x64,0x63,0x2f,0x65,0x6c,0x65,0x6d,0x65,0x6e,0x74,0x73,
+  0x2f,0x31,0x2e,0x31,0x2f,0x22,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+  0x20,0x20,0x20,0x78,0x6d,0x6c,0x6e,0x73,0x3a,0x49,0x70,0x74,0x63,0x34,0x78,0x6d,
+  0x70,0x45,0x78,0x74,0x3d,0x22,0x68,0x74,0x74,0x70,0x3a,0x2f,0x2f,0x69,0x70,0x74,
+  0x63,0x2e,0x6f,0x72,0x67,0x2f,0x73,0x74,0x64,0x2f,0x49,0x70,0x74,0x63,0x34,0x78,
+  0x6d,0x70,0x45,0x78,0x74,0x2f,0x32,0x30,0x30,0x38,0x2d,0x30,0x32,0x2d,0x32,0x39,
+  0x2f,0x22,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x78,
+  0x6d,0x6c,0x6e,0x73,0x3a,0x70,0x68,0x6f,0x74,0x6f,0x73,0x68,0x6f,0x70,0x3d,0x22,
+  0x68,0x74,0x74,0x70,0x3a,0x2f,0x2f,0x6e,0x73,0x2e,0x61,0x64,0x6f,0x62,0x65,0x2e,
+  0x63,0x6f,0x6d,0x2f,0x70,0x68,0x6f,0x74,0x6f,0x73,0x68,0x6f,0x70,0x2f,0x31,0x2e,
+  0x30,0x2f,0x22,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x64,
+  0x63,0x3a,0x63,0x72,0x65,0x61,0x74,0x6f,0x72,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x72,0x64,0x66,0x3a,0x53,0x65,0x71,0x3e,
+  0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+  0x3c,0x72,0x64,0x66,0x3a,0x6c,0x69,0x3e,0x4d,0x69,0x63,0x68,0x61,0x65,0x6c,0x20,
+  0x53,0x77,0x65,0x65,0x74,0x3c,0x2f,0x72,0x64,0x66,0x3a,0x6c,0x69,0x3e,0x0a,0x20,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x2f,0x72,0x64,0x66,
+  0x3a,0x53,0x65,0x71,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,
+  0x2f,0x64,0x63,0x3a,0x63,0x72,0x65,0x61,0x74,0x6f,0x72,0x3e,0x0a,0x20,0x20,0x20,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x64,0x63,0x3a,0x72,0x69,0x67,0x68,0x74,0x73,
+  0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x72,
+  0x64,0x66,0x3a,0x41,0x6c,0x74,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x72,0x64,0x66,0x3a,0x6c,0x69,0x20,0x78,
+  0x6d,0x6c,0x3a,0x6c,0x61,0x6e,0x67,0x3d,0x22,0x78,0x2d,0x64,0x65,0x66,0x61,0x75,
+  0x6c,0x74,0x22,0x3e,0x43,0x6f,0x70,0x79,0x72,0x69,0x67,0x68,0x74,0x20,0x32,0x30,
+  0x31,0x30,0x20,0x41,0x70,0x70,0x6c,0x65,0x20,0x49,0x6e,0x63,0x2e,0x3c,0x2f,0x72,
+  0x64,0x66,0x3a,0x6c,0x69,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+  0x20,0x20,0x20,0x3c,0x2f,0x72,0x64,0x66,0x3a,0x41,0x6c,0x74,0x3e,0x0a,0x20,0x20,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x2f,0x64,0x63,0x3a,0x72,0x69,0x67,0x68,
+  0x74,0x73,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x49,0x70,
+  0x74,0x63,0x34,0x78,0x6d,0x70,0x45,0x78,0x74,0x3a,0x48,0x65,0x61,0x64,0x6c,0x69,
+  0x6e,0x65,0x3e,0x4e,0x65,0x77,0x20,0x49,0x6d,0x61,0x67,0x65,0x3c,0x2f,0x49,0x70,
+  0x74,0x63,0x34,0x78,0x6d,0x70,0x45,0x78,0x74,0x3a,0x48,0x65,0x61,0x64,0x6c,0x69,
+  0x6e,0x65,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x70,0x68,
+  0x6f,0x74,0x6f,0x73,0x68,0x6f,0x70,0x3a,0x48,0x65,0x61,0x64,0x6c,0x69,0x6e,0x65,
+  0x3e,0x4e,0x65,0x77,0x20,0x49,0x6d,0x61,0x67,0x65,0x3c,0x2f,0x70,0x68,0x6f,0x74,
+  0x6f,0x73,0x68,0x6f,0x70,0x3a,0x48,0x65,0x61,0x64,0x6c,0x69,0x6e,0x65,0x3e,0x0a,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x2f,0x72,0x64,0x66,0x3a,0x44,0x65,0x73,0x63,
+  0x72,0x69,0x70,0x74,0x69,0x6f,0x6e,0x3e,0x0a,0x20,0x20,0x20,0x3c,0x2f,0x72,0x64,
+  0x66,0x3a,0x52,0x44,0x46,0x3e,0x0a,0x3c,0x2f,0x78,0x3a,0x78,0x6d,0x70,0x6d,0x65,
+  0x74,0x61,0x3e,0x0a,0xa0,0x50,0x98,0x64,0x00,0x00,0x6b,0x41,0x49,0x44,0x41,0x54,
+  0x78,0xda,0xed,0x9d,0x07,0xfc,0x1c,0x55,0xb9,0xb0,0x4f,0x7a,0xef,0x40,0x0a,0x49,
+  0x20,0x10,0x9a,0x54,0xe9,0x46,0x7a,0x13,0x14,0x2e,0x52,0x42,0x53,0x54,0x04,0x2f,
+  0x28,0x02,0xf7,0x7e,0x82,0x15,0x51,0x51,0x11,0x14,0x6c,0x28,0xc2,0xfd,0x79,0x51,
+  0x41,0x41,0xa4,0x37,0xf9,0x40,0x3a,0x48,0x07,0x29,0x86,0x96,0x90,0x00,0x09,0x24,
+  0x90,0x46,0x7a,0xcf,0x7e,0xe7,0x1d,0x32,0xff,0x6f,0x72,0x72,0xce,0x9c,0x33,0xbb,
+  0x33,0xbb,0xb3,0xbb,0xcf,0x93,0xdf,0xc9,0xee,0x7f,0x77,0x76,0x66,0xce,0xb4,0xb7,
+  0x9c,0xf7,0x7d,0x4f,0x27,0x55,0x52,0x2a,0x95,0x4a,0x1f,0xfd,0xb2,0xad,0x6e,0xdb,
+  0xe9,0x36,0x56,0xb7,0x31,0xba,0x8d,0xd4,0x6d,0x3d,0xdd,0x06,0xeb,0xd6,0x4b,0xb7,
+  0xee,0xba,0x75,0x51,0x00,0x00,0x00,0xf5,0x67,0x95,0x6e,0xcb,0x75,0x5b,0xa2,0xdb,
+  0x1c,0xdd,0x66,0xe9,0x36,0x4d,0xb7,0x29,0xba,0x4d,0xd2,0xed,0x45,0xdd,0x5e,0xea,
+  0xd4,0xa9,0xd3,0xa2,0x32,0xee,0x7c,0xa7,0x12,0x09,0xfc,0x7e,0xfa,0x65,0x7f,0xdd,
+  0x0e,0xd0,0x6d,0x8f,0x35,0xc2,0xbf,0x33,0xd7,0x17,0x00,0x00,0x34,0x31,0xab,0x45,
+  0x09,0xd0,0xed,0x51,0xdd,0xee,0xd5,0xed,0x3e,0xad,0x10,0x2c,0x68,0x7b,0x05,0x40,
+  0x0b,0xfd,0x41,0xfa,0xe5,0x08,0xdd,0x8e,0xd5,0x6d,0x5f,0xdd,0xba,0x71,0xad,0x00,
+  0x00,0x40,0x0b,0xb3,0x42,0xb7,0x07,0x74,0xbb,0x4e,0xb7,0x9b,0xb5,0x32,0x30,0xb7,
+  0xad,0x14,0x00,0x2d,0xf8,0xf7,0xd4,0x2f,0xa7,0xea,0x76,0xb4,0x6e,0x3d,0xb8,0x1e,
+  0x00,0x00,0xa0,0x0d,0x59,0xaa,0xdb,0x8d,0xba,0x5d,0xa1,0x15,0x81,0x47,0x5a,0x56,
+  0x01,0xd0,0x42,0x5f,0xdc,0xf9,0xe3,0x75,0x3b,0x5b,0xb7,0x9d,0x39,0xef,0x00,0x00,
+  0x00,0x1d,0x3c,0xa3,0xdb,0xc5,0xba,0x5d,0xaf,0x95,0x81,0xd5,0x2d,0xa3,0x00,0x68,
+  0xe1,0x7f,0xa4,0x7e,0x39,0x5f,0xb7,0xad,0x39,0xc7,0x00,0x00,0x00,0x4e,0x26,0xe8,
+  0x76,0x9e,0x56,0x02,0x6e,0x6a,0x6a,0x05,0x40,0x0b,0xfe,0x2d,0xf5,0xcb,0x65,0xea,
+  0xc3,0xf1,0x7d,0x00,0x00,0x00,0x08,0x43,0xe2,0x04,0xbe,0xa2,0x15,0x81,0x57,0x8b,
+  0xda,0x40,0x21,0x51,0xf6,0x5a,0xf0,0xf7,0xd6,0xed,0x02,0xfd,0xf6,0x05,0x84,0x3f,
+  0x00,0x00,0x40,0x66,0x44,0x76,0xbe,0x20,0xb2,0x54,0x64,0x6a,0x53,0x78,0x00,0xf4,
+  0x8e,0xee,0xae,0x5f,0xae,0x51,0x1f,0xe6,0xed,0x03,0x00,0x00,0x40,0x6d,0x48,0x5d,
+  0x81,0x13,0xb4,0x37,0xe0,0x89,0xd2,0x7a,0x00,0xb4,0xf0,0xff,0x9a,0x7e,0x79,0x18,
+  0xe1,0x0f,0x00,0x00,0x90,0x1b,0x22,0x53,0x1f,0x5e,0x23,0x63,0xcb,0xe5,0x01,0xd0,
+  0x3b,0x25,0x95,0xf9,0xfe,0xa8,0xdb,0x61,0x9c,0x27,0x00,0x00,0x80,0xc2,0xb8,0x5d,
+  0xb7,0x2f,0x68,0x6f,0xc0,0x9c,0x86,0x2b,0x00,0x5a,0xf8,0x8b,0x66,0x72,0x8f,0xfa,
+  0xb0,0x5c,0x2f,0x00,0x00,0x00,0x14,0x8b,0x94,0x19,0x3e,0x48,0x2b,0x01,0x53,0x6a,
+  0x59,0x49,0x4d,0x43,0x00,0x5a,0xf8,0x6f,0xaf,0x5f,0x1e,0x43,0xf8,0x03,0x00,0x00,
+  0xd4,0x0d,0x91,0xb9,0x8f,0xad,0x91,0xc1,0xf5,0x57,0x00,0xf4,0x86,0xf7,0xd6,0x2f,
+  0x0f,0xe9,0x36,0x8c,0x73,0x01,0x00,0x00,0x50,0x57,0x44,0xf6,0x3e,0xb4,0x46,0x16,
+  0x57,0x45,0x55,0x43,0x00,0x6b,0x36,0xf8,0x7f,0x75,0xeb,0xc9,0x39,0x00,0x00,0x00,
+  0x68,0x18,0x52,0x4e,0xf8,0x60,0x3d,0x1c,0xf0,0x50,0xe1,0x0a,0xc0,0x1a,0x97,0x83,
+  0x6c,0x68,0x00,0xc7,0x1d,0x00,0x00,0xa0,0xe1,0xcc,0xd3,0x6d,0x6f,0xad,0x04,0xbc,
+  0x50,0x98,0x02,0xb0,0x26,0xe0,0x4f,0xc6,0xfc,0x71,0xfb,0x03,0x00,0x00,0x94,0x87,
+  0x19,0xba,0x8d,0xcb,0x12,0x18,0x18,0xac,0x00,0xac,0x49,0xf5,0x7b,0x52,0x11,0xf0,
+  0x07,0x00,0x00,0x50,0x46,0x24,0x3b,0x60,0xb7,0xd0,0x14,0xc1,0x2c,0x41,0x80,0x7f,
+  0x44,0xf8,0x03,0x00,0x00,0x94,0x96,0xb1,0x6b,0x64,0x75,0x10,0x41,0x0a,0xc0,0x9a,
+  0xea,0x43,0x14,0xf9,0x01,0x00,0x00,0x28,0x37,0x87,0x85,0x56,0x0c,0xf4,0x0e,0x01,
+  0xac,0xa9,0xed,0x2f,0xe5,0x7d,0xbb,0x71,0x5c,0x01,0x00,0x00,0x4a,0xcf,0x0a,0xdd,
+  0xf6,0xf2,0xcd,0x1d,0xd0,0xc9,0x23,0xfc,0x65,0x06,0xa2,0x7f,0x2b,0x6a,0xfb,0x03,
+  0x00,0x00,0x34,0x13,0x12,0x0c,0xb8,0x8d,0x56,0x02,0x16,0xbb,0x16,0xf0,0x0d,0x01,
+  0x9c,0x8b,0xf0,0x07,0x00,0x00,0x68,0x3a,0xc6,0xac,0x91,0xe1,0xd9,0x3d,0x00,0xda,
+  0xfa,0xdf,0x52,0xbf,0x48,0x4e,0x61,0x77,0x8e,0x23,0x00,0x00,0x40,0xd3,0xb1,0x5c,
+  0xb7,0xed,0xb5,0x17,0xe0,0xd5,0xac,0x0a,0xc0,0xfd,0xfa,0x65,0xdf,0x5a,0xb7,0xbe,
+  0x72,0xe5,0x4a,0x35,0x77,0xee,0xdc,0xd4,0x65,0xba,0x75,0xeb,0xa6,0x06,0x0e,0x1c,
+  0xc8,0xa9,0x02,0x00,0x00,0xc8,0x97,0x07,0xb4,0x02,0xb0,0x5f,0xb0,0x02,0xa0,0x85,
+  0xff,0x51,0xfa,0xe5,0x86,0x3c,0xb6,0x7c,0xe9,0xa5,0x97,0xaa,0x33,0xcf,0x3c,0x33,
+  0x75,0x99,0xee,0xdd,0xbb,0xab,0x65,0xcb,0x96,0x71,0x9a,0x00,0x00,0x00,0xf2,0xe7,
+  0x68,0xad,0x04,0xdc,0x68,0x7e,0xd8,0xd9,0x22,0xfc,0xe5,0xb3,0x1f,0xe4,0xb5,0xd5,
+  0xe5,0xcb,0x97,0xe7,0xb2,0x0c,0x00,0x00,0x00,0x54,0xc5,0x0f,0xd6,0xc8,0xf6,0x74,
+  0x05,0x40,0x33,0x5e,0xb7,0xad,0x39,0x5e,0x00,0x00,0x00,0x2d,0xc1,0xd6,0x6b,0x64,
+  0xbb,0x57,0x01,0x38,0x9b,0x63,0x05,0x00,0x00,0xd0,0x52,0x9c,0x9d,0xaa,0x00,0x68,
+  0x17,0xc1,0x9e,0xfa,0x65,0x67,0x8e,0x13,0x00,0x00,0x40,0x4b,0xb1,0xf3,0x1a,0x19,
+  0xef,0xf4,0x00,0x9c,0xca,0x31,0x02,0x00,0x00,0x68,0x49,0x4e,0xb5,0x2a,0x00,0x5a,
+  0x33,0x18,0xa4,0x5f,0x8e,0xe2,0xf8,0x00,0x00,0x00,0xb4,0x24,0x47,0xad,0x91,0xf5,
+  0xeb,0x78,0x00,0x8e,0xd0,0xad,0x27,0xc7,0x07,0x00,0x00,0xa0,0x25,0xe9,0xb9,0x46,
+  0xd6,0xaf,0xa3,0x00,0x1c,0xcb,0xb1,0x01,0x00,0x00,0x68,0x69,0x3a,0x64,0x7d,0x57,
+  0xf9,0x4f,0xbb,0x04,0xfa,0xa9,0x1c,0xaa,0xfe,0xd9,0x18,0x3f,0x7e,0xbc,0xda,0x60,
+  0x83,0x0d,0x52,0x97,0xe9,0xdb,0xb7,0x2f,0xa7,0x04,0x00,0x00,0xa0,0x78,0xf6,0x15,
+  0x99,0xaf,0x0b,0x03,0x2d,0xe8,0xb4,0x46,0x01,0x10,0x97,0xc0,0x4d,0x1c,0x17,0x00,
+  0x00,0x80,0x96,0xe7,0x08,0xad,0x00,0xdc,0x12,0x0f,0x01,0xec,0xcf,0xf1,0x00,0x00,
+  0x00,0x68,0x0b,0x0e,0x90,0xff,0x62,0x05,0x60,0x0f,0x8e,0x07,0x00,0x00,0x40,0x5b,
+  0x10,0xc9,0xfc,0x4e,0xda,0xfd,0x2f,0x03,0xf0,0xf3,0x94,0xbd,0x2a,0x20,0x00,0x00,
+  0x00,0xb4,0x16,0xab,0x75,0xeb,0x2f,0x42,0x7f,0x1b,0x84,0x3f,0x00,0x00,0x40,0xdb,
+  0x20,0x32,0x7f,0x5b,0xf9,0x6f,0x3b,0x8e,0x05,0x00,0x00,0x40,0x5b,0xb1,0x9d,0xa4,
+  0x01,0x8e,0xe5,0x38,0xb8,0x99,0x37,0x6f,0x9e,0x7a,0xf3,0xcd,0x37,0xa3,0xf6,0xd6,
+  0x5b,0x6f,0xa9,0xd5,0xab,0x57,0xab,0xa1,0x43,0x87,0xaa,0xe1,0xc3,0x87,0xab,0x61,
+  0xc3,0x86,0xa9,0x51,0xa3,0x46,0xa9,0x3e,0x7d,0xfa,0xd0,0xcf,0x12,0xb0,0x68,0xd1,
+  0x22,0x35,0x75,0xea,0x54,0x35,0x7d,0xfa,0x74,0xf5,0xee,0xbb,0xef,0x46,0xaf,0x0b,
+  0x17,0x2e,0x54,0x43,0x86,0x0c,0x89,0xfa,0x20,0x6d,0xc4,0x88,0x11,0x6a,0x93,0x4d,
+  0x36,0x51,0x3a,0x02,0x96,0x8b,0x9b,0x73,0x01,0xd0,0xce,0x8c,0x15,0x05,0x60,0x4c,
+  0x91,0x5b,0x98,0x32,0x65,0x8a,0x7a,0xe0,0x81,0x07,0x52,0x97,0x11,0xc1,0x72,0xec,
+  0xb1,0xc7,0x96,0x62,0x3b,0x2b,0x57,0xae,0x54,0x37,0xde,0x78,0xa3,0xfa,0xdd,0xef,
+  0x7e,0xa7,0x5e,0x78,0xe1,0x05,0xf5,0xc1,0x07,0x1f,0xa4,0x2e,0xdf,0xb5,0x6b,0x57,
+  0xb5,0xef,0xbe,0xfb,0xaa,0xa3,0x8e,0x3a,0x4a,0x1d,0x71,0xc4,0x11,0xde,0x9a,0x07,
+  0x65,0x39,0x9e,0x65,0xef,0x67,0x28,0xb3,0x67,0xcf,0x56,0xb7,0xde,0x7a,0xab,0xba,
+  0xfe,0xfa,0xeb,0xd5,0x7d,0xf7,0xdd,0xa7,0x56,0xac,0x58,0xe1,0xfd,0x8d,0x28,0x33,
+  0xd2,0x87,0x23,0x8f,0x3c,0x52,0xed,0xb1,0xc7,0x1e,0xaa,0x4b,0x97,0x2e,0x35,0xed,
+  0xc3,0x8b,0x2f,0xbe,0xa8,0x9e,0x79,0xe6,0x99,0xd4,0x65,0x06,0x0c,0x18,0x10,0x1d,
+  0xbb,0x7a,0x72,0xd7,0x5d,0x77,0x45,0x82,0xd7,0x45,0xe7,0xce,0x9d,0xd5,0xe7,0x3e,
+  0xf7,0xb9,0xe8,0xb5,0x55,0xce,0x05,0x00,0x04,0x33,0x46,0x6a,0x00,0x3c,0x5e,0x29,
+  0x90,0x8b,0x2f,0xbe,0xb8,0xa2,0x37,0xe4,0x6d,0x8d,0xde,0x8e,0x7e,0x78,0x55,0x7e,
+  0xf2,0x93,0x9f,0x54,0x46,0x8e,0x1c,0x19,0xb4,0x1e,0x5b,0xd3,0x0f,0xd2,0xca,0xf1,
+  0xc7,0x1f,0x5f,0xd1,0x0f,0xdd,0xd2,0x1e,0xcf,0x66,0xe9,0xa7,0x8f,0x89,0x13,0x27,
+  0x56,0x0e,0x3f,0xfc,0xf0,0x8a,0x56,0x4c,0xaa,0xee,0x87,0xb4,0x8d,0x37,0xde,0xb8,
+  0x72,0xc7,0x1d,0x77,0xd4,0xb4,0x2f,0xe7,0x9c,0x73,0x4e,0xd0,0x31,0x7b,0xfb,0xed,
+  0xb7,0xeb,0x76,0x7c,0xb4,0x47,0xa7,0xd2,0xbb,0x77,0xef,0xd4,0x7d,0x92,0x63,0x37,
+  0x73,0xe6,0xcc,0x96,0x3a,0x17,0x00,0x10,0xcc,0xe3,0x22,0x29,0x26,0xb6,0xbb,0x02,
+  0x70,0xd3,0x4d,0x37,0x55,0xb4,0xd5,0x5c,0xd3,0xc3,0x2b,0xd9,0xb4,0xb5,0x57,0xb9,
+  0xec,0xb2,0xcb,0x2a,0xab,0x56,0xad,0x2a,0xd5,0xf1,0x6c,0xa6,0x7e,0xba,0x58,0xba,
+  0x74,0x69,0xe5,0x7b,0xdf,0xfb,0x5e,0xa5,0x47,0x8f,0x1e,0xb9,0xf5,0x43,0x9a,0xb6,
+  0x40,0x2b,0xd3,0xa6,0x4d,0xab,0x6a,0x9f,0x9e,0x7b,0xee,0xb9,0xa0,0x6d,0x5c,0x70,
+  0xc1,0x05,0x75,0x3b,0x4e,0x97,0x5f,0x7e,0xb9,0x77,0x7f,0x44,0x68,0xb7,0xda,0xb9,
+  0x00,0x80,0x70,0xdd,0x5d,0x24,0xc5,0xec,0x76,0x56,0x00,0xe4,0x77,0x62,0x9d,0xe5,
+  0xf9,0x00,0x8b,0xdb,0x21,0x87,0x1c,0x12,0x3d,0x24,0xcb,0x70,0x3c,0x9b,0xad,0x9f,
+  0x36,0x9e,0x7d,0xf6,0xd9,0xca,0xd8,0xb1,0x63,0x0b,0xe9,0x83,0xb4,0xf5,0xd6,0x5b,
+  0xaf,0xf2,0xd2,0x4b,0x2f,0x55,0xb5,0x6f,0xdb,0x6d,0xb7,0x9d,0x77,0xfd,0x5b,0x6e,
+  0xb9,0x65,0xdd,0xee,0xec,0x5d,0x76,0xd9,0xc5,0xbb,0x3f,0xb5,0x58,0xdb,0x65,0x3e,
+  0x17,0x00,0x10,0xc4,0x6c,0x19,0xfc,0xeb,0xd5,0x8e,0x83,0x1f,0x32,0x06,0x7e,0xda,
+  0x69,0xa7,0xa9,0xb3,0xcf,0x3e,0x3b,0x0a,0x78,0x2b,0x6a,0x0c,0x56,0xc6,0x7d,0x97,
+  0x2f,0x5f,0x4e,0x3f,0x6b,0xe4,0x89,0x27,0x9e,0x50,0xfb,0xed,0xb7,0x9f,0x9a,0x34,
+  0x69,0x52,0x61,0xdb,0x98,0x35,0x6b,0x96,0x3a,0xe0,0x80,0x03,0xd4,0x6b,0xaf,0xbd,
+  0x96,0xf9,0xb7,0x9f,0xff,0xfc,0xe7,0xbd,0xcb,0xbc,0xfa,0xea,0xab,0xea,0xa9,0xa7,
+  0x9e,0x2a,0xfc,0x9c,0x4b,0x4c,0xc2,0xd3,0x4f,0x3f,0x9d,0xba,0x8c,0x1e,0x02,0x52,
+  0x07,0x1f,0x7c,0x70,0x4b,0x9e,0x0b,0x00,0x08,0xa2,0x97,0x28,0x00,0xdd,0xdb,0xb1,
+  0xe7,0x9f,0xfd,0xec,0x67,0xd5,0x15,0x57,0x5c,0x51,0xf8,0x76,0xee,0xbc,0xf3,0x4e,
+  0x75,0xcc,0x31,0xc7,0x04,0x05,0x44,0xd1,0x4f,0x3b,0x0f,0x3f,0xfc,0xb0,0x3a,0xe8,
+  0xa0,0x83,0xa2,0x4c,0x85,0xa2,0x79,0xef,0xbd,0xf7,0xd4,0xfe,0xfb,0xef,0x1f,0x65,
+  0x43,0x64,0xe1,0x84,0x13,0x4e,0x88,0x02,0x25,0x7d,0xfc,0xe9,0x4f,0x7f,0x2a,0xbc,
+  0x0f,0xff,0xfb,0xbf,0xff,0xeb,0x5d,0xe6,0x8b,0x5f,0xfc,0x62,0x55,0x01,0x77,0xcd,
+  0x70,0x2e,0x00,0x20,0x88,0xee,0xa2,0x00,0xb4,0x5d,0xd8,0xed,0xd5,0x57,0x5f,0xad,
+  0xae,0xbb,0xee,0xba,0xba,0x6d,0x4f,0x22,0xa3,0x7f,0xf4,0xa3,0x1f,0xd1,0xcf,0x2a,
+  0x78,0xf4,0xd1,0x47,0x95,0x1e,0x62,0x50,0x0b,0x16,0x2c,0x08,0xfe,0x4d,0xb7,0x6e,
+  0xdd,0xd4,0xe8,0xd1,0xa3,0xd5,0x8e,0x3b,0xee,0xa8,0xb6,0xde,0x7a,0xeb,0x28,0xf5,
+  0x2c,0x0b,0xef,0xbc,0xf3,0x8e,0x3a,0xf9,0xe4,0x93,0x33,0xfd,0x46,0xd2,0xda,0x42,
+  0x2c,0xea,0xbf,0xfe,0xf5,0xaf,0x85,0x7a,0x4a,0x96,0x2d,0x5b,0xa6,0xfe,0xfc,0xe7,
+  0x3f,0xa7,0x2e,0x23,0x51,0xff,0x59,0xfb,0xd7,0x4c,0xe7,0x02,0x00,0x82,0xe8,0xa2,
+  0x8a,0x1e,0x64,0x28,0x5b,0x0c,0x80,0xce,0x4d,0xae,0x0c,0x1c,0x38,0x30,0x73,0xd4,
+  0xbb,0xaa,0x71,0x4c,0xb3,0x7b,0xf7,0xee,0x95,0x97,0x5f,0x7e,0x99,0x7e,0x66,0x40,
+  0xa7,0x26,0x56,0x74,0x9a,0x58,0xd0,0x76,0x75,0x2e,0x79,0x45,0x5b,0xe1,0x15,0xad,
+  0x84,0x54,0x74,0x0e,0xfa,0x3a,0xeb,0xd2,0xae,0xe4,0xca,0x4f,0x7f,0xfa,0xd3,0xca,
+  0x86,0x1b,0x6e,0x18,0xdc,0x97,0x6b,0xae,0xb9,0x26,0xd3,0xfe,0xea,0xf4,0xb7,0xa0,
+  0xf5,0xea,0xf4,0xcb,0xc2,0xee,0xb7,0x6b,0xaf,0xbd,0xd6,0xbb,0x7d,0xad,0xa8,0xb4,
+  0xfc,0xb9,0x00,0x00,0x3f,0x6d,0xa7,0x00,0x68,0xf7,0xa5,0x77,0x19,0x79,0xd0,0x9d,
+  0x7f,0xfe,0xf9,0x95,0x7f,0xfc,0xe3,0x1f,0x95,0xc9,0x93,0x27,0x57,0xf4,0x38,0x7a,
+  0x47,0xd4,0xf3,0x2b,0xaf,0xbc,0x12,0x45,0x73,0x6f,0xb3,0xcd,0x36,0x99,0x85,0xe3,
+  0x9e,0x7b,0xee,0x59,0xd1,0xe3,0xf0,0xf4,0x33,0x90,0x13,0x4f,0x3c,0x31,0x68,0x7b,
+  0x3b,0xec,0xb0,0x43,0x45,0x8f,0x79,0x07,0xad,0x53,0x5b,0xaf,0x95,0x33,0xce,0x38,
+  0x23,0x68,0xbd,0xba,0x08,0x52,0x94,0x4e,0x97,0x25,0x2a,0x7e,0xd0,0xa0,0x41,0x85,
+  0x47,0xdf,0xa7,0xa1,0x5d,0xe6,0x85,0x28,0x20,0xcd,0x76,0x2e,0x00,0x00,0x05,0x20,
+  0x53,0x3b,0xf0,0xc0,0x03,0x2b,0xb7,0xdc,0x72,0x4b,0x87,0x20,0xf4,0xa1,0x8b,0xe8,
+  0x64,0x4e,0xab,0xd3,0x6e,0x79,0xfa,0x19,0xc0,0x0d,0x37,0xdc,0x10,0xb4,0x1d,0x5d,
+  0x3c,0xa6,0x2a,0xc1,0xf0,0x9d,0xef,0x7c,0x27,0x68,0xfd,0xdf,0xff,0xfe,0xf7,0x33,
+  0xad,0xf7,0xcb,0x5f,0xfe,0xb2,0x77,0x9d,0xda,0x2d,0x9e,0x4b,0xfe,0xbd,0xc9,0x1b,
+  0x6f,0xbc,0x11,0x59,0xdf,0x69,0xdb,0xd6,0xd5,0x1d,0x2b,0x3a,0x4e,0xa3,0x2d,0xce,
+  0x05,0x00,0xa0,0x00,0x78,0x9b,0x1e,0x97,0xac,0xda,0x2d,0xab,0x23,0xbb,0x2b,0xeb,
+  0xaf,0xbf,0x7e,0xf0,0xb6,0x3e,0xf6,0xb1,0x8f,0xd1,0xcf,0x00,0xcb,0x50,0xd2,0xc0,
+  0x7c,0xdb,0xd0,0x65,0x64,0xa3,0x65,0xab,0xe5,0xb0,0xc3,0x0e,0x0b,0xda,0x46,0x16,
+  0x9e,0x7c,0xf2,0xc9,0xa0,0xe3,0xf3,0xeb,0x5f,0xff,0x3a,0xf7,0x7b,0xed,0xdc,0x73,
+  0xcf,0xf5,0x6e,0xf7,0x9b,0xdf,0xfc,0x66,0xdb,0x9c,0x0b,0x00,0x40,0x01,0xf0,0x8e,
+  0x87,0xea,0x5a,0xe5,0x35,0x6d,0xfb,0x9f,0xff,0xfc,0x67,0xa6,0x62,0x28,0xb5,0x8c,
+  0x91,0xb7,0x43,0x3f,0x2f,0xbd,0xf4,0xd2,0xa0,0x71,0xe6,0x87,0x1e,0x7a,0xa8,0xa6,
+  0xfe,0x48,0x05,0x3b,0x89,0x59,0xf0,0x6d,0x4b,0x07,0xbf,0x65,0x5a,0xaf,0xe4,0xfb,
+  0xfb,0xd6,0xb9,0xd3,0x4e,0x3b,0xe5,0x7a,0x9f,0x89,0x37,0xc7,0x57,0xdd,0x51,0x8e,
+  0x99,0x4e,0xdd,0x6b,0xab,0x73,0x01,0x00,0x6e,0xda,0x7a,0x1a,0xe0,0x8b,0x2e,0xba,
+  0x28,0xca,0x61,0x97,0x09,0x6f,0x6a,0x61,0xdc,0xb8,0x71,0x4a,0xbb,0x27,0x83,0x97,
+  0xbf,0xf2,0xca,0x2b,0xe9,0xa7,0x03,0x51,0x4a,0xb5,0x75,0xec,0x5d,0x4e,0xea,0xc7,
+  0xef,0xb5,0xd7,0x5e,0x35,0xf5,0x47,0x17,0xb2,0x51,0xe3,0xc7,0x8f,0xf7,0x2e,0x77,
+  0xd5,0x55,0x57,0x65,0x5a,0x6f,0x48,0x4d,0x00,0x5d,0x48,0x47,0x69,0x05,0x29,0xb7,
+  0x73,0x7c,0xf7,0xdd,0x77,0x2b,0x5d,0x3d,0x2f,0x75,0x19,0x99,0xcb,0x61,0xd3,0x4d,
+  0x37,0x6d,0xab,0x73,0x01,0x00,0xe9,0x37,0x79,0x5b,0x7a,0x00,0xf2,0x76,0xc1,0xea,
+  0x99,0xce,0x2a,0x7a,0x82,0x9c,0xa0,0x6d,0xcb,0x38,0x6c,0xb5,0x41,0x72,0xad,0xde,
+  0xcf,0xdb,0x6f,0xbf,0x3d,0x68,0xdd,0x7a,0x42,0xa4,0x5c,0xfa,0x73,0xdb,0x6d,0xb7,
+  0x79,0xb7,0x35,0x78,0xf0,0xe0,0x4c,0xfd,0x90,0x0c,0x8c,0x90,0x8c,0x8a,0xaf,0x7f,
+  0xfd,0xeb,0xb9,0x9d,0x17,0x2d,0x84,0xbd,0xdb,0x93,0x0c,0x81,0x76,0x3b,0x17,0x00,
+  0x80,0x07,0x60,0x2d,0x7e,0xf3,0x9b,0xdf,0x28,0x1d,0x7d,0x9c,0xeb,0x3a,0x65,0x06,
+  0xbe,0xaf,0x7d,0xed,0x6b,0x41,0xcb,0x4a,0x81,0x13,0x1d,0xb0,0x45,0x3f,0x2d,0x68,
+  0x97,0xb3,0x77,0x99,0xcd,0x36,0xdb,0x4c,0xed,0xb3,0xcf,0x3e,0xb9,0xf4,0xe7,0x13,
+  0x9f,0xf8,0x84,0xea,0xd9,0xb3,0x67,0xea,0x32,0x73,0xe6,0xcc,0x89,0x66,0x61,0x0c,
+  0x45,0xaa,0xec,0x49,0x01,0x1b,0x1f,0x7f,0xf9,0xcb,0x5f,0x72,0xa9,0xce,0x28,0xc7,
+  0x59,0x97,0xf5,0x4d,0x5d,0x46,0xf2,0xef,0xc5,0x52,0x6f,0xb7,0x73,0x01,0x00,0x6e,
+  0xda,0x4e,0x01,0xd0,0x93,0xd7,0xa8,0xd3,0x4f,0x3f,0xbd,0x90,0x75,0x4b,0x25,0xbc,
+  0x50,0x7c,0xd3,0xc7,0xb6,0x63,0x3f,0x75,0x1a,0x9d,0x7a,0xf0,0xc1,0x07,0xbd,0xcb,
+  0xe9,0x2c,0x86,0xdc,0xfa,0xa2,0xc7,0x9d,0xd5,0x56,0x5b,0x6d,0xe5,0x5d,0xee,0xf9,
+  0xe7,0x9f,0xcf,0xb4,0xde,0x2f,0x7c,0xe1,0x0b,0xde,0x65,0xa4,0xc8,0xcd,0xbd,0xf7,
+  0xde,0x5b,0x73,0x1f,0xc4,0x2d,0xee,0xab,0xc0,0x28,0xd3,0xfe,0xea,0xf8,0x8d,0xb6,
+  0x3c,0x17,0x00,0x80,0x02,0x10,0xa1,0xd3,0xb4,0x0a,0x5b,0xb7,0x9e,0xce,0x54,0xe9,
+  0xbc,0xf9,0x52,0x28,0x00,0xcd,0xd8,0x4f,0xa9,0x5f,0x1f,0x52,0x25,0x2f,0xc4,0xba,
+  0xce,0x42,0x48,0x5f,0xb2,0x0a,0x9d,0x4f,0x7f,0xfa,0xd3,0xaa,0x7f,0xff,0xfe,0x41,
+  0xc2,0xbb,0x56,0x42,0x4a,0xff,0x7e,0xe9,0x4b,0x5f,0xca,0xb4,0xce,0x56,0x3a,0x17,
+  0x00,0x80,0x02,0x50,0x17,0x42,0x27,0x58,0x29,0x5a,0x01,0x68,0xc6,0x7e,0x4a,0xa9,
+  0xd9,0x10,0x76,0xdb,0x6d,0xb7,0x5c,0xfb,0x32,0x66,0xcc,0x98,0xdc,0x85,0x4e,0xef,
+  0xde,0xbd,0x83,0x82,0xda,0x6e,0xbe,0xf9,0xe6,0x4c,0xa5,0x75,0x6d,0xc7,0xcc,0x37,
+  0x61,0x8e,0xce,0xcf,0x0f,0xb2,0xac,0x5b,0xf5,0x5c,0x00,0x00,0x0a,0x40,0x5d,0x08,
+  0xb5,0x8c,0x75,0xa5,0x3d,0xfa,0x59,0x85,0xd0,0x91,0x31,0xe2,0x11,0x23,0x46,0xe4,
+  0xda,0x97,0x7e,0xfd,0xfa,0x79,0x97,0x79,0xfd,0xf5,0xd7,0x33,0xaf,0x37,0x24,0x1b,
+  0x60,0xf1,0xe2,0xc5,0x4a,0x17,0xda,0xa9,0x7a,0xdf,0x7f,0xff,0xfb,0xdf,0xe7,0x6e,
+  0xfd,0xb7,0xe2,0xb9,0x00,0x80,0x75,0xe9,0xca,0x21,0xc8,0x97,0x2d,0xb6,0xd8,0x22,
+  0x68,0xb9,0xb9,0x73,0xe7,0xd2,0x4f,0x83,0x90,0xa9,0x72,0x57,0xad,0x5a,0x15,0xcd,
+  0x48,0x97,0x27,0x13,0x26,0x4c,0xf0,0x2e,0x53,0xcd,0xec,0x77,0x62,0x79,0xeb,0xe2,
+  0x35,0x4a,0x97,0x59,0x4e,0x5d,0x4e,0x66,0x08,0x3c,0xe9,0xa4,0x93,0x32,0xaf,0x7f,
+  0xfe,0xfc,0xf9,0x4a,0xcf,0x3f,0x90,0xba,0xcc,0x80,0x01,0x03,0x82,0x3c,0x11,0xad,
+  0x7e,0x2e,0xfe,0xfe,0xf7,0xbf,0xab,0xc7,0x1e,0x7b,0xac,0xb4,0xf7,0x93,0x78,0x3e,
+  0x98,0xf4,0x08,0x50,0x00,0xda,0x44,0x01,0x90,0xa0,0xad,0x25,0x4b,0x96,0xa8,0x5e,
+  0xbd,0x7a,0xd1,0x4f,0x8d,0x2e,0x64,0xa3,0x66,0xcf,0x9e,0x1d,0xb4,0xbe,0xbc,0xa2,
+  0xce,0xb3,0x0a,0xdb,0xac,0xe8,0x02,0x39,0x51,0xf0,0x9d,0xaf,0x76,0x82,0x08,0x51,
+  0x99,0xf2,0x56,0x62,0x2b,0xb2,0xa0,0xd3,0xfa,0x22,0x0f,0x42,0x1a,0x32,0x1d,0x74,
+  0xd6,0x6b,0xac,0x15,0xcf,0x85,0xcc,0x90,0x28,0xc7,0xab,0xac,0xc8,0x10,0x0d,0x0a,
+  0x00,0xd4,0x1b,0x86,0x00,0x72,0x46,0x4f,0x06,0x13,0x1c,0x6d,0x5d,0x8f,0x39,0xd5,
+  0x9b,0xa5,0x9f,0x7a,0xb6,0xb9,0xa8,0xf0,0x4c,0x59,0x11,0x41,0x2b,0x16,0x6f,0x56,
+  0xf4,0x24,0x3a,0x91,0x22,0x90,0x86,0xf4,0x5b,0xa6,0x6e,0xce,0x4a,0x11,0xc1,0x7f,
+  0xad,0x7c,0x2e,0x00,0x00,0x05,0xa0,0x70,0x24,0x57,0x3e,0xf4,0x41,0x4b,0x3f,0x3f,
+  0x24,0xc4,0xe2,0x6c,0x34,0xd5,0x58,0x9e,0x32,0x04,0x10,0x52,0x25,0x2f,0xab,0x02,
+  0xf0,0xe2,0x8b,0x2f,0x46,0x91,0xfa,0x69,0xec,0xb2,0xcb,0x2e,0x6a,0xfb,0xed,0xb7,
+  0xcf,0xbc,0xcf,0xad,0x7a,0x2e,0x00,0x00,0x05,0xa0,0x34,0x82,0xb1,0x96,0xe8,0xef,
+  0x56,0xeb,0xa7,0x14,0x78,0x29,0x3b,0xd5,0x9e,0xaf,0x90,0x60,0x40,0x5d,0x0b,0x3f,
+  0xd3,0x18,0x75,0x51,0xd6,0x7f,0xab,0x9f,0x0b,0x00,0x40,0x01,0x28,0x14,0x49,0x01,
+  0x0b,0xa1,0x6b,0xd7,0xae,0xf4,0x73,0x0d,0xcd,0x10,0x14,0x59,0x6d,0xd5,0xbe,0xa3,
+  0x8f,0x3e,0x3a,0xe8,0x58,0x85,0xd6,0x04,0x58,0xb6,0x6c,0x59,0x34,0xa6,0x9d,0x46,
+  0xdf,0xbe,0x7d,0xd5,0xf1,0xc7,0x1f,0x5f,0xd5,0xfe,0xb6,0xf2,0xb9,0x00,0x00,0x14,
+  0x80,0x42,0xf1,0x55,0x65,0x8b,0x91,0x08,0x6d,0xfa,0xd9,0x3c,0x0f,0xf4,0x6a,0x15,
+  0x36,0x49,0x6d,0x3b,0xf2,0xc8,0x23,0xbd,0xcb,0x5d,0x77,0xdd,0x75,0x91,0x70,0xf7,
+  0x71,0xd3,0x4d,0x37,0x79,0xad,0x74,0x11,0xfe,0xa2,0x04,0xb4,0xaa,0x70,0x6d,0x76,
+  0xe5,0x19,0xa0,0x14,0xf7,0x11,0x87,0x20,0x7f,0x16,0x2d,0x5a,0x14,0xb4,0xdc,0xc0,
+  0x81,0x03,0xe9,0xe7,0x1a,0xf4,0x24,0x2f,0x2d,0x2d,0x74,0xa4,0x34,0xb0,0xcf,0x6a,
+  0x97,0x58,0x09,0x3d,0x21,0x8e,0x37,0x6d,0xaf,0x48,0xf7,0x7f,0xab,0x9e,0x8b,0xdd,
+  0x77,0xdf,0x5d,0xcd,0x9a,0x35,0xab,0xb4,0xfd,0xc9,0x5a,0xa8,0x09,0x00,0x05,0xa0,
+  0xc9,0x05,0x63,0xb3,0x7b,0x00,0xf2,0xec,0xe7,0x7a,0xeb,0xad,0x17,0xb4,0xae,0xef,
+  0x7d,0xef,0x7b,0x99,0xa6,0x24,0x2e,0x0b,0x32,0x15,0xef,0xa8,0x51,0xa3,0x94,0x9e,
+  0x29,0x30,0x75,0x39,0xa9,0x09,0x90,0xa6,0x00,0x48,0x4d,0x81,0xfb,0xef,0xbf,0x3f,
+  0x75,0x1d,0x12,0xf8,0x27,0x01,0x80,0xd5,0xd2,0x8a,0xe7,0xe2,0xcc,0x33,0xcf,0x8c,
+  0x1a,0x00,0xfc,0x7f,0x18,0x02,0x28,0x00,0x5f,0x6e,0xb6,0x20,0x6e,0xe1,0x2e,0x5d,
+  0xba,0xd0,0xcf,0x8c,0x42,0x27,0xa4,0x50,0x4c,0x29,0x6f,0xb4,0xce,0x9d,0xa3,0x94,
+  0x40,0x1f,0x77,0xdf,0x7d,0xb7,0x7a,0xff,0xfd,0xf7,0x9d,0xdf,0xff,0xe1,0x0f,0x7f,
+  0xf0,0xa6,0xe8,0xd5,0x62,0xfd,0xb7,0xc3,0xb9,0x00,0x00,0x14,0x80,0x42,0x90,0xa9,
+  0x59,0x43,0xc6,0x50,0x9b,0xdd,0xfd,0x9f,0x77,0x3f,0xa5,0xae,0x40,0x88,0xa2,0xd0,
+  0xcc,0x42,0x47,0x8a,0x02,0xf9,0x90,0x22,0x3c,0x32,0x4d,0xb0,0x0d,0xc9,0x7d,0x17,
+  0x05,0x20,0x0d,0x29,0xfa,0xf3,0x99,0xcf,0x7c,0xa6,0xa6,0xfd,0x6c,0x87,0x73,0x01,
+  0x00,0x28,0x00,0xb9,0xe3,0x9b,0x98,0x25,0x66,0xf3,0xcd,0x37,0xa7,0x9f,0x09,0xa4,
+  0x58,0x8e,0xcc,0x59,0xef,0x43,0xd2,0xe5,0x42,0x87,0x1e,0xca,0x86,0x54,0x4f,0x94,
+  0xb1,0x68,0x1f,0xae,0x6c,0x00,0xf1,0x0e,0xc8,0x14,0xc2,0x69,0xc8,0xf0,0x41,0xad,
+  0xca,0x65,0x3b,0x9c,0x0b,0x00,0x40,0x01,0x68,0x98,0x60,0xac,0x65,0x8c,0xb6,0x55,
+  0xfb,0xb9,0xd3,0x4e,0x3b,0x05,0x59,0xc8,0x22,0x08,0x9b,0x15,0x09,0x06,0xf4,0x21,
+  0xb3,0xdd,0x49,0xa1,0x1f,0x93,0xa2,0x26,0xfe,0x69,0xd7,0x73,0x01,0x80,0x02,0x00,
+  0x28,0x00,0x25,0xe9,0x67,0xe8,0xdc,0xf2,0xb7,0xdc,0x72,0x4b,0xd3,0x1e,0xb7,0x63,
+  0x8e,0x39,0x26,0xa8,0x84,0xb2,0xe9,0x05,0x90,0x21,0x97,0x3b,0xee,0xb8,0x23,0xf5,
+  0x37,0x12,0x49,0x2e,0x13,0x10,0xe5,0x41,0x3b,0x9c,0x0b,0x00,0x14,0x00,0xc8,0x95,
+  0xd0,0x79,0xd4,0x9b,0x5d,0x01,0x28,0xa2,0x9f,0xfb,0xed,0xb7,0x5f,0xd0,0x72,0x77,
+  0xde,0x79,0x67,0x64,0x7d,0x36,0x23,0x32,0xbe,0x7e,0xf8,0xe1,0x87,0x7b,0x97,0x93,
+  0x38,0x80,0x64,0xbd,0x7b,0x51,0x08,0x7c,0x75,0x17,0xf2,0xb2,0xfe,0xdb,0xe5,0x5c,
+  0x00,0xa0,0x00,0x40,0x6e,0x48,0xf4,0xb6,0xaf,0x3e,0xbb,0x30,0x74,0xe8,0xd0,0x28,
+  0x25,0x8c,0x7e,0xae,0x8d,0xa4,0xaf,0x85,0x8c,0x3d,0x4b,0x11,0x9c,0xbf,0xfd,0xed,
+  0x6f,0x4d,0x7b,0xfc,0x42,0x4a,0x03,0xcf,0x98,0x31,0x43,0xdd,0x73,0xcf,0x3d,0x1d,
+  0x7f,0xfb,0x72,0xff,0xc5,0xab,0x10,0x12,0x64,0xc8,0xb9,0x00,0x00,0x14,0x80,0x02,
+  0x90,0x39,0xc7,0x43,0x22,0xe3,0x0f,0x39,0xe4,0x10,0xfa,0x69,0xbb,0x18,0x75,0xaa,
+  0x5c,0xa8,0xe5,0x79,0xfe,0xf9,0xe7,0x37,0xed,0x8c,0x70,0x07,0x1d,0x74,0x90,0x1a,
+  0x36,0x6c,0x98,0x77,0x39,0xa9,0x09,0x20,0x88,0xb7,0xc5,0x37,0xe4,0x72,0xc4,0x11,
+  0x47,0x04,0x09,0x6c,0xce,0x05,0x00,0xa0,0x00,0x14,0x80,0x2b,0x7d,0xcb,0xe4,0x94,
+  0x53,0x4e,0xa1,0x9f,0x0e,0xce,0x38,0xe3,0x8c,0xa0,0xe5,0x44,0x20,0x5e,0x73,0xcd,
+  0x35,0x4d,0x79,0xfc,0xa4,0x8a,0x5d,0x48,0xaa,0xde,0xad,0xb7,0xde,0x1a,0x4d,0xa5,
+  0x5c,0xcf,0xe0,0xbf,0x76,0x3b,0x17,0x00,0x28,0x00,0x6d,0xc4,0xd2,0xa5,0x4b,0x0b,
+  0x59,0xaf,0x58,0x69,0xf7,0xde,0x7b,0xaf,0x77,0xb9,0x2d,0xb7,0xdc,0x52,0x7d,0xfc,
+  0xe3,0x1f,0xa7,0x9f,0x0e,0xf6,0xdc,0x73,0x4f,0xb5,0xf7,0xde,0x7b,0x07,0x2d,0x7b,
+  0xce,0x39,0xe7,0xa8,0x77,0xdf,0x7d,0xb7,0x29,0xaf,0xc3,0x10,0x77,0xbd,0x9c,0x43,
+  0x11,0xfe,0xd7,0x5f,0x7f,0x7d,0xea,0x72,0x9b,0x6e,0xba,0x69,0x54,0x69,0x30,0x6f,
+  0xda,0xe5,0x5c,0x00,0xa0,0x00,0xb4,0x09,0x22,0x94,0xde,0x7a,0xeb,0xad,0xdc,0xd7,
+  0x7b,0xde,0x79,0xe7,0x05,0x2d,0x77,0xf2,0xc9,0x27,0xd3,0x4f,0x0f,0xe7,0x9e,0x7b,
+  0x6e,0xd0,0x72,0x12,0x19,0x2f,0x33,0xed,0x2d,0x5f,0xbe,0xbc,0xe9,0xae,0xc3,0xed,
+  0xb6,0xdb,0x4e,0xed,0xb8,0xe3,0x8e,0xde,0xe5,0xce,0x3e,0xfb,0x6c,0x6f,0xc5,0x45,
+  0xf1,0xb4,0x48,0xee,0x7e,0x11,0xb4,0xc3,0xb9,0x00,0x40,0x01,0x68,0x13,0x9e,0x7b,
+  0xee,0xb9,0x28,0xc7,0x39,0xc4,0x8a,0x0d,0xe5,0xb2,0xcb,0x2e,0x53,0x0f,0x3c,0xf0,
+  0x80,0x77,0xb9,0x9e,0x3d,0x7b,0xe6,0x1a,0xa8,0xd5,0xaa,0xfd,0x3c,0xe0,0x80,0x03,
+  0xd4,0x6e,0xbb,0xed,0x16,0xb4,0xec,0xe3,0x8f,0x3f,0x1e,0x09,0xc0,0xd0,0x99,0x09,
+  0xcb,0x44,0x48,0x30,0xa0,0x0f,0x19,0x4e,0x08,0xa9,0x2d,0xc0,0xb9,0x00,0x80,0xb6,
+  0x57,0x00,0x84,0xd9,0xb3,0x67,0xab,0x83,0x0f,0x3e,0x38,0x9a,0xc8,0xa4,0x56,0x57,
+  0xb9,0x44,0x6a,0x9f,0x75,0xd6,0x59,0xc1,0xd6,0xd4,0x06,0x1b,0x6c,0x40,0x3f,0x03,
+  0xb8,0xf4,0xd2,0x4b,0x55,0xf7,0xee,0xdd,0x83,0x96,0xbd,0xfa,0xea,0xab,0x23,0x41,
+  0x35,0x73,0xe6,0xcc,0x42,0x8e,0xa3,0x04,0xb8,0xf9,0xa6,0xdf,0xad,0x06,0x99,0xb2,
+  0xb7,0x5b,0xb7,0x6e,0x35,0xad,0xe3,0xb0,0xc3,0x0e,0x0b,0x0a,0x28,0xe4,0x5c,0x00,
+  0xc0,0x3a,0x54,0x0a,0xe6,0xe2,0x8b,0x2f,0x96,0x99,0x4b,0xbc,0xad,0x5e,0xdb,0x31,
+  0xdb,0x46,0x1b,0x6d,0x54,0xd1,0x63,0xac,0x55,0x6d,0x53,0xd7,0x65,0xaf,0xe8,0x39,
+  0xd7,0x83,0xb6,0xf3,0x91,0x8f,0x7c,0xa4,0xa2,0xdd,0xa3,0xf4,0x33,0x03,0xda,0xe3,
+  0x90,0xa9,0x8f,0xa3,0x47,0x8f,0xae,0xe8,0x60,0xb4,0x8a,0x16,0x12,0x35,0x6f,0x5b,
+  0x4f,0xcd,0x5b,0xb9,0xee,0xba,0xeb,0x2a,0x9f,0xfd,0xec,0x67,0x2b,0x3a,0xba,0xbe,
+  0xb2,0xe1,0x86,0x1b,0x16,0x72,0x7f,0xe8,0x9a,0x00,0x55,0x9d,0xcf,0xb8,0xdd,0x75,
+  0xd7,0x5d,0x95,0x7a,0xd0,0x0e,0xe7,0x02,0xa0,0xdd,0x68,0x7b,0x05,0x20,0x6e,0xba,
+  0x82,0x5a,0x45,0xcf,0xd7,0x5e,0x59,0xb8,0x70,0xa1,0x77,0x5b,0x2f,0xbf,0xfc,0x72,
+  0x45,0xa7,0x5d,0x05,0xaf,0x5b,0x8f,0xcf,0x56,0x1e,0x79,0xe4,0x91,0xba,0x1e,0xcf,
+  0x66,0xef,0x67,0x8c,0x9e,0x41,0x2f,0x73,0x1f,0x75,0xcd,0xfd,0x48,0x69,0xd1,0x56,
+  0x68,0xa6,0x6d,0x4d,0x9a,0x34,0xa9,0xf2,0x8b,0x5f,0xfc,0xa2,0xa2,0xab,0xe0,0x55,
+  0xb4,0x65,0xbe,0xd6,0x3a,0x75,0x4d,0x83,0x42,0xee,0x8f,0x9b,0x6f,0xbe,0xb9,0xea,
+  0x73,0x29,0x42,0x36,0x0f,0x01,0xcb,0xb9,0x00,0x68,0x4f,0xba,0xe2,0x03,0xf9,0x10,
+  0x89,0x6e,0x97,0xd6,0xa7,0x4f,0x9f,0xa8,0x52,0x9b,0x8c,0x7b,0x6a,0xab,0x59,0x69,
+  0x6b,0x23,0x72,0x9f,0x4b,0x84,0xb3,0x7e,0x28,0x45,0x11,0xd9,0x52,0xab,0x3d,0x0b,
+  0xa7,0x9e,0x7a,0x6a,0x6e,0x25,0x5a,0xdb,0xad,0x9f,0x97,0x5f,0x7e,0x79,0xb4,0x1f,
+  0x2f,0xbd,0xf4,0x52,0xf0,0x6f,0x24,0x2d,0xed,0xa4,0x93,0x4e,0x8a,0x02,0xe3,0x24,
+  0xd8,0x6e,0x9f,0x7d,0xf6,0x51,0x9b,0x6c,0xb2,0x49,0x94,0x27,0xdf,0xbb,0x77,0xef,
+  0x68,0x02,0x9b,0xb9,0x73,0xe7,0x46,0x41,0x92,0xd2,0xde,0x7e,0xfb,0xed,0xe8,0x55,
+  0x02,0xd9,0xea,0xcd,0x27,0x3f,0xf9,0xc9,0x68,0xfa,0xdd,0x59,0xb3,0x66,0x65,0xfe,
+  0xad,0x04,0x5a,0x4a,0xbe,0x7e,0xbd,0x68,0xf5,0x73,0x01,0xc0,0x10,0x40,0x9b,0x7a,
+  0x00,0x8a,0x6a,0x87,0x1e,0x7a,0x68,0x6e,0x2e,0xf1,0x76,0xea,0x67,0x12,0x5d,0x15,
+  0xaf,0xb2,0xeb,0xae,0xbb,0x36,0xb4,0x7f,0x45,0x5a,0x9d,0x3a,0xdf,0x3e,0xf3,0xfe,
+  0xe8,0xe9,0x7a,0x2b,0x53,0xa7,0x4e,0xad,0xbb,0xc5,0xd0,0xea,0xe7,0x02,0xa0,0x9d,
+  0x68,0xbb,0x20,0xc0,0x6f,0x7f,0xfb,0xdb,0x75,0xdb,0x96,0x54,0x52,0x13,0x4b,0xba,
+  0xd6,0x40,0xaf,0x76,0xef,0xa7,0x94,0x14,0x7e,0xf0,0xc1,0x07,0xd5,0x51,0x47,0x1d,
+  0xd5,0x92,0xd7,0x64,0x35,0xd9,0x00,0x12,0xdc,0x39,0x72,0xe4,0xc8,0xba,0xef,0x6b,
+  0xab,0x9f,0x0b,0x80,0x76,0xa2,0xed,0x14,0x80,0x1f,0xff,0xf8,0xc7,0xea,0x82,0x0b,
+  0x2e,0x28,0x7c,0x3b,0xe3,0xc6,0x8d,0x53,0xb7,0xdd,0x76,0x5b,0x94,0x12,0x47,0x3f,
+  0x6b,0xa7,0x57,0xaf,0x5e,0x91,0x92,0x21,0x05,0x67,0x5a,0x0d,0x49,0xd7,0xdc,0x7a,
+  0xeb,0xad,0x33,0xfd,0xa6,0x88,0xca,0x7f,0x9c,0x0b,0x00,0x14,0x80,0x96,0xe7,0x5b,
+  0xdf,0xfa,0x96,0xd2,0x81,0x49,0xd1,0xcc,0x6c,0x79,0xa3,0x5d,0xb3,0xea,0x1b,0xdf,
+  0xf8,0x86,0xba,0xef,0xbe,0xfb,0xa2,0x71,0x76,0xfa,0x99,0x1f,0x32,0x8e,0xfc,0xd3,
+  0x9f,0xfe,0x54,0xe9,0xc8,0xf7,0x68,0x3c,0xb9,0x95,0xc8,0x92,0xcb,0x3f,0x7c,0xf8,
+  0x70,0xf5,0xa9,0x4f,0x7d,0xaa,0xa1,0xfb,0xdb,0xca,0xe7,0x02,0x00,0x05,0xa0,0xc5,
+  0x91,0x07,0xae,0x04,0x28,0xc9,0x6b,0x5e,0x55,0xd4,0xb6,0xdd,0x76,0x5b,0xf5,0xe4,
+  0x93,0x4f,0xaa,0x0b,0x2f,0xbc,0xb0,0x61,0x96,0x7f,0x3b,0xf4,0x53,0xdc,0xdf,0xff,
+  0xfa,0xd7,0xbf,0xa2,0x29,0x72,0x25,0x80,0xb1,0x48,0x64,0x58,0x43,0xbc,0x1c,0xa7,
+  0x9f,0x7e,0x7a,0xa1,0xdb,0x39,0xe1,0x84,0x13,0x22,0xa5,0x2a,0x04,0x09,0xaa,0x93,
+  0x02,0x40,0x65,0xa0,0x15,0xcf,0x05,0x40,0xdb,0x50,0x74,0x90,0x81,0x8e,0x1c,0xf6,
+  0x06,0xf5,0x68,0x0b,0xb2,0xa1,0xc1,0x86,0x3a,0x2a,0xbe,0x32,0x7e,0xfc,0xf8,0x68,
+  0x3f,0x54,0xc6,0x80,0x24,0x1d,0x85,0x5d,0xd1,0x63,0xe0,0x15,0x5d,0xb3,0xbd,0xb0,
+  0x20,0xb8,0x76,0xec,0x67,0x28,0x3a,0x73,0xa1,0x72,0xe5,0x95,0x57,0x46,0xe9,0x8a,
+  0xfd,0xfa,0xf5,0xab,0x39,0xc0,0x4c,0x2b,0x34,0x15,0x5d,0xff,0xbe,0xa2,0x4b,0x1e,
+  0x57,0x74,0x15,0xc5,0x8a,0x8e,0x52,0xaf,0x5b,0x5f,0xf4,0xec,0x89,0x41,0xa9,0x96,
+  0x93,0x27,0x4f,0x2e,0x65,0x40,0x51,0x2b,0x9d,0x0b,0x80,0x76,0xa0,0x93,0xfc,0xd7,
+  0x0a,0x8a,0xcc,0x25,0x97,0x5c,0x12,0xd5,0x4d,0x0f,0x50,0x78,0x9c,0xdf,0x2d,0x59,
+  0xb2,0x24,0x72,0x69,0xea,0xdc,0xec,0xc8,0x6a,0x96,0x94,0x38,0x49,0x47,0x5a,0xb9,
+  0x72,0x65,0x34,0xdf,0xba,0x94,0x38,0x95,0x0a,0x77,0x23,0x46,0x8c,0x88,0x02,0xb0,
+  0x24,0xf8,0xed,0x98,0x63,0x8e,0x89,0x5c,0xb2,0xf4,0xb3,0xf1,0xc8,0x7e,0xeb,0x3a,
+  0x04,0xd1,0x74,0xc5,0x92,0xaa,0xf6,0xfe,0xfb,0xef,0x47,0x4d,0xaa,0xd2,0xc9,0x77,
+  0xd2,0xb7,0x65,0xcb,0x96,0x29,0x2d,0x9c,0xa2,0xbe,0x48,0x05,0x3d,0x79,0x95,0x26,
+  0x69,0x90,0x92,0x12,0xa9,0x23,0xdc,0xa3,0xe5,0x80,0x73,0x01,0xd0,0xea,0xa0,0x00,
+  0x78,0x90,0x79,0xef,0x25,0x4f,0x59,0x5c,0xae,0x32,0xd6,0xdd,0x68,0xd7,0x6b,0xbb,
+  0xf4,0x33,0x67,0x2f,0x57,0xd4,0x37,0x71,0xb1,0xc7,0xfd,0x03,0xce,0x05,0x40,0xbb,
+  0x43,0x21,0x20,0x0f,0x52,0x68,0x45,0x8a,0x96,0xd0,0xcf,0x26,0xd6,0x72,0x75,0xec,
+  0xc3,0xe0,0xc1,0x83,0xb9,0x98,0x39,0x17,0x00,0x90,0x7c,0xee,0x73,0x08,0x00,0x00,
+  0x00,0x50,0x00,0x00,0x00,0x00,0x00,0x05,0x00,0x00,0x00,0x00,0x50,0x00,0x00,0x00,
+  0x00,0x00,0x05,0x00,0x00,0x00,0x00,0x50,0x00,0x00,0x00,0x00,0x00,0x05,0x00,0x00,
+  0x00,0x00,0x50,0x00,0x00,0x00,0x00,0x00,0x05,0x00,0x00,0x00,0x00,0x50,0x00,0x00,
+  0x00,0x00,0x00,0x05,0x00,0x00,0x00,0x00,0x50,0x00,0x00,0x00,0x00,0x00,0x05,0x00,
+  0x00,0x00,0x00,0x50,0x00,0x00,0x00,0x00,0x20,0x23,0x2d,0x33,0x1d,0xf0,0x56,0x5b,
+  0x6d,0xa5,0xf6,0xdd,0x77,0xdf,0xd4,0x65,0xfa,0xf6,0xed,0x4b,0x3f,0x01,0x00,0x00,
+  0x34,0x9d,0x2a,0x1a,0x0e,0x03,0x00,0x00,0x40,0x7b,0xc1,0x10,0x00,0x00,0x00,0x00,
+  0x0a,0x00,0x00,0x00,0x00,0xa0,0x00,0x00,0x00,0x00,0x00,0x0a,0x00,0x00,0x00,0x00,
+  0xa0,0x00,0x00,0x00,0x00,0x00,0x0a,0x00,0x00,0x00,0x00,0xa0,0x00,0x00,0x00,0x00,
+  0x00,0x0a,0x00,0x00,0x00,0x00,0xa0,0x00,0x00,0x00,0x00,0x00,0x0a,0x00,0x00,0x00,
+  0x00,0xa0,0x00,0x00,0x00,0x00,0x00,0x0a,0x00,0x00,0x00,0x00,0xa0,0x00,0x00,0x00,
+  0x00,0x00,0x0a,0x00,0x00,0x00,0x00,0xa0,0x00,0x00,0x00,0x00,0x00,0x0a,0x00,0x00,
+  0x00,0x00,0xa0,0x00,0x00,0x00,0x00,0x00,0x0a,0x00,0x00,0x00,0x00,0x0a,0x00,0x00,
+  0x00,0x00,0xa0,0x00,0x00,0x00,0x00,0x00,0x0a,0x00,0x00,0x00,0x00,0xa0,0x00,0x00,
+  0x00,0x00,0x00,0x0a,0x00,0x00,0x00,0x00,0xa0,0x00,0x00,0x00,0x00,0x00,0x0a,0x00,
+  0x00,0x00,0x00,0x94,0x8a,0xae,0x1c,0x02,0x00,0x28,0x33,0x2b,0x57,0xae,0x54,0x73,
+  0xe7,0xce,0x4d,0x5d,0xa6,0x5b,0xb7,0x6e,0x6a,0xe0,0xc0,0x81,0x1c,0x2c,0x00,0x14,
+  0x00,0x00,0x68,0x15,0x7e,0xf7,0xbb,0xdf,0xa9,0x33,0xcf,0x3c,0x33,0x75,0x99,0xee,
+  0xdd,0xbb,0xab,0x65,0xcb,0x96,0x71,0xb0,0x00,0x32,0xc0,0x10,0x00,0x00,0x94,0x9a,
+  0xe5,0xcb,0x97,0xe7,0xb2,0x0c,0x00,0xa0,0x00,0x00,0x00,0x00,0xa0,0x00,0x70,0x08,
+  0x00,0x00,0x00,0x50,0x00,0x00,0x00,0x00,0x00,0x05,0x00,0x00,0x00,0x00,0x50,0x00,
+  0x00,0x00,0x00,0xa0,0x25,0x20,0x0d,0x10,0x00,0xa0,0x4d,0x59,0xb0,0x60,0x81,0x7a,
+  0xf3,0xcd,0x37,0xa3,0x36,0x65,0xca,0x94,0xe8,0x75,0xda,0xb4,0x69,0xea,0xdc,0x73,
+  0xcf,0x55,0xdb,0x6d,0xb7,0x1d,0x07,0x08,0x05,0x00,0x00,0x00,0x5a,0x81,0xf9,0xf3,
+  0xe7,0xab,0x93,0x4f,0x3e,0xb9,0x43,0xe0,0xcf,0x9e,0x3d,0xdb,0xba,0xdc,0xe1,0x87,
+  0x1f,0x8e,0x02,0x80,0x02,0x00,0x00,0xd0,0x58,0xc6,0x8f,0x1f,0xaf,0x36,0xd8,0x60,
+  0x83,0xd4,0x65,0xfa,0xf6,0xed,0xcb,0x81,0x0a,0x60,0xc9,0x92,0x25,0xea,0x86,0x1b,
+  0x6e,0xe0,0x40,0x00,0x0a,0x00,0x00,0x94,0x9f,0xd1,0xa3,0x47,0xab,0x13,0x4f,0x3c,
+  0x91,0x03,0x01,0x90,0x33,0x04,0x01,0x02,0x00,0x00,0xa0,0x00,0x00,0x00,0x00,0x00,
+  0x0a,0x00,0x00,0x00,0x00,0xa0,0x00,0x00,0x00,0x00,0x00,0x0a,0x00,0x00,0x00,0x00,
+  0x34,0x29,0x64,0x01,0x00,0x34,0x88,0x79,0xf3,0xe6,0x75,0x14,0x61,0x79,0xeb,0xad,
+  0xb7,0xd4,0xea,0xd5,0xab,0xd5,0xd0,0xa1,0x43,0xd5,0xf0,0xe1,0xc3,0xd5,0xb0,0x61,
+  0xc3,0xd4,0xa8,0x51,0xa3,0x54,0x9f,0x3e,0x7d,0x9a,0xba,0x8f,0x92,0x76,0x36,0x79,
+  0xf2,0xe4,0xa8,0x49,0xde,0xf9,0xaa,0x55,0xab,0xd4,0x7a,0xeb,0xad,0x17,0xb5,0xfd,
+  0xf7,0xdf,0x5f,0x75,0xef,0xde,0xbd,0x6d,0xce,0x75,0x7c,0x1c,0xde,0x7e,0xfb,0x6d,
+  0xd5,0xb9,0x73,0x67,0xb5,0xfe,0xfa,0xeb,0x47,0xe9,0x8d,0x5b,0x6c,0xb1,0x45,0x74,
+  0xae,0xc1,0xcf,0xa2,0x45,0x8b,0xd4,0xd4,0xa9,0x53,0xd5,0xf4,0xe9,0xd3,0xd5,0xbb,
+  0xef,0xbe,0x1b,0xbd,0x2e,0x5c,0xb8,0x50,0x0d,0x19,0x32,0x24,0xba,0x67,0xa4,0x8d,
+  0x18,0x31,0x42,0x6d,0xb2,0xc9,0x26,0xaa,0x53,0xa7,0x4e,0xdc,0x3b,0x28,0x00,0x00,
+  0xb5,0x21,0x37,0xdf,0x03,0x0f,0x3c,0x90,0xba,0x8c,0x08,0xea,0x63,0x8f,0x3d,0x36,
+  0x75,0x99,0x95,0x2b,0x57,0xaa,0x1b,0x6f,0xbc,0x51,0xfd,0xee,0x77,0xbf,0x53,0x2f,
+  0xbc,0xf0,0x82,0xfa,0xe0,0x83,0x0f,0xd2,0x6f,0xce,0xae,0x5d,0xd5,0xbe,0xfb,0xee,
+  0xab,0x8e,0x3a,0xea,0x28,0x75,0xc4,0x11,0x47,0x78,0x73,0xe1,0xcb,0xd2,0xcf,0xd7,
+  0x5f,0x7f,0x5d,0xfd,0xec,0x67,0x3f,0x53,0x7f,0xff,0xfb,0xdf,0xa3,0x07,0x74,0xa5,
+  0x52,0xb1,0x2e,0xf7,0xce,0x3b,0xef,0x44,0x0f,0xeb,0x7a,0xed,0x57,0x3d,0xb7,0x23,
+  0x0f,0xeb,0xdb,0x6e,0xbb,0x4d,0x5d,0x76,0xd9,0x65,0xea,0xd9,0x67,0x9f,0x55,0x73,
+  0xe7,0xce,0x4d,0x5d,0x7e,0xab,0xad,0xb6,0x52,0x07,0x1f,0x7c,0xb0,0xfa,0xea,0x57,
+  0xbf,0x1a,0x09,0xaf,0x3c,0x84,0xc7,0x5f,0xff,0xfa,0xd7,0x75,0x8e,0xfd,0xcc,0x99,
+  0x33,0x83,0x7e,0x7f,0xe7,0x9d,0x77,0xaa,0x65,0xcb,0x96,0x65,0xda,0xe6,0xae,0xbb,
+  0xee,0xaa,0xb6,0xd9,0x66,0x9b,0xdc,0xaf,0x4b,0x29,0x56,0x74,0xeb,0xad,0xb7,0xaa,
+  0xeb,0xaf,0xbf,0x5e,0xdd,0x77,0xdf,0x7d,0x6a,0xc5,0x8a,0x15,0xde,0xdf,0x88,0x42,
+  0x25,0xf7,0xcc,0x91,0x47,0x1e,0xa9,0xf6,0xd8,0x63,0x0f,0xd5,0xa5,0x4b,0x97,0xb6,
+  0xbc,0x77,0xbc,0x54,0x00,0x20,0x95,0x8b,0x2f,0xbe,0x58,0xee,0x42,0x6f,0x73,0xa1,
+  0x1f,0x60,0x95,0x9f,0xfc,0xe4,0x27,0x95,0x91,0x23,0x47,0x06,0xad,0xc7,0xd6,0xb4,
+  0xc5,0x58,0x39,0xfe,0xf8,0xe3,0x2b,0xfa,0xa1,0x50,0xda,0x7e,0x3e,0xf5,0xd4,0x53,
+  0x15,0xad,0xac,0x44,0xfb,0x1a,0xb2,0x1e,0xfd,0x10,0xab,0xcb,0x7e,0xd5,0xab,0xff,
+  0xf1,0xb9,0xbe,0xe8,0xa2,0x8b,0x2a,0x1b,0x6d,0xb4,0x51,0x55,0xe7,0xb9,0x5b,0xb7,
+  0x6e,0x95,0xaf,0x7c,0xe5,0x2b,0x15,0x2d,0xa8,0x6b,0xea,0xcb,0x33,0xcf,0x3c,0x53,
+  0xf5,0xb5,0x56,0x6d,0x3b,0xeb,0xac,0xb3,0x72,0xbd,0x1e,0x27,0x4e,0x9c,0x58,0xd1,
+  0x15,0x09,0x2b,0x5a,0x11,0xae,0x69,0xbf,0x36,0xde,0x78,0xe3,0xca,0x1d,0x77,0xdc,
+  0x51,0xea,0x67,0x44,0x51,0xf7,0x8e,0x0f,0x62,0x00,0x00,0x0a,0xe4,0xe6,0x9b,0x6f,
+  0x8e,0x0a,0xd9,0x7c,0xeb,0x5b,0xdf,0x8a,0x6a,0xac,0x57,0x8b,0x0c,0x0f,0x5c,0x7b,
+  0xed,0xb5,0x6a,0xcb,0x2d,0xb7,0x8c,0x3c,0x08,0xf2,0x77,0x59,0x90,0x7d,0x39,0xfd,
+  0xf4,0xd3,0x23,0x0b,0x50,0x3c,0x1c,0x65,0xda,0xb7,0x7a,0xf2,0xe7,0x3f,0xff,0x39,
+  0x3a,0xd7,0xdf,0xf8,0xc6,0x37,0xa2,0x21,0x9d,0x6a,0x10,0xeb,0x56,0xbc,0x06,0xbb,
+  0xec,0xb2,0x8b,0x7a,0xf9,0xe5,0x97,0xdb,0xf2,0x38,0x8a,0xe7,0xe1,0xfb,0xdf,0xff,
+  0x7e,0xe4,0x4d,0x10,0xcb,0x5f,0x3c,0x67,0xb5,0x20,0x43,0x6c,0x87,0x1e,0x7a,0x68,
+  0xe4,0x49,0x13,0xcb,0xb9,0x4c,0x34,0xfa,0xde,0x41,0x01,0x00,0x28,0x88,0x4b,0x2e,
+  0xb9,0x44,0x1d,0x7d,0xf4,0xd1,0xd1,0xb8,0x65,0x5e,0xc8,0x58,0xb2,0xb6,0x10,0xa3,
+  0x07,0x5a,0x56,0x17,0x6d,0x51,0x0f,0x6b,0x71,0x6b,0x8a,0xd0,0x6a,0x57,0x44,0x68,
+  0x8b,0xeb,0x5e,0xaa,0x15,0xe6,0x75,0xae,0x45,0x68,0x8d,0x1b,0x37,0x4e,0x3d,0xfe,
+  0xf8,0xe3,0x6d,0x75,0x2c,0x9f,0x7b,0xee,0xb9,0x48,0xf0,0xff,0xe0,0x07,0x3f,0xc8,
+  0xfd,0xfa,0xbe,0xe9,0xa6,0x9b,0xd4,0x0e,0x3b,0xec,0xa0,0xfe,0xfd,0xef,0x7f,0x97,
+  0x46,0xd1,0x69,0xf4,0xbd,0x83,0x02,0x00,0x90,0x33,0x62,0xb1,0x9c,0x76,0xda,0x69,
+  0xea,0xec,0xb3,0xcf,0x2e,0x4c,0xa3,0xbf,0xeb,0xae,0xbb,0x22,0x8b,0x66,0xf9,0xf2,
+  0xe5,0x0d,0xeb,0xa7,0x4c,0x2c,0x73,0xc8,0x21,0x87,0xb4,0x75,0x6d,0x79,0xb1,0x28,
+  0xf7,0xde,0x7b,0x6f,0xf5,0xdb,0xdf,0xfe,0x36,0xf7,0x75,0x8b,0xb2,0x27,0x0a,0x64,
+  0xe8,0xb8,0x7d,0xb3,0xf3,0xc4,0x13,0x4f,0xa8,0xfd,0xf6,0xdb,0x4f,0x4d,0x9a,0x34,
+  0xa9,0xb0,0x6d,0xcc,0x9a,0x35,0x4b,0x1d,0x70,0xc0,0x01,0xea,0xb5,0xd7,0x5e,0x6b,
+  0x68,0x5f,0xcb,0x72,0xef,0xa0,0x00,0x00,0xe4,0xcc,0x67,0x3f,0xfb,0x59,0x75,0xc5,
+  0x15,0x57,0x14,0xbe,0x1d,0x09,0xd4,0x3a,0xe6,0x98,0x63,0x82,0x82,0xa2,0xf2,0x46,
+  0x82,0xdc,0x24,0x68,0xcd,0x17,0xf8,0xd4,0xca,0xbc,0xf1,0xc6,0x1b,0x6a,0xa7,0x9d,
+  0x76,0x2a,0xd4,0x4a,0x97,0x48,0x77,0xb9,0x9e,0x5a,0x9d,0x87,0x1f,0x7e,0x58,0x1d,
+  0x74,0xd0,0x41,0x91,0xd2,0x53,0x34,0xef,0xbd,0xf7,0x5e,0x14,0x45,0x2f,0x5e,0x96,
+  0x46,0x50,0xa6,0x7b,0x07,0x05,0x00,0x20,0x47,0xae,0xbe,0xfa,0x6a,0x75,0xdd,0x75,
+  0xd7,0xd5,0x6d,0x7b,0x32,0x46,0xfa,0xa3,0x1f,0xfd,0xa8,0xee,0xfd,0xfc,0xf9,0xcf,
+  0x7f,0xde,0x76,0xee,0x69,0xd3,0x82,0x3b,0xec,0xb0,0xc3,0x22,0x61,0x52,0x34,0xf7,
+  0xdc,0x73,0x8f,0xfa,0xc7,0x3f,0xfe,0xd1,0xb2,0xc7,0xf2,0xd1,0x47,0x1f,0x8d,0xac,
+  0xe1,0x05,0x0b,0x16,0x04,0xff,0x46,0x07,0x4b,0x46,0xf1,0x16,0x3b,0xee,0xb8,0xa3,
+  0xda,0x7a,0xeb,0xad,0xa3,0x34,0xc0,0x2c,0x88,0xe7,0x46,0xa6,0x45,0x6e,0x04,0x65,
+  0xba,0x77,0x48,0x03,0x04,0xc8,0x09,0x09,0xf2,0x3b,0xf3,0xcc,0x33,0xb3,0x69,0xe0,
+  0x3a,0x1f,0xbc,0xd6,0x61,0x82,0x0b,0x2f,0xbc,0x50,0x1d,0x77,0xdc,0x71,0x51,0x2a,
+  0x59,0x3d,0xd0,0xd1,0xd9,0xea,0xbc,0xf3,0xce,0xcb,0xf4,0x1b,0xc9,0x59,0x6e,0xe4,
+  0x70,0x45,0x9e,0xc8,0xf9,0xd2,0x19,0x19,0xea,0x95,0x57,0x5e,0xc9,0xf4,0x3b,0xc9,
+  0xfb,0x97,0xdf,0x4a,0x5a,0x5b,0x35,0xe7,0xf8,0xc0,0x03,0x0f,0x0c,0x5e,0x7e,0xd0,
+  0xa0,0x41,0x6a,0xec,0xd8,0xb1,0xeb,0xa4,0x91,0x2d,0x5e,0xbc,0x38,0x4a,0x2f,0xf3,
+  0xd1,0xbb,0x77,0xef,0xa8,0x1e,0x45,0x16,0x74,0xe6,0x43,0xe6,0x7e,0x89,0xc5,0x7f,
+  0xc2,0x09,0x27,0x44,0xfb,0xe5,0x43,0xf2,0xfa,0xe5,0xb8,0xcb,0xb8,0xb9,0xb8,0xf1,
+  0x65,0x1f,0x93,0x48,0x0a,0x9d,0x28,0xc4,0xbf,0xfa,0xd5,0xaf,0x82,0x82,0xfd,0xee,
+  0xbf,0xff,0xfe,0x28,0xb0,0x56,0xd6,0x59,0x2f,0x4a,0x77,0xef,0x90,0xe4,0x05,0x90,
+  0x4f,0x8a,0x8f,0x76,0x61,0x7a,0x97,0xd1,0xf9,0xc9,0x95,0xf3,0xcf,0x3f,0xbf,0xa2,
+  0x2d,0xba,0x8a,0x2e,0xf0,0x51,0xd1,0xf1,0x02,0xd1,0x36,0x96,0x2e,0x5d,0x5a,0xd1,
+  0x02,0xa5,0x72,0xc1,0x05,0x17,0x54,0x74,0x10,0x54,0xe6,0x54,0xa7,0x3d,0xf7,0xdc,
+  0xb3,0xa2,0x85,0x4b,0x5d,0xfa,0x29,0xdb,0xf2,0x2d,0xb3,0xd7,0x5e,0x7b,0x55,0xf4,
+  0xb8,0x78,0x45,0xe7,0x6d,0x77,0xa4,0x2c,0xe9,0x5c,0xf8,0xca,0x83,0x0f,0x3e,0x58,
+  0xf9,0xc5,0x2f,0x7e,0x51,0x39,0xe7,0x9c,0x73,0x2a,0xfa,0xa1,0xdf,0x94,0x69,0x80,
+  0x3a,0xb6,0x23,0x68,0x39,0x9d,0xb1,0x51,0xb9,0xf4,0xd2,0x4b,0x2b,0xda,0xbd,0x5d,
+  0xd1,0x63,0xcf,0x1d,0xdb,0xd1,0x6e,0xfd,0x8a,0xce,0xf3,0xae,0x6c,0xbf,0xfd,0xf6,
+  0x99,0xce,0xb1,0x16,0x70,0x35,0xf7,0x71,0xc6,0x8c,0x19,0x41,0xdb,0xd2,0x19,0x0d,
+  0x75,0xb9,0xb7,0x74,0xe0,0x64,0xd0,0xfe,0xe8,0xe0,0xbd,0xca,0xd3,0x4f,0x3f,0x1d,
+  0xb4,0x4e,0xed,0x49,0xa8,0x9c,0x71,0xc6,0x19,0x41,0xeb,0xd5,0x4a,0x4e,0x45,0x2b,
+  0x21,0x75,0xbb,0x76,0xea,0x7d,0xef,0xf8,0x40,0x01,0x00,0xc8,0xe9,0xe6,0x4e,0x6b,
+  0xda,0x7a,0xab,0xdc,0x72,0xcb,0x2d,0x1d,0x02,0xdf,0x87,0x4e,0xf5,0xab,0xe8,0xc2,
+  0x21,0x99,0xb6,0xa1,0x87,0x1f,0x1a,0xde,0x4f,0x1d,0xb9,0x5e,0xb9,0xf7,0xde,0x7b,
+  0x4b,0x95,0x63,0x5d,0xcf,0xfe,0x4b,0xd3,0x85,0x7c,0x2a,0x7f,0xfa,0xd3,0x9f,0xbc,
+  0xe7,0x5a,0x57,0xb0,0x8b,0x72,0xbf,0x43,0xd7,0xab,0xe3,0x4a,0x5a,0x4a,0x01,0xd0,
+  0x01,0x70,0x41,0xfb,0xa2,0x0b,0xf9,0x54,0x25,0xa4,0xbf,0xf3,0x9d,0xef,0x04,0xad,
+  0x5f,0xa7,0x1c,0x96,0xe2,0xda,0x29,0xe2,0xde,0xa1,0x0e,0x00,0x40,0x03,0x91,0xb1,
+  0x49,0xc9,0xef,0x95,0x71,0x5c,0x5d,0xd4,0x24,0xb8,0x22,0x99,0x64,0x11,0x48,0x05,
+  0x39,0x71,0x1b,0x87,0xd2,0xc8,0x74,0xa2,0xfe,0xfd,0xfb,0x47,0x95,0xef,0xfe,0xf9,
+  0xcf,0x7f,0x46,0x01,0x56,0xed,0x88,0x8c,0x4b,0xff,0xfa,0xd7,0xbf,0x8e,0x22,0xcc,
+  0x3f,0xf7,0xb9,0xcf,0x79,0xcf,0xb5,0x54,0x86,0x93,0xea,0x76,0x52,0xdb,0x21,0x84,
+  0x87,0x1e,0x7a,0xa8,0x65,0x8e,0x95,0x94,0xef,0x95,0x6b,0xdc,0x87,0x54,0x45,0x94,
+  0x8c,0x17,0xb9,0xbe,0xb2,0x22,0xb1,0x31,0x12,0xa7,0xe1,0xe3,0xaa,0xab,0xae,0x6a,
+  0xe8,0xb1,0x68,0xe4,0xbd,0x83,0x02,0x00,0x50,0x10,0x12,0xe9,0xfb,0xd2,0x4b,0x2f,
+  0x45,0xe5,0x48,0xab,0x41,0x6a,0xc4,0x6b,0xaf,0x81,0xea,0xd1,0xa3,0x47,0xd0,0xf2,
+  0x12,0x58,0x94,0x75,0x5c,0x3a,0x0f,0xa4,0x36,0xb9,0x44,0x34,0x87,0x3c,0x6c,0x5b,
+  0x95,0x7e,0xfd,0xfa,0x45,0x59,0x19,0xda,0xf5,0x1c,0x95,0x70,0x0e,0x45,0xc6,0xb5,
+  0xbf,0xf8,0xc5,0x2f,0x06,0x2d,0x2b,0xe5,0xa3,0x5b,0x85,0x3f,0xfe,0xf1,0x8f,0x51,
+  0x4a,0x9e,0xef,0xd8,0xfc,0xe1,0x0f,0x7f,0x50,0x7d,0xfb,0xf6,0xad,0x7a,0x3b,0x12,
+  0x70,0xe7,0xab,0x99,0x2f,0xb5,0xf6,0x45,0xf8,0x36,0x82,0x46,0xdf,0x3b,0x28,0x00,
+  0x00,0x05,0xa0,0xcb,0xc1,0x46,0x96,0x4b,0xd6,0x40,0x2a,0x13,0x29,0x06,0x23,0x55,
+  0xd1,0x42,0xb9,0xf2,0xca,0x2b,0xeb,0xda,0x4f,0x5d,0xde,0x58,0x3d,0xf2,0xc8,0x23,
+  0x51,0x34,0x76,0xbb,0x22,0x35,0xd9,0xe5,0x18,0x64,0x09,0xd2,0x4b,0x22,0xde,0x82,
+  0x10,0xa5,0xa1,0x9a,0xe0,0xc1,0x32,0x22,0x43,0xcf,0xe2,0x29,0xf1,0x21,0xb5,0xfc,
+  0xf5,0x78,0x78,0x4d,0xdb,0x92,0x40,0xc8,0xf1,0xe3,0xc7,0x97,0xd2,0x0b,0x50,0x86,
+  0x7b,0x07,0x05,0x00,0x20,0x67,0xe4,0xe1,0xf6,0xf5,0xaf,0x7f,0x3d,0xb7,0xf5,0x89,
+  0x55,0x19,0x3a,0x11,0x90,0xa4,0x21,0x56,0x1c,0x13,0x88,0xe4,0x8d,0xcc,0xbc,0x26,
+  0x96,0x53,0xa8,0x0b,0xbb,0x15,0x91,0xbe,0x4b,0x01,0x1b,0x1d,0xd0,0x57,0xf5,0x3a,
+  0x64,0x06,0xc8,0x10,0x21,0x30,0x67,0xce,0x9c,0x96,0x38,0x66,0xe2,0x29,0x91,0x68,
+  0xf8,0x90,0xeb,0x3e,0x0f,0x42,0x26,0x6f,0x92,0x82,0x3c,0xf5,0xba,0x6f,0xca,0x74,
+  0xef,0xa0,0x00,0x00,0xe4,0xc8,0x6f,0x7e,0xf3,0x9b,0xdc,0x1e,0x5c,0x31,0x32,0x56,
+  0xfc,0xb5,0xaf,0x7d,0x2d,0x68,0x59,0xc9,0x4b,0x97,0x02,0x35,0xf5,0xe0,0xf7,0xbf,
+  0xff,0x7d,0x94,0x8b,0xdd,0xae,0x0c,0x1c,0x38,0x50,0xe9,0x49,0x66,0x72,0x99,0xca,
+  0x57,0x04,0x82,0x0f,0x49,0x05,0x93,0x59,0xfe,0x9a,0x1d,0x9d,0x19,0xe1,0x5d,0x66,
+  0xb3,0xcd,0x36,0x53,0xfb,0xec,0xb3,0x4f,0x2e,0xdb,0xfb,0xc4,0x27,0x3e,0xa1,0x7a,
+  0xf6,0xec,0xe9,0x55,0xae,0x64,0x46,0xbf,0x7a,0x51,0x96,0x7b,0x07,0x05,0x00,0x20,
+  0x27,0x24,0x08,0x4f,0x26,0xf6,0x28,0x02,0xa9,0xf8,0x17,0x8a,0x9e,0x09,0xae,0xf0,
+  0xbe,0x9e,0x72,0xca,0x29,0xea,0x53,0x9f,0xfa,0x54,0xdb,0x9e,0x6b,0x19,0x9f,0x96,
+  0xc9,0x7f,0x36,0xdd,0x74,0xd3,0x5c,0xd6,0x17,0x1a,0xec,0x59,0x4f,0x2b,0xb5,0x08,
+  0x74,0xba,0xab,0xd2,0xe9,0x6c,0xde,0xe5,0xaa,0x1d,0x4e,0xb1,0x21,0x31,0x00,0x21,
+  0x35,0x32,0x9e,0x7f,0xfe,0xf9,0xba,0x1c,0x83,0x32,0xdd,0x3b,0x28,0x00,0x00,0x39,
+  0xf1,0xe5,0x2f,0x7f,0xb9,0xb0,0x75,0xeb,0x29,0x4d,0x83,0xe7,0x5a,0x2f,0x5a,0x01,
+  0x18,0x33,0x66,0x8c,0xd2,0xf9,0xc8,0x6d,0x7d,0xae,0xbf,0xfb,0xdd,0xef,0xe6,0xfa,
+  0x10,0x0f,0x1d,0xe2,0x69,0x76,0x74,0x2e,0x7f,0x50,0x51,0x9b,0xbc,0xa3,0xe1,0x43,
+  0xee,0x9d,0x7a,0x28,0x00,0x65,0xbb,0x77,0x50,0x00,0x00,0x9a,0x04,0xc9,0x2a,0x28,
+  0x83,0x02,0xa0,0x73,0xdc,0x6b,0x8a,0xcc,0x6e,0x76,0xa4,0x6c,0xed,0xf7,0xbe,0xf7,
+  0xbd,0x5c,0xd7,0xd9,0x2e,0x0a,0x80,0x94,0xfd,0x0d,0x61,0xb7,0xdd,0x76,0xcb,0x5d,
+  0xf0,0x96,0x41,0x01,0x28,0xdb,0xbd,0x83,0x02,0x00,0xd0,0x24,0x84,0x7a,0x00,0x8a,
+  0x4e,0x05,0xd4,0xd5,0xcc,0xda,0xfa,0x3c,0xfc,0xe5,0x2f,0x7f,0x89,0x4a,0x38,0xe7,
+  0x89,0x6f,0x8c,0xba,0x9d,0x14,0x00,0x39,0x16,0x92,0x59,0x91,0x27,0x92,0xa6,0xe9,
+  0x43,0x4a,0x09,0x17,0x4d,0xd9,0xee,0x1d,0xe6,0x02,0x00,0x68,0x12,0xa4,0x2e,0x40,
+  0x08,0xba,0x6c,0x28,0x07,0xab,0x40,0xa4,0xce,0x3e,0x54,0xc7,0x53,0x4f,0x3d,0xe5,
+  0x5d,0x46,0x66,0xcb,0x93,0xd9,0x01,0xf3,0x64,0xc2,0x84,0x09,0xde,0x65,0xea,0x31,
+  0x13,0x61,0xd9,0x40,0x01,0x00,0x68,0x31,0x05,0x40,0xa6,0x07,0x96,0x68,0xf1,0x5e,
+  0xbd,0x7a,0x71,0xd0,0xa0,0x34,0xe8,0xd2,0xc8,0x41,0xb5,0x0c,0xe4,0xfa,0xcd,0x2b,
+  0x03,0x20,0x0b,0x32,0xc3,0x63,0xbb,0xc1,0x10,0x00,0x40,0x13,0x59,0x9e,0xa1,0x55,
+  0x01,0xdb,0xd1,0x9a,0x81,0x72,0xf3,0xc1,0x07,0x1f,0x94,0x3a,0x8b,0x41,0x66,0x24,
+  0x14,0xef,0x03,0x0a,0x00,0x00,0x94,0x12,0xa9,0x09,0x10,0xfa,0xb0,0x05,0x28,0x13,
+  0xcd,0x50,0xc9,0xb0,0xdd,0xbc,0x00,0x28,0x00,0x00,0x2d,0xa8,0x00,0xe8,0x29,0x51,
+  0x39,0x58,0x50,0x2a,0x9a,0xa1,0x92,0x61,0xbb,0xdd,0x37,0x28,0x00,0x00,0x4d,0x44,
+  0xef,0xde,0xbd,0x83,0x96,0xcb,0x32,0x21,0x0d,0x40,0x3d,0x68,0x86,0xe0,0xd4,0xd5,
+  0xab,0x57,0xa3,0x00,0x00,0x40,0x39,0x91,0x00,0xa9,0x10,0x06,0x0c,0x18,0xc0,0xc1,
+  0x02,0x84,0x6b,0x46,0xda,0x4d,0x71,0x46,0x01,0x00,0x68,0x22,0x16,0x2d,0x5a,0x14,
+  0xb4,0x9c,0xd4,0xa9,0x07,0x28,0x13,0x83,0x07,0x0f,0x46,0x01,0x40,0x01,0x00,0x80,
+  0xa2,0x15,0x00,0x3c,0x00,0x50,0x36,0xd6,0x5b,0x6f,0xbd,0xa0,0xe5,0xa4,0xca,0xa2,
+  0x64,0x0b,0x34,0xa2,0x85,0x4c,0xca,0x84,0x02,0x00,0x00,0x0d,0x41,0x52,0x95,0x7c,
+  0x48,0xd5,0xb3,0x2e,0x5d,0xba,0x70,0xb0,0xa0,0x29,0x15,0x80,0x90,0xa2,0x3d,0x80,
+  0x02,0x00,0xd0,0x56,0xc8,0x54,0xbf,0x21,0xe3,0xa8,0xb8,0xff,0xa1,0x8c,0x48,0x1d,
+  0x8b,0x10,0xc5,0x14,0x05,0x00,0x05,0x00,0x00,0x0c,0x5e,0x7b,0xed,0xb5,0xa0,0xe5,
+  0x36,0xdf,0x7c,0x73,0x0e,0x16,0x94,0x0e,0x99,0x42,0x79,0xc8,0x90,0x21,0xde,0xe5,
+  0x26,0x4e,0x9c,0x18,0x3c,0xd4,0x05,0x28,0x00,0x00,0x28,0x00,0x09,0x76,0xd9,0x65,
+  0x17,0x0e,0x16,0x94,0x92,0x9d,0x76,0xda,0xc9,0xbb,0x8c,0x94,0x0c,0xbe,0xfb,0xee,
+  0xbb,0x39,0x58,0x28,0x00,0x00,0x80,0x02,0x00,0xad,0xc2,0xfe,0xfb,0xef,0x1f,0xb4,
+  0xdc,0x2d,0xb7,0xdc,0xc2,0xc1,0x42,0x01,0x00,0x80,0x98,0xd0,0xb9,0xd4,0x51,0x00,
+  0xa0,0xac,0xec,0xb7,0xdf,0x7e,0x41,0xcb,0xdd,0x79,0xe7,0x9d,0x91,0x27,0x00,0x50,
+  0x00,0x00,0xda,0x9e,0xf7,0xdf,0x7f,0x5f,0x3d,0xfd,0xf4,0xd3,0xde,0xe5,0x86,0x0e,
+  0x1d,0xaa,0x46,0x8d,0x1a,0xc5,0x01,0x83,0x9a,0x58,0xb6,0x6c,0x59,0x21,0xeb,0xdd,
+  0x7e,0xfb,0xed,0x83,0xe2,0x00,0xa4,0x6c,0xf0,0xdf,0xfe,0xf6,0x37,0x4e,0x04,0x0a,
+  0x00,0x00,0xfc,0xfd,0xef,0x7f,0x0f,0xca,0x00,0x38,0xe4,0x90,0x43,0x38,0x58,0x50,
+  0x33,0xef,0xbe,0xfb,0x6e,0x31,0x02,0xa7,0x73,0xe7,0x60,0x2f,0xc0,0xf9,0xe7,0x9f,
+  0xdf,0x76,0xb3,0xf3,0xa1,0x00,0x00,0xc0,0x3a,0xfc,0xe5,0x2f,0x7f,0x09,0x5a,0xee,
+  0x94,0x53,0x4e,0xe1,0x60,0x81,0x93,0xd0,0xfa,0x10,0xd3,0xa6,0x4d,0x2b,0x6c,0x1f,
+  0xce,0x38,0xe3,0x8c,0xa0,0xe5,0x24,0xe6,0xe5,0x9a,0x6b,0xae,0xe1,0xa4,0xa1,0x00,
+  0x00,0x94,0x9f,0xa5,0x4b,0x97,0x16,0xb2,0x5e,0x19,0xfb,0xbf,0xf7,0xde,0x7b,0xbd,
+  0xcb,0x6d,0xb9,0xe5,0x96,0xea,0xe3,0x1f,0xff,0x38,0x27,0x02,0x9c,0x48,0x8d,0x08,
+  0x49,0xc7,0xf3,0xf1,0xce,0x3b,0xef,0x14,0xb6,0x0f,0x7b,0xee,0xb9,0xa7,0xda,0x7b,
+  0xef,0xbd,0x83,0x96,0x3d,0xe7,0x9c,0x73,0x0a,0xf3,0x46,0x00,0x0a,0x00,0x40,0x6e,
+  0x88,0xf0,0x7d,0xeb,0xad,0xb7,0x72,0x5f,0xef,0x79,0xe7,0x9d,0x17,0xb4,0xdc,0xc9,
+  0x27,0x9f,0xcc,0x49,0x80,0x54,0xa4,0xd6,0xbd,0x14,0xe4,0xf1,0xf1,0xe6,0x9b,0x6f,
+  0x16,0xba,0x1f,0xe7,0x9e,0x7b,0x6e,0xd0,0x72,0x52,0xfc,0xea,0xe8,0xa3,0x8f,0x56,
+  0xcb,0x97,0x2f,0xe7,0xe4,0xa1,0x00,0x00,0x94,0x97,0xe7,0x9e,0x7b,0x2e,0xca,0x73,
+  0x0e,0xb1,0xd6,0x43,0xb9,0xec,0xb2,0xcb,0xd4,0x03,0x0f,0x3c,0xe0,0x5d,0xae,0x67,
+  0xcf,0x9e,0xea,0x73,0x9f,0xfb,0x1c,0x27,0x01,0xbc,0xac,0xbf,0xfe,0xfa,0xde,0x65,
+  0xfe,0xfd,0xef,0x7f,0xab,0x27,0x9f,0x7c,0xb2,0xb0,0x7d,0x38,0xe0,0x80,0x03,0xd4,
+  0x6e,0xbb,0xed,0x16,0xb4,0xec,0xe3,0x8f,0x3f,0x1e,0x0d,0x6d,0x85,0xce,0x84,0x09,
+  0x28,0x00,0x00,0x0d,0x61,0xf6,0xec,0xd9,0xea,0xe0,0x83,0x0f,0x56,0xdf,0xff,0xfe,
+  0xf7,0x6b,0x1e,0x12,0xb8,0xe7,0x9e,0x7b,0xd4,0x59,0x67,0x9d,0x15,0x6c,0x51,0x6d,
+  0xb0,0xc1,0x06,0x9c,0x00,0xf0,0xb2,0xd9,0x66,0x9b,0x05,0x2d,0xf7,0xa3,0x1f,0xfd,
+  0xa8,0xd0,0xfd,0xb8,0xf4,0xd2,0x4b,0x55,0xf7,0xee,0xdd,0x83,0x96,0xbd,0xfa,0xea,
+  0xab,0x23,0xa5,0x61,0xe6,0xcc,0x99,0x85,0xec,0x8b,0x04,0x1b,0x4a,0xe6,0x01,0x0a,
+  0x00,0x00,0xd4,0xfc,0x30,0xf9,0xc1,0x0f,0x7e,0x10,0x8d,0xc9,0xdf,0x70,0xc3,0x0d,
+  0x55,0xad,0xe3,0x8f,0x7f,0xfc,0xa3,0x3a,0xea,0xa8,0xa3,0x82,0x72,0xa1,0x3f,0xf2,
+  0x91,0x8f,0xa8,0xaf,0x7f,0xfd,0xeb,0x1c,0x78,0x08,0x22,0x34,0x53,0xe4,0x8e,0x3b,
+  0xee,0x50,0xf7,0xdf,0x7f,0x7f,0x61,0xfb,0x21,0xf5,0x2a,0x7e,0xf9,0xcb,0x5f,0x06,
+  0x2f,0xff,0xf0,0xc3,0x0f,0xab,0x9d,0x77,0xde,0x59,0x5d,0x7b,0xed,0xb5,0x41,0x19,
+  0x31,0x3e,0xe6,0xcd,0x9b,0x17,0xa5,0x1a,0x9e,0x78,0xe2,0x89,0x51,0xfa,0xec,0x76,
+  0xdb,0x6d,0xd7,0x76,0xd7,0x42,0x57,0x6e,0x87,0xe6,0x44,0xdc,0x73,0x7f,0xfd,0xeb,
+  0x5f,0xd5,0xeb,0xaf,0xbf,0xae,0xfa,0xf4,0xe9,0xa3,0x7a,0xf7,0xee,0xad,0x7a,0xf5,
+  0xea,0x15,0xbd,0x97,0x57,0xf9,0x3b,0xd9,0x42,0xbe,0x93,0x14,0x1d,0xc8,0x0f,0x89,
+  0x07,0x18,0x3f,0x7e,0xbc,0xda,0x63,0x8f,0x3d,0xd4,0x69,0xa7,0x9d,0xa6,0x3e,0xfd,
+  0xe9,0x4f,0x47,0xc7,0x39,0x8d,0x57,0x5e,0x79,0x45,0x7d,0xe7,0x3b,0xdf,0x51,0x37,
+  0xdf,0x7c,0x73,0xd0,0x36,0x24,0xa0,0xeb,0x8a,0x2b,0xae,0x50,0xdd,0xba,0x75,0xe3,
+  0x80,0x43,0x10,0x9f,0xfc,0xe4,0x27,0x83,0x97,0x3d,0xf0,0xc0,0x03,0xa3,0xa8,0xfd,
+  0x1f,0xff,0xf8,0xc7,0xde,0x6b,0xb7,0x1a,0xbe,0xfc,0xe5,0x2f,0x47,0x2e,0x7e,0xb1,
+  0xf0,0x43,0x78,0xfb,0xed,0xb7,0xd5,0x09,0x27,0x9c,0x10,0x29,0xd8,0xdf,0xfc,0xe6,
+  0x37,0xd5,0xa1,0x87,0x1e,0x1a,0x3c,0xcb,0xa0,0xf0,0xc6,0x1b,0x6f,0xa8,0xdb,0x6f,
+  0xbf,0x3d,0x52,0x6e,0x44,0xa1,0x48,0x0e,0x2b,0x88,0x12,0x80,0x02,0x00,0xa5,0x45,
+  0xb4,0x5e,0x19,0x0f,0xbe,0xee,0xba,0xeb,0xd4,0x94,0x29,0x53,0xa2,0x87,0xbf,0xcc,
+  0x61,0x2d,0x17,0xf1,0x07,0x1f,0x7c,0x10,0xbd,0x8f,0x3f,0x8b,0x85,0x43,0xfc,0x59,
+  0x08,0xb2,0xac,0x6c,0x43,0xac,0x4e,0xb1,0x62,0xa5,0xc9,0xba,0xe3,0x57,0x69,0xb1,
+  0x45,0x2a,0xcb,0xc5,0xdb,0x49,0x6e,0x43,0xd2,0x8c,0x7a,0xf4,0xe8,0x11,0xb9,0xf6,
+  0x64,0x5c,0x3a,0x56,0x38,0x62,0x25,0x45,0xa6,0xaa,0xed,0xdb,0xb7,0x6f,0xf4,0x2a,
+  0x4d,0xe6,0xad,0x8f,0x9b,0x44,0x28,0x4b,0x80,0x92,0x34,0xf9,0x2e,0x74,0xbf,0xcb,
+  0x8e,0x44,0xf1,0x4b,0x93,0x63,0x70,0xf8,0xe1,0x87,0x47,0x63,0x9f,0x1b,0x6d,0xb4,
+  0x91,0xda,0x70,0xc3,0x0d,0xa3,0x61,0x02,0x89,0x72,0x9e,0x34,0x69,0x92,0xba,0xfe,
+  0xfa,0xeb,0xd5,0xf3,0xcf,0x3f,0x9f,0x69,0xdd,0xa7,0x9e,0x7a,0x6a,0xa4,0x60,0x00,
+  0x84,0xb2,0xf1,0xc6,0x1b,0x47,0xd6,0x77,0x48,0x61,0x29,0xb9,0xcf,0x7f,0xf5,0xab,
+  0x5f,0x45,0x0a,0xe9,0x41,0x07,0x1d,0x14,0x79,0xb5,0xb6,0xd8,0x62,0x8b,0x68,0x1d,
+  0xe2,0x8e,0x7f,0xf9,0xe5,0x97,0x23,0xa5,0x55,0x84,0xe7,0x77,0xbf,0xfb,0xdd,0xaa,
+  0xf6,0xe7,0xf2,0xcb,0x2f,0x8f,0xae,0xfb,0x97,0x5e,0x7a,0x29,0xf8,0x37,0x92,0x22,
+  0x78,0xd2,0x49,0x27,0x45,0xcf,0x08,0xb1,0xdc,0xf7,0xd9,0x67,0x1f,0xb5,0xc9,0x26,
+  0x9b,0x44,0x45,0x86,0xe4,0x39,0x23,0x93,0x09,0xcd,0x9d,0x3b,0x37,0x52,0xc2,0xa5,
+  0x89,0xe2,0x20,0xaf,0x12,0x54,0x08,0x28,0x00,0x4d,0x41,0x2c,0x60,0xa5,0x2a,0x97,
+  0x4c,0x8e,0x21,0xee,0x64,0xa9,0x08,0x97,0x14,0xb8,0x49,0x21,0x29,0x16,0xbc,0x7c,
+  0x17,0x5b,0xf2,0xf1,0xfb,0x78,0x3d,0x3e,0x64,0x59,0x59,0x9f,0x44,0x0a,0x27,0x05,
+  0x7b,0xa8,0x42,0x91,0x5c,0x5e,0x9a,0x28,0x0b,0xd2,0xe4,0x46,0x94,0x87,0x85,0x28,
+  0x12,0xf1,0x67,0xf1,0x7b,0xf3,0xb3,0x58,0xe1,0x90,0xdf,0xf7,0xef,0xdf,0xbf,0x43,
+  0x29,0x10,0x2d,0x5f,0x9a,0x04,0x30,0x49,0x93,0x07,0x8e,0x8c,0x79,0xcb,0xeb,0xb0,
+  0x61,0xc3,0xa2,0xef,0xca,0xee,0xc1,0x90,0x87,0x92,0xe4,0x35,0xe7,0x95,0xdb,0x2c,
+  0xd6,0xcf,0xaf,0x7f,0xfd,0x6b,0x6e,0x14,0xc8,0xcc,0x25,0x97,0x5c,0xa2,0xf6,0xda,
+  0x6b,0xaf,0xe0,0xe5,0x45,0x80,0xfe,0xfe,0xf7,0xbf,0x77,0x7e,0x2f,0xca,0x6c,0xb5,
+  0x0a,0x80,0x08,0xec,0x7f,0xfc,0xe3,0x1f,0xea,0x3f,0xfe,0xe3,0x3f,0xd4,0x53,0x4f,
+  0x3d,0x95,0xf9,0x19,0xf9,0xc2,0x0b,0x2f,0x44,0x0d,0x50,0x00,0x5a,0x4a,0xf0,0x2f,
+  0x58,0xb0,0x40,0xdd,0x7a,0xeb,0xad,0x91,0xf6,0x9d,0x9c,0x1e,0x33,0xcd,0x32,0x4e,
+  0x7e,0x67,0x53,0x12,0x7c,0xf8,0x7e,0x1f,0xb2,0x6d,0x79,0x95,0x26,0x5e,0x80,0xd0,
+  0x20,0x1f,0xdf,0xf1,0x98,0x3f,0x7f,0x7e,0x14,0xa4,0x23,0xd6,0x46,0xac,0x30,0x24,
+  0x15,0x08,0xb1,0x54,0xc4,0xdb,0x20,0x9e,0x03,0x51,0x1a,0xc4,0x12,0x10,0x05,0x61,
+  0xc4,0x88,0x11,0x6a,0xf4,0xe8,0xd1,0x91,0xc5,0x3d,0x76,0xec,0xd8,0xe8,0xbb,0xa2,
+  0xf8,0xf6,0xb7,0xbf,0xad,0x2e,0xb8,0xe0,0x82,0xba,0x5c,0x23,0x52,0x4d,0x4d,0x3c,
+  0x06,0xb8,0xfe,0xa1,0x1a,0x24,0x17,0xff,0xd8,0x63,0x8f,0x8d,0xbc,0x89,0x65,0x40,
+  0x14,0xf9,0x07,0x1f,0x7c,0x30,0x1a,0x8f,0xbf,0xf1,0xc6,0x1b,0x39,0x41,0x28,0x00,
+  0xed,0x29,0xf4,0x45,0xa0,0x89,0x36,0x2c,0xd6,0xbe,0x54,0xe3,0x4a,0x5a,0xe0,0x36,
+  0x81,0x9b,0xb4,0xc8,0x4d,0x8b,0x3d,0xeb,0xf2,0xd5,0x0c,0x19,0xd4,0xf2,0xfb,0xd0,
+  0xf5,0x0b,0x22,0xe8,0x4c,0x61,0xe7,0xea,0x8f,0x78,0x11,0x66,0xcc,0x98,0x11,0xb5,
+  0x17,0x5f,0x7c,0x31,0xfa,0x4e,0x14,0x08,0x19,0x92,0x88,0x83,0x9a,0x8a,0x18,0x5e,
+  0x90,0x71,0x52,0x19,0xde,0x10,0x45,0xa0,0x48,0xc6,0x8d,0x1b,0xa7,0x6e,0xbb,0xed,
+  0xb6,0xa8,0x3f,0x00,0xd5,0x22,0x51,0xf8,0x13,0x26,0x4c,0x88,0x52,0xfe,0xca,0x80,
+  0x28,0xf0,0xa2,0xd4,0x7e,0xe3,0x1b,0xdf,0x50,0x3f,0xfb,0xd9,0xcf,0x38,0x41,0x75,
+  0x80,0xa8,0xaf,0x12,0x08,0xfe,0x25,0x4b,0x96,0x44,0x17,0xfe,0x71,0xc7,0x1d,0xa7,
+  0x3e,0xf6,0xb1,0x8f,0x45,0x91,0xb1,0x52,0x89,0x2b,0x76,0x69,0xcb,0x6b,0xec,0x9e,
+  0x8f,0x5f,0x5d,0x43,0x00,0xb5,0x2c,0x9f,0xfc,0xcc,0x66,0xd1,0x67,0xfd,0x7d,0xcd,
+  0x17,0x67,0x0e,0xfd,0x17,0x2f,0xca,0xc2,0x85,0x0b,0xd5,0xc8,0x91,0x23,0x23,0xaf,
+  0x40,0x32,0x6e,0x21,0x6e,0x79,0xf2,0xad,0x6f,0x7d,0x4b,0xfd,0xe1,0x0f,0x7f,0x08,
+  0x2a,0xb6,0x92,0x15,0x89,0xaf,0x90,0x87,0xe3,0x7d,0xf7,0xdd,0x57,0x48,0x40,0x16,
+  0xb4,0x17,0x32,0x94,0x26,0x0a,0xf1,0xb6,0xdb,0x6e,0x5b,0x9a,0x7d,0x92,0x7b,0xf6,
+  0xa7,0x3f,0xfd,0xa9,0xba,0xeb,0xae,0xbb,0xda,0x32,0x2a,0x1f,0x05,0xa0,0x4d,0x84,
+  0xbe,0xb4,0x7f,0xfe,0xf3,0x9f,0xea,0x8b,0x5f,0xfc,0xa2,0xda,0x7c,0xf3,0xcd,0xd5,
+  0x45,0x17,0x5d,0x14,0x59,0xa9,0xf1,0x58,0x76,0x9a,0xfb,0x3d,0x16,0x80,0x66,0xcb,
+  0x7b,0xf9,0x5a,0xbf,0xaf,0xb5,0xd5,0xd2,0x1f,0x09,0x8a,0x94,0x21,0x83,0xe1,0xc3,
+  0x87,0x47,0xc3,0x00,0xe6,0xb1,0x4f,0x0a,0xfe,0xbc,0x95,0x80,0x2f,0x7c,0xe1,0x0b,
+  0x51,0x90,0x92,0xbc,0xe6,0xe5,0x69,0x90,0x87,0xb4,0x64,0x7e,0x5c,0x78,0xe1,0x85,
+  0x58,0xfe,0x90,0xab,0x12,0x20,0x81,0xc5,0x5f,0xf9,0xca,0x57,0x72,0x19,0xae,0xcb,
+  0x0b,0xa9,0xa5,0xf1,0xaf,0x7f,0xfd,0x4b,0x5d,0x75,0xd5,0x55,0xd1,0xf0,0x5d,0x91,
+  0x88,0x67,0x51,0xbc,0x6a,0xa7,0x9f,0x7e,0x3a,0x0a,0x00,0x14,0x2b,0xf4,0xc5,0xc5,
+  0x2f,0xb9,0xa7,0x62,0xe9,0x1f,0x79,0xe4,0x91,0xea,0xd5,0x57,0x5f,0x8d,0x1e,0xee,
+  0x32,0x06,0x66,0x0a,0xb4,0xa4,0xd5,0x6b,0xb3,0x80,0xf3,0x6e,0xb5,0x6e,0x2f,0xef,
+  0xfd,0xad,0x66,0x7d,0x12,0x70,0x38,0x7d,0xfa,0xf4,0x68,0xfc,0x5f,0xc6,0xfe,0x93,
+  0x41,0x89,0xf1,0x79,0x88,0x33,0x18,0xcc,0xcf,0xf3,0x54,0x04,0xe4,0xc1,0x2a,0x9e,
+  0x80,0x47,0x1e,0x79,0x24,0x4a,0x05,0xac,0xc6,0x62,0x8f,0x67,0x4e,0x93,0xe0,0xab,
+  0x67,0x9f,0x7d,0x36,0xaa,0x32,0x58,0x24,0x32,0x7c,0xe1,0xa3,0x11,0x9e,0x87,0x7a,
+  0xed,0x57,0x23,0xfb,0x1f,0xb2,0x5e,0x51,0xfc,0x42,0x27,0xf3,0xc9,0x82,0x78,0xc6,
+  0x7e,0xfb,0xdb,0xdf,0x46,0x29,0xc5,0x62,0x90,0x14,0xb1,0x8d,0x6a,0x3d,0x80,0x12,
+  0x13,0x20,0xca,0xf4,0x95,0x57,0x5e,0xa9,0x8e,0x38,0xe2,0x88,0x28,0xc6,0xa7,0x56,
+  0xe4,0x38,0xca,0x5c,0x04,0x52,0x62,0x5b,0xaa,0x76,0x8a,0xb1,0x20,0xc6,0x58,0xb5,
+  0x41,0x8c,0x65,0xbe,0x77,0xbc,0x1e,0x97,0x4a,0xde,0xe6,0x0f,0xac,0x23,0xf8,0x63,
+  0x64,0x6c,0x5f,0x5c,0xc4,0x92,0x8a,0xb2,0xe9,0xa6,0x9b,0x06,0x5d,0x34,0xf5,0xde,
+  0xd7,0x6a,0xa3,0xfe,0x43,0x96,0x2f,0x12,0xb1,0xf6,0xc5,0x83,0x22,0xd6,0x42,0x7c,
+  0xa3,0xd9,0x62,0x22,0x24,0x02,0xdf,0xe6,0x35,0x48,0x0b,0x74,0x94,0x88,0xe9,0xb3,
+  0xcf,0x3e,0x3b,0xd3,0xb9,0x36,0x91,0x61,0x1e,0x71,0x6b,0x4a,0x40,0xa7,0x3c,0xd0,
+  0x24,0xf5,0x4f,0xae,0x03,0x09,0x60,0x94,0xb4,0x49,0x89,0x5b,0x88,0x83,0x16,0x65,
+  0xb8,0x42,0x04,0xff,0x31,0xc7,0x1c,0x13,0x79,0x30,0x00,0xea,0xc9,0xc4,0x89,0x13,
+  0xa3,0x40,0x3c,0xc9,0x99,0x97,0xf4,0x54,0x69,0x32,0x24,0x29,0x1e,0x02,0xc9,0x48,
+  0x12,0x05,0x61,0xf0,0xe0,0xc1,0x6a,0xcc,0x98,0x31,0x51,0x61,0x1e,0x49,0x43,0x95,
+  0x34,0xbc,0x7a,0x5c,0xab,0x72,0x9f,0x88,0x52,0x2d,0xd3,0x63,0x4b,0xda,0xa0,0x64,
+  0x45,0x49,0x93,0x2c,0x23,0xf9,0x4e,0xee,0x25,0xd9,0x47,0x51,0x14,0x64,0x7f,0x24,
+  0x43,0x48,0x5e,0xa5,0x49,0xa6,0x82,0xa4,0xe0,0xee,0xba,0xeb,0xae,0xd1,0x72,0x80,
+  0x02,0x50,0x17,0xc1,0x2f,0x0f,0xfa,0xaf,0x7e,0xf5,0xab,0x91,0x15,0x27,0xb9,0xaa,
+  0xb1,0x0b,0xb7,0xd6,0xa0,0x3c,0xdf,0xf2,0x59,0x83,0x02,0x6b,0x5d,0x7f,0xbd,0x83,
+  0x12,0xe5,0xbb,0x38,0xc5,0x50,0xf2,0x92,0xa5,0x96,0x80,0x0f,0x29,0x38,0x92,0xe6,
+  0x45,0x28,0x4a,0x01,0xb0,0x21,0x9e,0x08,0xd9,0x7f,0x49,0xbb,0x14,0xa5,0x25,0x4e,
+  0xbf,0x04,0x28,0x1b,0x52,0xaf,0x42,0x04,0xab,0x5c,0xb3,0xa1,0x33,0x0a,0xd6,0xfb,
+  0x79,0x2b,0xf7,0x92,0x28,0x27,0xf1,0xfd,0x04,0x7e,0x78,0xe2,0x14,0x28,0xf8,0xe5,
+  0xfd,0x2d,0xb7,0xdc,0xa2,0x7e,0xf8,0xc3,0x1f,0x46,0xd6,0xdd,0x36,0xdb,0x6c,0xb3,
+  0x8e,0xc0,0x4b,0xe6,0xe9,0x9b,0x02,0xc8,0x7c,0xb5,0x09,0xc8,0xb4,0x57,0x9b,0x30,
+  0xb3,0x09,0x61,0xdf,0x77,0xae,0xf5,0x65,0xfd,0xde,0x26,0xf0,0xab,0xed,0xbf,0x58,
+  0xfc,0x62,0x95,0x88,0x9b,0x7f,0xfb,0xed,0xb7,0xcf,0x24,0x74,0xe3,0x75,0xda,0x02,
+  0x16,0xeb,0xe9,0xc5,0x90,0xed,0x8b,0xfb,0x15,0xa0,0xec,0x88,0xd1,0x52,0xe6,0xd8,
+  0x13,0xb9,0x5f,0xc5,0x2b,0x01,0x28,0x00,0xa5,0x10,0xfc,0x62,0x95,0x4a,0x49,0x57,
+  0x71,0xf5,0x8a,0x4b,0x37,0x54,0xe0,0x9a,0xc2,0x27,0x4b,0x5e,0x7f,0xde,0x16,0x7b,
+  0x11,0x69,0x81,0xb5,0xf6,0x5f,0x04,0xbf,0x54,0xf4,0x12,0x57,0xb9,0x54,0x33,0x33,
+  0x8f,0xbb,0xaf,0x7f,0x71,0x91,0x21,0x33,0x6b,0xc1,0x3c,0x06,0x00,0x00,0x28,0x00,
+  0x10,0x2c,0xfc,0xe5,0x55,0x2a,0x66,0xdd,0x74,0xd3,0x4d,0x51,0x51,0x0b,0x41,0x5c,
+  0x52,0xd5,0x16,0xee,0xa9,0x46,0x20,0x9b,0xdf,0xf9,0x2c,0xf2,0x5a,0x3c,0x08,0xd5,
+  0x78,0x24,0xaa,0xed,0xbf,0x08,0xfe,0xc9,0x93,0x27,0x47,0x9e,0x14,0x11,0xfc,0x49,
+  0xcf,0x41,0x16,0x85,0x46,0xc6,0xdc,0xcd,0x20,0x27,0x9b,0x17,0x02,0x45,0x00,0x00,
+  0x50,0x00,0x20,0x48,0xf0,0x4b,0x60,0x97,0x08,0xfe,0xb8,0x94,0x65,0x2c,0x78,0xd2,
+  0x4a,0xf1,0xd6,0xea,0x62,0x0f,0x59,0x9f,0x8f,0x5a,0x84,0x5c,0x56,0x17,0x7f,0x35,
+  0xfd,0x97,0xe9,0x75,0x25,0x08,0x49,0xc6,0x1d,0x45,0xf0,0x27,0x8b,0x01,0x85,0xc4,
+  0x1c,0x98,0xdb,0xb6,0xcd,0xae,0x67,0xfe,0x06,0xc1,0x0f,0x00,0x28,0x00,0x90,0x2a,
+  0xf8,0x85,0x67,0x9e,0x79,0x26,0x12,0xfc,0x32,0x29,0x46,0x1e,0x02,0x39,0xeb,0x7e,
+  0x14,0xe9,0xd2,0xaf,0x45,0x29,0xa8,0xb5,0xff,0x22,0xf8,0x45,0xa9,0x92,0x3a,0xe1,
+  0x92,0xfe,0x26,0x55,0xc2,0xd2,0x14,0x30,0xdb,0xb9,0xb1,0x1d,0x0f,0x51,0x00,0xcc,
+  0xe8,0x7f,0x89,0x0b,0x70,0x29,0x31,0x00,0x00,0x28,0x00,0xd0,0x21,0x5c,0x44,0x60,
+  0xc8,0x54,0x92,0x92,0xd2,0x25,0xe3,0xd1,0x59,0x2c,0x52,0x9f,0xf0,0xcc,0x1a,0x45,
+  0x9f,0x66,0x41,0xfb,0x26,0x07,0xaa,0x75,0x7f,0x6b,0xdd,0x7f,0xdb,0xef,0x67,0xcd,
+  0x9a,0x15,0x09,0x7e,0x71,0xd3,0x4b,0x70,0x5f,0x48,0x64,0x7f,0x88,0x87,0x26,0xe9,
+  0x01,0xb0,0x15,0x14,0x92,0x73,0x2a,0xdb,0x44,0xf8,0x03,0x00,0x0a,0x00,0xac,0x23,
+  0x48,0x96,0x2f,0x5f,0x1e,0xe5,0xf2,0x4b,0x1d,0x76,0x09,0xf2,0xb3,0xb9,0xb8,0x8b,
+  0x9e,0x8c,0x27,0xab,0xc0,0xad,0x25,0x6a,0xbf,0x88,0xed,0xa5,0x59,0xfc,0x52,0x14,
+  0x49,0x04,0xb4,0x64,0x4b,0xc8,0x58,0x7f,0x11,0xc8,0xfa,0x93,0x45,0x85,0x62,0xeb,
+  0x1f,0xcb,0x1f,0x00,0x50,0x00,0x60,0x1d,0xab,0x51,0xea,0xc9,0x4b,0xe1,0x09,0x29,
+  0xe4,0x32,0x6f,0xde,0xbc,0x60,0x01,0x19,0xb2,0x8d,0x5a,0x5d,0xf4,0x59,0xa3,0xea,
+  0xb3,0x1e,0x83,0x5a,0x3c,0x18,0x21,0xeb,0x8f,0x67,0xf8,0x5b,0xbc,0x78,0xb1,0xda,
+  0x7a,0xeb,0xad,0xa3,0x8c,0x89,0x22,0xb3,0x12,0x92,0x0a,0x80,0x58,0xfc,0xa2,0x00,
+  0xc4,0x4a,0x9c,0x59,0x1d,0x10,0x65,0x00,0x00,0x50,0x00,0xda,0x54,0xf0,0x8b,0x3b,
+  0xfa,0xf6,0xdb,0x6f,0x8f,0xac,0x7e,0x29,0x84,0xe1,0x2a,0x18,0x93,0x25,0xe8,0x2d,
+  0xcf,0x34,0x3f,0x13,0x9f,0xcb,0xbf,0x1a,0x01,0x9e,0x25,0x8b,0x20,0x4b,0xff,0xe5,
+  0xd8,0x8a,0xc5,0x2f,0x0a,0xd5,0x16,0x5b,0x6c,0x11,0x55,0x46,0x34,0xf3,0xf2,0x7d,
+  0x1e,0x8b,0x6a,0x14,0x04,0x49,0x03,0x94,0x26,0xc2,0x5f,0x5e,0x63,0x2f,0x40,0x96,
+  0xe3,0x04,0x00,0x80,0x02,0xd0,0xa2,0x82,0x7f,0xea,0xd4,0xa9,0xea,0xd6,0x5b,0x6f,
+  0x8d,0xc6,0xf9,0x45,0x48,0x84,0x08,0xe7,0xac,0xcb,0x84,0x08,0xb8,0x22,0xd6,0x9f,
+  0xc5,0xa3,0x50,0xc4,0xfe,0xc5,0xae,0x7e,0xb1,0xfc,0xa5,0x2a,0xe2,0xee,0xbb,0xef,
+  0xde,0x51,0x01,0x2f,0xab,0x00,0xce,0x9a,0x05,0x10,0x07,0x01,0xc6,0xc2,0x3f,0x1e,
+  0xf3,0x37,0xe7,0x04,0x00,0x00,0x40,0x01,0x68,0x33,0xc1,0x2f,0x82,0x49,0x2a,0xf7,
+  0x49,0xc9,0xde,0x32,0xb8,0x81,0x8b,0xae,0xcd,0x5f,0xcf,0x2c,0x01,0xb1,0xf8,0xc5,
+  0xd5,0x2f,0xaf,0xa3,0x46,0x8d,0x52,0x07,0x1e,0x78,0x60,0x14,0xe1,0x5f,0x4b,0xa1,
+  0xa2,0xb4,0x2c,0x00,0x89,0xd7,0x88,0x67,0x57,0x4c,0x2a,0x0c,0xb1,0x07,0x20,0x9e,
+  0x10,0xc8,0x35,0x31,0x10,0x31,0x01,0x00,0x80,0x02,0xd0,0x06,0x82,0x5f,0x04,0xbe,
+  0x08,0x7e,0x51,0x00,0x42,0x2c,0xdd,0x7a,0x91,0x87,0x05,0x9e,0xe7,0xf2,0xd5,0x0a,
+  0x7e,0x49,0x91,0x94,0xa0,0x49,0x09,0xec,0x93,0x49,0x6e,0xfa,0xf7,0xef,0xef,0x15,
+  0xe0,0x21,0xdf,0xdb,0xfa,0x23,0x13,0x82,0xc8,0xb0,0xc2,0xa2,0x45,0x8b,0xd6,0x0a,
+  0xee,0x8b,0x7f,0x1b,0x0b,0xff,0xb8,0xe5,0x3d,0x0b,0x20,0x00,0x00,0x0a,0x40,0xc9,
+  0x05,0xbf,0x3c,0xfc,0x1f,0x7d,0xf4,0xd1,0xc8,0xd5,0x2f,0xd5,0xfb,0xaa,0xb1,0x80,
+  0xeb,0x9d,0x67,0x9f,0x77,0x50,0x9c,0x4d,0x80,0xe6,0xd5,0xff,0x58,0xf0,0xcb,0x4c,
+  0x5d,0x52,0xc4,0x47,0x66,0x0c,0x13,0x6b,0xbc,0xa8,0xe3,0x25,0x82,0x5d,0x2c,0x7e,
+  0x09,0xd8,0x4c,0x4e,0x01,0x6c,0xf6,0xd5,0x26,0xfc,0x6d,0x01,0x80,0x00,0x00,0x28,
+  0x00,0x2d,0x26,0xf8,0x65,0x5a,0xd6,0xeb,0xaf,0xbf,0x3e,0x2a,0xd5,0xbb,0x70,0xe1,
+  0x42,0xab,0x25,0x5c,0x6d,0x1e,0x7e,0xd6,0xdf,0x87,0x78,0x00,0x7c,0xb5,0xf4,0xab,
+  0x19,0xdf,0x4f,0xcb,0x62,0xa8,0xb5,0xff,0x49,0xc1,0x2f,0x2e,0x7e,0x99,0x2e,0x54,
+  0x5c,0xfe,0xb6,0xdf,0xe5,0x31,0x5b,0xa0,0x08,0x7e,0x11,0xfa,0x62,0xf1,0xbb,0x84,
+  0x7a,0x72,0x7d,0xc9,0x65,0xf0,0x00,0x00,0x00,0x0a,0x40,0x0b,0x0b,0x7d,0x79,0xc8,
+  0xbf,0xf8,0xe2,0x8b,0xea,0xf1,0xc7,0x1f,0x8f,0xca,0xf4,0x8a,0xd0,0x37,0x27,0x80,
+  0x71,0x09,0xd4,0x5a,0xa3,0xf2,0xf3,0xa8,0x04,0x98,0x57,0x65,0xbd,0x22,0xb6,0x97,
+  0xec,0x7f,0x52,0xf0,0xcb,0xbc,0xe1,0x92,0xcb,0x2f,0x91,0xfd,0xb5,0x44,0xed,0xa7,
+  0x05,0xf5,0xc9,0x79,0x15,0xa1,0x2f,0xe7,0x33,0x2e,0xef,0x1b,0x9f,0xef,0xe4,0x72,
+  0xb6,0xdf,0xc7,0x82,0x3f,0xb9,0x9c,0xa9,0x08,0x30,0xfe,0x0f,0x00,0x28,0x00,0x4d,
+  0x28,0xf4,0x25,0x00,0xec,0xa1,0x87,0x1e,0x52,0x0f,0x3c,0xf0,0x80,0x7a,0xf2,0xc9,
+  0x27,0xa3,0x68,0xef,0x78,0x0e,0xeb,0x64,0xaa,0x59,0x1e,0x41,0x72,0x59,0x26,0xf3,
+  0xa9,0xc6,0xc2,0xad,0x65,0xff,0x6a,0x75,0xf9,0x87,0xec,0x8f,0x08,0xfe,0x09,0x13,
+  0x26,0x44,0x82,0x5f,0x8e,0xf3,0x66,0x9b,0x6d,0xa6,0x36,0xdf,0x7c,0xf3,0xb5,0x6a,
+  0xf6,0xe7,0x55,0xaa,0x38,0xb6,0xe0,0xa5,0x66,0x80,0x8c,0xf3,0x8b,0xf5,0x9f,0x74,
+  0xf7,0x9b,0x0a,0x42,0xf2,0xef,0xa4,0x90,0xf7,0x45,0xfe,0x9b,0xfb,0xb0,0xd5,0x56,
+  0x5b,0xa9,0x7d,0xf7,0xdd,0x37,0xf5,0xba,0xeb,0xdb,0xb7,0x2f,0x4f,0x13,0x00,0x40,
+  0x01,0x68,0x84,0xd0,0x17,0x9e,0x7f,0xfe,0xf9,0xa8,0x3c,0xef,0xfd,0xf7,0xdf,0x1f,
+  0x05,0x83,0xc9,0xfc,0xd0,0xeb,0xaf,0xbf,0x7e,0xb0,0xc5,0x6b,0xe2,0xcb,0xab,0x0f,
+  0x29,0xb5,0x6b,0xbe,0xa6,0x4d,0x96,0x93,0x75,0x48,0xa1,0xd6,0xd9,0xfc,0x6a,0xe9,
+  0xbf,0x08,0x61,0x49,0xe9,0x13,0xcf,0x8a,0xac,0x63,0xf4,0xe8,0xd1,0x91,0xa0,0xb4,
+  0xd5,0xec,0x37,0xcf,0x53,0xb5,0x41,0x7f,0x62,0xf1,0xcb,0x38,0xbf,0x9c,0xdb,0xa4,
+  0xe0,0x77,0x59,0xf4,0x2e,0x85,0xc7,0x54,0x06,0x6c,0xfb,0x98,0xe4,0x93,0x9f,0xfc,
+  0x64,0xd4,0x00,0x00,0x50,0x00,0x4a,0x24,0xf4,0xe5,0xe1,0x7f,0xef,0xbd,0xf7,0xaa,
+  0xab,0xaf,0xbe,0x3a,0xb2,0x44,0x45,0x00,0x0d,0x19,0x32,0x44,0xf5,0xe9,0xd3,0xa7,
+  0x2a,0x8b,0x36,0x4d,0x40,0x56,0x13,0x65,0xef,0x1b,0xc3,0xcf,0xb2,0x7c,0x9e,0xd3,
+  0xeb,0x56,0xdb,0x7f,0x11,0xfc,0x62,0xf5,0x4b,0x2c,0x85,0x20,0x91,0xfd,0x52,0xc1,
+  0xcf,0x56,0xb3,0x3f,0xaf,0x20,0x49,0x29,0xc2,0x24,0x16,0xbf,0xb8,0xfa,0xd3,0x82,
+  0xf7,0x62,0x65,0x20,0xf6,0x14,0x98,0xa4,0x8d,0xf9,0x13,0x07,0x00,0x00,0x28,0x00,
+  0x4d,0x22,0xf8,0x05,0xb1,0x3e,0x7f,0xf5,0xab,0x5f,0xa9,0xd7,0x5f,0x7f,0xbd,0xe3,
+  0x33,0x11,0x4c,0xd3,0xa6,0x4d,0xe3,0xcc,0xd6,0x89,0x71,0xe3,0xc6,0x79,0x95,0x87,
+  0x6a,0x2b,0xf9,0x2d,0x5b,0xb6,0x2c,0x12,0xfc,0x32,0xa4,0x63,0x0a,0xf1,0xa4,0x90,
+  0xb7,0x8d,0xfd,0xbb,0x3c,0x00,0x00,0x00,0xd0,0x64,0x0a,0x40,0xf2,0x81,0x2e,0xae,
+  0xe7,0x0b,0x2f,0xbc,0x50,0xdd,0x77,0xdf,0x7d,0x9c,0xc1,0x12,0x9c,0x97,0x6a,0x63,
+  0x0e,0x5c,0x1e,0x8a,0xb8,0x88,0x8f,0x28,0x00,0xb6,0x31,0x7d,0x9b,0xb5,0x1f,0xbf,
+  0x4f,0x7e,0x67,0x5e,0x37,0x28,0x00,0x00,0x00,0x4d,0xa4,0x00,0x98,0xe3,0xc1,0x92,
+  0xbb,0x7f,0xde,0x79,0xe7,0x45,0x96,0x21,0x94,0x9b,0xac,0x41,0x89,0x71,0x2e,0xbf,
+  0x78,0x71,0x4c,0x57,0xbe,0x29,0xf8,0x93,0x9f,0x99,0x55,0xfd,0xd2,0x66,0x28,0x04,
+  0x00,0x80,0x92,0x2b,0x00,0xb6,0x40,0xb0,0x2b,0xae,0xb8,0x42,0xfd,0xcf,0xff,0xfc,
+  0x0f,0x67,0xad,0x84,0x42,0x3e,0x44,0xe0,0xbb,0xbe,0x97,0xb1,0x7d,0x49,0xe7,0x93,
+  0x20,0xbf,0xd8,0xda,0xb7,0x09,0xfa,0xf8,0xbd,0x4d,0x39,0x30,0x3d,0x00,0x71,0xd5,
+  0x3f,0xf3,0x5a,0x02,0x00,0x80,0x12,0x2b,0x00,0xe6,0x38,0xae,0x3c,0xc8,0x7f,0xf8,
+  0xc3,0x1f,0x46,0x33,0xf3,0x41,0xf9,0x15,0xb5,0xd0,0xd2,0xbd,0xc9,0x5c,0x7e,0x9b,
+  0x90,0x37,0xd7,0xe9,0x1a,0xe7,0x4f,0x0b,0x0a,0x4c,0x7a,0x00,0x50,0x04,0x00,0x00,
+  0x4a,0xac,0x00,0x98,0x0f,0x75,0xb1,0x0e,0xbf,0xfb,0xdd,0xef,0x46,0x53,0xf2,0x42,
+  0x6b,0x28,0x0b,0xa2,0xd0,0x25,0x05,0x7f,0xd2,0xa2,0x4f,0xcb,0xe7,0xb7,0xb9,0xfe,
+  0x6d,0xd5,0xfd,0x5c,0xb5,0x01,0x00,0x00,0xa0,0x84,0x0a,0x80,0xab,0x60,0xcb,0x45,
+  0x17,0x5d,0x84,0xf0,0x6f,0x22,0x01,0xef,0x73,0xf9,0x4b,0x1a,0xa1,0x08,0xfe,0x78,
+  0x52,0x1e,0x57,0xe0,0x9e,0xcd,0xda,0x4f,0x2a,0x05,0xbe,0x3a,0x00,0x71,0x60,0x20,
+  0x00,0x00,0x94,0x58,0x01,0x70,0xb9,0x74,0xaf,0xbd,0xf6,0xda,0xa8,0xb0,0x0f,0x34,
+  0x07,0x69,0x75,0x07,0x24,0xb0,0x2f,0x59,0xb6,0xd7,0x96,0xcf,0xef,0xf2,0x04,0xb8,
+  0x14,0x04,0xd7,0xf0,0x80,0xd9,0x18,0x02,0x00,0x09,0x2e,0x9d,0x31,0x63,0x46,0xd4,
+  0xde,0x7b,0xef,0xbd,0x8e,0xf7,0x71,0x93,0xcc,0x93,0xe3,0x8f,0x3f,0x5e,0x1d,0x77,
+  0xdc,0x71,0xd1,0x1c,0x16,0x00,0x28,0x00,0x0d,0x12,0xfe,0xf2,0x30,0x7f,0xec,0xb1,
+  0xc7,0xd4,0x2f,0x7f,0xf9,0x4b,0xce,0x50,0x93,0x7b,0x00,0x44,0xf0,0x8b,0xbb,0x3f,
+  0xce,0xe5,0x4f,0x5a,0xef,0xf1,0xfb,0xb8,0xa4,0x6f,0x52,0x80,0xbb,0xb2,0x00,0x4c,
+  0x21,0x9f,0x54,0x26,0x4c,0x0f,0x80,0x29,0xf0,0xc9,0x06,0x68,0x2d,0xe4,0x9a,0x32,
+  0x05,0xb9,0xab,0xc5,0x85,0xab,0x4c,0x06,0x0d,0x1a,0xa4,0xfe,0xcf,0xff,0xf9,0x3f,
+  0xea,0xcc,0x33,0xcf,0x54,0xfd,0xfa,0xf5,0xe3,0x1a,0x01,0x14,0x80,0x46,0x08,0xff,
+  0x64,0x93,0xb9,0xe3,0x65,0xdc,0x1f,0x17,0x6e,0x73,0x08,0x7d,0xdb,0xdf,0xf2,0x70,
+  0x16,0x8b,0x5f,0xca,0xf6,0x26,0xdd,0xf1,0xb6,0x68,0x7d,0x53,0x60,0xbb,0xaa,0xfd,
+  0x99,0xc3,0x02,0xbe,0x21,0x83,0xe4,0xb6,0xa0,0x39,0x90,0x73,0x26,0x95,0x26,0x43,
+  0x84,0xfa,0xdc,0xb9,0x73,0xab,0xde,0x8e,0x08,0xfe,0xff,0xfe,0xef,0xff,0x5e,0x47,
+  0xf0,0x93,0x3e,0x0a,0x28,0x00,0x0d,0x14,0xfe,0xf2,0x00,0x90,0x88,0x7f,0x99,0xe2,
+  0x15,0x9a,0x03,0xd3,0xe5,0x2f,0xe7,0x70,0xce,0x9c,0x39,0xce,0x40,0x3c,0x9b,0x80,
+  0x77,0x09,0x74,0xdb,0xb0,0x80,0x29,0xd8,0x6d,0xf1,0x01,0xb1,0xd2,0xc1,0x10,0x40,
+  0x39,0x48,0xba,0xe0,0xd3,0x9a,0x4c,0x2a,0x15,0xa7,0x6f,0x16,0x41,0x2c,0xf8,0xbf,
+  0xfa,0xd5,0xaf,0xaa,0xfe,0xfd,0xfb,0xaf,0xf3,0x3c,0xb2,0x55,0xaa,0x04,0x40,0x01,
+  0x28,0x48,0xf8,0x27,0x1f,0xe0,0xf2,0xc0,0x96,0xea,0x7e,0x4f,0x3c,0xf1,0x04,0x67,
+  0xa6,0x49,0xbd,0x00,0xbe,0x4a,0x7d,0x49,0xc1,0x6e,0x73,0xf3,0x9b,0x02,0xdd,0xe7,
+  0x11,0xf0,0xa5,0x04,0x22,0xf8,0x8b,0x23,0x0f,0x17,0x7c,0xbd,0x10,0xc1,0xff,0x5f,
+  0xff,0xf5,0x5f,0xea,0xf4,0xd3,0x4f,0xef,0x10,0xfc,0x69,0xd7,0x85,0xa9,0xd4,0x02,
+  0xa0,0x00,0x14,0xe8,0x01,0x90,0x87,0xb9,0x3c,0x24,0x18,0xf7,0x6f,0x5e,0x05,0x20,
+  0x39,0xb6,0x6f,0x56,0xe7,0xf3,0xa5,0xe9,0xb9,0x82,0xf7,0x42,0x32,0x03,0xd2,0xd6,
+  0x05,0xd9,0xa8,0x97,0x0b,0xbe,0xde,0x82,0xff,0xb4,0xd3,0x4e,0xeb,0x10,0xfc,0xc9,
+  0x6b,0x30,0xf9,0x6a,0xfb,0x0c,0x25,0x00,0x50,0x00,0x0a,0xb4,0x16,0x63,0x61,0x21,
+  0xed,0xa6,0x9b,0x6e,0x8a,0xc6,0xff,0xa1,0xb9,0x30,0x1f,0x94,0xe2,0xc2,0xb5,0x59,
+  0xe8,0x36,0xeb,0xdd,0x54,0x0a,0x6c,0x31,0x02,0xae,0xc0,0xc0,0xb4,0xba,0x01,0xb6,
+  0x99,0xff,0xda,0xf9,0x21,0x5e,0x16,0x17,0x7c,0xe8,0xf5,0x24,0xd3,0x4e,0xbb,0x9a,
+  0x7c,0x2f,0x33,0x44,0x26,0xe7,0x8a,0xb0,0x09,0xfe,0xb3,0xce,0x3a,0x4b,0x9d,0x7a,
+  0xea,0xa9,0xaa,0x6f,0xdf,0xbe,0x6b,0x05,0x9b,0xc6,0x2d,0xde,0x96,0x39,0x59,0x95,
+  0x4d,0x09,0x00,0x40,0x01,0xc8,0xd9,0xea,0x4f,0x36,0xb9,0xa1,0xff,0xfc,0xe7,0x3f,
+  0x73,0x46,0x5a,0x40,0x11,0xb0,0x09,0x77,0x5b,0x10,0xa0,0x2b,0x9f,0xdf,0x15,0x1f,
+  0x10,0x62,0xed,0xb7,0x53,0x10,0x60,0x33,0xb9,0xe0,0x85,0x58,0x80,0x77,0xe9,0xd2,
+  0x65,0x1d,0xa1,0x2e,0x9f,0xc5,0x82,0xdf,0x14,0xba,0xc9,0x6b,0x44,0xea,0x48,0x48,
+  0x4b,0x13,0xfc,0x12,0xd8,0x77,0xca,0x29,0xa7,0x38,0x05,0xbf,0xa9,0x04,0xd8,0xae,
+  0x63,0x53,0xf8,0xa3,0x0c,0x00,0x0a,0x40,0x4e,0x4a,0x40,0xf2,0x81,0x2f,0x4d,0x6e,
+  0xd0,0x7b,0xee,0xb9,0xa7,0x29,0x5c,0x8a,0xe0,0xf6,0xe8,0xc4,0xc4,0x45,0x7e,0x4c,
+  0x45,0x20,0x79,0xfe,0x5d,0x13,0xf8,0xd8,0xd2,0xfe,0xd2,0x84,0xbd,0x2b,0x33,0x20,
+  0xb9,0xed,0x66,0x0a,0x02,0x6c,0x36,0x17,0xbc,0x29,0xc4,0x6d,0x7f,0xcb,0xf1,0x97,
+  0xf7,0xae,0x02,0x51,0xb6,0x6b,0xca,0x0c,0xf2,0x94,0x54,0x52,0x9f,0xe0,0x3f,0xe3,
+  0x8c,0x33,0xd4,0x49,0x27,0x9d,0xa4,0xfa,0xf4,0xe9,0xd3,0x31,0xc7,0x84,0x4b,0xf0,
+  0xc7,0xfb,0x15,0xbf,0xf7,0x79,0xb5,0x00,0x50,0x00,0x72,0x12,0x14,0x36,0x25,0x80,
+  0x82,0x3f,0xad,0xe1,0x01,0xc8,0x9a,0xba,0x67,0xfb,0x4d,0xda,0xf2,0x49,0x2f,0x82,
+  0x99,0x19,0x60,0x7a,0x18,0x7c,0xb3,0x0f,0xd6,0x93,0x66,0x73,0xc1,0x27,0x85,0xb9,
+  0xeb,0x7d,0x52,0x88,0x86,0x4c,0x02,0x15,0x0b,0xda,0xf8,0x7d,0xda,0xb4,0xd1,0x49,
+  0xc1,0x2f,0x2d,0x4d,0xf0,0x4b,0x60,0xdf,0x89,0x27,0x9e,0x18,0x59,0xfc,0x42,0x5c,
+  0x6c,0x2a,0x4d,0xe0,0xc7,0xfb,0x20,0x4d,0xae,0x99,0xa4,0x12,0x80,0xf0,0x07,0x14,
+  0x80,0x3a,0x59,0xff,0xd2,0x26,0x4f,0x9e,0xac,0x5e,0x7b,0xed,0x35,0xce,0x46,0x8b,
+  0x78,0x03,0xe4,0x01,0x9c,0xf4,0x00,0x98,0x82,0xd9,0xb4,0xd0,0x6d,0x4a,0x81,0x4d,
+  0x71,0x08,0xcd,0x02,0xb0,0x0d,0x17,0x14,0x41,0x33,0xb9,0xe0,0x63,0xc1,0x17,0x0b,
+  0x70,0x79,0x75,0xbd,0x77,0xb9,0xe0,0x43,0xa7,0x75,0xce,0xe3,0x3a,0x92,0x34,0x60,
+  0x69,0x69,0x82,0xff,0x2b,0x5f,0xf9,0x8a,0x3a,0xe1,0x84,0x13,0x3a,0x2a,0xf7,0x49,
+  0xcd,0x09,0x53,0xf0,0xc7,0xfd,0x8e,0x85,0x7c,0x2c,0xe8,0x93,0x7d,0x4c,0x2a,0x23,
+  0xa6,0xe2,0x02,0x80,0x02,0x90,0xa3,0xe0,0x37,0x1f,0xe0,0x62,0xed,0x3c,0xfc,0xf0,
+  0xc3,0x9c,0x89,0x16,0x22,0x1e,0x02,0xf0,0x95,0xe8,0x75,0x55,0xef,0x73,0x95,0x05,
+  0x0e,0x59,0x97,0x4d,0x29,0xc8,0x7a,0xad,0x8a,0x15,0x2e,0xc1,0xa8,0x52,0x32,0xd6,
+  0x56,0x36,0xb6,0x6c,0x2e,0xf8,0x58,0x80,0xc7,0x42,0xbc,0x6b,0xd7,0xae,0xd6,0xcf,
+  0x6b,0xb9,0x7f,0x93,0x42,0x32,0x69,0x41,0xe7,0x89,0x9c,0x3b,0x11,0xfa,0xe2,0x2d,
+  0x49,0x13,0xfc,0x12,0xd1,0x7f,0xcc,0x31,0xc7,0x74,0x08,0x7e,0x51,0xc4,0x92,0x63,
+  0xfa,0xa6,0xb5,0x1f,0x0b,0xff,0xe4,0xb5,0x12,0x0f,0x49,0x98,0x59,0x27,0x21,0x43,
+  0x13,0x00,0x28,0x00,0x35,0x2a,0x03,0x49,0x0f,0xc0,0xa3,0x8f,0x3e,0xca,0x99,0x68,
+  0x01,0xcb,0x3f,0x7e,0x80,0xda,0xb2,0x00,0x7c,0x56,0x7e,0x5a,0xb3,0xb9,0xfe,0x4d,
+  0x61,0x6f,0x0b,0x2e,0x4c,0x56,0x92,0x14,0xeb,0x50,0x02,0x4d,0x27,0x4e,0x9c,0x18,
+  0x55,0x28,0xfc,0xe0,0x83,0x0f,0xa2,0x62,0x45,0x32,0xde,0x2e,0x02,0x3f,0x16,0xf6,
+  0x65,0x70,0xc1,0xc7,0x96,0xaa,0x08,0x72,0x9f,0x50,0xaf,0x87,0x40,0x32,0xe7,0x78,
+  0xc8,0xdb,0x3a,0x96,0xf3,0x24,0x42,0x5f,0x84,0xbf,0xab,0xfa,0xa7,0x08,0xfe,0xff,
+  0xfc,0xcf,0xff,0x54,0x47,0x1e,0x79,0xa4,0xea,0xd5,0xab,0x57,0x87,0xe0,0xb7,0x59,
+  0xfc,0xc9,0x2c,0x02,0x59,0x9f,0x1c,0x2b,0xb3,0x3f,0xae,0xe1,0x27,0x02,0x00,0x01,
+  0x05,0xa0,0x00,0xe1,0xe0,0x0a,0xfe,0x93,0x07,0xf1,0xeb,0xaf,0xbf,0xce,0x99,0x68,
+  0x62,0x4c,0xd7,0x70,0x5c,0xfe,0xd7,0x67,0xe5,0xa7,0x05,0xf5,0xa5,0xcd,0x01,0xe0,
+  0xca,0x24,0x48,0x2e,0x23,0x81,0x60,0xa3,0x46,0x8d,0x52,0xaf,0xbe,0xfa,0xaa,0x7a,
+  0xeb,0xad,0xb7,0x3a,0x84,0xc5,0x83,0x0f,0x3e,0xd8,0xb0,0x63,0x94,0x14,0xde,0x66,
+  0x4b,0x0a,0xf8,0xd8,0x5a,0x6d,0x94,0xd0,0x09,0x99,0xd5,0x31,0xed,0xfb,0x2c,0x82,
+  0x7f,0xde,0xbc,0x79,0x91,0xf0,0x4f,0x13,0xfc,0x5f,0xfa,0xd2,0x97,0xd4,0x61,0x87,
+  0x1d,0xa6,0x7a,0xf6,0xec,0x19,0x24,0xf8,0x93,0x0a,0x80,0x4d,0xf8,0x53,0x2b,0x02,
+  0xa0,0x8e,0x1e,0x80,0x34,0x25,0xe0,0x95,0x57,0x5e,0xe1,0x2c,0x34,0xb9,0xf5,0x6f,
+  0x5a,0x88,0xb1,0x07,0xc0,0x1c,0x8f,0xb7,0x59,0xfb,0xa6,0x65,0xef,0x8a,0x15,0x48,
+  0x2e,0x17,0xbf,0xb7,0x15,0x19,0xea,0xd6,0xad,0x9b,0x1a,0x3e,0x7c,0x78,0x24,0x54,
+  0x9e,0x7d,0xf6,0xd9,0xc2,0x1f,0xf0,0x36,0x41,0x6e,0x7e,0x26,0xfb,0x94,0x74,0x51,
+  0x87,0x8c,0xa1,0x67,0x11,0xa6,0x79,0x8f,0xd1,0xfb,0x2c,0xfe,0xac,0x1e,0x01,0x73,
+  0xff,0xe4,0xfa,0x10,0xc1,0x2f,0x2d,0x4d,0xf0,0x9f,0x7c,0xf2,0xc9,0xea,0x90,0x43,
+  0x0e,0x51,0x3d,0x7a,0xf4,0x58,0x47,0xf0,0xc7,0xaf,0x49,0x81,0x9f,0x14,0xfc,0xb6,
+  0x7d,0xb5,0x15,0xa0,0x4a,0xbe,0xe6,0x71,0x2e,0x00,0x50,0x00,0x02,0x04,0x7f,0xec,
+  0x01,0x98,0x34,0x69,0x12,0x67,0xa1,0xc5,0x94,0x81,0x38,0x08,0x30,0xc4,0xca,0x4f,
+  0x2b,0xfa,0x13,0xe2,0x01,0x48,0x5a,0xa1,0x43,0x86,0x0c,0x89,0xdc,0xc8,0x2f,0xbf,
+  0xfc,0x72,0x4d,0xfd,0x88,0x2d,0xc7,0xa4,0x30,0x37,0xdf,0xc7,0x6e,0xf9,0x10,0xe1,
+  0x60,0x0a,0xe4,0xbc,0xc7,0xd0,0xcd,0x31,0x7a,0x53,0x40,0x67,0x4d,0xbb,0xcb,0xdb,
+  0xe2,0x8f,0xf7,0x2f,0xf6,0xf8,0xf9,0x04,0xbf,0xa4,0xf2,0x1d,0x70,0xc0,0x01,0x1d,
+  0x82,0x5f,0x0a,0xfe,0x98,0xc5,0x7b,0x6c,0x82,0x3f,0x69,0xed,0x27,0x05,0x7e,0x16,
+  0x45,0x07,0x45,0x00,0x50,0x00,0xea,0xa0,0x04,0xc8,0xc3,0x40,0xda,0xdb,0x6f,0xbf,
+  0xcd,0x59,0x68,0x01,0xc1,0x9f,0x7c,0x2f,0x0a,0x40,0x5a,0x0c,0x40,0x68,0xb3,0x29,
+  0x0c,0xb6,0x6b,0x49,0x66,0x73,0x13,0x8b,0xff,0xcd,0x37,0xdf,0x4c,0x7d,0x78,0x27,
+  0x05,0x79,0xda,0x6b,0xde,0x0f,0xfa,0xa2,0xc7,0xd0,0x7d,0x02,0x3f,0x34,0xed,0x2e,
+  0x2f,0x8b,0xdf,0x44,0xce,0x91,0x08,0x7e,0x09,0x9a,0x4c,0x13,0xfc,0x9f,0xff,0xfc,
+  0xe7,0xd5,0x3e,0xfb,0xec,0xa3,0xba,0x77,0xef,0xbe,0x8e,0xc5,0xef,0x1a,0xe3,0x4f,
+  0x2a,0x52,0x66,0xff,0x43,0x5c,0xfc,0xb6,0x8a,0x80,0x08,0x7a,0x40,0x01,0xc8,0x59,
+  0x40,0x98,0xd6,0x7f,0xac,0x04,0x4c,0x9f,0x3e,0x9d,0xb3,0xd0,0x62,0x24,0x3d,0x00,
+  0x69,0x2e,0xfd,0xac,0xb9,0xfe,0xe6,0xb5,0x24,0x82,0x42,0x72,0xc4,0x25,0x22,0xdf,
+  0x85,0xb8,0xdf,0x45,0xb8,0x48,0x1d,0xf8,0xd8,0x42,0xcc,0x6b,0x0c,0xbb,0x5a,0x0b,
+  0xda,0x26,0x84,0xf2,0x1c,0xf3,0xf7,0x45,0xed,0xe7,0x39,0x86,0x2f,0xe7,0x5a,0x9a,
+  0xdc,0xcb,0xf1,0x6b,0xfc,0x3e,0xf9,0x79,0x5a,0x54,0xbf,0xe4,0xf0,0xef,0xb1,0xc7,
+  0x1e,0xd1,0xb9,0x92,0xe5,0x5c,0x82,0x3f,0x69,0xed,0x9b,0x25,0x9e,0x6d,0x65,0x9f,
+  0xb3,0x34,0xac,0x7c,0x40,0x01,0x28,0xd8,0xf2,0x37,0x03,0x00,0xa5,0x49,0x14,0x36,
+  0xb4,0x96,0x37,0x20,0x8e,0xa2,0x77,0x4d,0x02,0x64,0xcb,0x02,0xb0,0x59,0xf7,0xae,
+  0xef,0x44,0x00,0x88,0x5b,0x58,0x84,0xbf,0x0b,0x49,0x11,0x13,0xe1,0x12,0x97,0x83,
+  0x2d,0xd2,0x22,0xaf,0xc6,0x82,0x4e,0x53,0x00,0x1a,0x39,0x86,0x1f,0x0b,0x75,0x9b,
+  0x10,0x37,0xdf,0xd7,0x12,0x5f,0x21,0xe7,0xe6,0x33,0x9f,0xf9,0x8c,0xda,0x7d,0xf7,
+  0xdd,0x3b,0x04,0x7f,0x5a,0x1e,0x7f,0xac,0xbc,0x98,0xe9,0x7c,0x36,0x81,0x6f,0xa6,
+  0x01,0xa6,0xcd,0x2d,0x60,0x53,0x04,0x7c,0xa5,0x82,0x01,0x50,0x00,0x32,0x28,0x01,
+  0x69,0x5e,0x00,0x19,0xb3,0x85,0xe6,0x16,0xf8,0xc9,0x07,0x65,0x32,0x05,0x30,0x69,
+  0xc9,0x87,0xb8,0xfa,0xcd,0xc0,0xc0,0xe4,0xe7,0xf1,0x67,0x62,0x1d,0xa6,0x09,0x9f,
+  0x01,0x03,0x06,0xa8,0xc1,0x83,0x07,0x77,0xa4,0x8a,0x55,0x63,0xf1,0xd6,0xdb,0x43,
+  0x90,0x55,0x61,0xc8,0x4a,0xac,0x6c,0x8b,0x80,0x35,0xad,0xf5,0x58,0x98,0xe7,0x21,
+  0xd4,0x43,0x05,0xbf,0x14,0xef,0xd9,0x79,0xe7,0x9d,0xa3,0xe1,0x16,0x97,0xe0,0x4f,
+  0x0a,0x6e,0x53,0x51,0x72,0x59,0xf8,0xb6,0xf9,0x05,0x5c,0x73,0x0f,0xd8,0x84,0xbf,
+  0x4d,0xe8,0x33,0x2c,0x00,0x28,0x00,0x35,0x0a,0x08,0x33,0x22,0x3c,0x7e,0x20,0x49,
+  0x8b,0xdd,0x7d,0xd0,0x1a,0xb8,0x02,0x00,0x4d,0x97,0xbe,0xaf,0x78,0x8f,0xe9,0x01,
+  0x10,0x21,0x21,0xcd,0x26,0xa0,0xe4,0x01,0x2f,0x82,0x45,0x04,0xbf,0x58,0x93,0x26,
+  0x36,0x17,0x78,0x2d,0x63,0xe2,0xb5,0x5a,0xe4,0x79,0x58,0xfc,0xa6,0xab,0x3d,0xad,
+  0x95,0x21,0xd5,0x4d,0xce,0xcd,0xb1,0xc7,0x1e,0xab,0x3e,0xfa,0xd1,0x8f,0xae,0x25,
+  0xf8,0x5d,0x6e,0xfe,0xf8,0xbc,0xd9,0x8e,0xa1,0x29,0xec,0x5d,0x69,0x95,0xae,0x94,
+  0xcb,0x50,0x65,0x00,0x00,0x05,0x20,0x27,0xe1,0xef,0xca,0x02,0x68,0x74,0xd1,0x15,
+  0xc8,0xd7,0xd3,0x93,0x54,0x00,0x92,0x1e,0x80,0xf8,0xbd,0x39,0xf9,0x4f,0x52,0xc8,
+  0x27,0xd7,0x15,0xff,0x4e,0x14,0x44,0x69,0x36,0x21,0x26,0x31,0x00,0xeb,0xad,0xb7,
+  0x5e,0x24,0xfc,0x93,0xc2,0xc2,0x66,0x71,0xa7,0xbd,0xd6,0xea,0x21,0xb0,0x09,0x7c,
+  0x9f,0x80,0xb7,0x29,0x17,0xb1,0x50,0xf4,0x09,0x76,0x97,0x22,0x54,0x6f,0xe4,0x98,
+  0x4b,0xa4,0xbe,0xe4,0xe7,0x9b,0xaf,0xf1,0xfb,0xf8,0x6f,0x39,0x57,0x52,0x64,0xe9,
+  0xee,0xbb,0xef,0x6e,0xb8,0xb7,0xaa,0x9e,0x9e,0x9d,0x32,0x7a,0xeb,0xe8,0x7f,0xfd,
+  0xfb,0x3f,0x62,0xc4,0x88,0x48,0x29,0xfd,0xf9,0xcf,0x7f,0xde,0xfa,0x0a,0x80,0x6d,
+  0x26,0x37,0xd3,0xf5,0x1f,0x2b,0x00,0xd0,0xfc,0x24,0x05,0x98,0x2d,0xf8,0x2f,0x64,
+  0x82,0x20,0x53,0xf0,0x8b,0xa0,0x13,0xc1,0x6f,0x8b,0x1a,0x97,0x22,0x3f,0xeb,0xaf,
+  0xbf,0x7e,0x14,0xfd,0x6f,0xbb,0xd9,0xaa,0xc9,0x53,0xaf,0x75,0x79,0xd7,0x32,0x36,
+  0x61,0x1e,0xbb,0xe2,0xcb,0x2c,0xd4,0x6d,0x82,0xdd,0xfc,0x3c,0x8e,0xd6,0x0f,0xc1,
+  0x76,0x1e,0xeb,0x91,0x7e,0x68,0xfe,0x3e,0xa9,0x90,0xd6,0x52,0x32,0xda,0xa6,0xfc,
+  0x66,0x5d,0x1f,0xfd,0x6f,0xfd,0xfe,0x4b,0x6a,0xb2,0xb4,0x97,0x5e,0x7a,0xc9,0x1a,
+  0xb7,0xd2,0x76,0x1e,0x80,0x64,0x1a,0xa0,0x2b,0x25,0x08,0x9a,0xd7,0x03,0x10,0x0b,
+  0x32,0x9b,0xeb,0xdf,0x25,0xec,0xcd,0xe5,0xe3,0x71,0x7e,0x13,0xb1,0xf4,0x45,0xf0,
+  0xc7,0x35,0xe0,0xeb,0x65,0x89,0x98,0xeb,0x4f,0x0a,0xf5,0xd8,0x62,0x4f,0x0a,0xf5,
+  0xf8,0x7d,0x99,0x84,0xba,0x08,0xeb,0xd8,0x12,0x37,0x05,0x7a,0xdc,0xe4,0x3b,0x69,
+  0xa1,0x9e,0x8d,0xd8,0x85,0x1f,0xda,0xc7,0x7a,0x5b,0x9c,0x8d,0xf0,0xec,0xd0,0x7f,
+  0xfa,0x1f,0xdf,0x1b,0x52,0xef,0x42,0x26,0x01,0x7b,0xf7,0xdd,0x77,0x9d,0xfb,0xd2,
+  0x68,0x65,0xa0,0xae,0x31,0x00,0xa6,0x85,0x88,0x02,0xd0,0x1a,0xc2,0x3f,0x79,0xf1,
+  0x26,0x67,0x02,0x4c,0x9e,0x7f,0x9f,0x47,0x20,0x4e,0xff,0x32,0xc7,0xac,0x65,0xcc,
+  0x56,0x84,0xbe,0xb8,0xfa,0xe3,0xc2,0x30,0xb5,0xa6,0xdd,0xd9,0x6e,0xec,0x38,0x28,
+  0x4e,0x6e,0x5c,0xd9,0x8f,0x38,0x3e,0x25,0x29,0xd4,0x63,0xc1,0x5e,0x86,0xeb,0x36,
+  0x16,0xea,0xa6,0x00,0x77,0x09,0xf5,0xd0,0x07,0x62,0x5a,0xdf,0x6c,0x16,0x4e,0x16,
+  0x05,0xc7,0x36,0x47,0x43,0x96,0x07,0xac,0x69,0xc1,0x85,0xac,0x2f,0x6d,0x79,0x57,
+  0xdd,0x7f,0xfa,0x4f,0xff,0xab,0xed,0x7f,0x5c,0xf3,0x42,0xbc,0x93,0x62,0xb0,0x98,
+  0xbf,0x33,0x97,0x6f,0xf4,0xd4,0xd3,0x85,0xa7,0x01,0x9a,0x42,0xc0,0x6c,0xd0,0xdc,
+  0x98,0x17,0x6d,0x2c,0xc0,0x5d,0xd1,0xfc,0xb6,0x80,0x3f,0x11,0xb4,0xa6,0xb5,0x2c,
+  0xc2,0x6b,0xe8,0xd0,0xa1,0x91,0xfb,0xcc,0x56,0xcf,0xdd,0xdc,0xb6,0x2b,0xa5,0x2d,
+  0x29,0xb8,0x6d,0xef,0xcb,0x2a,0xd4,0xcd,0xd7,0xb8,0x49,0x90,0xa3,0x58,0xf0,0xb6,
+  0x60,0x47,0x9f,0xfb,0xbd,0x56,0x8b,0xad,0x56,0x0b,0xc9,0x7c,0x20,0xd7,0x2a,0x20,
+  0xb2,0x3e,0xb0,0xe9,0x3f,0xfd,0x2f,0xb2,0xff,0x22,0xf8,0xc5,0x3b,0x39,0x70,0xe0,
+  0xc0,0x75,0xac,0x7c,0x33,0x05,0x3a,0x6f,0xef,0x48,0xa9,0x87,0x00,0x4c,0x4f,0x80,
+  0x39,0x55,0x2c,0xb4,0x86,0xfb,0x3f,0x16,0xe6,0xa6,0x07,0xc0,0x2c,0xe8,0x13,0x5f,
+  0x07,0xb1,0x00,0x4e,0x5e,0x07,0xa2,0x39,0x0f,0x1b,0x36,0x2c,0xba,0x89,0x6c,0x37,
+  0x5e,0xec,0x7e,0x8f,0xad,0xf3,0xa4,0x20,0x37,0x5b,0x99,0xdc,0xef,0x49,0x6b,0x3c,
+  0x29,0xd8,0x63,0x81,0x2e,0x7f,0xc7,0x55,0x08,0x43,0x3c,0x1b,0x21,0xf1,0x33,0xb5,
+  0x8e,0xa9,0xda,0x2c,0x26,0x73,0x0c,0xd5,0xb7,0xbe,0xe4,0x39,0xf0,0x59,0x60,0xbe,
+  0xf5,0xf9,0x04,0x04,0xfd,0xa7,0xff,0x8d,0xe8,0xbf,0x54,0x21,0x95,0xfb,0x37,0xb6,
+  0xf8,0x93,0x9e,0x4e,0xb3,0x48,0x55,0xfc,0x7b,0xb3,0xee,0x44,0xc8,0x74,0xd4,0x4d,
+  0x39,0x04,0x60,0x1b,0x06,0x60,0x08,0xa0,0x35,0xbd,0x00,0xc9,0xa9,0x80,0xd3,0xa6,
+  0xe9,0x8d,0xdd,0xec,0xc9,0xf3,0x2f,0x05,0x7b,0xc4,0xda,0x97,0x1b,0x49,0xbe,0x97,
+  0x71,0x33,0x53,0xa0,0xbb,0xb2,0x01,0x1a,0x25,0xd4,0xa5,0x89,0x00,0x4f,0x0a,0x77,
+  0xb3,0x89,0x50,0x0f,0x7d,0x20,0xc5,0xc7,0x2e,0x4f,0x8b,0x2b,0xcf,0x31,0xdb,0xbc,
+  0x2b,0x1e,0x96,0x6d,0x7d,0xf4,0x9f,0xfe,0x67,0x59,0xbf,0x8c,0xef,0x0b,0xb1,0xc5,
+  0xef,0xf2,0x7e,0xdb,0x94,0x0a,0x57,0x8d,0x8b,0x7a,0x2b,0x01,0x85,0x65,0x01,0x98,
+  0x82,0xdf,0xa6,0x08,0xa0,0x00,0xb4,0x9e,0x17,0x20,0xad,0x0e,0x40,0x5a,0x80,0xdf,
+  0xc2,0x85,0x0b,0xa3,0xd6,0x48,0xa1,0x2e,0xc2,0xdc,0x14,0xe0,0xb6,0xcf,0x92,0x42,
+  0x3d,0xd4,0xfd,0x5e,0xc4,0x03,0x29,0xab,0x45,0x54,0xab,0x8b,0x33,0x0f,0x45,0x91,
+  0xfe,0xd3,0xff,0x66,0xef,0x7f,0x3c,0x64,0x29,0x71,0x49,0xe6,0xba,0xcc,0xe7,0xa2,
+  0x29,0xc8,0x45,0xc9,0x4f,0xd6,0xba,0x48,0x2a,0x02,0x2d,0x1b,0x03,0xe0,0xf2,0x02,
+  0x30,0x17,0x77,0x6b,0xb1,0x74,0xe9,0xd2,0x8e,0xb9,0xdd,0x4d,0xa5,0x4f,0x4a,0xf7,
+  0xd6,0xbb,0x28,0x4d,0x52,0xa8,0x27,0x05,0xb9,0x29,0xd4,0xe5,0xef,0xa4,0xfb,0xdd,
+  0xf7,0x40,0x08,0x75,0x61,0x16,0xfd,0x40,0xf2,0xb9,0x64,0xab,0xd9,0x7e,0x96,0xf5,
+  0xd1,0x7f,0xfa,0xdf,0x4e,0xfd,0x97,0xe7,0x97,0x3c,0xe3,0x24,0x28,0x59,0xe2,0x92,
+  0x7c,0xc1,0x90,0xb6,0x00,0x3f,0x59,0x47,0x5c,0x8c,0x2a,0x7e,0x46,0xd9,0x02,0x03,
+  0xeb,0xe5,0x05,0xa8,0x6b,0x16,0x80,0x4d,0x11,0x80,0xe6,0xb7,0xfe,0xa5,0x9c,0xf3,
+  0x94,0x29,0x53,0x22,0xb7,0x7d,0x5c,0x7b,0x3f,0x3e,0xb7,0x22,0xf8,0xf3,0x1c,0x8f,
+  0x8f,0x85,0xba,0x29,0xd8,0x6d,0xaf,0xd5,0x5a,0xea,0x45,0x51,0x6f,0x8b,0xab,0x6c,
+  0xd0,0x7f,0xfa,0xdf,0x8c,0xfd,0x97,0xfd,0x93,0x79,0x47,0xc4,0xe2,0x97,0x52,0xe3,
+  0x2e,0x81,0x6f,0xeb,0x53,0x72,0x5a,0x6a,0x79,0x4d,0xce,0x93,0x62,0x3e,0xd7,0x5a,
+  0xc2,0x03,0x90,0xa6,0x15,0xe1,0x01,0x68,0x2d,0xc1,0x2f,0xd6,0xbe,0x4c,0xe7,0x3c,
+  0x67,0xce,0x9c,0x75,0xbe,0x8b,0xdd,0x64,0x21,0x82,0x35,0x2e,0x3e,0x63,0x4b,0x6b,
+  0x13,0x8d,0x5b,0xd6,0x13,0x97,0xf9,0xcd,0x22,0xd4,0x6d,0x43,0x0d,0x00,0x00,0xa1,
+  0x88,0xe0,0x97,0xd8,0xa4,0xe1,0xc3,0x87,0x07,0x3d,0x13,0x5d,0x55,0x46,0x63,0x25,
+  0x20,0xf6,0x82,0xc6,0x1e,0x47,0xd7,0xd4,0xd5,0x4d,0x1d,0x03,0x90,0xc5,0x0b,0x00,
+  0xcd,0x85,0x08,0x74,0x11,0xf8,0x33,0x67,0xce,0x8c,0xac,0x7b,0x9b,0xd0,0x8d,0x3f,
+  0x77,0x09,0x75,0xf3,0xbd,0x4d,0xa8,0x4b,0x4a,0x8d,0x78,0x16,0x92,0xe3,0x6c,0x66,
+  0x1a,0x61,0xbd,0x27,0xf5,0x09,0x7d,0x00,0xd4,0xab,0x20,0x11,0xfd,0xa7,0xff,0xf4,
+  0xbf,0x98,0xfe,0x4b,0x80,0x9f,0x4c,0x21,0x3e,0x72,0xe4,0xc8,0x54,0x41,0x9f,0x26,
+  0xf4,0x6d,0x1e,0x8e,0xd8,0x28,0xf1,0xcd,0x0f,0xd2,0xb4,0x1e,0x80,0x34,0x8f,0x00,
+  0xc2,0xbf,0x79,0x11,0x2b,0x7c,0xf6,0xec,0xd9,0x51,0x75,0x2b,0xb9,0x48,0x45,0x70,
+  0x8b,0xbb,0x5f,0x52,0x5f,0x92,0xa9,0x6d,0x71,0x8e,0x7a,0x48,0x9e,0xba,0xcd,0x25,
+  0x28,0x37,0x9e,0x6c,0x43,0xc6,0xc9,0x64,0x5d,0xa6,0x07,0x21,0x6b,0xe9,0xd1,0x5a,
+  0x4a,0x95,0xe6,0xe5,0x01,0xcb,0x73,0x7b,0xf4,0x9f,0xfe,0xd3,0xff,0xe2,0xfa,0x2f,
+  0xc6,0x8b,0xcc,0x24,0x6a,0x13,0xfc,0x69,0xbf,0xf5,0xd5,0x27,0x48,0xc6,0x00,0x24,
+  0xd3,0x00,0x6d,0x05,0xd2,0x5a,0x2e,0x0d,0x30,0x54,0x39,0x80,0xf2,0x22,0x02,0x59,
+  0xf2,0xf3,0xa5,0x25,0x49,0x73,0x8d,0xf9,0xc6,0xfc,0x92,0xaf,0x32,0x64,0x20,0x59,
+  0x00,0x72,0x43,0xb8,0xdc,0xfc,0x8c,0xa1,0xd2,0x7f,0xfa,0x4f,0xff,0x8b,0xe8,0x7f,
+  0x5c,0xd6,0x7a,0xc3,0x0d,0x37,0xb4,0x0a,0x72,0x57,0x8d,0x03,0x9b,0xa5,0x6f,0xfb,
+  0x2c,0x19,0x48,0x98,0x4c,0x03,0x94,0xe7,0x5d,0x1c,0x08,0x68,0x2e,0xdb,0xb4,0x41,
+  0x80,0x36,0x0b,0x1f,0xcb,0xbf,0xb9,0x49,0xe6,0xac,0x66,0x55,0xf0,0x5c,0xaf,0x71,
+  0x09,0xde,0x38,0x43,0x20,0x9e,0x9a,0xd5,0x76,0x83,0x95,0xe1,0x81,0x51,0xf4,0xfa,
+  0x5c,0x56,0x05,0xfd,0xa7,0xff,0xf4,0xbf,0x98,0xfd,0x8d,0x4b,0x7e,0x8b,0x61,0x63,
+  0x7b,0xf6,0xb8,0x66,0xed,0x0c,0x11,0xce,0x36,0x2f,0x40,0xf2,0x39,0x17,0xb7,0x58,
+  0x09,0xc8,0xb2,0xee,0xa6,0xf0,0x00,0xa4,0xb9,0x4b,0x50,0x06,0xda,0x8f,0xe4,0x78,
+  0x97,0x5c,0xf4,0x22,0xf8,0xcd,0xe2,0x3e,0xc9,0x1b,0x34,0xd6,0x8c,0x5d,0xca,0x47,
+  0xc8,0x18,0x9f,0xed,0x7d,0x2d,0x63,0x86,0x69,0xeb,0xab,0x66,0xcc,0xd1,0x65,0x51,
+  0xd0,0x7f,0xfa,0x4f,0xff,0x8b,0xeb,0xbf,0x2c,0xb7,0x78,0xf1,0xe2,0x28,0xa5,0x2f,
+  0x1e,0xae,0x34,0xc7,0xf3,0x5d,0x0a,0x88,0x69,0xd9,0x9b,0xcb,0xb8,0x9e,0x67,0x71,
+  0x10,0xa0,0x78,0x53,0xa5,0x25,0xa7,0x47,0x6f,0x94,0x3c,0xac,0x5b,0x10,0x20,0xb4,
+  0x2e,0x59,0x83,0x72,0xc4,0xdd,0x26,0xc2,0xdf,0xa6,0x65,0x9b,0xcb,0x27,0xf3,0x64,
+  0x6b,0x2d,0xed,0xe9,0xb3,0x28,0x7c,0x0f,0x1c,0xdf,0xfa,0xcc,0xdf,0xfb,0xf6,0x3f,
+  0x64,0xfd,0xf4,0x9f,0xfe,0xd3,0xff,0x7c,0xfb,0x2f,0xc1,0xc5,0x92,0x55,0x14,0x57,
+  0xf0,0xb3,0x3d,0x87,0x5c,0x55,0xf9,0xd2,0x94,0x01,0x73,0x9a,0x61,0xdb,0xf2,0xe2,
+  0x71,0x88,0x5b,0x5c,0x4b,0xc0,0xd6,0xea,0x15,0x14,0xd8,0x15,0xf1,0x05,0xb5,0x0a,
+  0xff,0x2c,0xb5,0xbc,0x45,0xf0,0x27,0x0b,0xe9,0x84,0x7a,0x0c,0x42,0x2d,0x9a,0x10,
+  0x6b,0x23,0xd4,0x22,0xc9,0xe2,0xd1,0xc8,0x63,0xff,0xe8,0x3f,0xfd,0xa7,0xff,0xc5,
+  0xad,0x5f,0x2c,0x7e,0x09,0xf0,0x1b,0x31,0x62,0x84,0xd7,0x8b,0x60,0x13,0xf0,0xb6,
+  0xdf,0x84,0xce,0x8c,0x98,0xac,0x03,0x20,0xcd,0x56,0x2d,0xb5,0x11,0xa0,0x00,0x40,
+  0xcd,0x6e,0x7d,0x9f,0x86,0x1e,0xcf,0xca,0x17,0x47,0xbc,0x9a,0xb3,0xfb,0x99,0xeb,
+  0x2a,0x4b,0xed,0xf2,0x46,0x1d,0x4b,0xfa,0x4f,0xff,0xe9,0x7f,0x7e,0xfd,0x97,0x5c,
+  0x7e,0x79,0xe6,0xc8,0xec,0xa2,0xa6,0xd1,0x62,0xfe,0xd6,0x25,0xdc,0xcd,0x67,0x5d,
+  0x5a,0xaa,0x9f,0x4d,0xf0,0xc7,0xdb,0x8b,0x85,0x7f,0xb2,0x35,0x52,0x11,0x40,0x01,
+  0x80,0x9a,0x3d,0x00,0xe6,0xfb,0xe4,0x67,0xc9,0x62,0x40,0xa6,0x6b,0xd1,0xf6,0x80,
+  0xf2,0x69,0xfc,0x3e,0x17,0x5f,0xd2,0x65,0xe8,0x73,0x49,0x66,0x75,0x79,0x16,0xe5,
+  0x3d,0xa1,0xff,0xf4,0x9f,0xfe,0xe7,0xdf,0xff,0x78,0x02,0x31,0x29,0xe4,0x13,0x62,
+  0xf1,0xa7,0x79,0x02,0x6c,0x16,0x7e,0x48,0x5a,0xa1,0xcd,0x18,0x2a,0x53,0x41,0x3c,
+  0x14,0x00,0x28,0x04,0xb9,0xd0,0x45,0xdb,0x4d,0x1b,0xe3,0x0f,0x19,0x33,0xcc,0xf2,
+  0x40,0xa8,0xc6,0xe2,0xc9,0x73,0x8c,0x2d,0xab,0x05,0x43,0xff,0xe9,0x3f,0xfd,0xcf,
+  0xbf,0xff,0x22,0xf8,0xe3,0x0a,0x7e,0xae,0xe7,0x4f,0x9a,0x80,0x77,0xd5,0xf5,0x0f,
+  0x71,0xf1,0xbb,0xde,0x27,0xff,0x4e,0x2a,0x01,0xf1,0x67,0x21,0x13,0x09,0xa1,0x00,
+  0x40,0x29,0x3d,0x00,0x66,0x90,0x8c,0x69,0xf1,0x67,0x19,0x73,0xcc,0xd3,0xe2,0x71,
+  0x3d,0x3c,0x8a,0xbc,0xb1,0xb2,0x6e,0x8f,0xfe,0xd3,0x7f,0xfa,0x9f,0x4f,0xff,0x65,
+  0x39,0x29,0x22,0x26,0xc1,0x7d,0x32,0xd6,0x1f,0x52,0x99,0xaf,0x16,0xeb,0x3f,0x4d,
+  0xe0,0x9b,0x25,0x80,0x93,0x53,0xa2,0xbb,0xac,0x7f,0x73,0x78,0x01,0x0f,0x00,0x94,
+  0x16,0x29,0xd6,0xd3,0xa7,0x4f,0x1f,0xeb,0x0d,0xec,0x1a,0xe3,0xaf,0x37,0x14,0x4e,
+  0xa1,0xff,0xf4,0xbf,0x3d,0xfa,0x3f,0x77,0xee,0x5c,0xd5,0xbb,0x77,0xef,0x75,0x4a,
+  0x87,0x9b,0xc7,0xc1,0xf5,0x59,0x68,0x30,0x5f,0x9a,0xa2,0x63,0x4b,0x23,0x74,0x6d,
+  0xcb,0x65,0xfd,0x13,0x03,0x00,0xa5,0x46,0x72,0x66,0xa5,0x04,0xb0,0x94,0xe9,0x8d,
+  0xc7,0xb4,0xcc,0x22,0x16,0x79,0xd5,0xea,0xce,0xe3,0xfb,0x34,0x97,0x62,0xad,0x69,
+  0x53,0x79,0xa7,0x65,0xd1,0x7f,0xfa,0x4f,0xff,0xb3,0xf5,0x4f,0x26,0x24,0x93,0x3e,
+  0x4a,0x5a,0x9f,0x6f,0x3c,0xdd,0x66,0xe1,0xfb,0xac,0xfe,0x2c,0xfb,0x1e,0x32,0x4c,
+  0xe0,0xb3,0xfe,0xeb,0x6e,0xc8,0x21,0xd2,0x20,0x0b,0x32,0xbe,0x26,0xda,0x36,0x00,
+  0x40,0xa3,0x89,0x4b,0x91,0xbb,0x02,0x0a,0x93,0x82,0xd6,0x15,0xdd,0xef,0x12,0xc0,
+  0x21,0x63,0xfa,0x69,0x93,0x02,0xd9,0xb6,0x5f,0x36,0x3a,0x73,0x09,0x01,0x00,0x40,
+  0xb3,0x62,0x0b,0xde,0xb3,0x09,0x5e,0xdf,0xb8,0xbe,0xb9,0x2e,0x9f,0x77,0xc0,0x15,
+  0x34,0x68,0x5a,0xf8,0xae,0xed,0xa3,0x00,0x00,0x00,0x00,0xd4,0x28,0xfc,0xd3,0x8a,
+  0x01,0xa5,0x0d,0x61,0x98,0xcb,0x25,0xad,0x78,0xdf,0x04,0x3f,0x69,0xef,0x43,0xb6,
+  0x8f,0x02,0x00,0x00,0x00,0x90,0x93,0x22,0x10,0x62,0xe9,0xa7,0xd5,0xed,0x37,0xbd,
+  0x00,0xa1,0xc3,0x06,0x65,0x18,0xcf,0x47,0x01,0x00,0x00,0x00,0x70,0x58,0xfa,0x69,
+  0x15,0xfb,0xd2,0xfe,0xb6,0xb9,0xf1,0xd3,0x52,0x18,0x51,0x00,0x00,0x00,0x00,0x1a,
+  0xe4,0x09,0x30,0x3f,0xb3,0x15,0xe5,0xb1,0xa5,0xe8,0xd9,0x52,0xf9,0xd2,0x3c,0x05,
+  0xc9,0xed,0xf8,0xb6,0x8f,0x02,0x00,0x00,0x00,0x50,0xb0,0x22,0xe0,0x4a,0x7f,0x0c,
+  0x15,0xc4,0xa1,0xde,0x82,0x50,0x4f,0x01,0x59,0x00,0x00,0x00,0x00,0x39,0x5b,0xfc,
+  0x36,0xeb,0xdd,0x54,0x06,0xcc,0xc9,0x7e,0x4c,0x2f,0x80,0x4d,0xc0,0xa7,0xd5,0x01,
+  0x48,0xfb,0xcc,0xdc,0x46,0xa3,0x6b,0xfe,0xa3,0x00,0x00,0x00,0x40,0x4b,0x61,0x96,
+  0xdd,0x4d,0x0a,0x63,0xb3,0x70,0x50,0x48,0x3a,0x60,0x35,0x11,0xfc,0xb6,0xe8,0x7f,
+  0x5b,0x49,0x60,0x3c,0x00,0x00,0x00,0x00,0x39,0x7a,0x00,0xcc,0x48,0xfd,0x34,0x4b,
+  0xbc,0x1a,0xcb,0xde,0xf4,0x34,0x98,0xca,0x84,0x2b,0x7b,0x20,0xb9,0x7d,0x3c,0x00,
+  0x00,0x00,0x00,0x05,0x79,0x02,0x6c,0x02,0xd9,0x25,0xf4,0x43,0x2d,0x7b,0x5b,0x1c,
+  0x41,0xc8,0xac,0x80,0xe6,0x90,0x43,0x9a,0xd2,0x81,0x02,0x00,0x00,0x00,0x50,0x85,
+  0xe0,0x37,0x05,0xad,0xab,0x86,0x7f,0x56,0x0b,0xdc,0xcc,0x18,0xb0,0x09,0xf8,0x90,
+  0xed,0x93,0x05,0x00,0x00,0x00,0x50,0x20,0xb5,0x14,0xe3,0xf1,0x15,0xf5,0x31,0x2d,
+  0x7f,0x9f,0x82,0xe1,0xaa,0x23,0x50,0x36,0xda,0x76,0x32,0xa0,0x85,0x0b,0x17,0xaa,
+  0x19,0x33,0x66,0x70,0xd7,0x00,0x00,0x14,0x44,0x8f,0x1e,0x3d,0xd4,0xa8,0x51,0xa3,
+  0x0a,0x17,0xfa,0xae,0xb2,0xbc,0xe6,0xb2,0x69,0x13,0xfc,0x98,0x16,0x7e,0xb2,0x1c,
+  0xb0,0x6b,0x08,0x20,0x74,0xfb,0x65,0xad,0x0e,0xd8,0x16,0x0a,0x80,0xcc,0x5d,0x3f,
+  0x70,0xe0,0xc0,0xb5,0x3e,0x93,0x79,0xa3,0x37,0xde,0x78,0x63,0xe7,0x6f,0x1a,0x3d,
+  0x97,0x76,0xad,0x53,0x75,0xe6,0xbd,0x7d,0xfa,0x4f,0xff,0xe9,0x3f,0xfd,0xaf,0x66,
+  0x7b,0x32,0x83,0xe8,0xbc,0x79,0xf3,0x0a,0xdd,0xcf,0x10,0xeb,0xdf,0x95,0x31,0xe0,
+  0x9a,0xd1,0x2f,0x6d,0x1e,0x80,0x6a,0xb6,0x8f,0x02,0xd0,0x20,0x7a,0xf7,0xee,0x5d,
+  0x95,0x0b,0x26,0xed,0x37,0xbe,0x1b,0x34,0xaf,0x8b,0xdb,0xf7,0x5d,0x23,0xb7,0x4f,
+  0xff,0xe9,0x3f,0xfd,0xa7,0xff,0x3e,0x96,0x2d,0x5b,0x56,0xb8,0x07,0x20,0xd4,0xca,
+  0x77,0x29,0x34,0xe6,0xe4,0x3f,0xa1,0xde,0x86,0x90,0x80,0x40,0x14,0x80,0x06,0x5b,
+  0xff,0x3d,0x7b,0xf6,0xcc,0xac,0xe1,0x86,0x68,0xe0,0x9d,0x3b,0x77,0xce,0xb4,0x7c,
+  0xd6,0xf5,0xa7,0x5d,0x90,0xb5,0x6a,0xe8,0xf4,0x9f,0xfe,0xd3,0x7f,0xfa,0x5f,0x74,
+  0xff,0xe5,0xb3,0x22,0x15,0x80,0x34,0xa5,0x25,0x2d,0x55,0xcf,0xd5,0x7f,0xdb,0x6f,
+  0xcd,0xdf,0x64,0x39,0xc6,0x65,0x57,0x04,0x5a,0x5e,0x01,0xe8,0xd3,0xa7,0x8f,0xf3,
+  0xe0,0xdb,0x4e,0x78,0xda,0xb4,0x92,0x3e,0x0d,0x3c,0xcf,0xe5,0xe3,0x9b,0x4b,0x5e,
+  0x5d,0x37,0x78,0xf2,0xf7,0x21,0xcb,0xd3,0x7f,0xfa,0x4f,0xff,0xe9,0x7f,0x3d,0xfb,
+  0xbf,0x64,0xc9,0x92,0xc2,0x5d,0xe2,0x3e,0x45,0x26,0x74,0x1c,0xdf,0xe5,0x59,0xc8,
+  0x22,0xf8,0x43,0xb6,0x8f,0x02,0x50,0x27,0xba,0x74,0xe9,0xa2,0x7a,0xf5,0xea,0xd5,
+  0xb4,0xfb,0x9f,0xbc,0x60,0x44,0x8b,0x5e,0xb4,0x68,0x51,0x74,0x43,0x2d,0x5f,0xbe,
+  0x5c,0xad,0x5e,0xbd,0xba,0xe1,0x63,0x4d,0xf2,0xb0,0xe9,0xde,0xbd,0xbb,0xea,0xdb,
+  0xb7,0xaf,0xea,0xdf,0xbf,0x7f,0x74,0xbc,0x8b,0xd6,0xe6,0x43,0x1e,0x4a,0xf5,0x72,
+  0x91,0x36,0xc2,0x9a,0xa1,0xff,0xf4,0xbf,0x99,0xfa,0x2f,0xcf,0xab,0x7a,0xe1,0x9a,
+  0xb0,0xc7,0x14,0xc2,0xbe,0xc0,0xbd,0x10,0x05,0xc1,0xa7,0x88,0xb8,0xb6,0x8f,0x02,
+  0x50,0x47,0x44,0x30,0x55,0xeb,0x92,0xab,0xd5,0x65,0x97,0xd7,0xf2,0x0b,0x16,0x2c,
+  0x50,0x73,0xe7,0xce,0xb5,0xba,0xd1,0x5c,0xa5,0x27,0xf3,0xd8,0x7e,0xc8,0xfa,0x62,
+  0xf7,0x9e,0xb4,0x0f,0x3e,0xf8,0x40,0x0d,0x1b,0x36,0xac,0x43,0xe1,0xca,0xfb,0x78,
+  0x55,0xa3,0x79,0x17,0xdd,0xff,0x7a,0x9c,0x7f,0xfa,0x4f,0xff,0x9b,0xb5,0xff,0xf2,
+  0x5c,0x58,0xb9,0x72,0x65,0xdd,0xac,0xff,0xb4,0x59,0xfe,0x7c,0x0a,0x43,0x16,0x81,
+  0xef,0x1a,0x3a,0xc8,0xba,0x7d,0x14,0x80,0x82,0xad,0x7f,0x09,0xfe,0xcb,0xe2,0x62,
+  0x4b,0x8e,0x69,0xf9,0xbe,0x77,0xd5,0x99,0x4e,0x5e,0x04,0xbe,0x31,0xb2,0x34,0x8d,
+  0x7d,0xe9,0xd2,0xa5,0x6a,0xe6,0xcc,0x99,0x6b,0x34,0x68,0xad,0x41,0x76,0x1e,0xa0,
+  0xbf,0x13,0x85,0xa6,0x97,0x6e,0x5d,0xa3,0xcf,0x72,0xbc,0x8d,0xd6,0xac,0x2f,0xbe,
+  0x50,0x3b,0x25,0x3e,0x73,0x2d,0x2f,0x1e,0x88,0x65,0xda,0x13,0x31,0x4f,0x55,0x74,
+  0x5b,0xb5,0x6a,0x95,0x9a,0x3e,0x7d,0x7a,0x94,0xf2,0x23,0xa9,0x3f,0xb5,0xf6,0x3f,
+  0xeb,0x03,0xc8,0x77,0xfc,0x9b,0xed,0xfc,0xd3,0x7f,0xfa,0xdf,0xec,0xfd,0x5f,0xbc,
+  0x78,0x71,0x5d,0xad,0xff,0xb4,0x4a,0x7f,0x59,0xc7,0xef,0x43,0xbc,0x0c,0x59,0xb7,
+  0x8f,0x02,0x50,0x47,0xfa,0xf5,0xeb,0xd7,0x71,0xf1,0x56,0xeb,0x32,0x2b,0x72,0x8c,
+  0xcc,0x76,0xe3,0xc4,0x17,0x91,0xa4,0xcc,0xbc,0xf7,0xde,0x7b,0x4a,0xae,0xa1,0x2e,
+  0x5d,0xd7,0x53,0x9d,0xbb,0x0c,0xd1,0xa2,0xb8,0x6b,0x87,0x80,0x36,0xc5,0xf5,0x3a,
+  0xdb,0x36,0xc4,0xb7,0x7f,0x79,0x7d,0x63,0xeb,0x7f,0x9d,0xd6,0xd4,0x85,0x8a,0xdf,
+  0x57,0x1c,0xbf,0xd0,0xea,0x88,0xfe,0xa6,0xb3,0xfe,0xd7,0x55,0x2b,0x5a,0x7d,0xb4,
+  0x12,0x30,0x40,0xad,0x5a,0x39,0x35,0xda,0xff,0xd9,0xb3,0x67,0xab,0x0d,0x37,0xdc,
+  0xb0,0xa6,0xfe,0xdb,0x1e,0x80,0x59,0x6f,0xa2,0x3c,0x5c,0xa6,0x8d,0x3a,0xff,0xf4,
+  0x9f,0xfe,0x37,0x7b,0xff,0xeb,0x15,0xfc,0x97,0xe6,0xda,0x4f,0x9b,0x07,0x20,0xab,
+  0x20,0x77,0x79,0x40,0xab,0xd9,0x3e,0x0a,0x40,0xc1,0x88,0xe0,0x4f,0x0b,0xfe,0x2b,
+  0x83,0xcb,0xce,0x75,0x31,0x8b,0xd5,0x3f,0x67,0xce,0x1c,0xdd,0x87,0x1e,0xaa,0x5b,
+  0x8f,0xd1,0xfa,0xb5,0xa7,0xea,0xd6,0xbd,0x97,0x1a,0x32,0x64,0x13,0xd5,0xb7,0xff,
+  0x50,0x6d,0x5d,0xf7,0xd5,0x42,0xb7,0x5b,0x6d,0xdb,0xce,0x6a,0xf0,0x1b,0xac,0x5a,
+  0xb5,0x42,0x2d,0x59,0x3c,0x57,0xbd,0x37,0xe3,0x15,0xb5,0x68,0xe1,0x2c,0xd5,0x45,
+  0x89,0x77,0x42,0xbb,0xfb,0x56,0xbc,0x17,0x69,0xfd,0xe2,0x0d,0x90,0xec,0x8b,0x6a,
+  0xfa,0x9f,0xe5,0x01,0x96,0x87,0xc5,0x50,0xb6,0xf3,0x4f,0xff,0xe9,0x7f,0x2b,0xf4,
+  0x5f,0xe2,0x95,0xea,0x29,0xf4,0x7c,0x81,0x7c,0x21,0x9f,0xdb,0x3c,0x30,0xbe,0xac,
+  0x82,0x6a,0xbc,0x05,0x28,0x00,0x75,0xb0,0xfe,0xcd,0x13,0x54,0x6f,0x97,0x5d,0x9a,
+  0xa6,0xea,0xba,0xa1,0x44,0xf8,0xcb,0x78,0x7f,0x97,0xae,0xfd,0x54,0xf7,0x9e,0x1b,
+  0xe9,0xfd,0xe9,0xa6,0x86,0x0d,0xdf,0x5a,0xad,0x3f,0x74,0x33,0xfd,0x7d,0x9e,0x55,
+  0x9b,0x3d,0x3e,0x02,0x8f,0x82,0xd0,0xa5,0x6b,0x17,0xd5,0xbd,0xc7,0x70,0xd5,0x7f,
+  0xe0,0x30,0x35,0x79,0xd2,0x23,0x6a,0xc1,0xfc,0xf7,0x54,0xd7,0xee,0x43,0xb4,0x17,
+  0xe0,0xfd,0xa8,0x3f,0x12,0xa4,0x68,0x2a,0x00,0x45,0x8f,0xb1,0x66,0x3d,0xfe,0x65,
+  0x3c,0xff,0xf4,0x9f,0xfe,0xb7,0x4a,0xff,0xeb,0xe5,0xfe,0xb7,0xf5,0x3b,0x4b,0xb4,
+  0x7e,0x9a,0xa5,0xef,0x2b,0xfe,0x13,0xb2,0x7d,0x62,0x00,0xea,0x8c,0x1c,0x70,0x57,
+  0xf0,0x5f,0xd6,0xb4,0x9b,0xac,0x63,0x62,0x69,0x2e,0x3d,0xdb,0xf6,0x93,0x7f,0x8b,
+  0xdb,0x5f,0x2c,0xff,0x2e,0x5d,0xfb,0xaa,0xee,0xbd,0xc6,0xa8,0x6e,0xdd,0x7a,0xab,
+  0x4d,0x37,0xdb,0x53,0xf5,0xee,0x33,0xd8,0x2b,0x91,0x65,0x35,0xb2,0x1b,0xf1,0xea,
+  0xe2,0xf7,0xa1,0xd7,0x9d,0xef,0xf7,0x69,0xea,0xc2,0x88,0x91,0xdb,0xaa,0x89,0xaf,
+  0xce,0xd4,0xef,0xba,0xeb,0x0f,0xbb,0xea,0xcf,0x57,0xae,0x75,0xbc,0x42,0xfb,0x1f,
+  0x32,0x06,0x9a,0xf6,0x1a,0x62,0x2d,0x95,0xf9,0xfc,0xd3,0x7f,0xfa,0xdf,0x2a,0xfd,
+  0x97,0xf8,0xa5,0xa2,0x83,0xff,0xf2,0xb4,0xb4,0x6d,0xe7,0xc9,0x54,0x02,0x5c,0xdb,
+  0xb2,0x0d,0xd3,0x34,0x53,0x55,0xc0,0x96,0x53,0x00,0xc4,0xf5,0x5f,0x6d,0x3a,0x9a,
+  0x6f,0x8c,0x2e,0xcf,0x1b,0x2e,0xb9,0x3e,0x19,0x2b,0x7b,0xff,0xfd,0xf7,0x75,0xa0,
+  0x5f,0x37,0xd5,0xa3,0xf7,0x87,0xc2,0x7f,0xf3,0x8f,0xec,0xaf,0x23,0xea,0x07,0x04,
+  0x5a,0x0f,0x1e,0x01,0x5e,0x6b,0xd1,0x90,0x14,0x05,0xa0,0x4f,0xbf,0xc1,0x3a,0x46,
+  0xa1,0xf3,0x5a,0xdb,0x8c,0xad,0xff,0x3c,0xc7,0x48,0xeb,0xe1,0x32,0x6d,0xd4,0xf9,
+  0xa7,0xff,0xf4,0xbf,0x95,0xfa,0x2f,0x99,0x4b,0x65,0xc3,0x56,0xe3,0x3f,0xcd,0xb3,
+  0x92,0x66,0xc1,0x9b,0xb3,0x00,0x86,0x0e,0x3b,0x50,0x07,0xa0,0x0e,0x48,0x3e,0x7a,
+  0x11,0xc5,0x17,0xaa,0xd1,0xf8,0x43,0x5d,0x78,0xe2,0xfa,0x97,0xf7,0xbd,0xfb,0x8d,
+  0xd1,0xae,0xf4,0x1e,0x6a,0xd3,0x2d,0x3e,0xae,0x06,0x0e,0xde,0xc0,0x69,0x81,0x7b,
+  0xa3,0xfc,0x8c,0xef,0xd7,0x55,0x08,0xd6,0x56,0x18,0xd6,0xdd,0xd9,0xf4,0xf5,0x25,
+  0xbf,0xef,0xb4,0x6c,0x55,0x34,0x24,0x50,0x59,0xbd,0x4a,0xff,0xbd,0xaa,0xa3,0xf6,
+  0x82,0xad,0x22,0x58,0x9e,0x69,0x47,0x59,0x5d,0xa4,0x65,0x3e,0xff,0xf4,0x9f,0xfe,
+  0xb7,0x4a,0xff,0x25,0xfe,0x47,0x3c,0x00,0x8d,0x16,0xf4,0xe6,0xdf,0xbe,0xf3,0xe4,
+  0x9a,0xe2,0x37,0xcd,0xf5,0x1f,0xe2,0xe6,0xb7,0xc5,0x12,0xa0,0x00,0x14,0x84,0x08,
+  0x1e,0x29,0x4c,0x13,0xe2,0x52,0xab,0x56,0x3b,0x4e,0x8b,0xda,0xad,0x26,0xed,0x46,
+  0x66,0x25,0x94,0x80,0x99,0x6e,0xdd,0xfb,0xab,0x6e,0x3d,0x07,0xaa,0x01,0x03,0x86,
+  0xe9,0x31,0xff,0x31,0x1e,0x81,0xed,0x93,0xf0,0x3e,0x05,0x21,0x9b,0xcf,0x3f,0xed,
+  0xeb,0x45,0x73,0x66,0x69,0xcf,0x45,0x67,0xb5,0x72,0xf9,0xdc,0xd4,0xe1,0x97,0x5a,
+  0x5d,0x8c,0xb6,0xf3,0x91,0xe7,0x18,0x6d,0xa3,0xce,0x3f,0xfd,0xa7,0xff,0xad,0xd4,
+  0x7f,0xc9,0x02,0x6a,0x24,0x2e,0xc1,0x6e,0x73,0xed,0xbb,0xbe,0x77,0x1d,0xab,0x3c,
+  0x82,0x0a,0x51,0x00,0xea,0x60,0xfd,0xe7,0xe1,0x22,0xcb,0x9a,0x96,0xe3,0x5b,0xbf,
+  0xcb,0x85,0x26,0xe3,0xfe,0xf2,0xda,0xa3,0xcf,0x88,0xe8,0x06,0x1a,0xb9,0xf1,0xf6,
+  0xaa,0x6b,0xb7,0xae,0x3e,0x35,0x37,0xd5,0xa4,0x5f,0x47,0xfe,0x9b,0xfb,0xee,0x75,
+  0x01,0x84,0x33,0x67,0xf6,0x9b,0xaa,0xb3,0x5e,0xcf,0x8a,0xe5,0x1f,0xde,0xf8,0x32,
+  0xeb,0x62,0x5a,0xfc,0x45,0xb5,0x63,0xa2,0x45,0xaf,0xaf,0x51,0xe7,0x9f,0xfe,0xd3,
+  0xff,0x56,0xe9,0xbf,0x7c,0x27,0x41,0xcc,0x32,0x04,0x58,0x6f,0x61,0x17,0x3a,0xd5,
+  0xaf,0xcf,0xb5,0xef,0x12,0xea,0x21,0x13,0x05,0x85,0x4c,0x42,0x84,0x02,0x50,0x10,
+  0xe2,0x7a,0x96,0xf1,0xff,0xa2,0xb4,0x49,0xdf,0x0d,0x14,0xe2,0x82,0x33,0xdf,0x4b,
+  0xb4,0xbc,0x44,0xcb,0x76,0xe9,0xda,0x53,0x47,0xfd,0x0f,0xd4,0x1e,0x8c,0xfe,0x6a,
+  0xc8,0x06,0xeb,0xce,0x9d,0xbd,0x6e,0x96,0xde,0xda,0x9f,0x7c,0x98,0xb7,0xdf,0xc9,
+  0x99,0xb7,0x9f,0xfd,0x6e,0x5a,0xdb,0x63,0xb0,0x8e,0xc3,0x60,0xcd,0xd7,0x8b,0x17,
+  0xcf,0x57,0xf3,0xe7,0xcd,0xd0,0xdf,0x2d,0xd7,0x1e,0x80,0xf9,0x1d,0x65,0x81,0xab,
+  0xb1,0x50,0x8a,0x3e,0x3f,0x65,0x3c,0xff,0xf4,0x9f,0xfe,0xb7,0x52,0xff,0x65,0xec,
+  0x5f,0xa6,0xfe,0x15,0x43,0x26,0xef,0xb2,0xe0,0x59,0x85,0xbf,0xad,0x04,0xb0,0x4d,
+  0x90,0x87,0x94,0x02,0x8e,0x97,0x0b,0x55,0x32,0x5c,0xdb,0xa7,0x14,0x70,0x81,0xc4,
+  0xae,0xe7,0x22,0xf3,0x74,0xf3,0xbe,0x61,0xa4,0x7c,0xae,0xbc,0xf6,0xea,0x33,0x3c,
+  0xd2,0x9a,0x47,0x8d,0xd9,0x56,0xf5,0xe8,0xd9,0xc3,0x27,0x8f,0xbd,0x31,0x01,0xbe,
+  0x11,0x01,0xef,0xfa,0x4d,0x07,0x81,0x23,0x4b,0x70,0xea,0xdb,0x93,0x55,0x67,0x3d,
+  0xfe,0xbf,0x64,0xd1,0xcc,0xe8,0xf3,0xc1,0x83,0x07,0xa7,0x06,0x0d,0x65,0x7d,0x60,
+  0x56,0xf3,0x10,0x68,0xa6,0xf3,0x4f,0xff,0xe9,0x7f,0x2b,0xf5,0x5f,0xbc,0x99,0x82,
+  0x64,0x00,0xd4,0x53,0x01,0xb0,0x29,0x02,0x2e,0x81,0xee,0x1a,0x0e,0x08,0x89,0xdc,
+  0xb7,0x05,0x11,0x26,0xcf,0xb1,0x6f,0xfb,0x0c,0x01,0x14,0x48,0x32,0xf8,0x2f,0xe4,
+  0xa0,0xe7,0xad,0x95,0x65,0x1d,0xc3,0x93,0xcf,0x25,0xf5,0xaf,0x73,0xe7,0xae,0xaa,
+  0x57,0xbf,0xa1,0xda,0x0b,0xd0,0x4d,0x8d,0x18,0xbd,0x95,0xea,0xa2,0xdd,0xff,0x99,
+  0x03,0x86,0x3c,0x02,0xde,0x94,0xe8,0x59,0x7f,0x6f,0x53,0x40,0x56,0xad,0x5a,0xa9,
+  0x66,0xce,0x98,0xa4,0xd7,0xa3,0xf3,0xfe,0x17,0xcf,0x8a,0x14,0x98,0x41,0x83,0x06,
+  0x75,0xdc,0xf8,0x21,0x63,0x98,0x3e,0x17,0x66,0x35,0x0f,0xdf,0x66,0x39,0xff,0xf4,
+  0x9f,0xfe,0xb7,0x52,0xff,0xc5,0xf2,0x97,0x58,0x26,0x41,0x26,0x2a,0xab,0xa7,0xd0,
+  0x4f,0xfb,0xdb,0xf7,0xbb,0x50,0xb7,0x7e,0x88,0xc2,0x15,0xb2,0x3e,0x14,0x80,0x22,
+  0x3a,0xa1,0x85,0x4f,0xcf,0x9e,0x3d,0x53,0x35,0xf2,0x90,0x1b,0xb0,0x9e,0x16,0x80,
+  0xb8,0xcb,0x24,0x62,0xb6,0x67,0x1f,0x11,0xfe,0xdd,0xd5,0xf0,0x91,0x9b,0xab,0x9e,
+  0xbd,0x7a,0xdb,0x4d,0xfa,0x8c,0x95,0xfa,0x2c,0x57,0x5e,0x7a,0x61,0x00,0x5f,0x4c,
+  0x80,0x25,0xe6,0xe0,0x7d,0x2d,0xfc,0x57,0xad,0x5a,0xae,0x96,0x2f,0x9d,0xad,0x3f,
+  0x5e,0xa9,0x83,0x17,0x07,0xae,0x55,0xfc,0xa7,0x0c,0xb3,0x91,0x95,0xf9,0xfc,0xd3,
+  0x7f,0xfa,0xdf,0x4a,0xfd,0x9f,0x35,0x6b,0xd6,0x5a,0x82,0x4e,0x94,0x00,0x5f,0x29,
+  0xf6,0x3c,0xfb,0x99,0x16,0xdc,0x57,0x6b,0xe0,0x63,0x5a,0xd6,0x80,0xcb,0xf5,0x6f,
+  0x53,0x32,0xf0,0x00,0x14,0x84,0xad,0xf2,0x5f,0x51,0xee,0xa5,0xbc,0x2a,0x77,0xc5,
+  0xee,0xb2,0x3e,0x03,0x46,0x44,0x51,0xf4,0xa3,0x36,0xd9,0x36,0xb2,0xfe,0x83,0x4c,
+  0xf0,0x75,0xae,0x54,0x95,0x29,0x2d,0x30,0x8e,0x17,0xe8,0xe4,0x8a,0x21,0x08,0x48,
+  0x03,0x9c,0xfe,0xce,0xab,0xd1,0x7e,0x2f,0x5d,0x38,0x23,0xfa,0x68,0xc8,0x90,0x21,
+  0x35,0xcd,0x4e,0x58,0x76,0xca,0x58,0x3a,0x96,0xfe,0xd3,0xff,0x32,0xf4,0x5f,0x84,
+  0xbd,0x04,0xff,0x25,0xa9,0x97,0x02,0xe0,0x12,0xf4,0x21,0x69,0x7a,0x2e,0xa1,0x6d,
+  0xf6,0xd3,0x57,0x10,0xc8,0xdc,0x7e,0x51,0x13,0x11,0xa1,0x00,0x38,0x88,0x03,0xcf,
+  0x42,0x35,0xb4,0x6a,0x6f,0xc8,0xbc,0xa2,0x74,0x65,0x86,0x3f,0xc9,0x95,0xed,0xde,
+  0xb3,0xbf,0xea,0xd9,0x7b,0xa0,0xea,0x3f,0x68,0x03,0xb5,0xfe,0xb0,0x51,0x89,0x20,
+  0x3e,0xa3,0xd2,0x5f,0x36,0xf9,0xee,0xbf,0x99,0x55,0x70,0x9a,0xbf,0xf5,0xfb,0x0f,
+  0xe6,0xea,0x9a,0xff,0x0b,0x67,0xab,0xd5,0xab,0x16,0xeb,0xe0,0xbf,0x85,0xd1,0xac,
+  0x8b,0xe6,0xcc,0x8b,0xd5,0x4c,0x1e,0x52,0x4b,0x29,0xd5,0x66,0x3a,0xff,0xf4,0x9f,
+  0xfe,0xb7,0x52,0xff,0x25,0x96,0x49,0xbc,0x99,0x66,0x7f,0xea,0xa5,0x98,0xa4,0x09,
+  0xf9,0xb4,0x7d,0xb1,0xa5,0x4a,0xda,0xac,0xff,0x10,0x2f,0x43,0x5a,0x10,0x21,0xa5,
+  0x80,0x0b,0x24,0x9e,0xf8,0xc7,0x76,0xe0,0x6b,0x99,0xcd,0xaa,0xd6,0x1b,0x3a,0x8d,
+  0xd8,0xfa,0xef,0x3b,0x68,0x64,0x64,0x45,0x6f,0x3c,0x76,0x87,0xa8,0x98,0x8e,0x5b,
+  0x40,0xa7,0x5b,0xec,0xd9,0x67,0xff,0xab,0x6d,0x7d,0xd3,0xdf,0x7e,0x39,0xda,0xef,
+  0xc5,0xf3,0xdf,0xb5,0x5a,0xff,0xb5,0xb8,0xdb,0x42,0x2b,0x9f,0xd9,0xc6,0x5c,0x9b,
+  0xe5,0xfc,0xd3,0x7f,0xfa,0xdf,0x4a,0xfd,0x4f,0xba,0xff,0x93,0x1e,0x80,0x7a,0x7b,
+  0x28,0x42,0x2c,0xfc,0xe4,0xe7,0xe6,0x7b,0x97,0x3b,0xdf,0x65,0xbd,0xbb,0x84,0x7c,
+  0x33,0x4c,0x02,0xd4,0x32,0x0a,0x80,0x59,0x75,0xae,0x2c,0xb3,0x67,0xb9,0x10,0x4d,
+  0x79,0xfe,0xfc,0xf9,0xfa,0xc6,0xd5,0x69,0x8b,0xfd,0x87,0xe9,0x71,0x73,0x3d,0xfe,
+  0xbf,0xd1,0x16,0x5a,0x01,0xe8,0x9a,0x10,0xc0,0x6b,0x0b,0xe8,0xec,0x4f,0x93,0x8c,
+  0x1a,0x41,0x06,0x9f,0xc2,0xd2,0xc5,0x0b,0xd4,0xf4,0x77,0x27,0xea,0xca,0x7f,0xcb,
+  0xd5,0x92,0x05,0xef,0x45,0xa9,0x7f,0xae,0xdc,0xff,0x7a,0xb8,0xff,0xb2,0x3c,0x40,
+  0xcb,0x70,0xfe,0xe9,0x3f,0xfd,0x6f,0xa5,0xfe,0x4b,0xe0,0x9f,0x6d,0xe2,0x9f,0x7a,
+  0x2b,0x00,0xa1,0x4a,0x4b,0xd6,0x69,0x80,0x4d,0x8f,0x4a,0xda,0xd0,0x42,0xd9,0x27,
+  0xfe,0x69,0x49,0x05,0x20,0x76,0x3d,0x17,0x3d,0xdb,0x96,0xef,0x86,0x0b,0x8d,0xdc,
+  0x97,0xca,0x7f,0x72,0x73,0xf4,0xec,0x33,0x44,0xd7,0xd0,0xef,0xaa,0x06,0x0e,0x19,
+  0xa6,0x03,0x18,0x7b,0xa7,0xbb,0xef,0x7c,0x63,0xf4,0xb5,0xdf,0x29,0xc1,0xb3,0x09,
+  0xbd,0x36,0xe1,0x51,0xb9,0xbd,0xd5,0xfc,0xd9,0x53,0xa2,0x1d,0x18,0x3a,0x74,0x68,
+  0x14,0xf9,0x9f,0xf7,0x6c,0x65,0x79,0xbb,0x48,0xcb,0x72,0xfe,0xe9,0x3f,0xfd,0x6f,
+  0xa5,0xfe,0x4f,0x9f,0x3e,0xdd,0xb9,0xbe,0x7a,0x06,0x02,0xfa,0x04,0x79,0x9a,0x27,
+  0x20,0xad,0xef,0x69,0xa5,0x7f,0x7d,0xb5,0x02,0x6c,0xdb,0x47,0x01,0x28,0x40,0x01,
+  0x88,0x2f,0x32,0xdf,0x0d,0x9a,0xa5,0x54,0xa7,0x4d,0x9b,0x4e,0xfb,0x3b,0x74,0xb6,
+  0xac,0xb8,0x4e,0x76,0xf7,0x9e,0x7d,0xa2,0x8a,0x7f,0x3d,0x7b,0xeb,0xf2,0xc5,0x3a,
+  0xf7,0x3f,0x7d,0xf6,0xbe,0xb5,0x25,0xfe,0xba,0x0a,0x42,0xb6,0x98,0x80,0x75,0xe4,
+  0xbb,0x27,0xe9,0x20,0x5e,0x7e,0xd2,0x2b,0x4f,0xab,0xf7,0xa7,0x4f,0x56,0xcb,0x16,
+  0xcf,0x56,0x8b,0xe6,0xbd,0x1b,0x0d,0xbd,0x48,0xea,0x5f,0x96,0xfe,0x87,0x96,0x52,
+  0x0d,0x79,0x00,0x65,0x7d,0x40,0x97,0xe1,0xfc,0xd3,0x7f,0xfa,0xdf,0x2a,0xfd,0x17,
+  0x4f,0xa6,0xb4,0x2c,0x6e,0xf9,0x7a,0x0f,0x09,0xf8,0xf2,0xf5,0xb3,0x0e,0x2b,0x84,
+  0xf6,0x2b,0x6d,0xfb,0x28,0x00,0x39,0xd2,0xa3,0x47,0x8f,0xaa,0xdc,0x41,0x59,0x6b,
+  0x79,0xe7,0x35,0x3b,0x97,0x14,0xc9,0x88,0x22,0x4b,0xf5,0xb6,0x3a,0x75,0xd6,0x1e,
+  0x81,0x05,0x73,0xa2,0xf1,0xff,0x0f,0x17,0x0b,0xf3,0xd9,0x67,0x4e,0x0a,0xf0,0xcd,
+  0x0e,0xe8,0xf1,0x30,0xc8,0x62,0x13,0x27,0x3c,0xa5,0x5e,0x79,0xe1,0x21,0x1d,0xf4,
+  0xb7,0x40,0xcd,0x7e,0xe7,0xdf,0x51,0xca,0xdf,0xe8,0xd1,0xa3,0x9d,0x0f,0x8c,0x3c,
+  0x8e,0x57,0x91,0x63,0x98,0x8d,0x3a,0xff,0xf4,0x9f,0xfe,0xb7,0x42,0xff,0xc5,0xba,
+  0x7f,0xfb,0xed,0xb7,0x53,0xb7,0x29,0xcb,0x14,0x5d,0x10,0x28,0xab,0xf5,0x6e,0x5a,
+  0xe3,0x36,0xcf,0x4a,0xa8,0x80,0x77,0x79,0x5d,0x6c,0xdb,0x60,0x08,0xa0,0xa0,0x31,
+  0x1e,0x19,0x83,0x0e,0xd5,0xe6,0xb2,0xce,0xaf,0x9d,0xd7,0x85,0x98,0x44,0x6e,0x08,
+  0xf9,0x6c,0xc5,0xd2,0x85,0xfa,0x55,0xa7,0xd1,0x2d,0x59,0xa4,0xa6,0x4e,0x7e,0x49,
+  0x6d,0xbc,0xf9,0x0e,0xa5,0x4c,0x29,0x5a,0xb2,0x68,0xbe,0x7a,0xf1,0xe9,0x7b,0xd5,
+  0xbb,0x6f,0xbf,0xa6,0xf7,0x79,0x81,0x9a,0x31,0xe5,0x99,0x48,0x55,0xd8,0x64,0x93,
+  0x4d,0xd6,0xaa,0xbd,0x90,0xb7,0xcb,0xb1,0x1e,0x95,0xd2,0x1a,0x71,0xfe,0xe9,0x3f,
+  0xfd,0x6f,0x85,0xfe,0xbf,0xf5,0xd6,0x5b,0xd1,0x34,0xe6,0x3e,0x05,0xa0,0x1e,0x32,
+  0xc0,0xe6,0x09,0xb1,0xb9,0xf7,0x43,0xa6,0xf0,0xcd,0xea,0xaa,0x77,0x55,0x07,0x74,
+  0x05,0x20,0xa2,0x00,0xe4,0x48,0x2c,0x4c,0x43,0x6e,0xa0,0xac,0x95,0xba,0x7c,0x17,
+  0x5a,0xb5,0xeb,0x8f,0x85,0xe6,0xd2,0x45,0x73,0xd4,0xaa,0x15,0x8b,0xf5,0x0c,0x80,
+  0x7d,0xd5,0x8b,0xcf,0xfc,0x43,0x2d,0x5e,0x32,0x5f,0x8d,0xd9,0x6c,0x3b,0xd5,0xa7,
+  0xef,0x20,0x1d,0x1b,0xd0,0xc5,0x67,0xd3,0x67,0xf2,0x10,0xac,0x1b,0x54,0xb8,0xf6,
+  0x12,0xe6,0xf2,0xcb,0x97,0x2e,0x56,0x73,0x67,0xcf,0x50,0xef,0xbc,0xf9,0x8a,0x56,
+  0x4e,0x26,0x44,0x55,0xff,0x16,0xcc,0x9d,0xa6,0x66,0x4d,0x9d,0xa0,0xfb,0xd4,0x49,
+  0x8d,0xd1,0xc2,0x5f,0xdc,0xff,0xb5,0x1c,0x5f,0x9f,0x45,0xe3,0x73,0x49,0x66,0x7d,
+  0x80,0x96,0xe5,0xfc,0xd3,0x7f,0xfa,0xdf,0xec,0xfd,0x7f,0xff,0xfd,0xf7,0xa3,0xe6,
+  0xa3,0x1e,0x0a,0x40,0x5a,0x6a,0x5e,0x9a,0x25,0x9e,0x56,0x1b,0x20,0xc4,0xe2,0xf7,
+  0x29,0x6a,0xd5,0x2a,0x14,0x28,0x00,0x19,0xb5,0xbf,0x50,0x97,0x59,0x88,0x8b,0xad,
+  0xd6,0xd9,0xbf,0x42,0xd2,0x74,0x64,0xcc,0x5c,0x02,0x67,0xe4,0xe6,0x78,0xef,0xad,
+  0x7f,0xa9,0x91,0x9b,0x8f,0x8b,0x2a,0x01,0x4e,0x7e,0xf5,0x69,0x35,0x45,0xb7,0x10,
+  0x17,0x7f,0xee,0xc7,0x31,0x45,0xbd,0x58,0xb6,0x78,0x9e,0x9a,0x39,0x6d,0x82,0x4e,
+  0xf9,0x9b,0x15,0x29,0x2f,0x63,0xc6,0x8c,0x59,0x6b,0xd8,0x25,0x6b,0xff,0xb3,0x3c,
+  0x70,0x92,0xaf,0x3e,0x0b,0xa6,0x59,0xce,0x3f,0xfd,0xa7,0xff,0xcd,0xdc,0x7f,0xc9,
+  0xf9,0x7f,0xe3,0x8d,0x37,0x82,0xbd,0xae,0xf5,0xb2,0x80,0x6d,0x53,0xf9,0xfa,0x5c,
+  0xff,0x2e,0x21,0x6f,0x2a,0x03,0x21,0x25,0xe6,0x43,0xb7,0x8f,0x02,0x50,0x80,0xf6,
+  0x97,0xe5,0x22,0xc9,0xba,0x6c,0xde,0xb3,0x75,0x75,0xeb,0xd6,0x4d,0x0d,0x1f,0x3e,
+  0x5c,0xbd,0xfb,0xee,0xbb,0x6a,0xf9,0x92,0x05,0xea,0xad,0x09,0x0f,0xa8,0xc1,0xc3,
+  0xc7,0xaa,0x3e,0x03,0x87,0xa9,0x6e,0x3d,0x7a,0x47,0xe9,0x81,0x9d,0x12,0x82,0xb9,
+  0x6e,0xca,0xd4,0x9a,0xd7,0x55,0x2b,0x57,0xa8,0x95,0x2b,0x96,0xa8,0xc5,0xf3,0x66,
+  0x6a,0xab,0x7f,0xba,0x4e,0xf5,0x9b,0x1d,0xed,0xfb,0x06,0x1b,0x6c,0xa0,0x86,0x0d,
+  0x1b,0x96,0x69,0x4c,0xaf,0xd6,0x34,0x25,0xdf,0xf8,0x69,0x33,0x9e,0x7f,0xfa,0x4f,
+  0xff,0x9b,0xb5,0xff,0x92,0xc1,0xf4,0xec,0xb3,0xcf,0x66,0x9a,0x75,0xb5,0xe8,0x38,
+  0x00,0x9b,0xf5,0xed,0x52,0xb6,0x7c,0xca,0x97,0x2b,0xe8,0x31,0x6b,0x31,0xa0,0x6a,
+  0xb7,0x8f,0x02,0x90,0x91,0xb8,0xfa,0x94,0x2f,0x95,0xa3,0x1a,0x17,0x5c,0x91,0x48,
+  0xea,0x5c,0xe4,0x01,0x78,0xef,0x3d,0x2d,0x70,0x97,0xab,0x99,0x53,0x5f,0x8e,0x5a,
+  0x19,0x3d,0x2c,0x32,0xc3,0x9f,0x08,0x7f,0xa9,0xb7,0x50,0x86,0xfd,0xc9,0x62,0x21,
+  0x95,0xf5,0xfc,0xd3,0x7f,0xfa,0xdf,0x6c,0xfd,0x97,0x5c,0xff,0xc7,0x1e,0x7b,0xcc,
+  0x3a,0xe7,0x4a,0x23,0x15,0x00,0x97,0x80,0xcd,0x2a,0x6c,0x43,0xa7,0xfa,0xb5,0x29,
+  0x1e,0x21,0xdb,0x27,0x0d,0xb0,0xa0,0x13,0x2e,0x81,0x28,0xc9,0x62,0x40,0xb5,0xb8,
+  0xb8,0xaa,0xd1,0x3c,0xab,0x5d,0xdf,0x86,0x1b,0x6e,0x18,0x15,0xd0,0x91,0xaa,0x80,
+  0x92,0x4a,0xb3,0x7c,0xf9,0xf2,0x86,0x5f,0x20,0xb2,0xff,0xe2,0xa1,0x90,0xe3,0x29,
+  0xf3,0x2b,0xc8,0xfe,0xc9,0xdf,0x45,0xf4,0xbf,0x9a,0x3c,0x69,0xdf,0xf9,0x6d,0xa6,
+  0xf3,0x4f,0xff,0xe9,0x7f,0xb3,0xf4,0x7f,0xf6,0xec,0xd9,0xea,0xc9,0x27,0x9f,0xec,
+  0x78,0x3e,0x64,0x55,0x00,0xea,0x21,0xf4,0xd3,0xc6,0xe1,0xb3,0x0a,0x79,0x73,0xac,
+  0xdf,0x15,0xdd,0x9f,0x65,0xfb,0xcc,0x05,0x50,0x10,0xe2,0x96,0x32,0xeb,0xd0,0x17,
+  0xe5,0x92,0xcb,0x7b,0x7d,0xe2,0x4a,0xcb,0xe2,0x4e,0x6b,0x26,0x8b,0xa4,0x11,0xe7,
+  0xa3,0xd9,0xce,0x3f,0xfd,0xa7,0xff,0x65,0xef,0xff,0x9b,0x6f,0xbe,0xa9,0xfe,0xf5,
+  0xaf,0x7f,0x45,0xb1,0x0c,0x71,0xcd,0x8f,0x32,0x29,0x00,0x59,0xac,0x7f,0x57,0xc4,
+  0xbe,0x4d,0x41,0xf0,0xa5,0x16,0x9a,0xeb,0x0c,0xdd,0x3e,0x0a,0x40,0xce,0xcc,0x9c,
+  0x39,0x33,0x72,0xa9,0xe7,0x71,0x01,0x15,0x99,0x96,0x53,0xf6,0xd9,0xc1,0xe8,0x3f,
+  0xfd,0xa7,0xff,0xf4,0x3f,0xde,0x3f,0xa9,0x57,0xf2,0xfc,0xf3,0xcf,0x77,0xe4,0xfa,
+  0xf7,0xef,0xdf,0xbf,0xaa,0xaa,0x7e,0x45,0x07,0x02,0x86,0xd6,0xf9,0x4f,0xab,0x02,
+  0xe8,0x52,0x24,0x42,0xbc,0x0d,0xbe,0xe5,0xcb,0x3e,0xac,0xd4,0xf4,0x0a,0x80,0x0c,
+  0x01,0x48,0x4e,0xea,0x46,0x1b,0x6d,0x54,0x93,0x0b,0xce,0xa7,0x21,0xfb,0x2a,0x6b,
+  0x85,0xdc,0xd0,0x59,0x34,0xf0,0xbc,0x67,0x07,0xa3,0xff,0xf4,0x9f,0xfe,0xd3,0xff,
+  0x90,0xfe,0x8b,0xd5,0x3f,0x61,0xc2,0x84,0x8e,0xaa,0xa5,0x32,0xdb,0x6a,0x56,0xd7,
+  0xbf,0xe9,0x05,0x28,0x2a,0x0e,0x20,0xad,0x5a,0x61,0xa8,0xf0,0xf7,0x05,0xf7,0xd9,
+  0x82,0xfc,0xb2,0xec,0x5b,0x99,0x15,0x81,0x96,0x98,0x0e,0x78,0xd2,0xa4,0x49,0x51,
+  0x6a,0x9a,0x44,0xd7,0x67,0x49,0xbb,0xa9,0xa5,0xd2,0x56,0xde,0x79,0xbf,0x21,0xeb,
+  0x4f,0x4b,0x4b,0xaa,0x26,0xed,0x88,0xfe,0xd3,0x7f,0xfa,0x4f,0xff,0x63,0xa6,0x4e,
+  0x9d,0xaa,0x5e,0x79,0xe5,0x15,0xb5,0x60,0xc1,0x82,0x8e,0xdf,0x49,0x3c,0x50,0xe8,
+  0x10,0x6b,0x23,0x14,0x00,0x97,0xa5,0x6f,0xa6,0xf0,0xf9,0xdc,0xfb,0xa6,0x35,0x1f,
+  0x5a,0xfb,0x3f,0xc4,0x53,0x54,0xe6,0x82,0x40,0x2d,0xa1,0x00,0xc8,0x81,0x7d,0xea,
+  0xa9,0xa7,0xd4,0xa6,0x9b,0x6e,0xaa,0xb6,0xdc,0x72,0xcb,0xb5,0xaa,0x03,0x16,0x55,
+  0x59,0x2b,0xab,0x46,0x5f,0x8d,0x8b,0xd0,0x67,0x81,0xd4,0xba,0x3c,0xfd,0xa7,0xff,
+  0xf4,0xbf,0xbd,0xfb,0x2f,0x79,0xfd,0xd3,0xa6,0x4d,0x8b,0xac,0xfe,0xd8,0xe2,0x8f,
+  0xbf,0x17,0xa3,0x4a,0xac,0xff,0x5a,0x69,0x44,0x1c,0x80,0x4b,0xd0,0xfb,0x52,0xf8,
+  0xcc,0xf7,0x69,0x6e,0x7e,0xf3,0x5c,0xa7,0x4d,0x2d,0x4c,0x16,0x40,0x91,0x9d,0xd0,
+  0x75,0xe9,0xe5,0x00,0x4f,0x9e,0x3c,0x39,0x1a,0x0e,0x18,0x31,0x62,0x44,0x94,0xba,
+  0x26,0x91,0xec,0x12,0x64,0x27,0xdf,0x9b,0x13,0x06,0xf9,0x5c,0x78,0xb5,0xce,0xee,
+  0x95,0xd5,0x65,0x97,0xb5,0xf2,0x57,0xc8,0xe4,0x23,0xb6,0x0b,0x92,0xfe,0xd3,0x7f,
+  0xfa,0xdf,0x7e,0xfd,0x97,0x94,0x69,0x19,0x2e,0x95,0xa0,0x69,0xc9,0x3a,0x92,0xc8,
+  0xfe,0x59,0xb3,0x66,0x59,0xa7,0xf2,0x15,0xc4,0x88,0x92,0xe7,0x67,0x1e,0x56,0x6b,
+  0x91,0x0a,0x80,0xcf,0x0a,0x4f,0x73,0xdb,0xbb,0x84,0xbc,0x39,0x4f,0x40,0x88,0xc7,
+  0xc1,0xa5,0x6c,0x51,0x09,0xb0,0x0e,0x24,0x2b,0xd3,0xc9,0x85,0x2e,0xae,0x2c,0x69,
+  0x69,0x48,0x90,0x4b,0xb3,0xcd,0xdd,0x0c,0x00,0x50,0x34,0xe2,0xf6,0x8f,0x4b,0x7d,
+  0xe7,0x25,0xa4,0xeb,0xed,0x02,0x0f,0x89,0xd6,0xcf,0xe2,0xe1,0xf1,0x79,0x03,0x5c,
+  0x55,0x04,0x6d,0xde,0x88,0x32,0xd1,0xb9,0x15,0x2e,0x58,0xb1,0xf0,0xa5,0x55,0xeb,
+  0xbe,0x03,0x00,0x68,0x77,0xe4,0x99,0x28,0x56,0xbf,0xb8,0xfd,0xf3,0x7e,0x3e,0x16,
+  0xe5,0x05,0xb0,0x59,0xfa,0x36,0x41,0x1c,0x2a,0x7c,0xd3,0xf2,0xf7,0x4d,0x77,0xbe,
+  0xcb,0xd3,0xd0,0x4c,0x33,0x02,0x76,0x6d,0x95,0x8b,0x57,0x2e,0xdc,0xb9,0x73,0xe7,
+  0x86,0x6b,0x3e,0x6b,0xdc,0x65,0x65,0x4f,0xcf,0xa9,0x87,0xa6,0x4c,0xff,0xe9,0x3f,
+  0xfd,0x6f,0xef,0xfe,0x4b,0x90,0x9e,0x3c,0x43,0xb3,0x1a,0x52,0x65,0xea,0x47,0x11,
+  0xc7,0x25,0x2d,0xab,0xc0,0x17,0x27,0xd0,0x0c,0x1e,0xe6,0x96,0x51,0x00,0xc4,0x6d,
+  0xb5,0x64,0xc9,0x92,0x68,0x9c,0x2b,0xcb,0x0d,0xdc,0x8c,0x25,0x41,0xf3,0xd6,0xa0,
+  0xe9,0x3f,0xfd,0xa7,0xff,0xed,0xd9,0x7f,0x31,0x84,0x24,0xca,0x5f,0x4a,0xfc,0x36,
+  0x63,0xbf,0x43,0x85,0xb1,0xeb,0x77,0xe6,0x6f,0x5c,0x53,0x08,0xdb,0xbc,0x0e,0x21,
+  0xdb,0x27,0x06,0xa0,0x8e,0x48,0xe9,0x5a,0xf1,0x02,0x48,0x59,0xdd,0x90,0x1b,0x5f,
+  0x2e,0xfe,0x7a,0x45,0xa8,0x02,0x00,0x94,0x49,0xf1,0x11,0xa3,0x49,0x04,0x7f,0x35,
+  0x05,0x7e,0x5a,0xc9,0xfa,0xb7,0xd5,0x43,0xb0,0x05,0x17,0xc6,0xcb,0xa6,0x15,0x0f,
+  0xaa,0x46,0x19,0x41,0x01,0xc8,0x51,0x9b,0x95,0xc9,0x6b,0x16,0x2d,0x5a,0x14,0x45,
+  0xbb,0xfa,0x0e,0x7e,0x72,0x18,0x00,0x00,0xa0,0xd5,0x91,0x82,0x3e,0x12,0x34,0x2d,
+  0xad,0x9e,0x16,0x7f,0xa3,0x95,0x0c,0x5b,0x8d,0x7f,0x9b,0x05,0x6f,0xab,0xb5,0x60,
+  0x93,0x0f,0x69,0xf3,0x0d,0x84,0x28,0x19,0x28,0x00,0x05,0x6a,0xb6,0x12,0xc4,0x22,
+  0x6e,0x2d,0x19,0x0e,0x90,0x26,0x11,0xff,0x92,0x1d,0x60,0x0a,0xfb,0xd8,0x0b,0x10,
+  0xcf,0x2a,0x08,0x00,0xd0,0x2a,0xcf,0x41,0x79,0xb6,0xc9,0xd8,0xbe,0x34,0x19,0xdb,
+  0x17,0xe1,0xdf,0x08,0x41,0xec,0xaa,0xbd,0x5f,0x94,0x27,0xc0,0x36,0x8d,0xaf,0x19,
+  0x98,0x67,0xab,0x20,0x68,0xc6,0x84,0xf9,0x5c,0xff,0x3e,0x65,0x20,0x29,0xf8,0xa9,
+  0x04,0xd8,0x00,0x6f,0x80,0xb8,0xb8,0x42,0xa6,0xb1,0x15,0x25,0xa1,0x0c,0x4a,0x00,
+  0x9e,0x88,0xda,0x1e,0x32,0x00,0x50,0x3e,0xea,0x35,0x1d,0xb0,0xab,0x2c,0x70,0xd6,
+  0x62,0x40,0xa1,0xf3,0x04,0x84,0x56,0x5b,0x34,0x15,0x13,0x14,0x80,0x92,0x21,0x45,
+  0x2f,0x44,0x09,0x68,0x74,0x3c,0x00,0x42,0x0c,0x00,0x5a,0x8d,0x7a,0x64,0x16,0x98,
+  0xc5,0x79,0x6c,0xd6,0xbe,0xcf,0x6a,0xcf,0x3a,0x76,0x5f,0xcd,0x24,0x44,0xa5,0x33,
+  0x94,0xb9,0x3c,0xff,0x7f,0xd9,0x4b,0x04,0x30,0x00,0x40,0xbe,0xd6,0x7f,0xd1,0xc3,
+  0x0e,0x3e,0xe1,0x9b,0x56,0xd7,0x3f,0x8b,0xd7,0xd5,0x54,0x10,0x6c,0x15,0x03,0x43,
+  0x26,0x15,0x42,0x01,0x40,0x09,0x00,0x00,0x68,0x79,0x6a,0x99,0x45,0xb0,0x16,0x45,
+  0xc0,0x25,0x90,0x6d,0xe3,0xfa,0x59,0x64,0x84,0xcd,0x9d,0xef,0x2a,0x0b,0x6c,0x2b,
+  0x16,0x84,0x02,0x50,0x62,0x44,0x53,0x95,0xb4,0x98,0x7a,0x8d,0x59,0x01,0x00,0xb4,
+  0x2a,0x32,0xb4,0x5a,0x0f,0xeb,0xdf,0xfc,0x3b,0x4b,0x66,0x57,0xe8,0x30,0x40,0xda,
+  0xf8,0xbf,0xcd,0x33,0xd0,0x2c,0x85,0x81,0x50,0x00,0x2c,0x5a,0x9e,0x5c,0xb8,0xf5,
+  0xd4,0x5c,0x01,0x00,0x5a,0x4d,0xf8,0xd7,0xab,0xaa,0xa0,0xcd,0xc2,0x4e,0xab,0xcb,
+  0xef,0x5b,0x57,0x9a,0x65,0x6f,0xf3,0x2a,0xd8,0x26,0x9e,0x72,0x15,0x19,0x42,0x01,
+  0x68,0x12,0x25,0x40,0x14,0x00,0xbc,0x01,0x00,0x00,0xd9,0x9e,0x9d,0x32,0x94,0x5a,
+  0x6f,0xe1,0x9f,0x66,0xb1,0xbb,0x04,0x6f,0xda,0xef,0x92,0x56,0x7c,0x5a,0x6d,0x00,
+  0xdb,0xf6,0x6d,0xe9,0xe6,0x65,0xf5,0x00,0x90,0x05,0x90,0xa6,0x1d,0x69,0xf7,0x95,
+  0x5c,0xcc,0x92,0x1d,0xb0,0x62,0xc5,0x0a,0xea,0x05,0x00,0x00,0xb8,0x84,0xc9,0x9a,
+  0x5a,0x03,0x8d,0x98,0xf5,0xcf,0x97,0x8b,0xef,0xb3,0xf6,0x6d,0xcb,0xb9,0xac,0xfc,
+  0xb4,0x14,0x42,0xdb,0xbe,0x50,0x0a,0xb8,0x45,0x14,0x01,0x39,0x91,0xa2,0x04,0x88,
+  0x42,0x20,0x8d,0x2a,0x82,0x00,0xd0,0xce,0xcf,0xc5,0x78,0x22,0x21,0x69,0x8d,0x74,
+  0x71,0xbb,0xc6,0xdc,0x5d,0xe5,0x7c,0x6d,0x41,0x82,0xae,0xcf,0x42,0xc6,0xf4,0x5d,
+  0x5e,0x84,0xb2,0x07,0x95,0xa3,0x00,0x64,0x40,0x4e,0x66,0xb3,0xce,0x96,0x05,0x00,
+  0xd0,0x6e,0xcf,0x6b,0xd3,0xd2,0xaf,0x36,0x38,0x30,0x4d,0x11,0xf0,0x6d,0xbf,0xd4,
+  0x4a,0x1c,0x97,0x09,0x00,0x00,0x34,0x2b,0xbe,0x68,0x7d,0xd3,0x22,0xf7,0x59,0xfa,
+  0x66,0x2a,0x9f,0xb9,0xde,0x34,0xc1,0xee,0xdb,0x3e,0x1e,0x00,0x00,0x00,0x80,0x9c,
+  0x2d,0x7d,0x9b,0x20,0x0e,0x89,0xea,0x77,0x09,0xe7,0xac,0x31,0x05,0xa1,0xdb,0xc7,
+  0x03,0x00,0x00,0x00,0x90,0x93,0xf5,0x9f,0x56,0x74,0x27,0x99,0x9b,0x6f,0x2b,0x0c,
+  0x14,0xa2,0x0c,0xa4,0x6d,0x37,0xf9,0x99,0x6b,0xd8,0xa1,0xac,0xf1,0x62,0x28,0x00,
+  0x00,0x00,0xd0,0xb4,0xd6,0xbf,0xe9,0xda,0x37,0xdd,0xfa,0xb6,0xea,0x80,0xd5,0x5a,
+  0xff,0xae,0xed,0xdb,0x84,0xbe,0x6b,0xfb,0x28,0x00,0x00,0x00,0x00,0x39,0x78,0x00,
+  0xd2,0xea,0xfb,0x57,0x33,0x8e,0x6f,0xfb,0xde,0x5c,0x87,0x2d,0x8e,0x20,0xcb,0xf6,
+  0x51,0x00,0x00,0x00,0x00,0x72,0xf2,0x04,0x24,0x05,0x72,0xfc,0xde,0x25,0xf4,0x43,
+  0xac,0x7e,0xb3,0x18,0x90,0x29,0xd0,0x6b,0xd9,0x3e,0x0a,0x00,0x00,0x00,0x40,0x0e,
+  0x5e,0x80,0x90,0x29,0x78,0x7d,0xae,0x7f,0xf3,0x37,0xf1,0xb0,0x82,0x2d,0x93,0xc0,
+  0x8c,0x27,0xa8,0x66,0xfb,0x28,0x00,0x00,0x00,0x00,0x35,0x5a,0xfe,0xa6,0x80,0x0d,
+  0x11,0xb6,0xb6,0x40,0x3d,0xdb,0xfb,0xa4,0x22,0x10,0x2a,0xe0,0x6b,0x99,0x75,0x10,
+  0x05,0x00,0x00,0x00,0x20,0xc0,0xfa,0xaf,0x66,0xd9,0x34,0x21,0x6f,0xa6,0xee,0xa5,
+  0xd5,0xf5,0x0f,0x4d,0xf7,0x23,0x0b,0x00,0x00,0x00,0xa0,0x81,0xde,0x82,0xa4,0xc0,
+  0xb6,0x05,0xfa,0x99,0x63,0xfd,0xb6,0xb4,0x41,0x9b,0x65,0x1f,0xe2,0x7d,0x20,0x06,
+  0x00,0x00,0x00,0xa0,0x20,0x0f,0x80,0xaf,0x3e,0xbf,0xf9,0xb7,0x2b,0xf0,0xaf,0xda,
+  0x92,0xc1,0xcd,0x32,0x09,0x10,0x0a,0x00,0x00,0x00,0x34,0xbd,0x55,0x9f,0x14,0xb6,
+  0x21,0x95,0xff,0x5c,0xb3,0xfa,0xb9,0xdc,0xf8,0xd5,0xd6,0xff,0x2f,0xf3,0x34,0xc0,
+  0x28,0x00,0x00,0x00,0xd0,0x12,0x5e,0x00,0xdb,0xd8,0xbc,0x6b,0x7a,0x5e,0xd7,0xd4,
+  0xbd,0x2e,0xeb,0xdd,0xe5,0xba,0x4f,0xfb,0x5d,0xda,0xf6,0xcb,0x04,0x73,0x01,0x00,
+  0x00,0x40,0x4b,0x28,0x02,0xa6,0x35,0x6e,0xb3,0xf2,0x6d,0x82,0x39,0x4d,0x48,0x87,
+  0x8e,0xe9,0xa7,0x05,0x0b,0x96,0x55,0x09,0xc0,0x03,0x00,0x00,0x00,0x4d,0x6d,0xfd,
+  0xdb,0x22,0xf9,0x6d,0x9e,0x01,0x97,0xc0,0x4e,0xfb,0xde,0x37,0xce,0x6f,0xdb,0xbe,
+  0xcb,0x33,0x81,0x02,0x00,0x00,0x00,0x50,0xa0,0x17,0x20,0x24,0x5a,0xdf,0x87,0x6b,
+  0x62,0x9f,0x6a,0xbd,0x11,0x28,0x00,0x00,0x00,0x00,0x05,0x79,0x01,0x5c,0x02,0x3b,
+  0x4d,0x70,0xfb,0xb2,0x05,0x5c,0xf5,0x02,0x4c,0xeb,0xdf,0xac,0x08,0x58,0xf6,0x79,
+  0x00,0x50,0x00,0x00,0x00,0xa0,0x69,0xc9,0xc3,0xc5,0x9e,0x56,0xb8,0xc7,0x9c,0x65,
+  0x30,0xa9,0x08,0xa4,0x59,0xfc,0x65,0x16,0xfa,0x28,0x00,0x00,0x00,0xd0,0x32,0xd6,
+  0x7f,0x88,0xe0,0x75,0x45,0xeb,0x9b,0x02,0xdf,0x96,0x36,0x98,0x6c,0xbe,0xb2,0xc0,
+  0xcd,0x20,0xf8,0x51,0x00,0x00,0x00,0xa0,0x25,0x94,0x80,0x90,0xcf,0x6c,0x96,0xbe,
+  0x19,0xc0,0x97,0xfc,0xcc,0x14,0xf0,0x2e,0x6f,0x43,0xd9,0x67,0xfc,0x4b,0x83,0x34,
+  0x40,0x00,0x00,0x68,0x29,0x5c,0x65,0x7e,0xb3,0xa4,0x00,0xba,0xea,0xfe,0xa7,0xfd,
+  0x26,0xcd,0xfb,0x40,0x29,0x60,0x00,0x00,0x80,0x82,0x3c,0x01,0xae,0x09,0x7f,0x6c,
+  0x11,0xfd,0xbe,0xf7,0x69,0x25,0x81,0x43,0x84,0xbf,0x6d,0xfb,0x78,0x00,0x00,0x00,
+  0x00,0x72,0x14,0xfc,0xb6,0xc9,0x7d,0x5c,0xc5,0x78,0x7c,0x9e,0x00,0x73,0x19,0xdf,
+  0x76,0x5d,0x5e,0x87,0xb4,0x32,0xc5,0x78,0x00,0x00,0x00,0x00,0x6a,0x24,0x29,0xb8,
+  0x4d,0xcb,0xdb,0x57,0xa0,0xc7,0x65,0xc1,0x87,0x04,0xf2,0xb9,0xea,0x03,0xf8,0xb6,
+  0x8f,0x02,0x00,0x00,0x00,0x90,0xb3,0x07,0xc0,0xac,0xbe,0x67,0x9b,0x07,0x20,0x29,
+  0xb0,0xb3,0x08,0x65,0x9f,0x90,0x77,0x79,0x05,0x98,0x0c,0x08,0x00,0x00,0xa0,0x0e,
+  0x8a,0x40,0x9a,0xa0,0xaf,0xa5,0x42,0x9f,0xab,0xd8,0x90,0x4d,0xf8,0xdb,0xbc,0x12,
+  0x0c,0x01,0x00,0x00,0x00,0xe4,0x28,0xf4,0xcd,0xbf,0xcd,0xe0,0xbd,0x34,0xc1,0xbb,
+  0x7a,0xf5,0xea,0x54,0x2b,0x3f,0x6d,0x3b,0xa6,0x90,0xf7,0x6d,0x9f,0x21,0x00,0x00,
+  0x00,0x80,0x1c,0xb1,0x15,0xef,0x09,0xad,0xdf,0xef,0x0a,0xdc,0x73,0x59,0xf6,0xa6,
+  0xf0,0xcf,0xb2,0x7d,0x3c,0x00,0x00,0x00,0x00,0x39,0x0b,0x7f,0x9f,0xc5,0x9e,0xe6,
+  0x3d,0x70,0x55,0x08,0x74,0xd5,0x09,0x70,0x65,0x11,0xb8,0xb6,0x8f,0x07,0x00,0x00,
+  0x00,0x20,0x67,0xf2,0x9c,0x03,0xc0,0x16,0x1f,0xe0,0x9a,0xf4,0xc7,0xa6,0x08,0x84,
+  0xae,0x17,0x05,0x00,0x00,0x00,0xa0,0x0e,0xca,0x81,0xab,0x74,0xaf,0x4d,0xb8,0x9b,
+  0x82,0x3e,0xcd,0x7a,0xf7,0xc5,0x0b,0x94,0x7d,0x26,0x40,0x14,0x00,0x00,0x00,0x68,
+  0x49,0x6c,0xd5,0xff,0x42,0x83,0x03,0x5d,0xd9,0x02,0x59,0x84,0xb9,0x6d,0xfb,0x65,
+  0x83,0x4a,0x80,0x00,0x00,0xd0,0xd4,0x96,0x7e,0x5a,0xc0,0x5e,0x9a,0x20,0xb7,0xb9,
+  0xf6,0x93,0xcb,0x66,0xb5,0xe2,0x5d,0xdb,0x2f,0x6b,0x3d,0x00,0x14,0x00,0x00,0x00,
+  0x68,0x7a,0x4b,0xdf,0x66,0xc1,0xbb,0xa6,0xf7,0x35,0x05,0xb2,0x2d,0xc8,0xaf,0x16,
+  0x81,0x1d,0x12,0x1b,0x50,0x06,0x18,0x02,0x00,0x00,0x80,0xa6,0xb5,0xfe,0xe3,0xd7,
+  0xb4,0xa2,0x3b,0xc9,0xfc,0x7c,0x5f,0x59,0xe0,0x6a,0x32,0x08,0x6c,0xf1,0x04,0xb6,
+  0x6d,0xa3,0x00,0x00,0x00,0x00,0xe4,0x64,0xfd,0x27,0x03,0xf8,0xd2,0xea,0xfe,0xbb,
+  0xc6,0xf1,0xb3,0x4c,0xeb,0xeb,0xdb,0xbe,0xf9,0x99,0x6d,0xfb,0x65,0x82,0x21,0x00,
+  0x00,0x00,0x68,0x5a,0x0f,0x80,0x2f,0x35,0xcf,0x36,0x8e,0xef,0x1b,0x93,0xf7,0x8d,
+  0xe3,0xbb,0xe6,0x1b,0x48,0xab,0x19,0x80,0x07,0x00,0x00,0x00,0xa0,0x00,0x4f,0x80,
+  0x69,0xf1,0xa7,0xb9,0xdd,0x5d,0x56,0xbf,0xad,0xac,0xaf,0x69,0xdd,0x57,0xbb,0x7d,
+  0x3c,0x00,0x00,0x00,0x00,0x39,0x7b,0x01,0x92,0xd6,0x76,0xb5,0x11,0xfb,0xae,0xb2,
+  0xc0,0xbe,0x8c,0x01,0xdb,0xf6,0x6d,0x1e,0x06,0x3c,0x00,0x00,0x00,0x00,0x39,0x5b,
+  0xfe,0x69,0x56,0x7d,0xe8,0x6f,0x5d,0x01,0x85,0x49,0xe1,0x6e,0x2a,0x0e,0xae,0xed,
+  0x97,0xb9,0xf8,0x0f,0x0a,0x00,0x00,0x00,0xb4,0x8c,0xf5,0x9f,0x26,0xe4,0x5d,0xb5,
+  0xfa,0x4d,0x81,0xee,0x9b,0xd4,0xc7,0xe6,0x15,0xc8,0x32,0xd1,0x0f,0x1e,0x00,0x00,
+  0x00,0x80,0x06,0x78,0x09,0x5c,0xb5,0xfb,0x93,0x02,0xda,0x5c,0x36,0xb4,0xac,0x6f,
+  0x88,0x70,0xa7,0x0e,0x00,0x00,0x00,0x40,0x41,0x1e,0x00,0x5f,0x7d,0x7e,0x53,0xd8,
+  0xdb,0x3e,0xcf,0x12,0xbc,0x57,0xed,0xf6,0x51,0x00,0x00,0x00,0x00,0x72,0xb0,0xee,
+  0xd3,0x2a,0xef,0xf9,0x2a,0x01,0xfa,0x5c,0xff,0xa1,0x71,0x04,0xa1,0xdb,0x47,0x01,
+  0x00,0x00,0x00,0xc8,0xc9,0x0b,0x60,0x1b,0x9b,0x0f,0xc9,0xcd,0x4f,0x8b,0x11,0xf0,
+  0x79,0x00,0xd2,0x7e,0x97,0xb6,0xfd,0x32,0x41,0x1a,0x20,0x00,0x00,0xb4,0x84,0x22,
+  0x60,0x5a,0xe3,0x69,0x82,0x3e,0xad,0x80,0x4f,0xda,0x7a,0x5d,0x8a,0x81,0x4d,0x69,
+  0x28,0xbb,0x12,0x80,0x07,0x00,0x00,0x00,0x9a,0xda,0xfa,0xb7,0x45,0xf2,0xdb,0x3c,
+  0x03,0x59,0xd2,0xf6,0x5c,0x81,0x7f,0xe6,0xef,0x6c,0xdb,0x77,0x79,0x26,0x50,0x00,
+  0x00,0x00,0x00,0x0a,0xf4,0x02,0xf8,0xa6,0x01,0x0e,0xc1,0x97,0xeb,0x5f,0xcd,0xf6,
+  0xcb,0x06,0x43,0x00,0x00,0x00,0xd0,0x12,0x5e,0x80,0x50,0x81,0x6c,0xfb,0xbd,0xf9,
+  0x3e,0x44,0x91,0xb0,0x55,0x07,0xb4,0x7d,0x46,0x0c,0x00,0x00,0x00,0x40,0x8e,0xd8,
+  0xca,0xff,0x66,0x1d,0x6f,0x77,0xd5,0x04,0x48,0xfb,0xce,0x55,0x0e,0xd8,0xb6,0x8e,
+  0x32,0xc3,0x10,0x00,0x00,0x00,0x34,0xb5,0xf5,0x1f,0x22,0x78,0x5d,0xd1,0xfa,0xf1,
+  0xab,0x2d,0x76,0x20,0xf9,0x9d,0xad,0xce,0x7f,0xb5,0xdb,0x47,0x01,0x00,0x00,0x00,
+  0xc8,0x41,0x09,0x08,0xf9,0xcc,0x66,0xcd,0x9b,0x01,0x7c,0xa6,0x07,0xc1,0x56,0xf7,
+  0x3f,0x2d,0x28,0x30,0x6d,0xac,0x9f,0xd9,0x00,0x01,0x00,0x00,0x0a,0xc6,0x66,0x95,
+  0xbb,0xd2,0xfe,0x5c,0x43,0x06,0xae,0xba,0xff,0x59,0x95,0x11,0x97,0xa7,0x00,0x05,
+  0x20,0xc1,0xca,0x95,0x2b,0xb9,0x6a,0x01,0x00,0x20,0x98,0xb9,0x73,0xe7,0x46,0xaf,
+  0x83,0x06,0x0d,0x4a,0x2d,0xfc,0x63,0x5a,0xfc,0x21,0xef,0xb3,0xba,0xec,0x5d,0x01,
+  0x84,0x49,0xef,0x02,0x0a,0x00,0x00,0x00,0x40,0x81,0x56,0x7f,0x5a,0xbe,0xbf,0x2b,
+  0x80,0x2f,0x29,0xf8,0x43,0x02,0x09,0x6d,0x35,0x00,0xd2,0x3c,0x08,0x4c,0x06,0x04,
+  0x00,0x00,0x90,0x33,0xe6,0xcc,0x7d,0x69,0x55,0xff,0x6c,0xe3,0xfa,0x36,0x45,0x21,
+  0x54,0xe1,0xb0,0x29,0x14,0xae,0xa9,0x86,0x51,0x00,0x00,0x00,0x00,0x72,0xb6,0xfe,
+  0x6d,0xd5,0xff,0x7c,0x56,0x79,0x16,0xa1,0xec,0x13,0xf2,0xb6,0x6d,0x96,0x79,0x1e,
+  0x00,0xa1,0x34,0x43,0x00,0x5d,0xbb,0x32,0x1a,0x01,0x00,0x00,0xe1,0xf4,0xeb,0xd7,
+  0x6f,0x1d,0x41,0x9c,0x7c,0xb5,0xa5,0xfb,0xd5,0xa2,0x64,0xa4,0x59,0xf4,0xb6,0xed,
+  0x9b,0xdf,0xe1,0x01,0x00,0x00,0x00,0xc8,0x01,0x57,0x4a,0x5e,0x68,0x6a,0x9e,0xaf,
+  0xce,0x7f,0xda,0x72,0x2e,0x25,0xc0,0xb5,0x7d,0x86,0x00,0x00,0x00,0x00,0x72,0xc4,
+  0x56,0xbc,0x27,0xb4,0x7e,0x7f,0x5a,0xa0,0x9e,0x19,0x14,0xe8,0x12,0xfe,0xa1,0xdb,
+  0x27,0x0d,0x10,0x00,0x00,0xa0,0x00,0x2f,0x40,0x48,0x10,0x9f,0x4f,0x78,0xdb,0xbe,
+  0xb7,0x59,0xf4,0x69,0xd3,0x0c,0xbb,0xb6,0x5f,0x46,0x0f,0x00,0x0a,0x00,0x00,0x00,
+  0xb4,0x8d,0xb7,0xc0,0x65,0x8d,0xdb,0x26,0xfe,0x09,0x99,0xf4,0xa7,0x99,0x61,0x08,
+  0x00,0x00,0x00,0x9a,0xda,0xfa,0xf7,0x79,0x06,0x5c,0xf3,0x00,0xd8,0x72,0xf9,0xf3,
+  0x9a,0xec,0xa7,0xec,0x33,0x01,0xa2,0x00,0x00,0x00,0x40,0xd3,0x5b,0xf4,0x3e,0x6b,
+  0xdf,0xe5,0xca,0xf7,0x09,0x6f,0xdf,0x3c,0x00,0xd5,0x7a,0x1b,0xca,0x02,0x43,0x00,
+  0x00,0x00,0xd0,0xd4,0x5e,0x00,0x57,0x1e,0xbe,0xcd,0xad,0x6f,0x0a,0xf8,0xb4,0xca,
+  0x7f,0x69,0x56,0xbc,0x6b,0x26,0xc0,0xd0,0x00,0x44,0x14,0x00,0x00,0x00,0x80,0x9c,
+  0xbd,0x00,0x69,0x11,0xfa,0x79,0x05,0xe8,0x85,0x7a,0x10,0xca,0x5a,0x03,0x40,0x60,
+  0x08,0x00,0x00,0x00,0x9a,0xd6,0xfa,0x8f,0x5f,0x6d,0x95,0xf9,0x92,0xcb,0xa5,0xa5,
+  0xf4,0xd5,0xb2,0xdd,0xe4,0xfa,0x5d,0x02,0xbf,0x9a,0xc9,0x85,0x50,0x00,0x00,0x00,
+  0x00,0x52,0xac,0x70,0x73,0xd6,0x3d,0x5f,0xdd,0xff,0xb4,0xe2,0x3f,0x59,0x3d,0x02,
+  0xb6,0xc9,0x80,0x42,0xe6,0x1d,0x28,0x0b,0x0c,0x01,0x00,0x00,0x40,0xd3,0x7a,0x00,
+  0x5c,0xd3,0xf7,0xd6,0x52,0xf7,0xdf,0x55,0xc8,0x27,0xeb,0xfb,0x6a,0xb7,0x8f,0x07,
+  0x00,0x00,0x00,0x20,0xa3,0xc0,0x4e,0x0a,0xee,0xac,0x93,0xfd,0xd8,0x26,0xfc,0x31,
+  0xad,0x7b,0xdb,0x36,0x6d,0x41,0x88,0x65,0x75,0xfb,0xe3,0x01,0x00,0x00,0x80,0x96,
+  0xf1,0x02,0x98,0xd6,0x77,0x16,0xef,0x81,0x4b,0x89,0x08,0xcd,0x18,0x30,0xbf,0x6f,
+  0xa6,0xe2,0x40,0x78,0x00,0x00,0x00,0xa0,0x65,0x14,0x01,0xdf,0x67,0x36,0x81,0x6f,
+  0x06,0x11,0x9a,0x6e,0xfb,0x90,0x71,0xfd,0x66,0xac,0x0a,0x88,0x02,0x00,0x00,0x00,
+  0x2d,0x49,0x5a,0xad,0x7e,0x53,0xa0,0xbb,0xe6,0x05,0x48,0xf3,0x0a,0x64,0xf5,0x38,
+  0xa0,0x00,0x00,0x00,0x00,0xd4,0x51,0x09,0x30,0x95,0x01,0x57,0x9a,0x9e,0x2b,0x63,
+  0xa0,0xd6,0x40,0xbe,0xb2,0xd6,0x02,0x40,0x01,0x00,0x00,0x80,0xa6,0xc4,0x96,0xd2,
+  0x17,0x32,0x3b,0x5f,0xda,0xac,0x7f,0x59,0xc6,0xf1,0xd3,0x52,0x0a,0xcd,0x7d,0x59,
+  0xbd,0x7a,0x35,0x0a,0x00,0x00,0x00,0x40,0x9e,0xd6,0xbd,0x59,0x0b,0x20,0x69,0xf1,
+  0xbb,0x8a,0xff,0xa4,0x55,0xeb,0x0b,0xb5,0xd6,0x7d,0xb3,0x0a,0x96,0x55,0xf0,0xc7,
+  0x90,0x05,0x00,0x00,0x00,0x4d,0xed,0x05,0x30,0xc7,0xed,0x5d,0xb9,0xf8,0x49,0x81,
+  0x6f,0xbe,0xf7,0xcd,0xfe,0xe7,0xda,0xae,0xf9,0x3b,0xf9,0x4c,0x84,0x7e,0x72,0xbf,
+  0xe4,0x6f,0x0a,0x01,0x01,0x00,0x00,0x14,0xa4,0x08,0x98,0xd6,0x79,0x9a,0xa0,0x77,
+  0x7d,0x1f,0xba,0x1d,0xd3,0xc3,0x60,0x1b,0x3a,0xc8,0xaa,0x54,0xd4,0x1b,0x86,0x00,
+  0x00,0x00,0xa0,0xa9,0xad,0x7f,0x57,0xae,0xbe,0x6d,0x88,0x20,0x54,0x38,0x9b,0x69,
+  0x81,0xa6,0x02,0x21,0x56,0x7d,0xec,0xde,0x4f,0xfe,0x3e,0xb6,0xfe,0xe3,0xd7,0xac,
+  0x71,0x05,0x78,0x00,0x00,0x00,0x00,0x32,0xe0,0x72,0xe7,0xa7,0x79,0x09,0x42,0xbd,
+  0x09,0xa6,0x70,0x37,0x97,0x35,0x15,0x11,0x9b,0x72,0x81,0x02,0x00,0x00,0x00,0x50,
+  0xa0,0x17,0x20,0x54,0xe0,0x9b,0x9e,0x02,0x9b,0x17,0x21,0x19,0xc0,0xe7,0x2b,0xf3,
+  0x6b,0xfb,0xcc,0xfc,0x3d,0x0a,0x00,0x00,0x00,0x40,0x8e,0x56,0x7f,0x35,0xc2,0xd5,
+  0x36,0x1c,0x60,0x9b,0xde,0xd7,0xf6,0xb9,0x4b,0xc9,0x30,0xe3,0x01,0x5c,0xd3,0x03,
+  0xa3,0x00,0x00,0x00,0x00,0xd4,0x68,0xfd,0x67,0xf5,0x10,0xd8,0xca,0xfa,0x26,0x05,
+  0xb6,0x39,0xae,0x9f,0x65,0xfa,0x60,0xd7,0x70,0x40,0x59,0x63,0x00,0x08,0x02,0x04,
+  0x00,0x80,0x96,0x55,0x0c,0x4c,0x37,0xbf,0x29,0x8c,0x6d,0x6e,0xfa,0xb4,0x57,0x73,
+  0x1d,0xb6,0xb8,0x00,0x5b,0x70,0x20,0x1e,0x00,0x00,0x00,0x80,0x3a,0x92,0x14,0xc6,
+  0xa6,0x85,0x1e,0xe7,0xe7,0xbb,0x2c,0x74,0xd7,0x04,0x41,0xb6,0xdf,0xd8,0x0a,0xfe,
+  0x94,0x3d,0x0d,0x10,0x05,0x00,0x00,0x00,0x5a,0xc6,0xea,0x4f,0x13,0xe8,0x66,0x60,
+  0x9f,0xcd,0xca,0x77,0x09,0x6f,0x5b,0x51,0xa1,0xd0,0x54,0x42,0x3c,0x00,0x00,0x00,
+  0x00,0x05,0x08,0xfd,0x50,0x21,0xec,0x9b,0xdc,0xc7,0x55,0x4f,0x20,0x2d,0x66,0xc0,
+  0x37,0xe7,0x00,0x0a,0x00,0x00,0x00,0x40,0x81,0x4a,0x80,0x2b,0x75,0xcf,0xb6,0x7c,
+  0x68,0xce,0x7e,0xb2,0x84,0xaf,0x6b,0x38,0xc0,0xa5,0x00,0x54,0x5b,0x69,0x10,0x05,
+  0x00,0x00,0x00,0x20,0x40,0xf8,0xbb,0xd2,0xf5,0xd2,0x84,0x72,0x9a,0x7b,0xdf,0x14,
+  0xd6,0xc9,0x18,0x02,0xd7,0x30,0x40,0x9a,0x27,0x20,0xa9,0x4c,0xa0,0x00,0x00,0x00,
+  0x00,0xe4,0x6c,0xfd,0x87,0x4c,0xff,0xeb,0xf2,0x0e,0xd8,0x4a,0xfd,0xfa,0xaa,0xf9,
+  0xd9,0x3c,0x09,0xc9,0xbf,0xcb,0x5e,0x04,0x08,0x05,0x00,0x00,0x00,0x9a,0x16,0x9b,
+  0x8b,0x3e,0x8b,0xd5,0x6f,0xce,0xd2,0x17,0x32,0x9e,0x9f,0xfc,0x9d,0x99,0x02,0x98,
+  0x26,0xf4,0x19,0x02,0x00,0x00,0x00,0x28,0xc0,0x0b,0xe0,0x12,0xba,0x3e,0xd7,0xbc,
+  0xed,0x33,0x9b,0x52,0xe1,0xf2,0x14,0x84,0x2a,0x22,0x9f,0xf9,0xcc,0x67,0x50,0x00,
+  0x00,0x00,0x00,0x8a,0x52,0x00,0x92,0xae,0xfe,0x58,0x28,0x27,0xf3,0xfd,0x43,0x14,
+  0x88,0xb4,0xd8,0x02,0x73,0xfd,0xbe,0xcc,0x02,0xe1,0xd8,0x63,0x8f,0x55,0xbb,0xec,
+  0xb2,0x4b,0xe9,0x8e,0x1d,0x95,0x00,0x01,0x00,0xa0,0x69,0x85,0xbf,0x59,0x91,0xcf,
+  0x35,0x69,0x8f,0x2f,0x8a,0xdf,0x35,0xe5,0x6f,0x48,0x6c,0x80,0x6b,0x5d,0xf2,0xfb,
+  0xa3,0x8f,0x3e,0x5a,0x7d,0xf4,0xa3,0x1f,0x2d,0xe5,0x7c,0x00,0x78,0x00,0x00,0x00,
+  0xa0,0x29,0xb1,0x59,0xf6,0xc9,0xf1,0x79,0xd3,0x82,0x77,0x59,0xec,0x49,0xa5,0xc1,
+  0x5c,0xa7,0xf9,0x77,0x9a,0x17,0x21,0xb9,0x5d,0xf9,0xec,0xa8,0xa3,0x8e,0x52,0xdb,
+  0x6c,0xb3,0x4d,0xc7,0x72,0xf2,0x79,0xdc,0x92,0xc4,0x7f,0xd7,0x5b,0x49,0x40,0x01,
+  0x00,0x00,0x80,0x96,0xf0,0x02,0xb8,0x2c,0xf3,0xe4,0x72,0x69,0x69,0x83,0xbe,0x39,
+  0x00,0x6c,0xdb,0x76,0xcd,0x35,0xb0,0xf7,0xde,0x7b,0xab,0x2d,0xb7,0xdc,0x32,0x55,
+  0xe8,0xa7,0x29,0x03,0x28,0x00,0x00,0x00,0x00,0x29,0xc2,0xdf,0xf6,0x3e,0xe9,0x0d,
+  0x30,0xbf,0xb3,0xcd,0xfe,0x67,0xce,0x0d,0x90,0xb6,0x7e,0x33,0x06,0x20,0x7e,0x9f,
+  0xcc,0x00,0x18,0x31,0x62,0x84,0xda,0x75,0xd7,0x5d,0xd7,0x12,0xf2,0x66,0x33,0x49,
+  0x7e,0x56,0x2f,0x25,0x00,0x05,0x00,0x00,0x00,0x5a,0x46,0x09,0x48,0x2b,0xd5,0x6b,
+  0x0a,0xea,0x90,0x71,0x7d,0x53,0x20,0x27,0x87,0x18,0x5c,0xeb,0x91,0x71,0xff,0xce,
+  0x9d,0x3b,0xa7,0x2a,0x00,0x3e,0x85,0xa0,0x1e,0x10,0x04,0x08,0x00,0x00,0x4d,0x89,
+  0x6d,0xa6,0x3f,0xdb,0x67,0xf1,0xe7,0xb6,0x80,0x41,0x73,0x7a,0x5f,0xdb,0xdf,0xb2,
+  0x7c,0xdc,0x92,0xdb,0x35,0xd7,0x33,0x7f,0xfe,0x7c,0x75,0xf2,0xc9,0x27,0xab,0xae,
+  0x5d,0xbb,0x5a,0x85,0xbc,0x4d,0x29,0x68,0x24,0x0d,0x57,0x00,0xe4,0x40,0x01,0x00,
+  0x00,0x54,0x23,0xfc,0xcd,0x62,0x3c,0xa6,0x62,0x60,0xbe,0xda,0x04,0xbd,0x2b,0x86,
+  0xc0,0x35,0xee,0x6f,0xcb,0x3e,0x98,0x33,0x67,0x8e,0xfa,0xc2,0x17,0xbe,0xa0,0xfa,
+  0xf4,0xe9,0xd3,0x21,0xec,0xcd,0xe6,0x52,0x02,0x1a,0xa5,0x10,0x34,0x5c,0x01,0xe8,
+  0xdb,0xb7,0x2f,0x57,0x32,0x00,0x00,0x64,0x56,0x00,0x92,0x6e,0xf8,0xa4,0x35,0xee,
+  0xb2,0xe4,0xd3,0xd2,0xfe,0xe2,0xdf,0xbb,0xbc,0x0a,0xa6,0x17,0x21,0xf9,0xfb,0xd9,
+  0xb3,0x67,0x47,0x85,0x7e,0x86,0x0f,0x1f,0x1e,0x09,0xf8,0x2e,0x5d,0xba,0x74,0xbc,
+  0xc6,0xcd,0x54,0x02,0x4c,0x45,0x20,0xa6,0x9e,0x19,0x01,0x0d,0x57,0x00,0x7a,0xf5,
+  0xea,0xc5,0x95,0x0c,0x00,0x00,0x99,0x58,0xb5,0x6a,0x95,0xd5,0x92,0x77,0xb5,0xa4,
+  0x05,0x6f,0x0a,0x79,0xdb,0xe7,0xb1,0x82,0xe1,0xab,0x06,0x28,0x96,0xbf,0x14,0xfa,
+  0xd9,0x78,0xe3,0x8d,0xd7,0x11,0xfe,0x49,0xeb,0xdf,0x54,0x06,0x4c,0xe1,0xdf,0x96,
+  0x1e,0x80,0x81,0x03,0x07,0x72,0x25,0x03,0x00,0x40,0x4d,0x0a,0x40,0x88,0x32,0x60,
+  0x0a,0x78,0xf3,0xf7,0x69,0x7f,0xdb,0x94,0x85,0x79,0xf3,0xe6,0xa9,0xcf,0x7f,0xfe,
+  0xf3,0x6a,0xec,0xd8,0xb1,0xeb,0x08,0x79,0x69,0x32,0xc4,0x2d,0xcd,0xf4,0x02,0x98,
+  0xc3,0x02,0x8d,0x8a,0x07,0x68,0xb8,0x02,0xb0,0xe1,0x86,0x1b,0x72,0x25,0x03,0x00,
+  0x40,0x26,0x42,0x2c,0xfe,0xb4,0x21,0x80,0xf8,0x33,0xc1,0x15,0x14,0x98,0xf6,0xfb,
+  0xa5,0x4b,0x97,0xaa,0x2f,0x7d,0xe9,0x4b,0x6b,0xb9,0xfd,0x5d,0x82,0x3f,0xf9,0xde,
+  0x36,0x1c,0x60,0xba,0xfd,0xdb,0x26,0x0d,0x70,0x83,0x0d,0x36,0xe0,0x4a,0x06,0x00,
+  0x80,0x4c,0xd6,0x7f,0xf7,0xee,0xdd,0xd7,0x49,0xf7,0x33,0x0b,0xf3,0x98,0x42,0xde,
+  0x95,0xef,0x9f,0x5c,0xce,0xf5,0x3e,0xb9,0x1e,0x09,0xf4,0x93,0x80,0xbf,0x1e,0x3d,
+  0x7a,0x58,0x05,0xbf,0xad,0xb9,0xbc,0x00,0xb6,0xa1,0x80,0x7a,0xd1,0x70,0x05,0x60,
+  0xe8,0xd0,0xa1,0x5c,0xcd,0x00,0x00,0x10,0x2c,0xfc,0x63,0x8b,0x3d,0x6d,0x32,0x9e,
+  0x90,0x7c,0x7f,0x73,0xaa,0x60,0x57,0xc9,0xdf,0xe4,0x3a,0xb7,0xda,0x6a,0x2b,0xb5,
+  0xe7,0x9e,0x7b,0xae,0x35,0xd6,0xef,0x12,0xfa,0xdd,0xba,0x75,0xf3,0x2a,0x02,0x8d,
+  0xcc,0x02,0x28,0x85,0x07,0x40,0x0e,0x46,0x3c,0x9e,0x03,0x00,0x00,0x90,0x26,0xfc,
+  0x93,0xc5,0x78,0x42,0xa6,0xe5,0xf5,0x59,0xf5,0xf1,0x7b,0x9b,0x17,0x21,0xb9,0xcc,
+  0xc1,0x07,0x1f,0xac,0x46,0x8f,0x1e,0x6d,0xb5,0xf8,0x45,0xd8,0xbb,0x9a,0x29,0xfc,
+  0x93,0x81,0x80,0x49,0x45,0xa0,0xde,0xd4,0x25,0x06,0xc0,0xd5,0x31,0xf9,0x5c,0x0e,
+  0x8e,0xd4,0x4b,0x06,0x00,0x00,0x48,0x13,0xfe,0x2b,0x57,0xae,0xb4,0x96,0xf7,0x75,
+  0xa5,0xe7,0xb9,0xc6,0xf1,0x4d,0xcb,0xdf,0x57,0x37,0x40,0xda,0xa7,0x3f,0xfd,0xe9,
+  0xb5,0x84,0x7f,0x52,0x01,0x48,0x0a,0x7b,0x19,0x9a,0x88,0x9b,0x4d,0x09,0x90,0x96,
+  0xcc,0x12,0x68,0x64,0x26,0x40,0xa1,0x0a,0x80,0xab,0xde,0xb1,0xd9,0xc9,0xad,0xb7,
+  0xde,0x9a,0xab,0x1b,0x00,0x00,0xac,0x88,0xe0,0x97,0x96,0x14,0xd8,0xb6,0xbc,0x7f,
+  0x9b,0xd0,0xb7,0x7d,0x66,0x56,0x05,0x34,0x97,0x31,0x97,0x17,0xe1,0xbf,0xfe,0xfa,
+  0xeb,0x7b,0x85,0xbf,0xcf,0x03,0xe0,0x1b,0x02,0xf0,0x19,0xcd,0x79,0x53,0xc8,0x10,
+  0x40,0xda,0xcc,0x47,0xb6,0x65,0x37,0xdb,0x6c,0x33,0xae,0x70,0x00,0x00,0x70,0x0a,
+  0xff,0xa4,0x30,0x37,0x05,0xbb,0xe9,0xaa,0x37,0x95,0x02,0x73,0xd2,0x1f,0xdf,0x94,
+  0xc0,0xc9,0x75,0x1d,0x71,0xc4,0x11,0x1d,0x43,0xd5,0x49,0xe1,0x6f,0x13,0xf4,0x36,
+  0xeb,0xdf,0x14,0xfe,0xb6,0xca,0x80,0x8d,0xb0,0xfe,0x0b,0xf7,0x00,0x84,0x7a,0x01,
+  0xa4,0x18,0xd0,0x76,0xdb,0x6d,0xc7,0x95,0x0e,0x00,0x00,0x6b,0x09,0xff,0x15,0x2b,
+  0x56,0xac,0x25,0xa4,0x6d,0x29,0x7b,0x2e,0x8b,0x3e,0x7e,0x75,0xe5,0xff,0xbb,0xaa,
+  0x07,0xc6,0xef,0x45,0xf8,0x4b,0xa0,0x7a,0x9a,0xf0,0x4f,0x0a,0xfd,0xa4,0xf0,0xb7,
+  0x0d,0x01,0xb8,0x52,0x01,0x1b,0x61,0xfd,0x17,0xe6,0x01,0x70,0x29,0x01,0x69,0x9e,
+  0x01,0x99,0x3a,0xf1,0xc5,0x17,0x5f,0xe4,0x8a,0x07,0x00,0x80,0x48,0xf0,0xc7,0x96,
+  0xbf,0xad,0x5e,0xbf,0x29,0xe4,0x93,0xd6,0xbd,0x6b,0x26,0xc0,0xb4,0x38,0x81,0x78,
+  0xf9,0xfe,0xfd,0xfb,0xab,0x71,0xe3,0xc6,0x75,0x8c,0xf7,0x27,0x23,0xfd,0xe5,0xd5,
+  0x27,0xfc,0x5d,0xe3,0xff,0x69,0x95,0x00,0x1b,0x55,0x08,0xa8,0x6e,0x59,0x00,0xa6,
+  0x86,0x63,0x36,0x29,0xa6,0x30,0x72,0xe4,0x48,0x35,0x6d,0xda,0x34,0xae,0x7c,0x00,
+  0x80,0x36,0x17,0xfe,0xb1,0xe5,0x6f,0x0a,0xef,0xe4,0x54,0xbc,0x49,0xd7,0x7e,0x32,
+  0xed,0x2f,0x29,0xd8,0x4d,0x65,0xc0,0x1c,0x06,0x88,0x3f,0xfb,0xe8,0x47,0x3f,0x1a,
+  0xc5,0xa3,0xf5,0xee,0xdd,0x3b,0xfa,0xcc,0x55,0xdc,0xc7,0x25,0xfc,0xa5,0x26,0x80,
+  0x4d,0x09,0xf0,0x0d,0x01,0x34,0xaa,0x06,0x40,0x21,0x0a,0x80,0x79,0xa0,0x6d,0xd6,
+  0xbe,0xab,0xed,0xb7,0xdf,0x7e,0xea,0xaa,0xab,0xae,0xe2,0xea,0x07,0x00,0x68,0x73,
+  0xe1,0x6f,0x0a,0xe8,0x18,0xd3,0xc5,0xef,0xca,0xdd,0x37,0x2d,0x7e,0x9b,0xe5,0x2f,
+  0x95,0x68,0xc5,0xfb,0x2c,0x01,0x7e,0x49,0x19,0x95,0xac,0xdf,0x9f,0xb4,0xfc,0x63,
+  0x05,0x20,0x4d,0xf8,0xdb,0x02,0x00,0x7d,0xf3,0x00,0x34,0x8a,0xc2,0x3d,0x00,0xae,
+  0x09,0x0f,0x6c,0xf3,0x24,0x0f,0x1b,0x36,0x4c,0x6d,0xb2,0xc9,0x26,0x6a,0xf2,0xe4,
+  0xc9,0xdc,0x05,0x00,0x00,0x6d,0xc6,0xf2,0xe5,0xcb,0xad,0x96,0xbf,0x59,0xac,0x27,
+  0x69,0xf5,0xbb,0x02,0x00,0x6d,0x7f,0xcb,0xfb,0x9e,0x3d,0x7b,0xaa,0xdd,0x76,0xdb,
+  0x4d,0x6d,0xba,0xe9,0xa6,0x91,0x40,0x8e,0x89,0x05,0xb3,0x39,0x93,0x9f,0x2f,0xd5,
+  0xaf,0x1a,0xcb,0xbf,0x0c,0xd6,0x7f,0xa1,0x0a,0x40,0x88,0xf5,0x6f,0x1e,0x04,0x39,
+  0x48,0x07,0x1d,0x74,0x90,0xba,0xfc,0xf2,0xcb,0xb9,0x13,0x00,0x00,0xda,0xd0,0xf2,
+  0x8f,0x05,0xb5,0x6d,0x0c,0xdf,0x66,0xd5,0x27,0x5d,0xff,0xae,0xdf,0x08,0x9b,0x6f,
+  0xbe,0x79,0xe4,0xe6,0x97,0x31,0xfe,0x58,0x71,0x30,0x65,0x51,0x56,0xe1,0x5f,0xcd,
+  0xd8,0x7f,0x59,0x84,0x7f,0x61,0x0a,0x40,0xb2,0x8a,0x92,0xaf,0x99,0x1a,0x91,0xd4,
+  0x58,0x96,0xa1,0x80,0xfb,0xef,0xbf,0x9f,0x3b,0x02,0x00,0xa0,0x4d,0x2c,0x7f,0x69,
+  0xa6,0xf0,0xb7,0xb9,0xf0,0x6d,0xa9,0x7a,0x36,0x17,0xbf,0x2c,0x27,0xc2,0xfe,0x63,
+  0x1f,0xfb,0x58,0x14,0x5f,0x96,0x5c,0x36,0x29,0x84,0x4d,0xcb,0x3c,0xe9,0xf6,0xb7,
+  0x09,0xff,0xf8,0xd5,0x74,0xfb,0x9b,0xc2,0xdf,0x9c,0x19,0xd0,0x55,0xf6,0xb7,0x91,
+  0xc3,0x00,0x0d,0xc9,0x02,0xb0,0x1d,0xf4,0xe4,0x67,0x12,0x88,0x31,0x71,0xe2,0x44,
+  0x35,0x75,0xea,0x54,0xee,0x0c,0x00,0x80,0x36,0x10,0xfe,0xb6,0x2a,0x7d,0x36,0x81,
+  0x6f,0xab,0xe7,0x9f,0xfc,0x3c,0x19,0xd0,0x27,0x42,0xda,0x26,0x83,0xcc,0x99,0xf8,
+  0x5c,0x96,0xbf,0x19,0xf4,0x97,0x96,0xf6,0x67,0x0a,0x7f,0xd3,0xf5,0x6f,0x7a,0xbd,
+  0x1b,0x2d,0xfc,0x0b,0x55,0x00,0x7c,0xd6,0xbe,0x4d,0xeb,0x4a,0xfe,0x2d,0x35,0x97,
+  0xaf,0xbe,0xfa,0xea,0x68,0xca,0x45,0x00,0x00,0x68,0x4d,0xe1,0x2f,0xcf,0xf8,0xa4,
+  0x40,0xf4,0x05,0xf2,0x99,0xc2,0x3f,0x1e,0x02,0x18,0x31,0x62,0x44,0x34,0xb6,0xbf,
+  0xde,0x7a,0xeb,0xad,0xa5,0x0c,0xa4,0xc9,0xa2,0x50,0xe1,0xef,0x52,0x00,0x92,0x9f,
+  0x27,0x27,0xff,0x49,0x5a,0xfd,0xf2,0x5a,0x46,0xe1,0x1f,0x2b,0x00,0x32,0x0b,0x4f,
+  0x97,0xa2,0xad,0xff,0x34,0x97,0x8b,0xa9,0x04,0xc8,0xab,0x1c,0xd4,0xa3,0x8e,0x3a,
+  0x4a,0x5d,0x73,0xcd,0x35,0xce,0x31,0x1d,0x00,0x00,0x68,0x4e,0x96,0x2d,0x5b,0xd6,
+  0xe1,0xf6,0x77,0x4d,0xe2,0x63,0x8b,0xf4,0x4f,0x0a,0x4e,0x91,0x13,0xbb,0xef,0xbe,
+  0x7b,0x14,0x3c,0x2e,0x82,0x37,0x5e,0x26,0x59,0x5d,0xcf,0x74,0xbd,0xdb,0xe4,0x4e,
+  0x48,0x89,0x5f,0x53,0xe0,0xbb,0x6a,0xfd,0xdb,0xc6,0xfb,0xcd,0xc9,0x7e,0xca,0x20,
+  0xfc,0x45,0xf6,0x8b,0x02,0x20,0x67,0xa0,0x57,0x91,0x5b,0xf1,0x79,0x01,0x4c,0x6d,
+  0x29,0xfe,0xbc,0x6f,0xdf,0xbe,0xea,0xc8,0x23,0x8f,0x54,0x37,0xde,0x78,0x23,0x77,
+  0x0b,0x00,0x40,0x8b,0x20,0x56,0x7f,0x72,0xcc,0xdf,0x25,0xf8,0xcd,0xef,0x63,0x8b,
+  0x7f,0x8b,0x2d,0xb6,0xe8,0x08,0xe8,0x4b,0x0e,0x03,0xd8,0x84,0xbd,0x4f,0xf6,0xc8,
+  0x6b,0x72,0xcc,0xdf,0xa7,0x00,0x98,0xef,0x6d,0x75,0xfe,0xcd,0xd9,0xfe,0xca,0x64,
+  0xf5,0x27,0x1d,0x30,0xa2,0x00,0x2c,0x29,0x4a,0x01,0x70,0x45,0xfd,0xbb,0x34,0x2f,
+  0xd3,0x15,0x23,0xef,0x07,0x0d,0x1a,0xa4,0x0e,0x3d,0xf4,0x50,0x75,0xc7,0x1d,0x77,
+  0x70,0xd7,0x00,0x00,0xb4,0x80,0xe5,0x2f,0xcd,0xb4,0xec,0xcd,0xbf,0xcd,0x98,0x80,
+  0x01,0x03,0x06,0x44,0x01,0x7d,0xa3,0x46,0x8d,0x5a,0x6b,0x7d,0xae,0xaa,0x7a,0xa6,
+  0xbc,0x09,0xb5,0xfc,0x43,0x14,0x00,0x97,0xcb,0x3f,0x44,0xf8,0x97,0x48,0x09,0x58,
+  0xd2,0x49,0x1f,0xd8,0x89,0xfa,0xcd,0xd8,0xbc,0xd7,0x1c,0xd7,0x59,0x8e,0x5b,0x3c,
+  0x95,0x63,0x9c,0xea,0x11,0x5f,0x04,0xd2,0x44,0x1b,0x34,0x5b,0xfc,0x5d,0x9c,0x17,
+  0x3a,0x6f,0xde,0x3c,0x75,0xf3,0xcd,0x37,0x33,0x1c,0x00,0x00,0xd0,0xc4,0x96,0xbf,
+  0x3c,0xd7,0x6d,0x81,0x7c,0xb6,0xb2,0xbe,0xf2,0xba,0xe3,0x8e,0x3b,0xa6,0x06,0xf4,
+  0xb9,0x02,0xfb,0x42,0x05,0xbf,0x2d,0xea,0x3f,0xa9,0x00,0xd8,0x94,0x01,0x53,0x59,
+  0x30,0x3d,0xd8,0x4d,0x20,0xfc,0x85,0x49,0xe2,0x01,0x98,0x55,0x84,0x02,0x60,0x3b,
+  0x41,0x3e,0xeb,0xdf,0xd5,0x44,0x81,0xe8,0xd7,0xaf,0x9f,0x1a,0x3f,0x7e,0xbc,0xba,
+  0xed,0xb6,0xdb,0x08,0x0c,0x04,0x00,0x68,0x42,0xe1,0x9f,0x7c,0x76,0xbb,0x66,0xea,
+  0x13,0xa4,0x34,0xbc,0x8c,0xed,0x87,0x06,0xf4,0xf9,0x04,0xbf,0xe9,0x5d,0x76,0x09,
+  0xff,0xa4,0xf5,0x6f,0x53,0x02,0x6c,0x82,0xdf,0x37,0xe6,0x5f,0x52,0xe1,0x2f,0xcc,
+  0x12,0x05,0xa0,0xd0,0xe2,0xfb,0x21,0xc1,0x17,0xe6,0x41,0x95,0x26,0x1e,0x03,0x69,
+  0x49,0x2f,0x82,0x54,0x70,0x3a,0xfa,0xe8,0xa3,0xd5,0x43,0x0f,0x3d,0x44,0x8a,0x20,
+  0x00,0x40,0x93,0x09,0x7f,0x33,0x72,0x3f,0xf9,0x5e,0x5c,0xec,0x12,0xc5,0x3f,0x76,
+  0xec,0xd8,0xcc,0x01,0x7d,0xa6,0x7c,0x49,0x0a,0x64,0xdb,0xf0,0x72,0x9a,0xf0,0x37,
+  0x95,0x00,0xf3,0x7d,0xf2,0x77,0x65,0xad,0xf0,0x17,0xc8,0x34,0x51,0x00,0xa6,0x14,
+  0x29,0xfc,0x6d,0x05,0x81,0x42,0xc6,0x5f,0x62,0x05,0x40,0x5a,0xec,0x05,0x88,0xc7,
+  0x84,0xf6,0xda,0x6b,0xaf,0x68,0xd2,0x20,0x51,0x04,0x00,0x00,0xa0,0xbc,0x2c,0x59,
+  0xb2,0x24,0x72,0xfb,0xbb,0xca,0xf6,0xca,0x74,0xbb,0xfb,0xee,0xbb,0x6f,0x47,0x40,
+  0x5f,0x4c,0x48,0x40,0x9f,0xe9,0x55,0x0e,0xb1,0xf8,0x6d,0xc2,0xdf,0xa5,0x04,0xd8,
+  0x84,0xbe,0xcf,0xe5,0xdf,0x24,0xc2,0x5f,0x98,0x22,0x0a,0xc0,0xa4,0xa2,0x85,0x7f,
+  0xfc,0xea,0xaa,0xb8,0x14,0x0b,0xfa,0x58,0xd3,0x4a,0x0a,0xff,0xd8,0x0b,0x60,0xce,
+  0xfb,0x2c,0x39,0x9f,0xc7,0x1d,0x77,0x9c,0x7a,0xf2,0xc9,0x27,0xd5,0x94,0x29,0x53,
+  0xb8,0xcb,0x00,0x00,0x4a,0x28,0xfc,0xa5,0x25,0x05,0x7e,0x5c,0x89,0x4f,0x82,0xf9,
+  0x0e,0x38,0xe0,0x00,0x6b,0x3d,0xfe,0xac,0x01,0x7d,0xa1,0x42,0x3f,0x44,0x01,0x70,
+  0x7d,0xe7,0xca,0x56,0x2b,0x63,0x85,0xbf,0x40,0xa2,0x18,0x80,0x17,0x8b,0xde,0x8a,
+  0x2b,0x06,0x40,0x84,0x79,0x52,0x09,0x88,0x85,0x7f,0xfc,0x1a,0xbb,0xfe,0x4d,0xe1,
+  0x1f,0x5f,0x48,0xf2,0xf7,0x2e,0xbb,0xec,0xa2,0x76,0xd8,0x61,0x07,0xf5,0xd4,0x53,
+  0x4f,0xa9,0x77,0xde,0x79,0x87,0x3b,0x0e,0x00,0xa0,0xa4,0xc2,0x5f,0x9e,0xed,0x5b,
+  0x6d,0xb5,0x55,0x14,0xcd,0x9f,0x4c,0xdf,0xab,0x25,0xa0,0xcf,0x14,0xfa,0xe6,0xf0,
+  0x72,0x9a,0xf0,0x4f,0x7b,0xef,0xb2,0xf6,0xd3,0xac,0xfe,0x26,0x12,0xfe,0xc2,0x8b,
+  0x92,0x05,0xd0,0x57,0xbf,0x99,0x27,0xca,0x57,0xde,0x6b,0x37,0x85,0x75,0x9c,0x0d,
+  0x60,0x66,0x04,0xc4,0xa5,0x20,0x93,0x59,0x01,0xc9,0x2c,0x81,0x64,0x36,0x40,0xdc,
+  0xe2,0x75,0x24,0xd7,0x2b,0xdb,0x79,0xf5,0xd5,0x57,0xd5,0x84,0x09,0x13,0xb8,0xfb,
+  0x00,0x00,0x1a,0x2c,0xfc,0x63,0x21,0x2f,0xee,0xfd,0x71,0xe3,0xc6,0xa9,0x8d,0x36,
+  0xda,0x68,0x9d,0x89,0x78,0xd2,0xaa,0xf4,0x85,0x08,0x7d,0x5f,0x70,0x5f,0xe8,0xe7,
+  0xae,0x66,0x6e,0xd7,0x54,0x4c,0x92,0x0a,0x4c,0x13,0x09,0x7f,0x09,0xbc,0xe8,0xdf,
+  0x55,0xef,0xec,0x42,0x7d,0x92,0x5e,0xd2,0x7f,0x6c,0x5f,0x84,0xe5,0x6f,0x46,0x70,
+  0xca,0x01,0x8b,0x5d,0x40,0xb1,0x17,0x40,0x4e,0x48,0x2c,0xc4,0x93,0xaf,0xa6,0x07,
+  0xc0,0x9c,0x16,0x52,0x90,0x65,0x93,0x0a,0x87,0x68,0x97,0xdb,0x6c,0xb3,0x8d,0x9a,
+  0x3f,0x7f,0xbe,0x7a,0xf3,0xcd,0x37,0xd5,0xeb,0xaf,0xbf,0xbe,0xd6,0x32,0x00,0x00,
+  0x50,0x1c,0x8b,0x17,0x2f,0x8e,0x8c,0x38,0x99,0xd8,0x6d,0xfb,0xed,0xb7,0x8f,0x9e,
+  0xc9,0xb1,0xa0,0x34,0x27,0xe2,0xa9,0x36,0x8a,0x3f,0x74,0x7c,0xdf,0xf5,0xb9,0xaf,
+  0x0e,0x8d,0xcd,0xcd,0x1f,0x32,0xd6,0xdf,0x24,0xc2,0x5f,0x78,0x49,0xef,0xeb,0xa2,
+  0x78,0x2e,0x80,0x47,0x8b,0x50,0x00,0x92,0x8a,0x80,0xa9,0x04,0x24,0x15,0x80,0xa4,
+  0x12,0x20,0x4d,0xa2,0x41,0xd3,0x84,0xbe,0xa9,0x71,0xc5,0x7f,0xc7,0xd1,0xa4,0xf2,
+  0x2a,0x17,0xdf,0x47,0x3e,0xf2,0x91,0x28,0x7f,0x54,0x7e,0x2b,0xda,0xa8,0xd4,0x12,
+  0x98,0x39,0x73,0x66,0xa4,0x1c,0xc8,0xdf,0x8b,0x16,0x2d,0x8a,0xbc,0x08,0x00,0x00,
+  0x90,0x1d,0xc9,0xcd,0x17,0xeb,0x5e,0xd2,0xb4,0xa5,0x50,0x4f,0x3c,0xac,0x3b,0x66,
+  0xcc,0x98,0x75,0x02,0xc0,0xe3,0xe7,0xb4,0x2f,0x98,0xcf,0x26,0xf4,0x43,0xc7,0xf6,
+  0xb3,0x58,0xf7,0xa6,0x42,0x91,0x45,0xe8,0x9b,0xfd,0x6a,0x32,0xe1,0x1f,0xcb,0xfc,
+  0x8e,0xc9,0x80,0xee,0xd5,0xed,0xf4,0xa2,0x84,0xbf,0x2d,0x8f,0x33,0xf6,0x04,0xc8,
+  0x01,0x4f,0x8e,0xf1,0xc7,0x16,0xbf,0x69,0xfd,0xc7,0xda,0xa3,0x4b,0xa9,0x88,0x3d,
+  0x07,0xf1,0xf6,0x92,0xbf,0x95,0xcf,0x7a,0xf5,0xea,0x15,0x35,0x89,0x38,0x4d,0x42,
+  0x61,0x21,0x00,0x80,0xda,0x8c,0x3b,0xd7,0x73,0x39,0xeb,0xd8,0x7e,0x35,0x42,0x3f,
+  0x8b,0xf0,0xf7,0x59,0xf8,0xb6,0xc0,0x3e,0xdf,0x38,0x7f,0x93,0x09,0x7e,0x95,0x90,
+  0xf9,0x1d,0x0a,0xc0,0x7d,0xba,0xad,0xd0,0xad,0x5b,0x3d,0xbd,0x00,0x49,0x05,0x20,
+  0xf6,0x02,0xd8,0xac,0xfe,0x34,0xc1,0x2f,0x16,0xbc,0xbc,0xc6,0xc2,0x3f,0x56,0x1c,
+  0x64,0xfd,0xe6,0xf0,0x81,0xb9,0xae,0x64,0x10,0x0a,0x00,0x00,0xd4,0xa6,0x04,0xa4,
+  0x29,0x00,0x45,0x8d,0xeb,0xa7,0x09,0xfe,0xb4,0xb9,0x66,0xd2,0x2c,0xfd,0x34,0xa1,
+  0xdf,0xc4,0x56,0x7f,0xcc,0x8a,0x35,0x32,0xff,0x43,0x05,0x40,0x77,0x62,0x81,0x16,
+  0x86,0x0f,0xe8,0xb7,0x07,0xd5,0xc3,0x0b,0x90,0x1c,0x0f,0x32,0xbd,0x00,0x3e,0x05,
+  0xc0,0x54,0x22,0x4c,0x57,0x52,0x32,0x7e,0xc0,0x54,0x02,0x92,0xdb,0xc4,0x03,0x00,
+  0x00,0x90,0xbf,0xe0,0xf7,0x3d,0xa3,0xab,0x4d,0xdd,0x0b,0x15,0xfe,0x79,0x0a,0x7d,
+  0x97,0xb5,0xdf,0xe4,0x86,0xe3,0x03,0x22,0xf3,0x93,0x1e,0x00,0xe1,0xba,0xa2,0x14,
+  0x00,0xd7,0x05,0x13,0x2b,0x02,0x49,0xc1,0xec,0x1a,0xf7,0xf7,0x69,0x94,0x71,0x56,
+  0x40,0x2c,0xf4,0xd3,0x82,0x08,0x6d,0x9e,0x00,0x00,0x00,0xc8,0xd7,0xf2,0x4f,0xab,
+  0xd2,0xe7,0xab,0xce,0x17,0xf2,0x99,0xed,0xf7,0xa1,0xee,0xfd,0xb4,0x71,0x7d,0x57,
+  0x54,0x7f,0x8b,0x78,0x8c,0xaf,0x8b,0xdf,0x24,0x15,0x80,0x9b,0x75,0xfb,0xad,0x6e,
+  0x3d,0x8b,0xf6,0x02,0x24,0x15,0x80,0x64,0x46,0x80,0x2d,0xd8,0xcf,0xb6,0x1e,0xdb,
+  0x05,0x15,0x0b,0x7f,0x5b,0x09,0x61,0x33,0x26,0x20,0x29,0xf4,0x6d,0xdb,0x43,0x21,
+  0x00,0x00,0x70,0x0b,0x7c,0x9f,0xe0,0x0f,0x99,0xfe,0x3d,0xc4,0xd2,0x0f,0x0d,0xea,
+  0x73,0x55,0x02,0x34,0x15,0x90,0x90,0x80,0xbe,0x16,0x16,0xfc,0xc2,0xd2,0x35,0xb2,
+  0x7e,0x6d,0x05,0x40,0x77,0x70,0xae,0x16,0x7c,0x37,0xea,0xb7,0x9f,0xa9,0xe7,0x45,
+  0x94,0x1c,0x0e,0x48,0x56,0x84,0xb2,0x09,0xfd,0x34,0x8d,0x32,0x6e,0x66,0x05,0x41,
+  0x5b,0x31,0xa1,0xa4,0xc7,0x01,0xa1,0x0f,0x00,0x50,0x9b,0xf5,0x1f,0x22,0xfc,0x43,
+  0x2d,0xfe,0x50,0x05,0x20,0x34,0x65,0xcf,0x15,0xd0,0x67,0xee,0xbb,0x4d,0x3e,0xb5,
+  0x60,0x8c,0xd8,0x8d,0x22,0xeb,0x6d,0x1e,0x00,0xe1,0x8a,0x22,0x15,0x80,0x64,0x59,
+  0x60,0x53,0x01,0x08,0xb1,0xfa,0x4d,0x05,0x20,0xbe,0x10,0xa4,0x30,0x50,0x7c,0xb1,
+  0x88,0x27,0x20,0xa9,0x00,0xc4,0x05,0x82,0x4c,0x4f,0x80,0xcb,0x0b,0x80,0x22,0x00,
+  0x00,0x10,0x26,0xf8,0x93,0xcf,0xe7,0xf8,0x79,0x6e,0x7b,0x4e,0xa7,0x59,0xfe,0x21,
+  0x95,0xf8,0xb2,0x8c,0xed,0xdb,0x04,0x7f,0x9b,0x5a,0xfb,0x36,0xae,0x48,0xfe,0xd1,
+  0xd5,0x38,0xb9,0x8f,0x68,0x01,0xf8,0x8c,0x7e,0xbb,0x73,0x3d,0x95,0x00,0x33,0x1e,
+  0x20,0x4d,0x01,0x48,0x5e,0x54,0x22,0xf8,0x93,0x43,0x00,0xd2,0x92,0x4a,0x80,0x19,
+  0x0b,0x10,0x12,0x0f,0x80,0x22,0x00,0x00,0xa0,0x52,0x2d,0x61,0x5f,0xd0,0x5f,0x16,
+  0xb7,0xbf,0xad,0xde,0x7e,0x88,0x9b,0xbf,0xd6,0x28,0xfe,0x36,0x12,0xfa,0x31,0xcf,
+  0x88,0x8c,0x77,0x2a,0x00,0x6b,0xb8,0x58,0xb7,0xbf,0x16,0x7d,0x31,0x25,0x95,0x80,
+  0x38,0x70,0xcf,0xa6,0x04,0xa4,0xb9,0x95,0xe2,0x0b,0x23,0x16,0xfe,0xb1,0xe0,0x4f,
+  0x2a,0x00,0xe6,0x9c,0x02,0xc4,0x02,0x00,0x00,0x54,0x2f,0xfc,0x6d,0x82,0xdf,0xe6,
+  0xa5,0xb5,0x4d,0xc9,0x9b,0xc5,0xfd,0x6f,0x2b,0xd4,0x53,0x6d,0x40,0x5f,0x9b,0x5a,
+  0xfb,0x36,0xd9,0xbe,0xf6,0x79,0xb4,0x08,0x3d,0x91,0xc2,0x32,0x41,0xd0,0xd6,0x45,
+  0xee,0x89,0x4d,0x00,0x27,0x85,0x74,0x52,0x80,0x27,0x85,0x7a,0x52,0xd8,0xdb,0x9a,
+  0x6d,0x26,0x41,0xdf,0x30,0x80,0x29,0xe8,0x11,0xfc,0x00,0x00,0x6e,0x45,0xc0,0xa7,
+  0x00,0x84,0xa6,0xfa,0xb9,0xac,0x7e,0x57,0x50,0x1f,0x01,0x7d,0x55,0x23,0x13,0xe4,
+  0x6c,0xa7,0xfb,0xbe,0x3a,0xd5,0x03,0x20,0x0b,0x68,0x01,0xf8,0x3d,0xfd,0xf6,0x86,
+  0x7a,0x79,0x01,0x92,0xd3,0x05,0x27,0x3d,0x01,0x3e,0xf7,0x92,0x79,0x21,0xb9,0x14,
+  0x80,0x90,0x79,0x05,0xd2,0x84,0x3e,0x0a,0x01,0x00,0x60,0xf9,0xfb,0x3d,0x00,0x69,
+  0x41,0xda,0x21,0x19,0x00,0xa1,0x82,0x9f,0x80,0xbe,0xcc,0x9c,0x67,0x0a,0x7f,0xab,
+  0x07,0x20,0x21,0xf4,0xee,0xd7,0x2f,0xfb,0x16,0xbd,0x57,0x36,0x4f,0x40,0xb2,0x14,
+  0x70,0xb2,0x99,0xc2,0xdd,0xf4,0x0e,0xf8,0x84,0x7f,0xa8,0x02,0x80,0xc0,0x07,0x00,
+  0xc8,0xc7,0x03,0x10,0x32,0x6d,0xaf,0x4d,0xf0,0x63,0xed,0xe7,0x86,0x14,0xfe,0xd9,
+  0xcf,0x7a,0x4e,0x53,0x04,0xf3,0x96,0xfa,0xe5,0x05,0xdd,0xba,0x37,0x4a,0x09,0xf0,
+  0x29,0x02,0x2e,0xa5,0xc0,0x36,0xa3,0xa0,0x2d,0x06,0x00,0xe1,0x0f,0x00,0x50,0xbd,
+  0x12,0x90,0x25,0x08,0x30,0xed,0x35,0x6b,0x3d,0x7e,0xdb,0xf6,0x11,0xfa,0x56,0x96,
+  0xeb,0xb6,0xbd,0x3e,0x26,0xaf,0xda,0xbe,0xec,0x9a,0x72,0xa2,0x5f,0xd5,0xc2,0xf0,
+  0x12,0xfd,0xf6,0x5b,0xf5,0xb8,0xa8,0x5c,0x75,0xf9,0x5d,0x5a,0x5f,0x72,0xb8,0x20,
+  0xce,0xff,0x77,0x09,0xfe,0x34,0xeb,0x1f,0xe1,0x0f,0x00,0x50,0x9b,0x12,0x10,0x5a,
+  0xf3,0x3f,0x8f,0x2a,0x7d,0x58,0xfb,0x99,0xb8,0xc4,0x25,0xfc,0x53,0x3d,0x00,0x6b,
+  0x04,0x62,0x6f,0xfd,0xf2,0x6f,0xdd,0xc6,0xd4,0x6b,0x6f,0x6d,0xc1,0x79,0xa6,0xe5,
+  0xee,0x12,0xf0,0x69,0x82,0x1f,0xf7,0x3f,0x00,0x40,0xbe,0xc2,0x3f,0xab,0x12,0xe0,
+  0x52,0x0c,0xd2,0x52,0xf8,0xb0,0xf6,0xab,0x66,0x8a,0x6e,0xdb,0xe8,0x63,0xb4,0xb8,
+  0x2a,0x05,0x60,0x8d,0x40,0xdc,0x5d,0xbf,0x3c,0xac,0x0a,0x9c,0x29,0x30,0x4d,0x09,
+  0x48,0x2a,0x03,0xe6,0xd0,0x80,0x6b,0x0a,0x61,0x53,0xe8,0x23,0xfc,0x01,0x00,0x1a,
+  0xa7,0x04,0xd8,0xc6,0xf3,0xb3,0x58,0xfb,0x04,0xf4,0x65,0x46,0x66,0xfc,0xdb,0x4b,
+  0x1f,0xa7,0x27,0x52,0xcf,0x65,0xa0,0x40,0xfe,0x9a,0xb2,0xe4,0x10,0xd6,0x43,0x09,
+  0x08,0x55,0x04,0x5c,0x02,0xdf,0x57,0xfc,0x27,0x24,0x0b,0x00,0x00,0x00,0x94,0x55,
+  0xf0,0xdb,0x2c,0x74,0x9b,0x60,0x77,0x09,0x7c,0x57,0x34,0x3f,0xd6,0x7e,0x4d,0x9c,
+  0xad,0x8f,0xd7,0x25,0xde,0xf3,0x98,0x41,0x20,0xdf,0xa6,0x5f,0x0e,0xab,0x77,0x2f,
+  0x4c,0x45,0x20,0x4d,0x19,0x70,0x29,0x07,0xb6,0xe5,0x6d,0x42,0x1f,0x25,0x00,0x00,
+  0xa0,0x3a,0x0f,0x80,0xcb,0x13,0x10,0xda,0x6c,0xeb,0x43,0xf0,0x57,0xc5,0xed,0xfa,
+  0x98,0xfd,0x47,0xd0,0xb9,0xcc,0x20,0x88,0x07,0xeb,0x97,0x27,0x75,0x1b,0xdb,0x88,
+  0x1e,0xf9,0x3c,0x02,0x2e,0xa5,0xc0,0xb5,0x5c,0x9a,0xd0,0x47,0x11,0x00,0x00,0x70,
+  0x0b,0x7e,0x97,0x32,0x90,0x96,0x93,0x4f,0x69,0xde,0xba,0x30,0x49,0xb7,0xdd,0xf4,
+  0xf1,0x9b,0x93,0xab,0x02,0xb0,0x46,0x30,0x4a,0x30,0xe0,0x63,0xba,0x0d,0x6b,0x54,
+  0xef,0x5c,0x8a,0x80,0xcd,0x43,0x90,0xf6,0x19,0x02,0x1f,0x00,0x20,0x3f,0x85,0x20,
+  0x64,0x58,0xc0,0xb5,0x1c,0x82,0x3f,0x17,0x66,0xe8,0x36,0x4e,0x1f,0xc3,0x29,0xc1,
+  0xe7,0xb0,0x0a,0x01,0xbc,0xbd,0x7e,0x79,0x48,0xb7,0x01,0x8d,0xec,0xa9,0x4b,0x88,
+  0xa7,0x59,0xf9,0xa1,0x01,0x7f,0x28,0x04,0x00,0x00,0x7e,0x0f,0x80,0xcb,0x13,0xe0,
+  0x13,0xf0,0x04,0xf5,0xe5,0xce,0x3c,0xdd,0xf6,0xd6,0xc7,0xf1,0x85,0x4c,0xe7,0xb4,
+  0x4a,0xe1,0xbb,0xb7,0x7e,0xf9,0xbf,0xba,0xf5,0x2c,0x43,0xcf,0x7d,0x16,0x7d,0x88,
+  0xe0,0x47,0xe8,0x03,0x00,0xd4,0xa6,0x0c,0xa4,0x59,0xf3,0x08,0xfd,0xc2,0x58,0xaa,
+  0xdb,0xc1,0xfa,0x78,0x3e,0x94,0xf9,0x3c,0xd6,0x20,0x74,0x45,0x09,0xb8,0xb5,0xd1,
+  0x9e,0x80,0x2c,0xc2,0x3c,0x54,0xc8,0xa3,0x0c,0x00,0x00,0x84,0x7b,0x00,0xb2,0x2a,
+  0x07,0x90,0xab,0xe5,0x7f,0x78,0x35,0xc2,0xbf,0x26,0x05,0x60,0x8d,0xa0,0xdc,0x7e,
+  0x8d,0x27,0x60,0x58,0x33,0x1d,0x31,0x04,0x3c,0x00,0x40,0x63,0x14,0x04,0xc8,0x8d,
+  0x19,0x6b,0x2c,0xff,0x17,0xaa,0x3e,0x67,0x39,0x08,0x53,0x09,0x0c,0xbc,0x47,0x35,
+  0x28,0x3b,0x00,0x00,0x00,0xa0,0xcd,0x90,0x68,0xff,0x83,0xb2,0x04,0xfc,0xd9,0xe8,
+  0x9c,0x83,0xd6,0x27,0x3b,0xb0,0x9b,0x6e,0xb7,0x73,0x4e,0x00,0x00,0x00,0x0a,0x45,
+  0x64,0xed,0x6e,0xb5,0x0a,0xff,0x5c,0x14,0x80,0x35,0x4a,0xc0,0x9c,0x35,0x85,0x07,
+  0xce,0x56,0x1f,0x96,0x20,0x04,0x00,0x00,0x80,0xfc,0x10,0xd9,0x2a,0x15,0xfe,0xfe,
+  0x23,0x34,0xcf,0xdf,0x2b,0xbb,0xf3,0xde,0xc3,0x35,0x73,0x07,0x5c,0xa3,0xea,0x38,
+  0x81,0x10,0x00,0x00,0x40,0x0b,0x23,0xd6,0xfe,0x09,0xbe,0xda,0xfe,0x0d,0xf1,0x00,
+  0x18,0xde,0x00,0xd9,0xc1,0x6d,0x74,0xfb,0x89,0xfa,0x70,0x2e,0x62,0x00,0x00,0x00,
+  0xc8,0xce,0xf2,0x35,0xb2,0x74,0x9b,0xbc,0x85,0x7f,0x21,0x1e,0x00,0xc3,0x1b,0xb0,
+  0xa5,0x7e,0xb9,0x4c,0xb7,0x7d,0x39,0x8f,0x00,0x00,0x00,0xc1,0x3c,0xa0,0xdb,0x57,
+  0xb4,0xe0,0x7f,0xb5,0xa8,0x0d,0x74,0x2e,0x72,0xef,0x65,0xc7,0x75,0xdb,0x4f,0xbf,
+  0x3d,0x5a,0xb7,0x09,0x9c,0x4f,0x00,0x00,0x80,0x54,0x44,0x56,0x1e,0x2d,0xb2,0xb3,
+  0x48,0xe1,0x5f,0xb8,0x07,0xc0,0xf0,0x06,0x88,0xb2,0x31,0x5e,0x7d,0x18,0x28,0xb8,
+  0x33,0xe7,0x18,0x00,0x00,0xa0,0x83,0x67,0x74,0xbb,0x58,0xb7,0xeb,0xb5,0xe0,0x5f,
+  0x5d,0x8f,0x0d,0x36,0xa4,0x72,0x83,0x56,0x06,0xf6,0xd4,0x2f,0xa7,0xea,0x76,0x94,
+  0x2a,0x49,0x39,0x61,0x00,0x00,0x80,0x3a,0x23,0x65,0x7c,0x6f,0xd4,0xed,0x0a,0x2d,
+  0xf4,0x1f,0xa9,0xf7,0xc6,0x1b,0x5a,0xba,0x49,0x2b,0x02,0x83,0xf4,0xcb,0x11,0xba,
+  0x1d,0xab,0x3e,0x8c,0x13,0xe8,0xc6,0xf5,0x00,0x00,0x00,0x2d,0x8c,0xa4,0xf3,0xc9,
+  0xf8,0xfe,0x75,0xba,0xdd,0xac,0x05,0xff,0xdc,0x46,0xed,0x48,0x69,0x6a,0x37,0x6a,
+  0x65,0xa0,0x9f,0x7e,0x39,0x40,0xb7,0xfd,0x75,0xdb,0x43,0xb7,0x6d,0x55,0xc1,0x31,
+  0x0a,0x00,0x00,0x00,0x05,0x23,0xee,0xfc,0x97,0x74,0x7b,0x54,0xb7,0xfb,0x74,0xbb,
+  0x57,0x0b,0xfd,0x05,0x65,0xd8,0xb1,0xd2,0x16,0x6f,0xd6,0x0a,0x41,0x5f,0xf5,0x61,
+  0x3a,0xe1,0x76,0xea,0xc3,0x32,0xc3,0x52,0x57,0x60,0xa4,0x6e,0xeb,0xe9,0x36,0x58,
+  0xb7,0x5e,0xba,0x75,0xd7,0xad,0x0b,0xd7,0x17,0x00,0x00,0x34,0x80,0x55,0xea,0xc3,
+  0x54,0xbd,0x25,0xba,0x49,0x71,0x9e,0x59,0xba,0x4d,0x53,0x1f,0xe6,0xed,0x4b,0xb9,
+  0xde,0x17,0x45,0xf8,0x6b,0x81,0xbf,0xa8,0x8c,0x3b,0xff,0xff,0x00,0xa9,0xd9,0x66,
+  0x33,0x79,0x3c,0x5d,0x0d,0x00,0x00,0x00,0x00,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,
+  0x82,
+  
+};
Binary files 2.3.3-3/tools/printer.opacity and 2.3.3op1-3/tools/printer.opacity differ
Binary files 2.3.3-3/tools/printer.png and 2.3.3op1-3/tools/printer.png differ
diff -pruN 2.3.3-3/tools/printer-png.h 2.3.3op1-3/tools/printer-png.h
--- 2.3.3-3/tools/printer-png.h	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/tools/printer-png.h	2020-11-27 14:25:26.000000000 +0000
@@ -2,304 +2,450 @@ static const unsigned char printer_png[]
 {
   0x89,0x50,0x4e,0x47,0x0d,0x0a,0x1a,0x0a,0x00,0x00,0x00,0x0d,0x49,0x48,0x44,0x52,
   0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x80,0x08,0x06,0x00,0x00,0x00,0xc3,0x3e,0x61,
-  0xcb,0x00,0x00,0x12,0x8c,0x49,0x44,0x41,0x54,0x78,0x01,0xec,0xd5,0x01,0x44,0x2c,
-  0x51,0x14,0xc6,0xf1,0xcf,0x06,0x10,0x25,0x45,0xa9,0x01,0x12,0x48,0x02,0x01,0x10,
-  0x64,0x42,0x28,0x28,0x03,0xa1,0x24,0x01,0xc5,0x14,0x04,0x29,0x50,0x29,0x54,0x01,
-  0x50,0x51,0xa0,0xc8,0xc0,0x50,0xa1,0x28,0x80,0x0a,0x02,0x01,0xad,0x10,0xb2,0xc4,
-  0x32,0xbb,0xcb,0xff,0xed,0xbb,0x76,0xc7,0x1a,0xdb,0xbe,0x17,0xc0,0x6d,0x7e,0x1c,
-  0xec,0x39,0xe3,0x0c,0xf7,0xdb,0xbb,0xab,0x46,0x00,0x07,0xf0,0x81,0x10,0xc8,0x02,
-  0x11,0x16,0xb0,0x5c,0x54,0xc9,0x2a,0xac,0x64,0xe7,0xe8,0xa7,0x80,0x6e,0xe0,0x18,
-  0x28,0x61,0x3b,0xfb,0x95,0x2a,0x59,0x76,0xff,0x6f,0xf8,0x2e,0x90,0xc3,0x36,0xa9,
-  0x1c,0xe0,0xaa,0x11,0x60,0xce,0xea,0x5b,0x9f,0x2a,0x01,0x73,0x8d,0x6e,0x7e,0x09,
-  0xdb,0xa5,0x4a,0x80,0x5b,0xef,0x3f,0x3f,0xc7,0x6f,0x91,0xca,0x01,0xdd,0xaa,0x02,
-  0x8e,0x49,0x18,0x1c,0x1c,0xa4,0xa7,0xa7,0x87,0xf5,0xf5,0x75,0xac,0x94,0x3a,0x56,
-  0x59,0x06,0x70,0x24,0x79,0x4a,0xc8,0x66,0xb3,0xa6,0x3e,0x3f,0x3f,0x65,0xa5,0x94,
-  0x67,0xb2,0x07,0x7c,0xea,0x58,0x5e,0x5e,0x66,0x7e,0x7e,0x9e,0xf3,0xf3,0x73,0x52,
-  0xd6,0xf2,0x05,0x84,0xa4,0x7e,0xab,0x30,0x23,0xa9,0x5f,0x75,0x1c,0x1c,0x1c,0x68,
-  0x73,0x73,0x53,0xb7,0xb7,0xb7,0xaa,0xf5,0xfc,0xfc,0x6c,0xfa,0x5b,0x5b,0x5b,0x2a,
-  0x16,0x8b,0xfa,0xf8,0xf8,0xd0,0xc9,0xc9,0x89,0xa6,0xa7,0xa7,0x35,0x35,0x35,0xa5,
-  0xed,0xed,0x6d,0xbd,0xbf,0xbf,0xeb,0x5f,0x3b,0x01,0x3d,0x3c,0x3c,0x68,0x6d,0x6d,
-  0x4d,0x63,0x63,0x63,0x5a,0x5a,0x5a,0x52,0x10,0x04,0x6a,0xe4,0xed,0xed,0x4d,0xbb,
-  0xbb,0xbb,0xf2,0x3c,0x4f,0x13,0x13,0x13,0xda,0xd8,0xd8,0xd0,0xeb,0xeb,0xab,0x6a,
-  0xed,0xed,0xed,0x99,0x77,0x5c,0x5d,0x5d,0xe9,0x3b,0x37,0x37,0x37,0xe6,0x99,0xa3,
-  0xa3,0x23,0x25,0x5d,0x5e,0x5e,0xca,0xf7,0x7d,0x8d,0x8e,0x8e,0x6a,0x61,0x61,0x41,
-  0xa7,0xa7,0xa7,0x02,0x64,0xa9,0x7e,0x01,0x11,0x75,0xb4,0xb7,0xb7,0x23,0x89,0xc5,
-  0xc5,0x45,0x6a,0xed,0xef,0xef,0x23,0xc9,0xd4,0xd3,0xd3,0x13,0x9d,0x9d,0x9d,0x48,
-  0xaa,0x2d,0xd3,0x2b,0x87,0xdb,0x70,0xe7,0xca,0xca,0x0a,0x92,0x48,0xd6,0xec,0xec,
-  0x2c,0x85,0x42,0x81,0xa4,0x30,0x0c,0x69,0x6b,0x6b,0x23,0xf9,0x7c,0x4b,0x4b,0x8b,
-  0x99,0x55,0xb9,0xae,0x6b,0xfa,0xbd,0xbd,0xbd,0x7c,0xa7,0xaf,0xaf,0x0f,0x49,0x94,
-  0x03,0xa6,0xea,0xeb,0xeb,0x8b,0xc9,0xc9,0x49,0xd3,0x4f,0xd6,0xf8,0xf8,0x38,0xf9,
-  0x7c,0x1e,0x0b,0x45,0x22,0xf6,0xf3,0x2f,0x40,0x57,0x57,0x17,0x99,0x4c,0x86,0xa1,
-  0xa1,0x21,0x73,0x98,0xc3,0xc3,0xc3,0xf1,0xcc,0x71,0x1c,0xa2,0x28,0xaa,0xbb,0xb3,
-  0xb5,0xb5,0x15,0x49,0x7f,0x3f,0x9b,0x43,0x9f,0x99,0x99,0xa9,0xce,0x4c,0x1d,0x1e,
-  0x1e,0x52,0xeb,0xe5,0xe5,0x85,0xa6,0xa6,0x26,0x33,0x1b,0x19,0x19,0x21,0x08,0x02,
-  0x2e,0x2e,0x2e,0x18,0x18,0x18,0x30,0xbd,0x8e,0x8e,0x8e,0x38,0xa0,0xb3,0xb3,0xb3,
-  0x78,0xcf,0xfd,0xfd,0x3d,0x49,0x77,0x77,0x77,0xf1,0xfc,0xf1,0xf1,0x91,0x2a,0xcf,
-  0xf3,0x4c,0xaf,0xb9,0xb9,0x99,0x9d,0x9d,0x1d,0xae,0xaf,0xaf,0x59,0x5d,0x5d,0x8d,
-  0xdf,0x5b,0xfe,0xc5,0xc3,0x46,0x7f,0xd8,0x33,0x03,0x8f,0xda,0x82,0x20,0x8c,0x7f,
-  0x3d,0xb7,0xaa,0x22,0x88,0x50,0x54,0x49,0x52,0x10,0x08,0x55,0x55,0x10,0x08,0x22,
-  0x80,0x0a,0xa8,0xa0,0x84,0x82,0x42,0xe8,0x9f,0xa8,0x92,0x84,0x90,0x00,0xa9,0x28,
-  0x54,0x14,0x92,0x84,0x40,0x44,0x29,0x52,0xa9,0x54,0x29,0x85,0x6a,0xde,0x67,0x98,
-  0x63,0x9d,0xb7,0x75,0xea,0x7a,0x91,0xea,0xc7,0x70,0xdf,0xee,0xdb,0xdd,0x75,0x76,
-  0x76,0x67,0xbe,0x29,0x6e,0x07,0xb0,0xdb,0xb7,0xb8,0xb8,0x28,0x0e,0xea,0x08,0xd6,
-  0x3f,0x3a,0x3a,0xea,0x9b,0x53,0xad,0xb9,0xb9,0x59,0xee,0xef,0xef,0xc5,0xd8,0xdb,
-  0xdb,0x93,0x8c,0x8c,0x8c,0xc0,0x79,0x18,0x5e,0xc4,0x68,0x6c,0x6c,0xd4,0xf6,0xd2,
-  0xd2,0x52,0x79,0x7a,0x7a,0x12,0x83,0xa1,0x46,0x92,0x92,0x92,0xb4,0x8f,0xe1,0x45,
-  0xdb,0x1e,0x1e,0x1e,0x74,0x5f,0x00,0xa4,0xb3,0xb3,0x53,0xc2,0x30,0x54,0x69,0x5f,
-  0x79,0x79,0xb9,0x18,0x9b,0x9b,0x9b,0x92,0x90,0x90,0x20,0x00,0xd4,0x81,0x5c,0xba,
-  0xba,0xba,0xcc,0xd9,0x6d,0x4f,0xc6,0xaf,0x03,0x6c,0x6f,0x6f,0x4b,0x98,0xe3,0xe3,
-  0xe3,0xe0,0xd6,0xb4,0xb4,0xb4,0x78,0xe7,0x6c,0x6a,0x6a,0x92,0x97,0x97,0x17,0x09,
-  0xa1,0xaa,0xc3,0xe6,0x66,0x6c,0xd7,0xb6,0xf3,0xf3,0xf3,0xa0,0x8d,0xf9,0x85,0x84,
-  0xa9,0xaa,0xaa,0xd2,0xbe,0xb6,0xb6,0x36,0x31,0x3a,0x3a,0x3a,0x82,0x97,0xe6,0xf1,
-  0xf1,0x51,0x8c,0x9b,0x9b,0x1b,0x49,0x4b,0x4b,0xd3,0xbe,0xb1,0xb1,0xb1,0xf0,0x21,
-  0xab,0x03,0x86,0xf7,0xc5,0x5c,0x22,0x58,0x7f,0x7f,0x7f,0xdf,0xe9,0xf9,0x75,0x00,
-  0xfd,0xa0,0x3e,0x72,0x73,0x73,0xb5,0x9f,0x87,0x13,0x39,0xa7,0xcb,0xc4,0xc4,0x84,
-  0xcd,0xad,0x1f,0x9e,0xe8,0x33,0x6e,0x6d,0x65,0x65,0x65,0xc2,0xe4,0xcf,0x35,0xc9,
-  0xcc,0xcc,0xd4,0xbe,0xfa,0xfa,0x7a,0x31,0xdc,0x31,0x33,0x33,0x33,0x62,0x8c,0x8c,
-  0x8c,0xd8,0x33,0xaf,0x31,0xdf,0x68,0x68,0x68,0xd0,0xf6,0xc4,0xc4,0xc4,0x7f,0xe6,
-  0xaf,0xae,0xae,0x0e,0xe6,0x5a,0x5d,0x5d,0x15,0x63,0x7a,0x7a,0x5a,0xd7,0x8c,0xb2,
-  0x9e,0x9e,0x1e,0xf9,0xca,0xfc,0xc1,0x27,0xc0,0x83,0x06,0xc1,0xc5,0xc5,0x45,0x5c,
-  0xe3,0xdc,0xb1,0xbc,0x75,0xae,0x02,0x01,0x63,0xbf,0x6b,0xb8,0xbc,0xbc,0x04,0x51,
-  0x35,0x62,0x54,0x56,0x56,0xa2,0xa8,0xa8,0x08,0xc4,0xcd,0xf4,0x31,0x3e,0x3e,0x0e,
-  0xa2,0x6a,0x85,0x4e,0x00,0xe2,0xae,0xa1,0xaa,0x26,0x3c,0xff,0xfa,0xfa,0x3a,0x0c,
-  0x77,0x8d,0x83,0x83,0x03,0xd0,0x21,0x22,0x6d,0x6b,0x6b,0x0b,0x5f,0x99,0x4f,0x71,
-  0x80,0xdb,0xdb,0x5b,0x10,0xb0,0x94,0x1c,0xd7,0x38,0x77,0x2c,0x13,0x3c,0x18,0x94,
-  0x8c,0x58,0x59,0x59,0xf1,0xda,0xe4,0xe4,0x24,0x5c,0x18,0x12,0x40,0xc0,0x1c,0x05,
-  0x67,0x67,0x67,0xea,0x3c,0x76,0x18,0xed,0xed,0xed,0x30,0xdc,0x35,0x0a,0x0a,0x0a,
-  0xbc,0x73,0x9b,0xf1,0x46,0x83,0xd8,0x1c,0x3a,0x67,0x84,0xa9,0x44,0xfe,0xca,0xc4,
-  0xf0,0x9f,0x61,0x92,0x86,0x93,0x93,0x93,0xe0,0x83,0x7e,0x84,0xa3,0xa3,0x23,0x18,
-  0x36,0x96,0x89,0x1f,0x0c,0x11,0xb1,0x43,0x88,0xa4,0xb5,0xb5,0x15,0x83,0x83,0x83,
-  0xba,0x1f,0x6a,0x79,0xbd,0xb1,0x04,0x54,0x0e,0xa0,0x6a,0x81,0x61,0x6b,0x6c,0x6c,
-  0x6c,0xe8,0xbe,0x2b,0x2a,0x2a,0x90,0x9c,0x9c,0x8c,0x28,0x18,0x7a,0xd4,0xe2,0xe0,
-  0xfb,0xbc,0x00,0xd4,0xeb,0x08,0x33,0x3f,0x3f,0x0f,0x66,0xf7,0x20,0x60,0x0e,0x10,
-  0x3d,0xce,0x81,0xf1,0x3a,0x38,0xfc,0xec,0xec,0x6c,0x80,0x50,0x11,0x20,0x3f,0x3f,
-  0x1f,0x20,0xc3,0xc3,0xc3,0xb8,0xbe,0xbe,0xc6,0x7b,0xc8,0xcb,0xcb,0x03,0x65,0x29,
-  0x40,0x98,0xf0,0x61,0x6a,0x6a,0xca,0x77,0xfb,0x95,0x9a,0x9a,0x1a,0x80,0x30,0x61,
-  0x04,0x25,0x20,0xe2,0xe0,0x67,0x3a,0x40,0x6d,0x6d,0xad,0x1b,0xe3,0xb4,0x52,0xc7,
-  0x02,0x0f,0x88,0x1e,0x1a,0x55,0x00,0x7c,0x30,0x19,0x43,0x7f,0x7f,0xbf,0xeb,0x08,
-  0x5a,0x99,0x63,0x61,0x09,0x20,0x03,0x03,0x03,0xa0,0x2c,0x83,0x5b,0xdd,0x23,0xfa,
-  0x94,0xb3,0x28,0x83,0xc3,0xc3,0x43,0x18,0xcf,0xcf,0xcf,0x3a,0x6e,0x69,0x69,0x09,
-  0x61,0x28,0xf9,0x00,0xb2,0xbb,0xbb,0x8b,0xab,0xab,0x2b,0xa4,0xa6,0xa6,0xfa,0xf6,
-  0xa4,0xe1,0x82,0xb2,0x10,0x20,0x43,0x43,0x43,0xea,0x30,0x22,0x02,0x83,0x4a,0x04,
-  0x73,0x73,0x73,0xfa,0x42,0x7c,0x3b,0xe2,0x55,0x01,0xae,0x15,0x17,0x17,0x0b,0x6f,
-  0x91,0xa4,0xa7,0xa7,0xeb,0xbf,0xf9,0x84,0xca,0xec,0xec,0xec,0x6b,0x73,0x9a,0x69,
-  0x36,0x5e,0x57,0x57,0xa7,0x55,0x3b,0x6b,0xa3,0x53,0x79,0x2b,0x81,0xdd,0xdd,0xdd,
-  0xc1,0xff,0xa1,0xf6,0x57,0x45,0xc0,0xa7,0xdc,0xd6,0xd4,0xdf,0x61,0xee,0xee,0xee,
-  0x74,0x0d,0x00,0x8e,0x54,0xf4,0xb3,0xb3,0xb3,0x23,0x39,0x39,0x39,0x6e,0x91,0x4b,
-  0x55,0x4c,0x61,0x61,0x61,0xd0,0xb6,0xb0,0xb0,0xf0,0x73,0x64,0x60,0x56,0x56,0x96,
-  0x00,0x90,0xde,0xde,0xde,0x57,0x1d,0x60,0x79,0x79,0x59,0x4a,0x4a,0x4a,0xdc,0x43,
-  0xd5,0x0f,0xc6,0xcc,0xf9,0x2d,0xa7,0x52,0xdd,0xdd,0xd7,0xd7,0x27,0x29,0x29,0x29,
-  0xc1,0x38,0xfe,0x16,0x3e,0xcf,0x56,0x3d,0xf4,0xc2,0x3a,0xbd,0xeb,0x2c,0x6a,0xb1,
-  0x58,0x4c,0x0b,0x44,0x7c,0x79,0x44,0xf1,0x17,0x7e,0xd4,0xd6,0xd6,0xd6,0xe4,0x2d,
-  0xf8,0xa7,0x6f,0xad,0x5d,0x58,0xad,0xc0,0x8c,0xb1,0x5e,0x25,0x1d,0x93,0xba,0x6f,
-  0xea,0x00,0x1f,0xc0,0x57,0x07,0x38,0x3d,0x3d,0xd5,0x43,0xe7,0x13,0x29,0xca,0x3b,
-  0x5f,0x15,0xde,0x74,0x2d,0xc7,0xd2,0xf4,0xf7,0x7b,0x61,0x1e,0x20,0x4c,0xda,0x74,
-  0xdc,0x5f,0x76,0xce,0x40,0x23,0xde,0x26,0x0a,0xe3,0x07,0xdd,0x40,0xd7,0x51,0xa1,
-  0x44,0x00,0x54,0x20,0x29,0x50,0x04,0xd0,0x05,0xa4,0x1b,0x88,0x80,0x82,0xa8,0x00,
-  0xba,0x82,0x84,0x2e,0x23,0x21,0x20,0x52,0x74,0x2d,0xf3,0xfd,0x3c,0x3c,0x2c,0x8d,
-  0xf5,0x1d,0xbb,0xfd,0x8d,0xed,0xfc,0x18,0x6f,0x6f,0xb3,0xdb,0xf6,0xce,0x9c,0x9d,
-  0x99,0x39,0xe7,0x3c,0x23,0x47,0xcf,0x9c,0x61,0x5a,0x69,0x9f,0x9f,0x9f,0x0d,0x83,
-  0x91,0xb7,0x71,0x3a,0x65,0x00,0xd3,0x48,0x39,0x82,0x8a,0xa1,0x1d,0x41,0x45,0xed,
-  0x02,0x8a,0x32,0x00,0x56,0xed,0x71,0x7b,0x7b,0x1b,0x77,0x77,0x77,0xc1,0x62,0x29,
-  0x32,0x5c,0x5d,0x5d,0xe9,0xbd,0xf8,0xd8,0xa3,0x18,0x84,0x56,0xfc,0x69,0xa2,0xf5,
-  0x29,0xca,0x00,0x8a,0x32,0x80,0xa2,0x0c,0xa0,0x28,0x03,0x28,0xca,0x11,0x54,0xac,
-  0xaf,0xaf,0x2b,0x34,0x8d,0x16,0xe1,0x2f,0xfa,0x01,0x8a,0xdf,0xd4,0x4a,0x92,0x88,
-  0x3a,0xba,0x01,0x14,0xa7,0xa7,0xa7,0x41,0xd6,0x72,0x90,0x24,0x1a,0x73,0x42,0x0e,
-  0xb1,0xe5,0xe5,0x65,0xe5,0x2d,0xfc,0x41,0x47,0x50,0xb1,0xb2,0xb2,0xd2,0x22,0x42,
-  0xa2,0x94,0x24,0xb5,0x06,0x98,0x5d,0x77,0xd8,0xd7,0x3a,0x32,0xcc,0x2b,0xf5,0x0c,
-  0xe1,0x8a,0x32,0x97,0xb2,0x5a,0x49,0x84,0x29,0xca,0x1e,0x3a,0x3b,0x3b,0x8b,0xc3,
-  0xc3,0xc3,0x40,0x5d,0xe4,0xcc,0x65,0xe1,0x0c,0x25,0xde,0xa3,0x0c,0xa7,0x80,0xf7,
-  0xf7,0xf7,0xe0,0x5e,0xe5,0xfe,0xfe,0x3e,0xaf,0x89,0xcc,0x3f,0xcf,0xe2,0x8d,0x00,
-  0x39,0xdd,0x61,0x3f,0xbc,0x4d,0x8e,0x81,0x65,0x6b,0xd6,0x0e,0xa6,0x32,0xa4,0x48,
-  0x3c,0x6d,0x9b,0x9b,0x9b,0xbe,0x9f,0xcc,0x2e,0x92,0xc0,0xc5,0x90,0x9f,0xd8,0xfd,
-  0xff,0x9c,0x25,0x95,0xd7,0x44,0xe6,0x9f,0xc7,0x2c,0x9c,0x01,0x24,0x75,0x87,0x6e,
-  0x30,0x6b,0x0c,0x2d,0x40,0x51,0x63,0xd1,0x51,0x09,0x03,0x90,0x20,0xd5,0x1d,0x2e,
-  0x63,0x5b,0x5d,0x5d,0x75,0x9d,0x32,0xa0,0xcc,0xc7,0xc7,0x47,0xbb,0xbe,0xbe,0xf6,
-  0xdf,0x6c,0x6b,0x6b,0x6b,0xba,0xa7,0x34,0x82,0x65,0x69,0x4d,0x64,0xe2,0x79,0x16,
-  0xdb,0x00,0x12,0xba,0xc3,0x5e,0x83,0x49,0xe8,0xfa,0xfc,0xfc,0x3c,0x53,0x8e,0x24,
-  0xd3,0x8d,0x32,0x8a,0x40,0x57,0xe7,0x24,0x92,0xa1,0x9c,0x5e,0x03,0x24,0x34,0x91,
-  0x89,0xe7,0x59,0x70,0x3f,0x00,0xba,0xc3,0x78,0x7a,0x7a,0x72,0xa8,0x5a,0xf0,0xcd,
-  0xd4,0xfc,0xe9,0xf9,0x54,0x59,0xc5,0x1d,0x98,0x37,0xf5,0xfe,0x59,0x76,0x0a,0x37,
-  0x37,0x37,0x41,0xc3,0x07,0xe8,0xba,0xb1,0xb1,0x11,0xa0,0x75,0x40,0x06,0x94,0x51,
-  0x4a,0xb1,0xf7,0xdf,0x65,0x24,0x08,0xc3,0x08,0xe3,0x2c,0xe6,0x78,0x7d,0x7d,0x0d,
-  0x48,0x3c,0xcf,0x82,0x6f,0x03,0xd1,0x14,0x38,0xa5,0xdc,0x08,0x8b,0x41,0x2c,0xeb,
-  0xea,0xc1,0xb0,0x1d,0x33,0xa0,0xce,0x37,0x86,0xb3,0x12,0x22,0x0d,0x7c,0x7d,0x7d,
-  0x85,0x41,0x5d,0xa4,0x45,0xdc,0x64,0x61,0x21,0xf9,0x43,0x4c,0x93,0x7e,0x1e,0x58,
-  0x8a,0x45,0x23,0xa1,0x3b,0x9c,0x37,0xfa,0xe6,0xcf,0x4e,0x4f,0x13,0xa9,0xd2,0x43,
-  0x7a,0xc5,0x72,0x04,0xe5,0x75,0x87,0xa3,0x93,0xd3,0x44,0x4e,0xa1,0x46,0x80,0xbe,
-  0xee,0x70,0x24,0xac,0x42,0x32,0x79,0x4d,0x64,0x8d,0x00,0x69,0xdd,0xe1,0x08,0x78,
-  0x61,0xf7,0xfd,0xfd,0x1d,0x06,0xf2,0x9a,0xc8,0x32,0x80,0xbc,0xee,0x70,0x00,0xb4,
-  0x3b,0x09,0x78,0x7b,0x7b,0xeb,0xcc,0xe5,0x09,0x4d,0xe4,0xe0,0x06,0xa0,0x68,0xd7,
-  0xe3,0xe3,0xa3,0x24,0xdb,0x7b,0x7b,0x7b,0xe1,0xc2,0x89,0x5e,0x81,0x83,0x23,0x76,
-  0x76,0x76,0x54,0x76,0x77,0x77,0x55,0xf8,0x9d,0x5c,0xb8,0x47,0x47,0x47,0x0a,0x94,
-  0x70,0xca,0x46,0x5c,0x5e,0x5e,0x06,0x7b,0xdc,0x60,0x5f,0x1b,0x34,0x98,0xc4,0x9e,
-  0x1d,0xd4,0x30,0x38,0x54,0x24,0xdd,0x66,0xd8,0xd4,0x41,0x11,0x78,0x06,0x2d,0x66,
-  0xd5,0xdf,0x1b,0x04,0x3d,0xa3,0xff,0x67,0x9c,0x46,0xc1,0xbd,0x5c,0xc8,0x66,0x7f,
-  0x7f,0x3f,0xd0,0x44,0x06,0xe8,0xb0,0x09,0x4e,0x37,0x0b,0x8e,0xf0,0x8d,0xad,0xad,
-  0xad,0xc0,0x13,0xa8,0x10,0xf5,0xc5,0xc5,0xc5,0x98,0xc1,0x20,0x3a,0xbd,0xe1,0x37,
-  0x97,0x53,0x86,0x8e,0x68,0x9c,0xbb,0xa7,0x42,0xa7,0xfb,0xda,0x2d,0xae,0x9b,0xf6,
-  0x7a,0x4e,0x00,0x91,0x63,0x85,0x86,0xd3,0xe7,0xcc,0xa0,0x3b,0x94,0x67,0xd0,0xaf,
-  0x63,0xa1,0xd8,0xfe,0x97,0x56,0x32,0xf1,0xfe,0x93,0x93,0x13,0xd5,0xd1,0x71,0xad,
-  0x07,0x1d,0x68,0x51,0xaa,0x0a,0x9d,0x9b,0xd6,0x44,0xe6,0x9f,0x47,0x88,0xf8,0x8d,
-  0x8e,0xe7,0xdb,0xd9,0x8e,0x8f,0x8f,0x1b,0xdf,0x6a,0x79,0xb3,0x26,0x0b,0x56,0xed,
-  0xeb,0xe4,0xcf,0xbd,0xfa,0x1f,0x85,0x50,0xac,0x3a,0x1f,0xa3,0x52,0x21,0xf0,0x22,
-  0x0f,0x19,0x9f,0x99,0xd0,0x1d,0x8e,0x86,0xda,0x4c,0xea,0x64,0x8e,0xb0,0x93,0x40,
-  0x35,0xaf,0x89,0x1c,0x23,0x25,0x4c,0x5a,0x41,0x9c,0x16,0x8d,0x28,0x58,0x3b,0x38,
-  0x38,0x98,0x57,0x51,0xc7,0xe3,0xf9,0xd2,0xe9,0x62,0x93,0x07,0x38,0xb1,0x9f,0x57,
-  0x43,0x30,0x12,0xe4,0x75,0x87,0xa2,0x58,0x8a,0x39,0x40,0xa4,0x4b,0xe1,0x56,0x0e,
-  0x57,0x0c,0x3a,0x64,0x5e,0x0e,0x11,0x39,0x6c,0xd0,0xf8,0x6b,0xdf,0xce,0x09,0x5e,
-  0x61,0x0c,0x75,0x3a,0xce,0x85,0xe1,0x30,0x8a,0x7f,0xeb,0x07,0xd0,0xc2,0xe5,0xe5,
-  0xe5,0x45,0xb1,0x6f,0x5c,0xab,0xba,0xf7,0xd6,0xa6,0xb5,0xd6,0x5d,0x69,0x83,0xeb,
-  0x74,0x05,0xff,0xac,0xab,0xeb,0xf1,0x9b,0xcb,0xa8,0xd8,0x0a,0x69,0x31,0xe7,0xd7,
-  0xf8,0x24,0x2f,0x46,0x1a,0x79,0xf6,0x98,0x02,0x82,0x29,0x40,0x75,0x22,0x4f,0x91,
-  0x9d,0xab,0x58,0x81,0xb7,0xf3,0xf3,0x73,0x0d,0xc7,0x84,0x5b,0x7f,0x14,0xe6,0x7e,
-  0x5f,0xbb,0xc5,0x75,0xbd,0xd7,0x33,0xcf,0xeb,0x1c,0xdf,0xed,0xed,0xed,0xc6,0xb6,
-  0x47,0x9f,0xe1,0x2b,0x53,0x81,0x16,0x93,0x04,0x57,0x14,0xde,0xe4,0x77,0x9a,0x37,
-  0x31,0x16,0x45,0xf7,0x1e,0x1e,0x1e,0x14,0x4a,0xfd,0xaf,0xbd,0x73,0x80,0xb5,0x2d,
-  0x87,0xc2,0x70,0xc7,0x7c,0xf6,0xbb,0x1a,0xdb,0xb6,0xad,0x60,0x3c,0xc1,0xd8,0x88,
-  0x86,0xe1,0x8d,0xed,0x0c,0xc3,0x61,0xcc,0xb1,0x1d,0x8c,0x6d,0xdb,0xf3,0x6c,0xf5,
-  0x7b,0xc9,0x9f,0xa4,0x3b,0xdd,0x39,0x7d,0xa7,0xe9,0x3e,0xf7,0xec,0xbb,0xfe,0x64,
-  0xa5,0x3d,0xdd,0x3c,0xfd,0x57,0xd7,0xaa,0x76,0xcb,0x37,0xfd,0x05,0x60,0x2e,0x00,
-  0xd3,0xce,0x4c,0x14,0x46,0xa8,0x0a,0x42,0x3d,0x60,0x28,0xa6,0x9a,0x90,0x98,0x7a,
-  0x4a,0x3d,0xa5,0x1f,0x4b,0x83,0x70,0x5c,0x92,0x31,0x90,0x63,0xd8,0x38,0xc1,0x42,
-  0x40,0x3e,0xed,0xd3,0xd2,0xe4,0x83,0x80,0x58,0x3f,0xd9,0xc1,0xb1,0xf4,0x3c,0x75,
-  0x01,0xde,0xc1,0x37,0xe3,0x1c,0x1d,0x3c,0x84,0xbd,0x06,0x4a,0xe8,0x57,0x46,0x71,
-  0x7e,0x25,0x91,0xf6,0xd6,0x01,0x20,0x81,0x3f,0xca,0xa7,0xe0,0x6f,0xbf,0xfd,0x76,
-  0x63,0xfd,0xe2,0x90,0x4c,0x89,0x87,0x68,0x9e,0x4f,0x88,0x25,0x20,0x8e,0xcf,0x27,
-  0x2c,0x05,0xba,0x5c,0x21,0x56,0xc2,0xca,0x60,0x28,0x21,0xbd,0x70,0xcc,0xaf,0xa3,
-  0x57,0x8e,0xa9,0xe1,0xbc,0x07,0x56,0xc7,0xef,0xac,0xa2,0x3a,0x4c,0xfb,0x14,0x80,
-  0x4c,0xf7,0xb3,0x69,0xe8,0xc5,0x6b,0x74,0x60,0x84,0x6e,0x51,0x9e,0x2d,0xb2,0x31,
-  0xfd,0x8a,0x13,0x72,0x0c,0x49,0x04,0xd6,0x23,0x20,0x54,0x71,0x48,0x65,0x82,0x08,
-  0x69,0x58,0x19,0xc8,0xa7,0x05,0xc3,0x72,0x72,0x6a,0x59,0xe8,0xf9,0x00,0xc5,0xe4,
-  0xfd,0x98,0xa0,0x01,0xf1,0x4c,0xcc,0xa0,0xd2,0xcb,0xbb,0x70,0x1d,0x4a,0xd0,0x1a,
-  0x05,0x10,0x01,0x74,0xbd,0x36,0x5d,0xcb,0x26,0xa3,0xe5,0xeb,0x45,0x3c,0x69,0x22,
-  0x5f,0x35,0x7f,0x08,0xc3,0x52,0x30,0xd4,0x8b,0xd2,0x40,0x2a,0x84,0x32,0xf2,0x47,
-  0xa9,0x25,0x8d,0xd2,0x0a,0x81,0xcc,0x10,0xf2,0xd3,0xa8,0x20,0x4a,0x56,0x86,0x38,
-  0x04,0x22,0x34,0x33,0x99,0xbc,0x11,0x90,0x28,0x05,0x40,0x81,0x68,0x71,0xd0,0x95,
-  0xcd,0xb7,0x01,0x0c,0xd5,0x72,0x2f,0xd2,0x7c,0x2f,0x23,0xd7,0xa8,0xe9,0xdb,0x2a,
-  0x05,0xc0,0xf4,0xf6,0x64,0xb1,0x63,0x99,0x7e,0x44,0xa4,0x4b,0x01,0xc8,0x78,0x32,
-  0xdd,0xaf,0xd9,0xc7,0x78,0x38,0x71,0xc8,0x83,0xd4,0xa0,0x29,0x8a,0x50,0x8a,0x21,
-  0x95,0x78,0x2a,0x20,0x53,0xf7,0x62,0xc5,0x53,0x2a,0xa0,0xbe,0x85,0xe2,0xce,0x3b,
-  0xef,0x3c,0xe7,0x27,0x9c,0xf2,0x2e,0x28,0x9c,0xf3,0xeb,0x13,0x42,0x3a,0xef,0xd3,
-  0xbe,0x3a,0x80,0x32,0x00,0x0d,0xf7,0xeb,0xff,0x37,0xdd,0x2c,0x0d,0x2c,0x80,0x94,
-  0x00,0x62,0x10,0x4a,0x3d,0x5f,0xd3,0x30,0xc8,0x03,0xc1,0x9d,0xfa,0x15,0xaa,0xf7,
-  0xd6,0xfd,0x24,0x58,0x07,0x14,0x84,0xf3,0x65,0x5d,0x28,0xf1,0xa4,0x33,0x18,0xe5,
-  0x97,0x92,0x67,0x65,0x71,0x8e,0x51,0x29,0x85,0x78,0x07,0xa4,0x60,0xfd,0x6a,0xfa,
-  0x85,0x8d,0x68,0x0b,0xc6,0x4a,0x3f,0xe4,0xe3,0x17,0x99,0x54,0xd8,0x24,0x18,0xab,
-  0xf7,0x1b,0x51,0x88,0x0c,0x85,0x10,0x87,0xe9,0x85,0x7c,0x99,0x5b,0x91,0x1a,0x90,
-  0xa9,0x50,0xd7,0xe8,0xb7,0xd2,0x20,0x8d,0xde,0x43,0x59,0x12,0x84,0xdf,0x31,0xa9,
-  0x27,0x36,0xde,0x81,0xa5,0xb4,0xfa,0xf3,0xd3,0x3a,0xc8,0x72,0x81,0xd5,0xe2,0xff,
-  0xfa,0xb1,0x05,0xee,0xd9,0x9d,0x05,0x20,0xb3,0x7a,0xd5,0xdc,0xc2,0x02,0xc8,0xec,
-  0x53,0x1a,0xfd,0x87,0x11,0xf8,0x70,0x7d,0xe9,0x12,0x25,0x15,0x42,0x25,0x90,0xc7,
-  0xf9,0x8a,0x13,0x4a,0xc8,0x90,0x14,0x2b,0xc4,0x7f,0xcf,0x21,0x38,0x83,0xd0,0x6e,
-  0x15,0x48,0xf9,0x45,0xef,0x29,0x8a,0xcd,0x6f,0xf2,0x46,0x2e,0x30,0xdd,0x02,0x90,
-  0xa9,0x7e,0x47,0x0d,0x2a,0x52,0x5a,0x5c,0xb9,0x09,0xf0,0xf2,0xf8,0x5d,0x2c,0x0f,
-  0xa5,0x57,0x04,0xe2,0xe3,0x51,0x08,0xe2,0xf2,0xf9,0x1c,0x23,0x44,0xc8,0x94,0x08,
-  0x01,0xe9,0xae,0xa1,0xfc,0xf9,0x65,0x15,0x48,0x95,0x64,0x2c,0xa4,0xf2,0x02,0x3c,
-  0xfa,0xe8,0xa3,0x2a,0x08,0xa4,0xa5,0x5b,0x00,0xbd,0x00,0x99,0xde,0x14,0x78,0x16,
-  0xcf,0xc4,0xb7,0xfb,0x0f,0x26,0xe4,0x93,0x35,0xf1,0x03,0xb3,0x9f,0xff,0x69,0x75,
-  0x79,0xc2,0x1b,0xaf,0x2f,0xe1,0xaa,0xfd,0x5c,0x05,0x0a,0x42,0x90,0x2e,0x57,0x40,
-  0x7a,0xdc,0x0a,0x24,0x28,0x00,0xd2,0x14,0xd4,0xfe,0xa6,0x94,0xf3,0x5c,0x2c,0x10,
-  0x69,0x94,0x78,0x90,0x5b,0xc2,0x0b,0x12,0x5a,0xbe,0xc4,0x47,0xce,0xa7,0x25,0x42,
-  0xab,0x84,0x3a,0x51,0xec,0x3a,0xf5,0xa4,0x4e,0x98,0x30,0x81,0x78,0x5f,0xcc,0x0a,
-  0x46,0x53,0x71,0x03,0x68,0x2d,0xca,0x90,0x91,0x81,0x79,0xc7,0x13,0x90,0xa7,0x90,
-  0x19,0xef,0x43,0xc1,0x20,0x7f,0x66,0xcd,0x9a,0x15,0xdc,0x2b,0xf6,0x7e,0xaa,0x4b,
-  0xf5,0xcd,0xb4,0x70,0xea,0x1e,0x32,0xf9,0x06,0x21,0xf9,0x4b,0xa3,0xaa,0x32,0x49,
-  0x5a,0x3a,0x2b,0xd8,0x20,0x72,0x43,0xa2,0x23,0xbf,0x4d,0x01,0x5a,0x48,0x3c,0xa2,
-  0xb8,0x10,0x4b,0x2b,0xa6,0x00,0x34,0x2d,0x68,0x76,0x98,0x94,0x11,0xa6,0x7d,0x47,
-  0x50,0x5b,0xd2,0xc3,0xb0,0xec,0x94,0x30,0x7c,0x0c,0x2f,0x48,0x65,0x24,0xb5,0x62,
-  0x44,0x73,0x05,0xe9,0xf8,0x82,0x54,0xfe,0x68,0xbb,0xf6,0x15,0x0a,0x74,0x06,0x31,
-  0xc8,0x15,0x83,0xee,0x59,0x7d,0x66,0xfc,0x78,0x21,0x0b,0x00,0x41,0x34,0xcf,0x34,
-  0x9a,0x46,0x88,0xf0,0x60,0x85,0x8a,0x83,0xbf,0xfe,0x5e,0xe4,0x96,0x2c,0x1f,0x70,
-  0xdb,0x4c,0x3a,0xc1,0xcb,0x89,0x0e,0xd9,0x76,0xb2,0x42,0xc4,0x8b,0x8f,0x6f,0xb9,
-  0xed,0x91,0xfe,0xdc,0x95,0xea,0x9f,0xaf,0x4a,0xf5,0x79,0x41,0x5a,0x81,0xf3,0x25,
-  0x75,0xd7,0xa7,0xfc,0x7f,0xc2,0xe4,0xe7,0x4b,0xf8,0xff,0xd4,0xe0,0x37,0xd4,0xff,
-  0x57,0x95,0xaf,0x98,0x05,0xf0,0xab,0x6d,0x24,0x0f,0x7f,0xfe,0xfd,0xcf,0x02,0x37,
-  0x77,0xe4,0x14,0x37,0x77,0x70,0x5f,0xe7,0x5f,0xd5,0xf9,0xac,0x71,0x80,0xc0,0xff,
-  0x24,0x0c,0xb0,0x62,0xf9,0x6f,0x2c,0xa7,0xc0,0xfd,0xfb,0xb7,0x04,0xe7,0x7f,0xc9,
-  0x9c,0x40,0x7e,0x7d,0x9a,0xe2,0x45,0x14,0x80,0x92,0xcf,0x88,0x58,0x0a,0xd0,0xe4,
-  0xb5,0x9b,0x4c,0x75,0xbb,0xec,0x75,0xa4,0xdb,0xa8,0x23,0xa1,0x90,0xbf,0xc4,0xad,
-  0x5e,0x33,0x0f,0x05,0x23,0xe3,0x73,0x08,0xeb,0x5b,0x97,0x41,0x3b,0x9f,0xee,0xf0,
-  0xf8,0x54,0xf7,0xfa,0x52,0xae,0x74,0x42,0xc5,0x4b,0x28,0x00,0x3d,0x4b,0x98,0xa9,
-  0xa4,0xce,0x8c,0xff,0xe7,0xcd,0x77,0x7b,0x1d,0x74,0xa1,0x9b,0x39,0x94,0xb6,0x4a,
-  0xc6,0xd7,0x9f,0xbe,0xe9,0x26,0x6c,0xbd,0x9a,0xfb,0xa7,0x76,0xa6,0x60,0x29,0x82,
-  0xe7,0x2b,0x2c,0xdf,0x59,0x53,0xe4,0x7e,0x9a,0x0d,0x95,0x66,0x01,0xe2,0xc7,0x8a,
-  0xba,0x00,0x4a,0x3f,0x95,0xbf,0xa4,0x3f,0xb8,0x6a,0xed,0x96,0x6e,0xbb,0xdd,0xf6,
-  0x71,0x13,0xa6,0x4c,0x8c,0xa9,0x3f,0x17,0x10,0x3a,0xb0,0x64,0xd1,0x3c,0xf7,0xc3,
-  0x97,0x2f,0xb9,0x99,0x33,0xa6,0xa7,0x29,0x58,0x01,0xf4,0xb8,0x7b,0x19,0xd3,0x4f,
-  0xe9,0x97,0xfb,0x4b,0xb7,0x00,0x21,0xf9,0x65,0x15,0x40,0x93,0x20,0x92,0xb0,0x66,
-  0x99,0xfb,0xfa,0x93,0x57,0xdd,0xc0,0x0e,0x7b,0x05,0x99,0x53,0xad,0x02,0x2c,0x5e,
-  0xf0,0x8f,0xfb,0xf2,0x83,0x17,0xdc,0xa4,0xad,0x56,0x78,0xe5,0xda,0xba,0xbc,0xc9,
-  0x2f,0x74,0xbf,0x9c,0xe7,0x51,0xea,0x7f,0xf8,0xe1,0x07,0x92,0x89,0xeb,0x58,0xf2,
-  0xb0,0x70,0x24,0xad,0x8c,0x02,0xa0,0xa1,0xb8,0x81,0x14,0x0c,0x0d,0xcc,0x72,0x7f,
-  0x7d,0xf3,0xb2,0xfb,0xe3,0xab,0x17,0x6b,0x4b,0x88,0xfa,0x14,0x66,0xae,0x9f,0xe8,
-  0x31,0xa1,0xe9,0x01,0x9b,0xc0,0x85,0x28,0x4e,0x98,0x8f,0xf4,0xe7,0x21,0xfe,0x83,
-  0x4f,0xea,0x4c,0x1d,0x09,0xcd,0xef,0x00,0xca,0x54,0x00,0x96,0x28,0xc5,0x05,0xf0,
-  0x69,0x16,0xa6,0x5a,0xa4,0x44,0x10,0x0c,0xea,0x44,0x50,0x74,0x00,0xa7,0xbc,0xcf,
-  0xce,0x9f,0x05,0xc4,0xa4,0x13,0x26,0xb2,0xb2,0xe2,0x57,0x75,0xc8,0x56,0x33,0x8d,
-  0x53,0xfa,0xfd,0xeb,0xd3,0x0b,0x35,0x03,0xd9,0x6b,0x1f,0x68,0xae,0x7e,0xea,0xc3,
-  0x9a,0xaf,0x64,0x35,0x72,0x7e,0xce,0xff,0x87,0x78,0x5a,0x3d,0x01,0xf9,0xca,0xdb,
-  0x84,0x0a,0x20,0xe7,0x05,0xef,0xa1,0x78,0xa9,0x3a,0x00,0x9d,0x40,0x9a,0x30,0x9a,
-  0xdc,0xec,0x50,0x66,0x25,0xa7,0xe7,0xfb,0xda,0x84,0x4a,0x53,0xde,0x00,0x4c,0xee,
-  0x71,0x08,0xd7,0x9c,0x44,0xde,0x2f,0x3f,0x5f,0x9a,0xa9,0x04,0xf2,0x62,0x68,0x2c,
-  0x12,0x4c,0x1f,0xcf,0xce,0x5c,0x83,0x20,0x05,0x49,0xb1,0x42,0x4a,0x8b,0x59,0xce,
-  0x66,0x46,0x03,0x35,0x6b,0x07,0x53,0xc6,0x43,0x0d,0xf9,0xf9,0xc9,0xac,0xa8,0x14,
-  0xff,0x1f,0x49,0xcf,0xe8,0x07,0xc8,0x34,0xb9,0x45,0x3f,0x90,0x30,0xa4,0x5a,0x83,
-  0x8c,0xe1,0xe0,0xd6,0xc0,0xe6,0x03,0x80,0xd6,0x29,0x80,0x21,0x7d,0x3e,0x80,0x59,
-  0x80,0xf6,0x2b,0x80,0xc2,0x68,0x85,0xb0,0xfd,0x16,0xc0,0x90,0x3e,0x1f,0xc0,0x14,
-  0xa0,0xa5,0xe4,0x27,0xa4,0xb5,0x4d,0x01,0x0c,0xa1,0xe9,0x4f,0xa8,0x03,0xb4,0x60,
-  0xb9,0x78,0x43,0xde,0x7c,0x80,0xf6,0x5b,0x00,0x6b,0x05,0x44,0x49,0x6f,0x9f,0x02,
-  0x18,0xa2,0xa6,0x3f,0x85,0x70,0x73,0x01,0xed,0xaf,0x00,0x8e,0xe3,0x8e,0x20,0xeb,
-  0x0d,0x14,0xac,0x23,0x68,0x1c,0x12,0xaf,0x79,0x03,0x4a,0xb3,0x7e,0x80,0x71,0xaa,
-  0x14,0xe5,0x46,0x03,0xf9,0x64,0xbb,0x3f,0x60,0x23,0x80,0xa4,0x87,0xf1,0x7c,0x05,
-  0xe8,0x93,0xb5,0xf8,0xad,0x22,0x68,0xcd,0x40,0x1b,0x18,0x1a,0x17,0xeb,0x03,0x18,
-  0x6c,0x3e,0x80,0x91,0x2f,0xd8,0x58,0x80,0x55,0x02,0x15,0x0f,0xd6,0x0c,0x54,0xfa,
-  0xf8,0x50,0x00,0x53,0x04,0x48,0x8f,0xc5,0xcd,0x05,0xb4,0x14,0xfa,0x96,0x50,0x02,
-  0xe9,0x92,0x60,0x6d,0xe5,0xf6,0x29,0x80,0x41,0x24,0x8b,0x68,0x91,0x1d,0x84,0xed,
-  0x55,0x00,0x43,0x95,0xf8,0x5a,0x61,0xff,0xe5,0xf6,0x29,0x80,0x21,0x20,0xbe,0xae,
-  0xf4,0x8f,0x8c,0x8c,0xb8,0xa3,0x8f,0x3e,0x5a,0x6b,0x14,0x65,0x29,0xc0,0x18,0x5b,
-  0xb1,0xcb,0xcc,0xbf,0x56,0x06,0xaf,0xf3,0xfb,0x2c,0xad,0xef,0xb7,0xd5,0xd5,0x2a,
-  0xeb,0xfa,0x82,0xbb,0x7b,0x05,0x60,0x4d,0x5a,0xc3,0xd8,0x40,0xb5,0xa4,0x57,0xdd,
-  0x81,0xdf,0x61,0xdc,0x5d,0x72,0xc9,0x25,0xac,0xdf,0x80,0x68,0xf3,0xab,0xee,0x14,
-  0x80,0x8b,0x90,0xbd,0xf7,0xde,0xdb,0xf5,0x1c,0x06,0x11,0x0e,0xd1,0x0a,0x83,0xb4,
-  0x53,0x4f,0x3d,0x15,0xbf,0xcf,0x0a,0xe2,0x6c,0x18,0xc1,0x2a,0xe2,0x5a,0xce,0xa7,
-  0x7b,0x05,0xc0,0x7c,0xb0,0x93,0x27,0x61,0xef,0x60,0xd0,0x3e,0x46,0xd5,0x5a,0x3e,
-  0x04,0xb3,0xa7,0xd1,0xd5,0x57,0x5f,0xed,0x76,0xdd,0x75,0x57,0xcc,0x3f,0x7b,0x07,
-  0x60,0xb5,0x51,0x00,0x2c,0x40,0x77,0x2e,0x40,0xe4,0x63,0x3e,0xb8,0xd1,0x69,0xa7,
-  0x9d,0xe6,0x7a,0x02,0x83,0xb6,0x81,0x09,0x9a,0x7f,0xfb,0xed,0xb7,0x1f,0x5b,0xd8,
-  0xb9,0x8b,0x2f,0xbe,0xd8,0xed,0xb8,0xe3,0x8e,0x70,0xc4,0x8a,0x2d,0xac,0x24,0x8e,
-  0x10,0xc7,0x05,0x68,0x9b,0xbc,0x8e,0x3d,0x81,0x2b,0x58,0xa6,0x27,0xa6,0x00,0x54,
-  0x24,0xd0,0xa2,0xdd,0x76,0xdb,0x8d,0xe5,0xcb,0x1a,0xda,0x3d,0xd4,0x20,0x68,0xbb,
-  0x5c,0xd5,0xc5,0x0e,0x3b,0xec,0x30,0x42,0xed,0x73,0xc8,0x67,0xf9,0x54,0xd2,0x59,
-  0xab,0x81,0xd2,0x0f,0xf1,0x84,0x90,0x0f,0x77,0x1d,0x4b,0x3f,0xdc,0xa3,0x1e,0x7f,
-  0xc7,0x2c,0x00,0xa5,0x1f,0xf2,0xb9,0x19,0x0f,0x38,0xf0,0xc0,0x03,0xf1,0x31,0xe6,
-  0x0e,0x1a,0x24,0x1f,0xa1,0x84,0x5f,0x76,0xd9,0x65,0xec,0xde,0xc6,0x76,0xfa,0x6c,
-  0x61,0x07,0xc9,0x28,0x02,0x3b,0xac,0x91,0xe6,0x86,0x87,0x87,0xdd,0xc0,0xc0,0x00,
-  0x8b,0x4c,0xc3,0x55,0x2a,0xf9,0xe0,0x6f,0x36,0x8d,0x7a,0xc6,0x47,0x4e,0x8d,0xf9,
-  0x1d,0xb6,0x1c,0x61,0x2f,0x7f,0xf6,0x0e,0xd4,0x26,0xce,0xa4,0x61,0x0d,0xbe,0xfa,
-  0xea,0x2b,0xf6,0xf8,0xe7,0xb7,0xcb,0x87,0x41,0x80,0x60,0x0a,0x1e,0x15,0xb9,0x7d,
-  0xf6,0xd9,0x47,0x3b,0xa2,0x51,0xda,0x49,0xc7,0xef,0x73,0x4e,0x20,0xa4,0x71,0x8c,
-  0x73,0x36,0x70,0x2f,0xc3,0x67,0x71,0x01,0x2f,0xc6,0x14,0x40,0x2e,0x00,0x0b,0x80,
-  0x69,0x41,0x21,0x00,0x3b,0x7a,0x70,0x8c,0x34,0x6d,0xe3,0x0e,0x08,0x0d,0xf9,0xeb,
-  0x1a,0x11,0x42,0xa0,0x88,0x17,0xe9,0xf0,0x00,0xd9,0x84,0xfc,0xc6,0xf4,0x73,0x4c,
-  0xdb,0xe2,0x89,0x78,0x24,0x15,0x70,0xbf,0xc9,0xe8,0xe8,0xe8,0xcf,0x3e,0x72,0x0b,
-  0x15,0xc2,0x48,0x33,0x10,0xb2,0x03,0xe1,0x41,0xda,0xae,0x4d,0xdb,0xba,0x21,0x68,
-  0x9f,0x49,0xd7,0xa2,0x3c,0x0c,0x08,0x97,0x5f,0xc7,0xdc,0x53,0xbb,0xc7,0xc4,0x63,
-  0x19,0x58,0xaa,0x9f,0xe3,0x28,0x41,0xa4,0xc3,0x27,0x15,0x0c,0x16,0x5c,0xbd,0xb1,
-  0xbf,0x08,0x05,0x78,0xcc,0x45,0xa0,0xbd,0x71,0x65,0x05,0xf0,0x33,0xf8,0x1b,0x09,
-  0xfe,0x67,0x70,0x70,0x10,0xe1,0x58,0x86,0x98,0x28,0x1f,0x11,0xf2,0x95,0xee,0x5c,
-  0x09,0x69,0xec,0x54,0x8e,0x02,0xd0,0xce,0x57,0x27,0x4f,0x97,0xc4,0x0b,0x8f,0xc1,
-  0xbd,0xe6,0x03,0xdc,0xe5,0xe5,0x1c,0x2f,0x93,0xaa,0x56,0x40,0x4a,0xa0,0x10,0xad,
-  0xa3,0xd9,0x41,0xed,0x94,0x95,0x2d,0xb5,0xac,0xa9,0x21,0x1f,0xca,0x6f,0xb9,0x5f,
-  0x44,0xd6,0x41,0x64,0xcb,0xbf,0x67,0x62,0x3e,0x9c,0x13,0xd1,0x9d,0x20,0x91,0xc6,
-  0xfe,0x13,0xb8,0xff,0x9a,0x31,0xe8,0xea,0x20,0x44,0xc1,0x3a,0x80,0xd5,0x01,0xe4,
-  0x6e,0x09,0x11,0xd2,0x91,0x4c,0xc8,0xf4,0x9f,0xe5,0xef,0xf5,0x8c,0x14,0x40,0x80,
-  0xc4,0x6b,0x7c,0x70,0x4f,0x8d,0x12,0xe8,0x9c,0x40,0x0c,0x45,0x94,0x21,0x90,0x00,
-  0xf9,0xe4,0xdf,0xe0,0xef,0xf9,0x80,0xab,0x03,0x96,0xc0,0xcb,0xbc,0xb5,0x6d,0x83,
-  0x61,0x1e,0xdc,0xa6,0x4e,0x39,0x1a,0xf0,0xf2,0x90,0x97,0x55,0x96,0x6f,0x7d,0x0f,
-  0x38,0x84,0xcb,0x81,0x6e,0xe6,0x9e,0x0d,0x79,0xb9,0x8d,0xce,0x22,0x2f,0xbf,0x78,
-  0x59,0x6e,0xf9,0x39,0xe6,0xb1,0x1c,0xae,0xe0,0x0c,0xee,0xe0,0xd0,0xd5,0xc3,0xad,
-  0x03,0x63,0x75,0xc1,0xae,0xdd,0xd9,0xb0,0x20,0x00,0x00,0x00,0x00,0x49,0x45,0x4e,
-  0x44,0xae,0x42,0x60,0x82,
+  0xcb,0x00,0x00,0x04,0x19,0x69,0x43,0x43,0x50,0x6b,0x43,0x47,0x43,0x6f,0x6c,0x6f,
+  0x72,0x53,0x70,0x61,0x63,0x65,0x47,0x65,0x6e,0x65,0x72,0x69,0x63,0x52,0x47,0x42,
+  0x00,0x00,0x38,0x8d,0x8d,0x55,0x5d,0x68,0x1c,0x55,0x14,0x3e,0xbb,0x73,0x67,0x23,
+  0x24,0xce,0x53,0x6c,0x34,0x85,0x74,0xa8,0x3f,0x0d,0x25,0x0d,0x93,0x56,0x34,0xa1,
+  0xb4,0xba,0x7f,0xdd,0xdd,0x36,0x6e,0x96,0x49,0x36,0xda,0x22,0xe8,0x64,0xf6,0xee,
+  0xce,0x98,0xc9,0xce,0x38,0x33,0xbb,0xfd,0xa1,0x4f,0x45,0x50,0x7c,0x31,0xea,0x9b,
+  0x14,0xc4,0xbf,0xb7,0x80,0x20,0x28,0xf5,0x0f,0xdb,0x3e,0xb4,0x2f,0x95,0x0a,0x25,
+  0xda,0xd4,0x20,0x28,0x3e,0xb4,0xf8,0x83,0x50,0xe8,0x8b,0xa6,0xeb,0x99,0x3b,0x33,
+  0x99,0x69,0xba,0xb1,0xde,0x65,0xee,0x7c,0xf3,0x9d,0xef,0x9e,0x7b,0xee,0xb9,0x67,
+  0xef,0x05,0xe8,0xb9,0xaa,0x58,0x96,0x91,0x14,0x01,0x16,0x9a,0xae,0x2d,0x17,0x32,
+  0xe2,0x73,0x87,0x8f,0x88,0x3d,0x2b,0x90,0x84,0x87,0xa0,0x17,0x06,0xa1,0x57,0x51,
+  0x1d,0x2b,0x5d,0xa9,0x4c,0x02,0x36,0x4f,0x0b,0x77,0xb5,0x5b,0xdf,0x43,0xc2,0x7b,
+  0x5f,0xd9,0xd5,0xdd,0xfe,0x9f,0xad,0xb7,0x46,0x1d,0x15,0x20,0x71,0x1f,0x62,0xb3,
+  0xe6,0xa8,0x0b,0x88,0x8f,0x01,0xf0,0xa7,0x55,0xcb,0x76,0x01,0x7a,0xfa,0x91,0x1f,
+  0x3f,0xea,0x5a,0x1e,0xf6,0x62,0xe8,0xb7,0x31,0x40,0xc4,0x2f,0x7a,0xb8,0xe1,0x63,
+  0xd7,0xc3,0x73,0x3e,0x7e,0x8d,0x69,0x66,0xe4,0x2c,0xe2,0xd3,0x88,0x05,0x55,0x53,
+  0x6a,0x88,0x97,0x10,0x8f,0xcc,0xc5,0xf8,0x46,0x0c,0xfb,0x31,0xb0,0xd6,0x5f,0xa0,
+  0x4d,0x6a,0xeb,0xaa,0xe8,0xe5,0xa2,0x62,0x9b,0x75,0xdd,0xa0,0xb1,0x70,0xef,0x61,
+  0xfe,0x9f,0x6d,0xc1,0x68,0x85,0xf3,0x6d,0xc3,0xa7,0xcf,0x99,0x9f,0x3e,0x84,0xef,
+  0x61,0x5c,0xfb,0x2b,0x35,0x25,0xe7,0xe1,0x51,0xc4,0x4b,0xaa,0x92,0x9f,0x46,0xfc,
+  0x08,0xe2,0x6b,0x6d,0x7d,0xb6,0x1c,0xe0,0xdb,0x96,0x9b,0x91,0x11,0x3f,0x06,0x90,
+  0xdc,0xde,0x9a,0xaf,0xa6,0x11,0xef,0x44,0x5c,0xac,0xdb,0x07,0xaa,0xbe,0x9f,0xa4,
+  0xad,0xb5,0x8a,0x21,0x7e,0xe7,0x84,0x36,0xf3,0x2c,0xe2,0x2d,0x88,0xcf,0x37,0xe7,
+  0xca,0x53,0xc1,0xd8,0xab,0xaa,0x93,0xc5,0x9c,0xc1,0x76,0xc4,0xb7,0x35,0x5a,0xf2,
+  0xf2,0x3b,0x04,0xc0,0x89,0xba,0x5b,0x9a,0xf1,0xc7,0x72,0xfb,0x6d,0x53,0x9e,0xf2,
+  0xe7,0xe5,0xea,0x35,0x9a,0xcb,0x7b,0x79,0x44,0xfc,0xfa,0xbc,0x79,0x48,0xf6,0x7d,
+  0x72,0x9f,0x39,0xed,0xe9,0x7c,0xe8,0xf3,0x84,0x96,0x2d,0x07,0xfc,0xa5,0x97,0x94,
+  0x83,0x15,0xc4,0x83,0x88,0x7f,0xa1,0x46,0x41,0xf6,0xe7,0xe2,0xfe,0xb1,0xdc,0x4a,
+  0x10,0x03,0x19,0x6a,0x1a,0xe5,0x49,0x7f,0x2e,0x92,0xa3,0x0e,0x5b,0x2f,0xe3,0x5d,
+  0x6d,0xa6,0xe8,0xcf,0x4b,0x0c,0x17,0x37,0xd4,0x1f,0x4b,0x16,0xeb,0xfa,0x81,0x52,
+  0xa0,0xff,0x44,0xb3,0x8b,0x72,0x80,0xaf,0x59,0x06,0xab,0x51,0x8c,0x8d,0x4f,0xda,
+  0x2d,0xb9,0xea,0xeb,0xf9,0x51,0xc5,0xce,0x17,0x7c,0x9f,0x7c,0x85,0x36,0xab,0x81,
+  0x7f,0xbe,0x0d,0xb3,0x09,0x05,0x28,0x98,0x30,0x87,0xbd,0x0a,0x4d,0x58,0x03,0x11,
+  0x64,0x28,0x40,0x06,0xdf,0x16,0xd8,0x68,0xa9,0x83,0x0e,0x06,0x32,0x14,0xad,0x14,
+  0x19,0x8a,0x5f,0xa1,0x66,0x17,0x1b,0xe7,0xc0,0x3c,0xf2,0x3a,0xb4,0x99,0xcd,0xc1,
+  0xbe,0xc2,0x94,0xfe,0xc8,0xc8,0x5f,0x83,0xf9,0xb8,0xce,0xb4,0x2a,0x64,0x87,0x3e,
+  0x82,0x16,0xb2,0x1a,0xfc,0x8e,0xac,0x16,0xd3,0x65,0xf1,0xab,0x85,0x5c,0x63,0x13,
+  0x3f,0x7e,0x2c,0x37,0x02,0x3f,0x26,0x19,0x20,0x12,0xd9,0x83,0xcf,0x5e,0x32,0x49,
+  0xf6,0x91,0x71,0x32,0x01,0x22,0x79,0x8a,0x3c,0x4d,0xf6,0x93,0x1c,0xb2,0x13,0x64,
+  0xef,0xfa,0xd8,0x4a,0x6c,0x45,0x5e,0x3c,0x37,0xd6,0xfd,0xbc,0x8c,0x33,0x52,0xa6,
+  0x9b,0x45,0xdd,0x39,0xb4,0xbb,0xa0,0x60,0xff,0x33,0x2a,0x4c,0x5c,0x53,0xd7,0xac,
+  0x2c,0x0e,0xb6,0x86,0x23,0xcb,0x29,0xfb,0x05,0x5d,0xbd,0xfc,0xc6,0x5f,0xb1,0x5c,
+  0xe9,0x2c,0x37,0x51,0xb6,0xe2,0x19,0x9d,0xba,0x57,0xce,0xf9,0x5f,0xf9,0xeb,0xfc,
+  0x32,0xf6,0x2b,0xfc,0x6a,0xa4,0xe0,0x7f,0xe4,0x57,0xf1,0xb7,0x72,0xc7,0x5a,0xcc,
+  0xbb,0xb2,0x4c,0xc3,0xec,0x6c,0x58,0x73,0x77,0x55,0x1a,0x6d,0x06,0xe3,0x16,0xf0,
+  0xd1,0x99,0xc5,0x89,0xc5,0x1d,0xf3,0x71,0xf1,0xe4,0x57,0x0f,0x46,0x7e,0x96,0xc9,
+  0x99,0xe7,0xaf,0xf4,0x5d,0x3c,0x59,0x6f,0x2e,0x0e,0x46,0xac,0x97,0x05,0xfa,0x6a,
+  0xf9,0x56,0x19,0x4e,0x8d,0x44,0xac,0xf4,0x83,0xf4,0x87,0xb4,0x2c,0xbd,0x27,0x7d,
+  0x28,0xfd,0xc6,0xbd,0xcd,0x7d,0xca,0x7d,0xcd,0x7d,0xce,0x7d,0xc1,0x5d,0x02,0x91,
+  0x3b,0xcb,0x9d,0xe3,0xbe,0xe1,0x2e,0x70,0x1f,0x73,0x5f,0xc6,0xf6,0x6a,0xf3,0x1a,
+  0x5a,0xdf,0x7b,0x16,0x79,0x18,0xb7,0x67,0xe9,0x96,0x6b,0xac,0x4a,0x21,0x23,0x6c,
+  0x15,0x1e,0x16,0x72,0xc2,0x36,0xe1,0x51,0x61,0x32,0xf2,0x27,0x0c,0x08,0x63,0x42,
+  0x51,0xd8,0x81,0x96,0xad,0xeb,0xfb,0x16,0x9f,0x2f,0x9e,0x3d,0x1d,0x0e,0x63,0x1f,
+  0xe6,0xa7,0xfb,0x5c,0xbe,0x2e,0x56,0x01,0x89,0xfb,0xb1,0x02,0xf4,0x4d,0xfe,0x55,
+  0x55,0x54,0xe9,0x70,0x94,0x29,0x1d,0x56,0x6f,0x4d,0x38,0xbe,0x41,0x13,0x8c,0x24,
+  0x43,0x64,0x8c,0x94,0x36,0x54,0xf7,0xb8,0x57,0xf3,0xa1,0x22,0x95,0x4f,0xe5,0x52,
+  0x69,0x10,0x53,0x3b,0x53,0x13,0xa9,0xb1,0xd4,0x41,0x0f,0x87,0xb3,0xa6,0x76,0xa0,
+  0x6d,0x02,0xfb,0xfc,0x1d,0xd5,0xa9,0x6e,0xb2,0x52,0xea,0xd2,0x63,0xde,0x7d,0x02,
+  0x59,0xd3,0x3a,0x6e,0xeb,0x0d,0xcd,0x15,0x77,0x4b,0xd2,0x93,0x62,0x1a,0xaf,0x36,
+  0x2a,0x96,0x9a,0xea,0xe8,0x88,0xa8,0x18,0x86,0xc8,0x4c,0x8e,0x68,0x53,0x87,0xda,
+  0x6d,0x5a,0x1b,0x05,0xef,0xde,0xf4,0x8f,0xf4,0x9b,0x32,0xbb,0x0f,0x13,0x5b,0x2e,
+  0x47,0x9c,0xfb,0x0c,0xc0,0xbe,0x3f,0xf1,0xec,0xfb,0x2e,0xe2,0x8e,0xb4,0x00,0x96,
+  0x1c,0x80,0x81,0xc7,0x23,0x6e,0x18,0xcf,0xca,0x07,0xde,0x05,0x38,0xf3,0x84,0xda,
+  0xb2,0xdb,0xc1,0x1d,0x91,0x48,0x7c,0x0b,0xe0,0xd4,0xf7,0xec,0xf6,0xbf,0xfa,0x32,
+  0x78,0x7e,0xfd,0xd4,0xe9,0xdc,0xc4,0x73,0xac,0xe7,0x2d,0x80,0xb5,0x37,0x3b,0x9d,
+  0xbf,0xdf,0xef,0x74,0xd6,0x3e,0x40,0xff,0xab,0x00,0x67,0x8d,0x7f,0x01,0xa0,0x9f,
+  0x7c,0x55,0x03,0x5c,0x0b,0xef,0x00,0x00,0x00,0x38,0x65,0x58,0x49,0x66,0x4d,0x4d,
+  0x00,0x2a,0x00,0x00,0x00,0x08,0x00,0x01,0x87,0x69,0x00,0x04,0x00,0x00,0x00,0x01,
+  0x00,0x00,0x00,0x1a,0x00,0x00,0x00,0x00,0x00,0x02,0xa0,0x02,0x00,0x04,0x00,0x00,
+  0x00,0x01,0x00,0x00,0x00,0x80,0xa0,0x03,0x00,0x04,0x00,0x00,0x00,0x01,0x00,0x00,
+  0x00,0x80,0x00,0x00,0x00,0x00,0x6b,0x46,0x26,0x4d,0x00,0x00,0x03,0x62,0x69,0x54,
+  0x58,0x74,0x58,0x4d,0x4c,0x3a,0x63,0x6f,0x6d,0x2e,0x61,0x64,0x6f,0x62,0x65,0x2e,
+  0x78,0x6d,0x70,0x00,0x00,0x00,0x00,0x00,0x3c,0x78,0x3a,0x78,0x6d,0x70,0x6d,0x65,
+  0x74,0x61,0x20,0x78,0x6d,0x6c,0x6e,0x73,0x3a,0x78,0x3d,0x22,0x61,0x64,0x6f,0x62,
+  0x65,0x3a,0x6e,0x73,0x3a,0x6d,0x65,0x74,0x61,0x2f,0x22,0x20,0x78,0x3a,0x78,0x6d,
+  0x70,0x74,0x6b,0x3d,0x22,0x58,0x4d,0x50,0x20,0x43,0x6f,0x72,0x65,0x20,0x35,0x2e,
+  0x34,0x2e,0x30,0x22,0x3e,0x0a,0x20,0x20,0x20,0x3c,0x72,0x64,0x66,0x3a,0x52,0x44,
+  0x46,0x20,0x78,0x6d,0x6c,0x6e,0x73,0x3a,0x72,0x64,0x66,0x3d,0x22,0x68,0x74,0x74,
+  0x70,0x3a,0x2f,0x2f,0x77,0x77,0x77,0x2e,0x77,0x33,0x2e,0x6f,0x72,0x67,0x2f,0x31,
+  0x39,0x39,0x39,0x2f,0x30,0x32,0x2f,0x32,0x32,0x2d,0x72,0x64,0x66,0x2d,0x73,0x79,
+  0x6e,0x74,0x61,0x78,0x2d,0x6e,0x73,0x23,0x22,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,
+  0x20,0x3c,0x72,0x64,0x66,0x3a,0x44,0x65,0x73,0x63,0x72,0x69,0x70,0x74,0x69,0x6f,
+  0x6e,0x20,0x72,0x64,0x66,0x3a,0x61,0x62,0x6f,0x75,0x74,0x3d,0x22,0x22,0x0a,0x20,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x78,0x6d,0x6c,0x6e,0x73,
+  0x3a,0x64,0x63,0x3d,0x22,0x68,0x74,0x74,0x70,0x3a,0x2f,0x2f,0x70,0x75,0x72,0x6c,
+  0x2e,0x6f,0x72,0x67,0x2f,0x64,0x63,0x2f,0x65,0x6c,0x65,0x6d,0x65,0x6e,0x74,0x73,
+  0x2f,0x31,0x2e,0x31,0x2f,0x22,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+  0x20,0x20,0x20,0x78,0x6d,0x6c,0x6e,0x73,0x3a,0x49,0x70,0x74,0x63,0x34,0x78,0x6d,
+  0x70,0x45,0x78,0x74,0x3d,0x22,0x68,0x74,0x74,0x70,0x3a,0x2f,0x2f,0x69,0x70,0x74,
+  0x63,0x2e,0x6f,0x72,0x67,0x2f,0x73,0x74,0x64,0x2f,0x49,0x70,0x74,0x63,0x34,0x78,
+  0x6d,0x70,0x45,0x78,0x74,0x2f,0x32,0x30,0x30,0x38,0x2d,0x30,0x32,0x2d,0x32,0x39,
+  0x2f,0x22,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x78,
+  0x6d,0x6c,0x6e,0x73,0x3a,0x70,0x68,0x6f,0x74,0x6f,0x73,0x68,0x6f,0x70,0x3d,0x22,
+  0x68,0x74,0x74,0x70,0x3a,0x2f,0x2f,0x6e,0x73,0x2e,0x61,0x64,0x6f,0x62,0x65,0x2e,
+  0x63,0x6f,0x6d,0x2f,0x70,0x68,0x6f,0x74,0x6f,0x73,0x68,0x6f,0x70,0x2f,0x31,0x2e,
+  0x30,0x2f,0x22,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x64,
+  0x63,0x3a,0x63,0x72,0x65,0x61,0x74,0x6f,0x72,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x72,0x64,0x66,0x3a,0x53,0x65,0x71,0x3e,
+  0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+  0x3c,0x72,0x64,0x66,0x3a,0x6c,0x69,0x3e,0x4d,0x69,0x63,0x68,0x61,0x65,0x6c,0x20,
+  0x53,0x77,0x65,0x65,0x74,0x3c,0x2f,0x72,0x64,0x66,0x3a,0x6c,0x69,0x3e,0x0a,0x20,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x2f,0x72,0x64,0x66,
+  0x3a,0x53,0x65,0x71,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,
+  0x2f,0x64,0x63,0x3a,0x63,0x72,0x65,0x61,0x74,0x6f,0x72,0x3e,0x0a,0x20,0x20,0x20,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x64,0x63,0x3a,0x72,0x69,0x67,0x68,0x74,0x73,
+  0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x72,
+  0x64,0x66,0x3a,0x41,0x6c,0x74,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x72,0x64,0x66,0x3a,0x6c,0x69,0x20,0x78,
+  0x6d,0x6c,0x3a,0x6c,0x61,0x6e,0x67,0x3d,0x22,0x78,0x2d,0x64,0x65,0x66,0x61,0x75,
+  0x6c,0x74,0x22,0x3e,0x43,0x6f,0x70,0x79,0x72,0x69,0x67,0x68,0x74,0x20,0x32,0x30,
+  0x31,0x30,0x20,0x41,0x70,0x70,0x6c,0x65,0x20,0x49,0x6e,0x63,0x2e,0x3c,0x2f,0x72,
+  0x64,0x66,0x3a,0x6c,0x69,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+  0x20,0x20,0x20,0x3c,0x2f,0x72,0x64,0x66,0x3a,0x41,0x6c,0x74,0x3e,0x0a,0x20,0x20,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x2f,0x64,0x63,0x3a,0x72,0x69,0x67,0x68,
+  0x74,0x73,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x49,0x70,
+  0x74,0x63,0x34,0x78,0x6d,0x70,0x45,0x78,0x74,0x3a,0x48,0x65,0x61,0x64,0x6c,0x69,
+  0x6e,0x65,0x3e,0x4e,0x65,0x77,0x20,0x49,0x6d,0x61,0x67,0x65,0x3c,0x2f,0x49,0x70,
+  0x74,0x63,0x34,0x78,0x6d,0x70,0x45,0x78,0x74,0x3a,0x48,0x65,0x61,0x64,0x6c,0x69,
+  0x6e,0x65,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x70,0x68,
+  0x6f,0x74,0x6f,0x73,0x68,0x6f,0x70,0x3a,0x48,0x65,0x61,0x64,0x6c,0x69,0x6e,0x65,
+  0x3e,0x4e,0x65,0x77,0x20,0x49,0x6d,0x61,0x67,0x65,0x3c,0x2f,0x70,0x68,0x6f,0x74,
+  0x6f,0x73,0x68,0x6f,0x70,0x3a,0x48,0x65,0x61,0x64,0x6c,0x69,0x6e,0x65,0x3e,0x0a,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x2f,0x72,0x64,0x66,0x3a,0x44,0x65,0x73,0x63,
+  0x72,0x69,0x70,0x74,0x69,0x6f,0x6e,0x3e,0x0a,0x20,0x20,0x20,0x3c,0x2f,0x72,0x64,
+  0x66,0x3a,0x52,0x44,0x46,0x3e,0x0a,0x3c,0x2f,0x78,0x3a,0x78,0x6d,0x70,0x6d,0x65,
+  0x74,0x61,0x3e,0x0a,0xa0,0x50,0x98,0x64,0x00,0x00,0x13,0xdb,0x49,0x44,0x41,0x54,
+  0x78,0xda,0xed,0x9d,0x07,0x90,0x55,0x35,0x17,0xc7,0xd7,0x5e,0xc7,0xde,0xd7,0x55,
+  0xec,0xbd,0x0b,0x0a,0x28,0x88,0x88,0xae,0x05,0x7b,0xd7,0xc1,0xbe,0x2a,0x28,0x22,
+  0xba,0xe8,0x88,0x8d,0xcf,0x82,0x34,0xa5,0x0a,0xa2,0x28,0xae,0xa8,0x58,0x41,0x71,
+  0x64,0x11,0x07,0xc5,0x2e,0xa2,0xa0,0xa8,0xe8,0x88,0xd8,0x16,0x15,0xb0,0x20,0x56,
+  0x14,0xcd,0xb7,0xbf,0xb8,0xe7,0x9a,0xcd,0xe6,0xbe,0x77,0xef,0x6b,0xbb,0xdc,0x97,
+  0xcc,0xfc,0x27,0xf7,0xdd,0x92,0x77,0x6f,0xce,0x3f,0x27,0x27,0xc9,0x49,0x52,0x52,
+  0x92,0x22,0x28,0xa5,0xca,0x6a,0x51,0x59,0x8b,0xea,0x5a,0xd4,0xd4,0x62,0x89,0xf2,
+  0xa1,0xa9,0x87,0x25,0x75,0xb2,0xaa,0xae,0x93,0x5d,0x59,0x49,0xdc,0x50,0xfb,0x50,
+  0x69,0x2d,0xaa,0x6a,0xb1,0xd4,0xe7,0xe7,0x32,0x1f,0x96,0xd6,0xc9,0xb2,0x34,0xaa,
+  0xf0,0xcb,0x6b,0xb1,0xc8,0xe7,0x5b,0xe2,0x02,0x32,0x2d,0x4f,0x27,0xfc,0x0a,0x5f,
+  0xea,0x13,0xaf,0x0d,0x2a,0x52,0x95,0x7c,0x2f,0xfc,0xe2,0x20,0x41,0xb9,0xab,0xce,
+  0xf7,0x6a,0xbf,0xb8,0xaa,0x83,0x52,0x93,0x00,0x55,0xf6,0x1d,0x7b,0xee,0xb9,0xa7,
+  0xda,0x7c,0xf3,0xcd,0xd5,0x4d,0x37,0xdd,0xe4,0xb3,0x2b,0x99,0xa1,0xca,0x6c,0xea,
+  0x35,0x50,0xfd,0x1b,0x6c,0xb0,0x81,0xe2,0xf2,0xe5,0x97,0x5f,0xee,0xb3,0x2a,0xb9,
+  0x55,0x41,0x59,0x49,0x5d,0x5b,0xb1,0x41,0xe8,0xd1,0xa3,0x87,0xba,0xe8,0xa2,0x8b,
+  0xd4,0x13,0x4f,0x3c,0xe1,0xb3,0x2a,0xb9,0xa1,0xb2,0xa4,0xae,0xc3,0xc0,0x87,0xe2,
+  0x0c,0xd5,0x10,0xa0,0xc6,0x75,0x65,0xe8,0xd0,0xa1,0xaa,0x4f,0x9f,0x3e,0xea,0xc5,
+  0x17,0x5f,0xac,0x77,0x7e,0xe6,0xcc,0x99,0xfa,0x7c,0xdf,0xbe,0x7d,0xd5,0x9f,0x7f,
+  0xfe,0xa9,0xe6,0xcf,0x9f,0xaf,0xaa,0xaa,0xaa,0x54,0xa7,0x4e,0x9d,0xd4,0x29,0xa7,
+  0x9c,0xa2,0xfa,0xf5,0xeb,0xa7,0xe6,0xcd,0x9b,0xa7,0xd2,0xa5,0xf9,0xcf,0x3f,0xff,
+  0xa8,0x57,0x5f,0x7d,0x55,0xdd,0x78,0xe3,0x8d,0xea,0xa8,0xa3,0x8e,0xd2,0x55,0xcd,
+  0xd3,0x4f,0x3f,0x9d,0xf2,0x6d,0xbf,0xfc,0xf2,0x4b,0x75,0xfb,0xed,0xb7,0xab,0xd3,
+  0x4e,0x3b,0x4d,0x1d,0x77,0xdc,0x71,0xda,0x3e,0xf9,0xe4,0x93,0x4f,0xea,0xdd,0x33,
+  0x78,0xf0,0x60,0xfd,0x1f,0xcf,0x3d,0xf7,0x5c,0x68,0x3a,0xcf,0x3f,0xff,0xbc,0xbe,
+  0x67,0xf4,0xe8,0xd1,0x0d,0xae,0x8d,0x1f,0x3f,0x5e,0x5d,0x79,0xe5,0x95,0xaa,0xbc,
+  0xbc,0x5c,0x5d,0x7c,0xf1,0xc5,0xea,0xc1,0x07,0x1f,0xd4,0xef,0x9a,0xd0,0x50,0x03,
+  0x01,0x9c,0xdd,0xbb,0x61,0x36,0x00,0x42,0xe4,0x3c,0x80,0x0c,0x9b,0x6c,0xb2,0x49,
+  0xf0,0x5b,0xc0,0xb9,0xd7,0x5e,0x7b,0x2d,0x65,0x9a,0x57,0x5d,0x75,0x55,0x83,0xe7,
+  0xc0,0xf9,0xe7,0x9f,0xaf,0x89,0xd5,0x80,0xaa,0xd5,0xd5,0x6a,0xbd,0xf5,0xd6,0x6b,
+  0x70,0xff,0xda,0x6b,0xaf,0xad,0xaf,0x49,0x40,0x70,0x9c,0xdf,0x76,0xdb,0x6d,0x43,
+  0xbf,0x7a,0xfb,0xed,0xb7,0xd7,0xf7,0x74,0xee,0xdc,0x39,0x38,0xf7,0xf3,0xcf,0x3f,
+  0x6b,0x02,0xbb,0xde,0x09,0xb2,0xfd,0xf6,0xdb,0x6f,0x49,0x24,0xc0,0x92,0x92,0xb0,
+  0x2b,0x51,0x08,0xb0,0xe9,0xa6,0x9b,0xaa,0xe5,0x97,0x5f,0x5e,0xb5,0x68,0xd1,0x42,
+  0x67,0x66,0xbb,0x76,0xed,0x82,0x6b,0x65,0x65,0x65,0x6a,0xc9,0x92,0x25,0xce,0x34,
+  0xd7,0x59,0x67,0x1d,0x1d,0xf3,0x9b,0x4c,0x3f,0xef,0xbc,0xf3,0x82,0x6b,0xe0,0xce,
+  0x3b,0xef,0xac,0xf7,0xdc,0x87,0x1f,0x7e,0xa8,0x56,0x58,0x61,0x05,0x7d,0xed,0xd0,
+  0x43,0x0f,0x55,0x13,0x26,0x4c,0x50,0x4f,0x3e,0xf9,0xa4,0xda,0x7d,0xf7,0xdd,0xf5,
+  0xb9,0x0d,0x37,0xdc,0x30,0x10,0xd0,0xc3,0x0f,0x3f,0x1c,0xa4,0x83,0x86,0xb1,0xc3,
+  0x4b,0x2f,0xbd,0x14,0x5c,0x9f,0x31,0x63,0x46,0x70,0xfe,0xf4,0xd3,0x4f,0xd7,0xe7,
+  0xd6,0x5c,0x73,0x4d,0xad,0x65,0xd0,0x12,0xd7,0x5e,0x7b,0x6d,0xf0,0xbf,0x68,0xb6,
+  0x24,0x86,0xac,0x08,0x40,0xe9,0x9b,0x34,0x69,0x52,0xbd,0xeb,0x10,0x41,0xae,0xdf,
+  0x75,0xd7,0x5d,0xce,0x34,0xc1,0x09,0x27,0x9c,0xa0,0x7e,0xfd,0xf5,0xd7,0xe0,0x1a,
+  0xaa,0x7c,0xad,0xb5,0xd6,0x0a,0xc8,0xf3,0xd7,0x5f,0x7f,0x05,0xd7,0x8e,0x3c,0xf2,
+  0x48,0x7d,0x7e,0xe7,0x9d,0x77,0x56,0x4b,0x97,0xfe,0xd7,0x60,0xf9,0xfa,0xeb,0xaf,
+  0xd5,0xca,0x2b,0xaf,0xac,0xaf,0x0d,0x1b,0x36,0x4c,0x9f,0xfb,0xfd,0xf7,0xdf,0xf5,
+  0x7b,0x71,0xee,0xc2,0x0b,0x2f,0x6c,0xf0,0x5d,0x67,0x9d,0x75,0x96,0xbe,0xd6,0xbc,
+  0x79,0xf3,0xe0,0xdc,0xb4,0x69,0xd3,0xd4,0x72,0xcb,0x2d,0xa7,0xcf,0x43,0x20,0x33,
+  0x5c,0x72,0xc9,0x25,0x01,0xd9,0xcd,0x77,0xf2,0x04,0xa8,0xc5,0x3b,0xef,0xbc,0xd3,
+  0xe0,0x39,0xea,0x7f,0x29,0x35,0x67,0x9e,0x79,0xa6,0x33,0xcd,0x63,0x8f,0x3d,0xd6,
+  0x59,0xaf,0xd2,0xea,0x90,0xb4,0xe7,0xcc,0x99,0xa3,0xcf,0x2d,0x5c,0xb8,0x30,0x38,
+  0xd7,0xbf,0x7f,0xff,0x06,0xcf,0xb4,0x6e,0xdd,0x5a,0x5f,0xc3,0x06,0x91,0x50,0x51,
+  0x51,0x11,0x68,0x9a,0x3f,0xfe,0xf8,0x23,0x38,0xff,0xd3,0x4f,0x3f,0xa9,0xd5,0x57,
+  0x5f,0x5d,0x5f,0x1b,0x39,0x72,0x64,0x03,0x21,0x43,0x40,0xfb,0xbd,0x26,0x4f,0x9e,
+  0x1c,0xfc,0xff,0xdc,0xb9,0x73,0x3d,0x01,0x4c,0x02,0x90,0xa1,0xae,0xb0,0xc5,0x16,
+  0x5b,0xe8,0xeb,0x08,0x27,0x4e,0xdf,0xc2,0xbd,0xf7,0xde,0x1b,0xa4,0x4d,0xc6,0x13,
+  0x50,0xe3,0x72,0x6e,0x8f,0x3d,0xf6,0x50,0xc7,0x1f,0x7f,0x7c,0x3d,0xac,0xbf,0xfe,
+  0xfa,0xfa,0xda,0x41,0x07,0x1d,0x14,0xa4,0x63,0x3e,0xf3,0xe8,0xa3,0x8f,0x06,0xe7,
+  0x47,0x8c,0x18,0x11,0xa8,0x79,0xea,0x7c,0x09,0x1d,0x3a,0x74,0xd0,0xe7,0x57,0x5a,
+  0x69,0xa5,0x06,0xe9,0x1f,0x70,0xc0,0x01,0x41,0x5a,0xa6,0x41,0x3c,0x76,0xec,0x58,
+  0xfd,0x9f,0xe9,0x70,0xd9,0x65,0x97,0x15,0x1f,0x01,0xf6,0xde,0x7b,0x6f,0x7d,0x7d,
+  0x87,0x1d,0x76,0x88,0x45,0x00,0x5a,0x01,0x92,0xb6,0xa8,0xe2,0x07,0x1e,0x78,0xc0,
+  0x69,0x98,0xd9,0xa0,0x7a,0x30,0xc3,0x76,0xdb,0x6d,0xa7,0xcf,0x53,0x7d,0x48,0xd8,
+  0x77,0xdf,0x7d,0x03,0x43,0xd3,0x0c,0xdb,0x6c,0xb3,0x4d,0xa4,0xff,0x30,0xc9,0xd4,
+  0xbb,0x77,0xef,0x48,0xcf,0xd8,0x85,0xa0,0x28,0x08,0x80,0x05,0xce,0xf5,0xf6,0xed,
+  0xdb,0xc7,0x22,0xc0,0x98,0x31,0x63,0x82,0xb4,0x5f,0x7e,0xf9,0xe5,0xc0,0xfa,0x97,
+  0x73,0xbd,0x7a,0xf5,0x52,0x2f,0xbc,0xf0,0x82,0x13,0xd4,0xe3,0x66,0xa0,0x89,0xc8,
+  0x33,0x2b,0xae,0xb8,0xa2,0xfa,0xf6,0xdb,0x6f,0x75,0x8b,0x45,0xd2,0x79,0xf3,0xcd,
+  0x37,0xeb,0xdd,0xbb,0xff,0xfe,0xfb,0xeb,0xf3,0x5b,0x6d,0xb5,0x55,0x68,0xfa,0x60,
+  0xc1,0x82,0x05,0xc1,0x33,0xdf,0x7d,0xf7,0x9d,0x7a,0xf7,0xdd,0x77,0xd3,0xa2,0xa9,
+  0x57,0x1b,0x39,0x27,0x00,0x86,0xd2,0x1a,0x6b,0xac,0xe1,0x2c,0x69,0xe9,0x08,0x70,
+  0xeb,0xad,0xb7,0x06,0x69,0xd7,0xd4,0xd4,0x04,0x6d,0x7f,0x39,0x47,0x9f,0x41,0xd4,
+  0xf0,0xf9,0xe7,0x9f,0x07,0x86,0x1d,0x56,0xfd,0xa5,0x97,0x5e,0xaa,0x8f,0x69,0x39,
+  0xd8,0xe1,0xdc,0x73,0xcf,0xd5,0xd7,0x56,0x5d,0x75,0xd5,0x7a,0x36,0x43,0x31,0x84,
+  0xac,0x08,0x80,0x81,0xe6,0xea,0x48,0x91,0xeb,0xf7,0xdd,0x77,0x9f,0x33,0xcd,0x2e,
+  0x5d,0xba,0x38,0xff,0x93,0x01,0x28,0x29,0x89,0xa6,0x31,0xd6,0xac,0x59,0x33,0x7d,
+  0x7e,0xe3,0x8d,0x37,0x56,0x3f,0xfe,0xf8,0x63,0xe4,0x8f,0x3b,0xf8,0xe0,0x83,0xf5,
+  0x73,0x3b,0xee,0xb8,0xa3,0x5a,0x77,0xdd,0x75,0xf5,0xf1,0x90,0x21,0x43,0x1a,0xdc,
+  0xc7,0x7b,0xca,0x3b,0x43,0x42,0x4f,0x80,0x88,0x04,0xd8,0x69,0xa7,0x9d,0xd4,0x5b,
+  0x6f,0xbd,0x55,0xaf,0xa7,0x8e,0x7a,0x9f,0x6b,0x08,0xcd,0x6e,0x36,0x49,0x9a,0xb4,
+  0x12,0xae,0xbe,0xfa,0xea,0x7a,0xfd,0x04,0xf4,0xcc,0x49,0xba,0x77,0xdf,0x7d,0x77,
+  0xbd,0xe7,0x68,0xf7,0xcb,0x35,0x0c,0x2b,0x4a,0xb7,0x04,0x9a,0x85,0xb4,0xe7,0xed,
+  0xe6,0x28,0xe1,0xfe,0xfb,0xef,0xaf,0x57,0x1f,0xaf,0xb6,0xda,0x6a,0x4e,0x02,0xfd,
+  0xfd,0xf7,0xdf,0xba,0x59,0x28,0x5a,0x80,0xe6,0xab,0x49,0x40,0x54,0x3f,0xef,0x40,
+  0xb3,0xd3,0x13,0xc0,0x20,0x80,0x00,0xa1,0x1f,0x78,0xe0,0x81,0x81,0xea,0x5f,0x65,
+  0x95,0x55,0x9c,0xdd,0xba,0x66,0x3f,0x80,0x58,0xe3,0x6d,0xdb,0xb6,0x0d,0x6c,0x06,
+  0xd0,0xa6,0x4d,0x1b,0x67,0x4f,0xa0,0xa8,0x70,0x40,0xdb,0x9f,0x16,0x01,0x1d,0x50,
+  0xf2,0x9f,0x1c,0xdb,0xe1,0x97,0x5f,0x7e,0xd1,0xff,0x21,0xcf,0x99,0x4d,0x45,0x3b,
+  0xbc,0xf7,0xde,0x7b,0xaa,0xb4,0xb4,0xb4,0x5e,0x27,0x17,0x06,0x9c,0x69,0x20,0x3e,
+  0xfb,0xec,0xb3,0xc5,0x43,0x80,0x8d,0x36,0xda,0x48,0x7f,0xf4,0x15,0x57,0x5c,0x11,
+  0x4a,0x80,0x29,0x53,0xa6,0x68,0x2d,0x60,0x0a,0x95,0x0c,0x7b,0xe5,0x95,0x57,0x52,
+  0x92,0x8a,0x76,0x37,0xfd,0xed,0x94,0x36,0x79,0x8e,0xe3,0x0b,0x2e,0xb8,0xa0,0x41,
+  0xef,0xa1,0x19,0x9e,0x7a,0xea,0xa9,0x7a,0x64,0x11,0x23,0x8f,0x16,0x00,0x5d,0xcb,
+  0xae,0x20,0x1d,0x3f,0xa6,0x61,0x19,0x16,0x7e,0xf8,0xe1,0x07,0xdd,0x77,0x21,0x7d,
+  0x05,0x02,0x9a,0x9a,0x68,0x1e,0x8c,0xba,0xa2,0x21,0x40,0x58,0x70,0x19,0x81,0x58,
+  0xd9,0x08,0xfd,0x9b,0x6f,0xbe,0x49,0xf9,0xac,0xad,0x55,0x28,0xe9,0xa8,0x6f,0xe0,
+  0x2a,0xf5,0x61,0x61,0xd1,0xa2,0x45,0xea,0x8d,0x37,0xde,0xd0,0xcf,0xe5,0xc3,0x68,
+  0xa3,0x4a,0xf8,0xf8,0xe3,0x8f,0x35,0x61,0x92,0xa8,0xf6,0x73,0x4e,0x80,0xa8,0xc1,
+  0x3b,0x99,0x78,0x02,0x78,0x02,0x78,0x02,0x78,0x02,0x2c,0xd3,0x04,0x98,0x35,0x6b,
+  0x96,0x1a,0x38,0x70,0xa0,0x1a,0x34,0x68,0x50,0xec,0xd1,0x31,0x9a,0x77,0x3c,0x9b,
+  0xce,0x18,0xf3,0xa1,0x09,0x13,0xc0,0x07,0x4f,0x00,0x1f,0x3c,0x01,0x7c,0xf0,0x04,
+  0xf0,0xc1,0x13,0xc0,0x07,0x4f,0x00,0x1f,0x3c,0x01,0x8a,0x23,0x24,0x75,0xae,0xa4,
+  0x27,0x40,0xc4,0x90,0xcf,0x4e,0x2c,0xc6,0x1e,0x3c,0x01,0x9a,0x78,0xc8,0xc7,0x5c,
+  0x49,0x26,0x9c,0xe0,0xb9,0x6c,0x7b,0x4f,0x7b,0x02,0x14,0x49,0xd8,0x65,0x97,0x5d,
+  0xb4,0x56,0x61,0x52,0x8a,0x27,0x40,0x96,0x21,0xd3,0x79,0x87,0xf6,0x5c,0xc7,0xaf,
+  0xbe,0xfa,0x4a,0xcf,0x4c,0xc2,0x25,0x7c,0xf8,0xf0,0xe1,0xce,0xf4,0x53,0x3d,0xcf,
+  0x0c,0x25,0xbc,0x87,0x70,0x60,0x39,0xfa,0xe8,0xa3,0x55,0xcf,0x9e,0x3d,0xb5,0x03,
+  0xa9,0x19,0x66,0xcf,0x9e,0xad,0x9f,0x91,0x6a,0x05,0x3f,0x45,0x7e,0x03,0xba,0xd8,
+  0xed,0x10,0x65,0x4e,0x64,0xdc,0xef,0x49,0x1c,0x01,0x32,0x9d,0x77,0x68,0x0e,0x6e,
+  0xe1,0x63,0x20,0xd3,0xd6,0xec,0xb9,0x83,0x51,0x3c,0xa4,0x3e,0xfb,0xec,0xb3,0xc0,
+  0xf5,0xdc,0x04,0xde,0x45,0xa6,0xff,0xa4,0xe9,0xfd,0x6c,0x03,0x0f,0x26,0x33,0x44,
+  0x9d,0x13,0x19,0xf7,0x7b,0x12,0x4b,0x80,0xb8,0xf3,0x0e,0xcd,0x0c,0x63,0x8e,0xa1,
+  0x4c,0x40,0x21,0xb3,0x10,0x54,0x1c,0x02,0x88,0xb7,0x12,0x02,0x87,0x6c,0xbb,0xee,
+  0xba,0x6b,0x70,0x0d,0x0f,0x28,0x53,0x03,0xdc,0x76,0xdb,0x6d,0x41,0x9a,0xbb,0xed,
+  0xb6,0x9b,0xfe,0x0d,0x18,0x2c,0x93,0x10,0x67,0x4e,0x64,0xdc,0xef,0x49,0x2c,0x01,
+  0xe2,0xce,0x3b,0x34,0x33,0x8c,0x89,0xae,0xe3,0xc6,0x8d,0x8b,0xd5,0x0a,0xb0,0x7d,
+  0x24,0xbb,0x77,0xef,0x1e,0x58,0xf5,0xc4,0xe2,0x93,0xc8,0xc4,0xd9,0xb8,0x36,0x40,
+  0x9c,0x39,0x91,0x71,0xbf,0x27,0xb1,0x04,0x88,0x33,0xef,0xd0,0xce,0xb0,0x01,0x03,
+  0x06,0xc4,0x6e,0x06,0x9a,0xcf,0x33,0xbf,0xc0,0x0e,0x38,0xb9,0x86,0xcd,0x47,0x48,
+  0x45,0x80,0x4c,0xe6,0x44,0xc6,0xf9,0x9e,0x44,0xdb,0x00,0xae,0xe0,0x9a,0x77,0x68,
+  0x67,0x58,0x2a,0x07,0x97,0x28,0x04,0x70,0xb9,0x9c,0x9f,0x7c,0xf2,0xc9,0x19,0x11,
+  0x20,0x93,0x39,0x91,0x71,0xbe,0xa7,0xe8,0x08,0xe0,0x9a,0x77,0x98,0x6b,0x02,0xb8,
+  0x9e,0xcf,0x94,0x00,0x99,0xce,0x89,0xf4,0x04,0x88,0x31,0xef,0xb0,0x29,0x13,0x20,
+  0xd3,0x39,0x91,0x9e,0x00,0x31,0xe6,0x1d,0x36,0x15,0x02,0xd0,0xbe,0x77,0xb5,0xfd,
+  0x33,0x99,0x13,0x59,0xf4,0x04,0x88,0x3b,0xef,0xb0,0x31,0x09,0x20,0xcd,0x39,0xd7,
+  0xac,0x26,0x42,0x26,0x73,0x22,0x8b,0x9e,0x00,0x71,0xe7,0x1d,0x36,0x26,0x01,0x30,
+  0xe6,0xe4,0x9d,0x59,0x6d,0xcd,0x0e,0x99,0xcc,0x89,0x6c,0x92,0x04,0xa0,0x3d,0xcc,
+  0x8a,0x1a,0x0c,0x7a,0x1c,0x7e,0xf8,0xe1,0x01,0x0e,0x3b,0xec,0x30,0xbd,0x3a,0x07,
+  0xb3,0x78,0x01,0xeb,0x09,0x00,0xce,0xd1,0x85,0x7b,0xe2,0x89,0x27,0xea,0x66,0x4e,
+  0xd7,0xae,0x5d,0xd5,0x0d,0x37,0xdc,0xa0,0x67,0xf6,0xd2,0x11,0x32,0x7d,0xfa,0x74,
+  0x3d,0x8d,0x2b,0xac,0x1f,0x20,0xce,0xbc,0xc3,0xc6,0x24,0x80,0x39,0x2b,0x99,0x4e,
+  0x1b,0xbe,0x99,0x2e,0x64,0x33,0xc4,0x9d,0x13,0xd9,0x64,0x08,0x80,0x9a,0x9d,0x3a,
+  0x75,0xaa,0xee,0x94,0x81,0xbd,0x22,0x74,0x96,0x71,0x93,0xd8,0x05,0xf3,0x9e,0xb0,
+  0xfb,0x5b,0xb5,0x6a,0xa5,0x3b,0x56,0x20,0x96,0xa8,0xf3,0x4c,0xe7,0x1d,0xd2,0x33,
+  0x28,0xf7,0x2d,0x5e,0xbc,0x38,0xf4,0x7b,0xc2,0xe6,0x4a,0xa6,0x7b,0x9e,0xfa,0x9d,
+  0x6b,0x54,0x41,0xae,0x70,0xdd,0x75,0xd7,0xd5,0x9b,0x94,0xba,0xdf,0x7e,0xfb,0x35,
+  0xb8,0x27,0xce,0x9c,0xc8,0xa8,0xdf,0x93,0x37,0x02,0x20,0x10,0xea,0x2b,0x98,0x4f,
+  0x69,0xa6,0x37,0xcb,0x04,0x2c,0x97,0xd8,0x3c,0x0e,0xbb,0x6e,0x82,0xf5,0x7a,0x10,
+  0x3e,0xa4,0x02,0xac,0x08,0x86,0x2a,0xe4,0x3f,0x73,0x35,0xef,0xb0,0x31,0x02,0xef,
+  0xcf,0xec,0x64,0x96,0xb0,0xb3,0x35,0x9b,0x19,0xf2,0x31,0x27,0x32,0xa7,0x04,0x40,
+  0xe5,0xd0,0x7e,0x3d,0xe6,0x98,0x63,0xf4,0x48,0x58,0xae,0x80,0xe0,0x99,0xbf,0x4f,
+  0x2f,0x9f,0xd9,0x19,0xc2,0x28,0x1b,0x19,0x81,0x26,0xf0,0xb3,0x8e,0x1a,0x91,0x00,
+  0x2c,0xa0,0x30,0x6a,0xd4,0xa8,0x60,0xb8,0x32,0x57,0x60,0xcd,0x81,0xbd,0xf6,0xda,
+  0x4b,0x75,0xec,0xd8,0xb1,0x41,0x4f,0x18,0xc0,0x28,0x62,0xb5,0x2f,0xb4,0x80,0x27,
+  0x40,0x81,0x09,0x40,0xa6,0xd3,0xa1,0x42,0x1d,0x84,0xba,0x17,0xb5,0x8c,0xe1,0x26,
+  0xb1,0x0b,0xe6,0x3d,0xae,0xfb,0xc5,0x66,0xa0,0x8d,0x4c,0x7d,0x4f,0xa9,0x37,0x49,
+  0x41,0x55,0x00,0x31,0x38,0x66,0x54,0x8d,0xea,0x86,0xc1,0x1d,0x4f,0x80,0x02,0x10,
+  0x80,0xba,0xea,0xed,0xb7,0xdf,0x56,0xdd,0xba,0x75,0xd3,0x82,0x61,0xb8,0xd5,0x06,
+  0x64,0x90,0xd8,0x05,0xf3,0x1e,0xfb,0x7e,0x84,0xcb,0x3a,0xbe,0xb4,0x08,0x10,0xb0,
+  0x08,0x9f,0x98,0xaa,0x00,0x62,0xb0,0x04,0x1d,0x96,0x30,0xe7,0xa8,0x37,0xbf,0xff,
+  0xfe,0x7b,0x4d,0x00,0x3f,0xef,0x30,0xcf,0x04,0xc0,0xe0,0xc2,0xbb,0x05,0x6b,0x36,
+  0x9f,0x40,0xb0,0x26,0xb0,0x27,0x30,0x26,0x71,0xb4,0x40,0xf0,0x8c,0xb1,0xb3,0x2a,
+  0x09,0xe7,0x59,0xb1,0x03,0x3b,0x20,0x89,0x4b,0xb8,0x36,0x19,0x02,0x50,0xea,0x11,
+  0x3e,0xcd,0xa8,0x7c,0x0b,0x1f,0x20,0x58,0x01,0x4e,0x10,0x18,0x7f,0x22,0x78,0x56,
+  0xfb,0x42,0x43,0x6c,0xbd,0xf5,0xd6,0x8d,0x4e,0x00,0xaa,0x40,0x56,0x44,0xf9,0xe8,
+  0xa3,0x8f,0x92,0x4b,0x00,0x84,0x4f,0xe6,0xe2,0xa9,0x52,0x08,0xe1,0x03,0x54,0x3d,
+  0x75,0x7f,0xcb,0x96,0x2d,0x03,0x75,0x2f,0x82,0x67,0xfd,0xa1,0x2d,0xb7,0xdc,0x52,
+  0xfb,0xe7,0xe7,0x8b,0x00,0xd8,0x14,0xd8,0x16,0x0c,0xb4,0x30,0x6a,0x88,0x2f,0x1e,
+  0xfd,0x0a,0x27,0x9d,0x74,0x92,0x7e,0x27,0xc8,0x87,0xd7,0x11,0x1d,0x4d,0x54,0x85,
+  0x38,0x67,0x2c,0xcb,0xfb,0x09,0x94,0xa4,0x63,0x39,0x6e,0x49,0x58,0xe2,0x85,0x22,
+  0x00,0x16,0x3f,0x82,0xe7,0x58,0xd4,0xbd,0x29,0x78,0xf6,0x22,0xa0,0x53,0x86,0xfb,
+  0xa2,0x12,0x00,0x0d,0x86,0xbf,0xde,0xeb,0xaf,0xbf,0xae,0x7b,0x12,0xe9,0x2c,0xb9,
+  0xfe,0xfa,0xeb,0xf5,0x02,0x52,0xd8,0x1b,0xfc,0x07,0x3d,0x71,0xac,0x15,0xcc,0x0a,
+  0x67,0x08,0x18,0xa3,0x12,0xb0,0xbe,0x20,0xc2,0x06,0xf4,0xc4,0x71,0x0f,0xab,0x90,
+  0x7f,0xfa,0xe9,0xa7,0xda,0x1d,0x8b,0xce,0x25,0xe9,0x8b,0x48,0x14,0x01,0x68,0x5b,
+  0xd3,0xc6,0xbe,0xe5,0x96,0x5b,0x0a,0x26,0x7c,0x21,0x80,0x08,0x5e,0xd4,0x3d,0xc2,
+  0xc7,0xcf,0x0e,0x21,0xe1,0x08,0x81,0x43,0x24,0x06,0x23,0x3d,0x8d,0x74,0x9e,0x3c,
+  0xf3,0xcc,0x33,0xda,0xe1,0x83,0x11,0x3f,0x76,0xf9,0xa0,0x23,0x09,0xd2,0xd2,0xc3,
+  0xc6,0xda,0x80,0xf4,0x9a,0xe1,0x12,0x86,0x40,0x21,0x0f,0xe9,0x90,0x06,0xc2,0xe5,
+  0x1c,0x83,0x2d,0x9b,0x6d,0xb6,0x99,0x76,0x17,0x63,0xa1,0x6b,0x13,0xa4,0xc1,0x7f,
+  0xb2,0x72,0x18,0xfe,0x85,0xac,0x8b,0x48,0xf3,0x93,0x92,0x8f,0x01,0x8a,0xeb,0x19,
+  0x1d,0x4d,0x89,0x23,0x00,0xa5,0x8a,0x8e,0x1d,0xac,0xf0,0x42,0x13,0x80,0x85,0x9e,
+  0x45,0xf0,0x08,0x00,0xe1,0x8b,0xe0,0x11,0x1e,0x02,0xc3,0xdf,0x8d,0xfe,0x70,0xce,
+  0xa3,0x15,0x38,0x27,0xa5,0x56,0x04,0x8a,0x00,0x19,0xfd,0xa3,0x1b,0x35,0x2a,0xf8,
+  0x6f,0x62,0x9e,0x83,0x2c,0x08,0xfe,0xec,0xb3,0xcf,0xd6,0x24,0x63,0x25,0x34,0xd6,
+  0x19,0xa6,0xf5,0x81,0x06,0x60,0x75,0x34,0xfa,0x21,0x12,0x47,0x00,0x3e,0x86,0xd2,
+  0xcf,0x07,0x32,0xd8,0x50,0x48,0x02,0x50,0xb2,0x45,0xdd,0x23,0x78,0x84,0x80,0x5b,
+  0x34,0x82,0x46,0x35,0xa3,0x82,0x39,0xc7,0xe2,0x94,0xf4,0x15,0xd0,0x1f,0x2e,0xb1,
+  0x79,0x4c,0x6c,0x83,0xf3,0x3c,0x27,0x55,0x0a,0xe4,0x22,0x2d,0xfe,0x07,0xc2,0x40,
+  0x24,0x08,0x84,0xba,0xa7,0x2a,0x60,0xf0,0x8a,0xd5,0x46,0x99,0x0d,0x84,0x47,0x11,
+  0xfb,0x10,0xe1,0xaa,0x05,0x01,0xd0,0x02,0x54,0x3f,0x68,0x00,0x0a,0x4b,0xa2,0x08,
+  0x80,0xfa,0x67,0x95,0x4d,0x3e,0xb2,0x90,0xc2,0x07,0x47,0x1c,0x71,0x44,0x50,0xcf,
+  0x23,0x78,0x31,0xb8,0x50,0xe5,0x94,0x68,0x8c,0x42,0xd4,0xbb,0x40,0x6c,0x05,0x0c,
+  0x45,0x11,0x2c,0xc2,0xe4,0x79,0xd1,0x1a,0x94,0x62,0x88,0xc3,0xe2,0xd1,0xc4,0xa4,
+  0x47,0xda,0xdc,0x87,0xa6,0xa1,0xba,0x21,0x1d,0x06,0x62,0x18,0x31,0x94,0xd1,0x48,
+  0xb4,0x51,0x18,0x30,0x56,0x25,0x36,0x8f,0xa3,0xde,0x6f,0x23,0xdd,0xf3,0x71,0xc0,
+  0x40,0x19,0xdd,0xe7,0x51,0x48,0x59,0x12,0x66,0xfc,0x31,0xf0,0xc0,0x62,0x89,0x8d,
+  0x41,0x00,0x11,0x3c,0x82,0x43,0xd5,0x53,0x2a,0x11,0xbe,0x59,0x15,0xd8,0x42,0xa5,
+  0x3a,0xa0,0x4e,0x47,0xfd,0x73,0x2f,0x6a,0x9c,0x12,0x0f,0x49,0x10,0x2c,0xbd,0x87,
+  0xf4,0x27,0x1c,0x72,0xc8,0x21,0x91,0x00,0x09,0x24,0x36,0x8f,0x73,0x75,0x7f,0x5c,
+  0xd8,0xe9,0xdb,0xe0,0x1a,0xe4,0x45,0x63,0xcb,0x48,0x2a,0x5a,0xdc,0x74,0x27,0x8f,
+  0x4c,0x00,0x54,0x1a,0xa3,0x52,0xef,0xbf,0xff,0x7e,0x41,0x85,0x4f,0x29,0xc6,0x10,
+  0xa3,0xb4,0x63,0x71,0x53,0x52,0xa5,0x8e,0xa7,0x44,0x73,0x8d,0x3a,0x1a,0xc1,0x72,
+  0x3f,0x7d,0x04,0x8c,0x0e,0xe2,0x22,0x0d,0xe3,0x25,0x36,0x8f,0x89,0x5d,0xd7,0x6d,
+  0x14,0xfa,0x7e,0x1b,0xe9,0xde,0x3f,0x15,0xd8,0xef,0x80,0x96,0x13,0xfe,0x15,0xe6,
+  0x50,0x3a,0x32,0x84,0x04,0xa9,0x34,0x41,0x28,0x01,0xb0,0x70,0xa9,0xeb,0x0a,0x25,
+  0x7c,0x1c,0x26,0xa8,0x9f,0x69,0x96,0xc9,0x47,0xf0,0x41,0x30,0x1a,0xf0,0x91,0xb9,
+  0x04,0x5a,0x41,0x62,0xf3,0x38,0x57,0xf7,0x17,0x02,0xfc,0x3f,0xf9,0x46,0xe9,0x37,
+  0x1d,0x6d,0xc4,0x6f,0x02,0xbf,0x42,0x19,0x2c,0x8b,0x4d,0x00,0xd9,0x11,0xa3,0xd0,
+  0x55,0x80,0x7c,0x00,0xec,0x47,0xa5,0x09,0xf0,0xee,0x91,0xd8,0x3c,0x0e,0xbb,0x9e,
+  0x0e,0xd9,0x3e,0x1f,0x37,0x7d,0x1b,0xe9,0xbe,0x27,0xdd,0xfd,0x54,0x6d,0xd4,0xf5,
+  0x61,0x0e,0x36,0x14,0x1e,0x7a,0x29,0x65,0xb0,0x6c,0x99,0x20,0x00,0xfd,0xfd,0x7c,
+  0x14,0x5d,0xc0,0xd4,0x6b,0x12,0xbb,0x60,0xde,0xe3,0xba,0x3f,0xdb,0xeb,0xe9,0x10,
+  0x37,0x7d,0x1b,0x99,0xbe,0x0f,0x25,0x1f,0x7b,0x26,0xcc,0xa3,0xca,0x84,0x39,0x58,
+  0xb6,0xcc,0x68,0x00,0x8f,0xd4,0x48,0x25,0x70,0x4a,0xbd,0xd8,0x01,0xc4,0x51,0x7a,
+  0x4a,0x3d,0x01,0x96,0x61,0x02,0x98,0xc2,0xb6,0x81,0xf6,0xf0,0x04,0x48,0x28,0x01,
+  0x5c,0x02,0x17,0xa1,0x4b,0x9c,0x77,0x02,0x60,0x99,0x47,0xad,0x2f,0x3d,0xe2,0x03,
+  0x43,0xcf,0x95,0xef,0xb6,0xc0,0x6d,0xa1,0x9b,0xc8,0x1b,0x01,0xb0,0x40,0x79,0x49,
+  0x3a,0x6d,0x4c,0x30,0x08,0x23,0xb1,0x79,0x4c,0x8c,0x71,0x67,0x36,0xa3,0xc2,0x80,
+  0xd7,0x8f,0x9d,0xee,0xb2,0x82,0x54,0xdf,0x1f,0x17,0x61,0x5d,0xf0,0x22,0x70,0x57,
+  0x89,0xb7,0x0d,0xc9,0xbc,0x11,0x80,0xce,0x07,0xba,0x1c,0xa5,0xbb,0xd4,0xe5,0xc2,
+  0x6d,0xba,0x7d,0xef,0xdb,0xbc,0x8d,0xda,0xaf,0xd5,0x99,0xaa,0xfd,0x61,0xd7,0xa8,
+  0x83,0x0f,0xfd,0x17,0x72,0x4c,0xac,0x51,0x7b,0xdc,0xb6,0x7d,0x77,0xb5,0xf3,0x2e,
+  0xad,0xf5,0x47,0xb8,0xba,0x38,0xed,0xff,0x33,0xcf,0xe5,0xe3,0x7e,0x1b,0xf6,0xf3,
+  0x51,0xbe,0x3f,0xd5,0xf3,0x61,0xe0,0xfb,0xc3,0x34,0x6f,0x2a,0xa1,0xdb,0xad,0x88,
+  0xbc,0x11,0x80,0x76,0xa7,0xe9,0xb9,0x93,0x0a,0xad,0x5a,0xb7,0x53,0x47,0x9f,0x78,
+  0xb3,0xba,0xa8,0xdb,0x04,0x75,0x61,0xb7,0xa7,0x75,0xac,0x71,0xb9,0x11,0x1b,0x68,
+  0x79,0xc0,0xa9,0xfa,0xe5,0xa3,0xa6,0x9f,0x4b,0x88,0x0b,0x9a,0xe9,0x8e,0x26,0x71,
+  0x21,0x81,0x26,0x4c,0x45,0x00,0x57,0x93,0xd2,0x6e,0x4e,0xe6,0x8d,0x00,0xa8,0xf1,
+  0x30,0x8f,0x5f,0x1b,0x7c,0x4c,0xcb,0x36,0x27,0xa8,0x2b,0x6f,0x7c,0x41,0x55,0xfe,
+  0x6f,0x6a,0x5a,0x5c,0xd6,0x73,0xa2,0x6a,0xd1,0xaa,0x3c,0xa5,0x57,0xb1,0x09,0xbc,
+  0x74,0x24,0x36,0x8f,0xa3,0xbe,0x5f,0x63,0xc3,0xf5,0xfe,0x94,0x6e,0x06,0xb7,0xc2,
+  0x08,0x60,0x97,0x72,0x7b,0xec,0xc1,0x3c,0xce,0x0b,0x01,0x48,0x38,0xcc,0x03,0xd8,
+  0xf6,0xf8,0x6d,0x7f,0x48,0x07,0x75,0x41,0xf7,0x7b,0x54,0xdf,0x51,0xb3,0x23,0x81,
+  0x7b,0x79,0x26,0x2c,0xbd,0x5c,0x7a,0x20,0x67,0x92,0x7e,0x21,0xd2,0xc3,0xbe,0x92,
+  0xb1,0x8e,0x30,0x02,0x84,0x0d,0x06,0xd9,0x83,0x4f,0x79,0x21,0x00,0x2a,0x91,0x71,
+  0x72,0x17,0xce,0x38,0xe3,0x8c,0x20,0x06,0x6d,0xdb,0x77,0x54,0xb7,0x8c,0x9c,0xa6,
+  0x86,0x3f,0x39,0xaf,0x21,0xc6,0x7d,0xfd,0x5f,0x5c,0x8b,0x01,0x0f,0x7c,0xa8,0x3a,
+  0x1c,0x79,0xba,0x9e,0x5c,0x12,0x96,0x9e,0x79,0x2e,0x1f,0xc8,0xf6,0xff,0xb2,0x7d,
+  0x9e,0xe1,0x60,0xbc,0xa0,0x18,0x14,0x0b,0x23,0x80,0x5d,0xd2,0xc3,0xc0,0xc8,0x67,
+  0x5e,0x08,0x20,0x33,0x76,0xa3,0xa0,0x6d,0xbb,0x0e,0xea,0xec,0xae,0xfd,0x54,0xcf,
+  0x81,0x13,0xd5,0x35,0x77,0x3c,0x1b,0xc4,0xfa,0xd8,0x88,0xbb,0xf5,0xaa,0x52,0x87,
+  0x1f,0xd7,0x29,0x6d,0xda,0xf8,0xf0,0x49,0x6c,0x1e,0x47,0x7d,0x9f,0x7c,0xa7,0x97,
+  0xcd,0xff,0x41,0x00,0x06,0x76,0x20,0x00,0xc0,0xef,0x21,0x4c,0x03,0xb8,0x4a,0xbb,
+  0x3d,0xd4,0x9d,0x37,0x02,0x60,0x00,0x9e,0x73,0xce,0x39,0x91,0xc0,0x47,0xd1,0xa4,
+  0x09,0xeb,0xb9,0x92,0xf3,0x30,0x9f,0x8c,0xb0,0x9f,0xc7,0x15,0x4b,0x62,0xf3,0x38,
+  0xea,0xff,0xa7,0x43,0xbe,0xd3,0x8f,0xfa,0x7f,0x10,0x00,0x8f,0x25,0x11,0x3e,0x80,
+  0x0c,0x61,0x1a,0xc0,0x55,0xda,0x5d,0xc8,0x0b,0x01,0x18,0x8f,0x47,0x60,0x2c,0x89,
+  0xc6,0x5c,0x81,0x8a,0x8a,0x0a,0x1d,0xbb,0x20,0xd7,0x88,0x5d,0xb0,0x9f,0xb7,0xef,
+  0x8f,0x7b,0x3d,0xdd,0xff,0xa7,0x4b,0x2f,0xdb,0xf7,0x8b,0xfb,0xfd,0x90,0x9e,0x82,
+  0x80,0x17,0x13,0xde,0x4c,0x26,0x01,0xc2,0x0c,0x41,0x5b,0xe8,0x36,0x01,0xcc,0xb5,
+  0x16,0xf2,0x46,0x00,0x9c,0x33,0x80,0xb8,0x4d,0xe3,0xc1,0x93,0x09,0xe4,0x59,0x62,
+  0xf3,0x38,0xea,0xf5,0xb8,0xe9,0x15,0xfa,0xfe,0x28,0xdf,0x8f,0x93,0xab,0x2d,0x7c,
+  0x10,0x66,0x08,0xda,0xa5,0x5c,0x84,0x6d,0x2e,0xb0,0x21,0x24,0xc8,0x0b,0x01,0xa8,
+  0x9b,0xf0,0xa3,0xc3,0x3d,0x0b,0xf7,0x2b,0x3c,0x76,0xc4,0x69,0x33,0x15,0xc4,0x63,
+  0xd7,0x06,0x19,0x90,0x6b,0x08,0x41,0xc5,0x05,0xdc,0x3c,0xce,0x16,0x61,0xdf,0x21,
+  0x48,0x97,0x0f,0x22,0x7c,0xd2,0x12,0x0f,0x27,0x5b,0xf8,0x80,0x2a,0x21,0x2e,0x01,
+  0x4c,0xd0,0xf3,0x5a,0x90,0xc1,0x20,0xf1,0xe4,0x71,0x7d,0x84,0x47,0xe6,0x08,0xb3,
+  0x01,0x52,0x09,0xdc,0x3e,0x2e,0xd8,0x68,0x20,0x5a,0x41,0x5c,0xae,0xbd,0xf0,0xb2,
+  0x03,0x4d,0x40,0x16,0x8f,0x0e,0xcb,0x6b,0x5b,0xf0,0xa6,0xd0,0x6d,0xf8,0xe1,0xe0,
+  0x04,0xc2,0x55,0xea,0x6d,0xc1,0x33,0xa0,0x06,0x3c,0x01,0x12,0x4a,0x00,0x57,0x69,
+  0x17,0xc1,0x7b,0x02,0x24,0x1c,0xae,0x92,0x6e,0x1e,0x03,0x7c,0x09,0x3c,0x01,0x12,
+  0x0a,0x5b,0xe0,0x2e,0xe1,0x7b,0x02,0x14,0x01,0x01,0x44,0xc8,0x66,0x89,0x37,0x63,
+  0xe0,0x09,0x90,0x50,0x02,0x98,0xc2,0x36,0x05,0xee,0x09,0x50,0x04,0x08,0x13,0xbc,
+  0x6b,0x92,0x89,0x27,0x40,0x42,0x09,0x10,0x75,0x26,0x92,0x27,0x40,0x02,0x61,0x97,
+  0xf4,0x30,0x30,0x7b,0xc8,0x13,0x20,0xa1,0x1a,0x20,0x4c,0xe0,0x9e,0x00,0x45,0xa2,
+  0x01,0x5c,0xc2,0x77,0xc1,0x13,0x20,0xc1,0x04,0x10,0x21,0xdb,0x04,0x90,0xf5,0x05,
+  0x3c,0x01,0x12,0x0a,0xbb,0x94,0x8b,0xb0,0x25,0x36,0x49,0xe0,0x09,0x50,0x24,0x04,
+  0x08,0x5b,0x91,0x24,0x27,0x04,0xc0,0x35,0xc9,0xa3,0xe9,0xc0,0x2c,0xf1,0xae,0x25,
+  0x68,0xcc,0x63,0xaf,0x01,0x12,0x88,0x54,0x25,0xde,0x86,0x27,0x40,0xc2,0x09,0x10,
+  0xb6,0x90,0x14,0x0b,0x67,0x01,0x4f,0x80,0x84,0x12,0x20,0x6c,0xb5,0x30,0x59,0x31,
+  0xcd,0x13,0x20,0xc1,0x70,0x95,0x74,0xf3,0x18,0xb0,0xaa,0xb9,0x27,0x40,0x42,0x61,
+  0x0b,0xdc,0x16,0xbe,0xb9,0x8c,0x9d,0x27,0x40,0x82,0x09,0x20,0xa5,0x5c,0x84,0x2e,
+  0x8b,0x6f,0xb0,0xd2,0x1a,0x0b,0x68,0x12,0x7b,0x02,0x24,0x94,0x00,0xa6,0xd0,0x81,
+  0x29,0x74,0x56,0x0c,0x95,0x75,0x94,0x3d,0x01,0x12,0x08,0x11,0xbc,0x08,0x1c,0x98,
+  0x8b,0x67,0x33,0x9f,0x00,0xb7,0x72,0x62,0x4f,0x80,0x04,0x42,0x04,0x6f,0x0b,0x5d,
+  0x20,0xcb,0xe2,0xb3,0xcd,0x8d,0x27,0x40,0x02,0xe1,0x2a,0xe9,0xe6,0x3e,0x09,0x4c,
+  0xce,0x61,0x06,0x37,0xfb,0x0d,0xcf,0x9a,0x35,0x2b,0xfb,0x95,0x42,0xa9,0x6f,0x7c,
+  0xc6,0x37,0x0d,0x88,0xc0,0xcd,0x0d,0x30,0x88,0x99,0x4d,0x84,0xe0,0x01,0xc6,0x21,
+  0x7b,0x28,0x56,0x57,0x57,0xeb,0xb5,0x82,0x59,0xf6,0x3f,0xab,0xc5,0xa2,0x0b,0xbd,
+  0x65,0x8c,0x47,0x38,0xd8,0xd8,0x02,0x81,0x8b,0xb0,0x45,0xf0,0xb2,0xdd,0x0d,0x2b,
+  0xb2,0x0d,0x19,0x32,0x44,0x8d,0x1d,0x3b,0x56,0xef,0x6c,0xf2,0xc5,0x17,0x5f,0xe8,
+  0x8d,0x3f,0xd8,0x00,0x24,0xe3,0xe5,0xe2,0xd9,0x5d,0xcb,0x67,0x7e,0xe3,0x83,0x81,
+  0x20,0x11,0xba,0xec,0x6b,0x24,0x7b,0x1c,0xb1,0xbf,0x51,0x97,0x2e,0x5d,0xd4,0xa0,
+  0x41,0x83,0xf4,0xe6,0xdd,0x93,0x27,0x4f,0xd6,0xbb,0xbd,0x51,0x88,0xd9,0xd5,0x2c,
+  0xa3,0xfd,0x02,0xd8,0x6c,0xe0,0x83,0x0f,0x3e,0xd0,0x6c,0xda,0x67,0x9f,0x7d,0xbc,
+  0x10,0x1a,0x59,0xf8,0xe6,0xc6,0x56,0x08,0x1c,0x30,0x29,0xb7,0x73,0xe7,0xce,0x7a,
+  0xb7,0xb4,0xc1,0x83,0x07,0x6b,0xe1,0x4f,0x9a,0x34,0x49,0x17,0x5c,0x36,0xb5,0x64,
+  0x3f,0xa3,0x8c,0x76,0x0c,0xe1,0x21,0x76,0x0c,0x63,0xcb,0x18,0x12,0x2c,0xc4,0x96,
+  0xb1,0x1e,0x6e,0x50,0xcf,0x8b,0xd0,0x59,0x97,0x01,0x50,0x2d,0xa3,0x99,0xd9,0xd0,
+  0x73,0xc0,0x80,0x01,0x6a,0xf8,0xf0,0xe1,0xea,0xa1,0x87,0x1e,0xd2,0x25,0x9f,0x6a,
+  0x9b,0x2d,0xed,0x50,0xfd,0x51,0x36,0xb3,0x82,0x00,0x4b,0x52,0x6d,0x1a,0xc5,0xbe,
+  0x7c,0x30,0xab,0x50,0x5b,0xc7,0x7a,0xd4,0xdf,0x42,0x47,0x4a,0x3b,0x6d,0x7f,0x76,
+  0x2a,0xed,0xdd,0xbb,0xb7,0xea,0xdb,0xb7,0xaf,0xba,0xe3,0x8e,0x3b,0xb4,0xe0,0xd9,
+  0xd5,0x6c,0xdc,0xb8,0x71,0x7a,0x0f,0x45,0x34,0x36,0x25,0x3f,0xaa,0xf0,0x91,0x3d,
+  0x04,0xa8,0x09,0xdb,0x36,0x6e,0xfe,0xfc,0xf9,0x6a,0xc6,0x8c,0x19,0xba,0x49,0x31,
+  0x62,0xc4,0x08,0xd5,0xa3,0x47,0x0f,0x5f,0x1d,0x14,0x50,0xf8,0xcd,0x9a,0x35,0xd3,
+  0x6b,0x00,0xf5,0xea,0xd5,0x2b,0x28,0xed,0x18,0x79,0xf7,0xdc,0x73,0x8f,0x2e,0xf1,
+  0xc8,0x65,0xca,0x94,0x29,0x7a,0x47,0xf7,0x39,0x73,0xe6,0xa8,0x05,0x0b,0x16,0xc4,
+  0xdd,0xc6,0xae,0x06,0x02,0x54,0xa7,0xda,0x38,0x72,0xee,0xdc,0xb9,0x7a,0x4b,0xf6,
+  0x47,0x1e,0x79,0x44,0x0d,0x1b,0x36,0x4c,0xf5,0xeb,0xd7,0x4f,0x55,0x56,0x56,0xfe,
+  0xbb,0x0c,0xac,0x6f,0x22,0xe6,0x65,0xb8,0x97,0x25,0xe0,0x4e,0x3d,0xf5,0x54,0x5d,
+  0xb7,0x53,0xda,0x07,0x0e,0x1c,0xa8,0x0b,0x20,0xa5,0xfd,0xf1,0xc7,0x1f,0xd7,0x4d,
+  0x3c,0x36,0xb1,0x9c,0x39,0x73,0xa6,0x16,0x3c,0xa5,0x9e,0xe6,0x9e,0xec,0x12,0x16,
+  0x63,0x0f,0xc3,0x6a,0x08,0x50,0x99,0x6a,0xf3,0xc8,0x85,0x0b,0x17,0x06,0x9b,0x29,
+  0x43,0x02,0x5e,0x84,0x0d,0x95,0xfb,0xf4,0xe9,0xa3,0x5f,0x90,0xad,0x65,0xc1,0xcd,
+  0x37,0xdf,0xec,0x91,0x05,0x24,0x1f,0xc9,0x53,0x4a,0x7b,0xff,0xfe,0xfd,0xb5,0x61,
+  0x47,0x9b,0x9e,0xd2,0x3e,0x61,0xc2,0x04,0x2d,0x83,0xe9,0xd3,0xa7,0x6b,0x79,0xd0,
+  0xc4,0xa3,0xc4,0x53,0x48,0xd9,0x1b,0x99,0x02,0x9b,0xaa,0xb9,0x17,0x12,0x2a,0x21,
+  0x40,0x19,0x76,0x5f,0x98,0x31,0xc8,0x06,0xc9,0x54,0x05,0xfc,0x29,0x9a,0x00,0xb5,
+  0x33,0x66,0xcc,0x18,0xfd,0x62,0x6c,0xc2,0x3c,0x74,0xe8,0x50,0xad,0x96,0x3c,0xb2,
+  0x07,0x79,0x49,0x9e,0x8e,0x1c,0x39,0x52,0x8d,0x1e,0x3d,0x5a,0x3d,0xf6,0xd8,0x63,
+  0x6a,0xe2,0xc4,0x89,0xc1,0x6e,0xa5,0x6c,0x57,0x4b,0x69,0xa7,0x85,0x46,0x3d,0x9f,
+  0xe5,0xc6,0xd5,0xc8,0xbc,0xac,0x84,0x50,0x7b,0x50,0x15,0xa6,0x05,0x84,0x04,0x68,
+  0x02,0xaa,0x03,0x6c,0x02,0x0c,0x43,0x5a,0x07,0xb0,0x72,0xfc,0xf8,0xf1,0xda,0x08,
+  0x61,0x57,0x6e,0x8f,0xcc,0x41,0x1e,0x92,0x97,0x6c,0x51,0x8b,0xd0,0x29,0xed,0xd3,
+  0xa6,0x4d,0xd3,0xed,0x79,0x4a,0x3b,0xf9,0xbf,0x78,0xf1,0xe2,0x7a,0xa5,0x3d,0xcb,
+  0xed,0x6a,0xab,0x4a,0x24,0xd4,0xfe,0x28,0xad,0xc5,0xa2,0x54,0x24,0xa0,0x3a,0x40,
+  0xdd,0xb0,0x9f,0x30,0xad,0x03,0x9a,0x88,0x6c,0x2c,0x09,0x33,0x69,0x7a,0x78,0x64,
+  0x0f,0xf2,0x92,0x3c,0x45,0xdb,0x52,0xd8,0xe6,0xcd,0x9b,0xa7,0x3b,0xe4,0x72,0x50,
+  0xda,0xed,0x80,0xac,0x4b,0x4b,0xcc,0x50,0x7b,0xa2,0x3c,0xac,0x2a,0x10,0x22,0xc0,
+  0x3c,0x88,0xc0,0x0b,0x41,0x06,0x54,0x11,0x2f,0x08,0xe8,0x75,0xf2,0xc8,0x1c,0x92,
+  0x8f,0xe4,0x29,0x06,0x1d,0x1b,0x3e,0x52,0xda,0xd9,0x99,0x3c,0x07,0xa5,0xdd,0x56,
+  0xfd,0xe5,0x25,0xae,0x50,0x7b,0xa1,0x22,0x15,0x09,0x84,0x08,0xbc,0x10,0x6c,0x84,
+  0x10,0x1e,0xb9,0x07,0x79,0x9b,0x63,0xa1,0x9b,0xc2,0xaf,0x28,0x49,0x15,0xea,0x34,
+  0xc1,0x22,0xe5,0x43,0xd2,0xc2,0xa2,0xd0,0x92,0xef,0x20,0x41,0x69,0x9d,0x61,0xb8,
+  0xd4,0xe7,0xdb,0x32,0x1f,0x96,0xd6,0xc9,0xb2,0xb4,0x24,0x6e,0xa8,0x6b,0x22,0x56,
+  0xd6,0x75,0x16,0xd5,0xb8,0xba,0x8d,0x7d,0x68,0x72,0x61,0x49,0x9d,0xac,0xaa,0xeb,
+  0x64,0x57,0x96,0x4a,0xc6,0xff,0x07,0x09,0xd2,0xdd,0xcf,0xb2,0x57,0xe1,0x2d,0x00,
+  0x00,0x00,0x00,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
   
 };
Binary files 2.3.3-3/tools/printer-sm.png and 2.3.3op1-3/tools/printer-sm.png differ
diff -pruN 2.3.3-3/tools/printer-sm-png.h 2.3.3op1-3/tools/printer-sm-png.h
--- 2.3.3-3/tools/printer-sm-png.h	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/tools/printer-sm-png.h	2020-11-27 14:25:26.000000000 +0000
@@ -0,0 +1,235 @@
+static const unsigned char printer_sm_png[] =
+{
+  0x89,0x50,0x4e,0x47,0x0d,0x0a,0x1a,0x0a,0x00,0x00,0x00,0x0d,0x49,0x48,0x44,0x52,
+  0x00,0x00,0x00,0x30,0x00,0x00,0x00,0x30,0x08,0x03,0x00,0x00,0x00,0x60,0xdc,0x09,
+  0xb5,0x00,0x00,0x04,0x19,0x69,0x43,0x43,0x50,0x6b,0x43,0x47,0x43,0x6f,0x6c,0x6f,
+  0x72,0x53,0x70,0x61,0x63,0x65,0x47,0x65,0x6e,0x65,0x72,0x69,0x63,0x52,0x47,0x42,
+  0x00,0x00,0x38,0x8d,0x8d,0x55,0x5d,0x68,0x1c,0x55,0x14,0x3e,0xbb,0x73,0x67,0x23,
+  0x24,0xce,0x53,0x6c,0x34,0x85,0x74,0xa8,0x3f,0x0d,0x25,0x0d,0x93,0x56,0x34,0xa1,
+  0xb4,0xba,0x7f,0xdd,0xdd,0x36,0x6e,0x96,0x49,0x36,0xda,0x22,0xe8,0x64,0xf6,0xee,
+  0xce,0x98,0xc9,0xce,0x38,0x33,0xbb,0xfd,0xa1,0x4f,0x45,0x50,0x7c,0x31,0xea,0x9b,
+  0x14,0xc4,0xbf,0xb7,0x80,0x20,0x28,0xf5,0x0f,0xdb,0x3e,0xb4,0x2f,0x95,0x0a,0x25,
+  0xda,0xd4,0x20,0x28,0x3e,0xb4,0xf8,0x83,0x50,0xe8,0x8b,0xa6,0xeb,0x99,0x3b,0x33,
+  0x99,0x69,0xba,0xb1,0xde,0x65,0xee,0x7c,0xf3,0x9d,0xef,0x9e,0x7b,0xee,0xb9,0x67,
+  0xef,0x05,0xe8,0xb9,0xaa,0x58,0x96,0x91,0x14,0x01,0x16,0x9a,0xae,0x2d,0x17,0x32,
+  0xe2,0x73,0x87,0x8f,0x88,0x3d,0x2b,0x90,0x84,0x87,0xa0,0x17,0x06,0xa1,0x57,0x51,
+  0x1d,0x2b,0x5d,0xa9,0x4c,0x02,0x36,0x4f,0x0b,0x77,0xb5,0x5b,0xdf,0x43,0xc2,0x7b,
+  0x5f,0xd9,0xd5,0xdd,0xfe,0x9f,0xad,0xb7,0x46,0x1d,0x15,0x20,0x71,0x1f,0x62,0xb3,
+  0xe6,0xa8,0x0b,0x88,0x8f,0x01,0xf0,0xa7,0x55,0xcb,0x76,0x01,0x7a,0xfa,0x91,0x1f,
+  0x3f,0xea,0x5a,0x1e,0xf6,0x62,0xe8,0xb7,0x31,0x40,0xc4,0x2f,0x7a,0xb8,0xe1,0x63,
+  0xd7,0xc3,0x73,0x3e,0x7e,0x8d,0x69,0x66,0xe4,0x2c,0xe2,0xd3,0x88,0x05,0x55,0x53,
+  0x6a,0x88,0x97,0x10,0x8f,0xcc,0xc5,0xf8,0x46,0x0c,0xfb,0x31,0xb0,0xd6,0x5f,0xa0,
+  0x4d,0x6a,0xeb,0xaa,0xe8,0xe5,0xa2,0x62,0x9b,0x75,0xdd,0xa0,0xb1,0x70,0xef,0x61,
+  0xfe,0x9f,0x6d,0xc1,0x68,0x85,0xf3,0x6d,0xc3,0xa7,0xcf,0x99,0x9f,0x3e,0x84,0xef,
+  0x61,0x5c,0xfb,0x2b,0x35,0x25,0xe7,0xe1,0x51,0xc4,0x4b,0xaa,0x92,0x9f,0x46,0xfc,
+  0x08,0xe2,0x6b,0x6d,0x7d,0xb6,0x1c,0xe0,0xdb,0x96,0x9b,0x91,0x11,0x3f,0x06,0x90,
+  0xdc,0xde,0x9a,0xaf,0xa6,0x11,0xef,0x44,0x5c,0xac,0xdb,0x07,0xaa,0xbe,0x9f,0xa4,
+  0xad,0xb5,0x8a,0x21,0x7e,0xe7,0x84,0x36,0xf3,0x2c,0xe2,0x2d,0x88,0xcf,0x37,0xe7,
+  0xca,0x53,0xc1,0xd8,0xab,0xaa,0x93,0xc5,0x9c,0xc1,0x76,0xc4,0xb7,0x35,0x5a,0xf2,
+  0xf2,0x3b,0x04,0xc0,0x89,0xba,0x5b,0x9a,0xf1,0xc7,0x72,0xfb,0x6d,0x53,0x9e,0xf2,
+  0xe7,0xe5,0xea,0x35,0x9a,0xcb,0x7b,0x79,0x44,0xfc,0xfa,0xbc,0x79,0x48,0xf6,0x7d,
+  0x72,0x9f,0x39,0xed,0xe9,0x7c,0xe8,0xf3,0x84,0x96,0x2d,0x07,0xfc,0xa5,0x97,0x94,
+  0x83,0x15,0xc4,0x83,0x88,0x7f,0xa1,0x46,0x41,0xf6,0xe7,0xe2,0xfe,0xb1,0xdc,0x4a,
+  0x10,0x03,0x19,0x6a,0x1a,0xe5,0x49,0x7f,0x2e,0x92,0xa3,0x0e,0x5b,0x2f,0xe3,0x5d,
+  0x6d,0xa6,0xe8,0xcf,0x4b,0x0c,0x17,0x37,0xd4,0x1f,0x4b,0x16,0xeb,0xfa,0x81,0x52,
+  0xa0,0xff,0x44,0xb3,0x8b,0x72,0x80,0xaf,0x59,0x06,0xab,0x51,0x8c,0x8d,0x4f,0xda,
+  0x2d,0xb9,0xea,0xeb,0xf9,0x51,0xc5,0xce,0x17,0x7c,0x9f,0x7c,0x85,0x36,0xab,0x81,
+  0x7f,0xbe,0x0d,0xb3,0x09,0x05,0x28,0x98,0x30,0x87,0xbd,0x0a,0x4d,0x58,0x03,0x11,
+  0x64,0x28,0x40,0x06,0xdf,0x16,0xd8,0x68,0xa9,0x83,0x0e,0x06,0x32,0x14,0xad,0x14,
+  0x19,0x8a,0x5f,0xa1,0x66,0x17,0x1b,0xe7,0xc0,0x3c,0xf2,0x3a,0xb4,0x99,0xcd,0xc1,
+  0xbe,0xc2,0x94,0xfe,0xc8,0xc8,0x5f,0x83,0xf9,0xb8,0xce,0xb4,0x2a,0x64,0x87,0x3e,
+  0x82,0x16,0xb2,0x1a,0xfc,0x8e,0xac,0x16,0xd3,0x65,0xf1,0xab,0x85,0x5c,0x63,0x13,
+  0x3f,0x7e,0x2c,0x37,0x02,0x3f,0x26,0x19,0x20,0x12,0xd9,0x83,0xcf,0x5e,0x32,0x49,
+  0xf6,0x91,0x71,0x32,0x01,0x22,0x79,0x8a,0x3c,0x4d,0xf6,0x93,0x1c,0xb2,0x13,0x64,
+  0xef,0xfa,0xd8,0x4a,0x6c,0x45,0x5e,0x3c,0x37,0xd6,0xfd,0xbc,0x8c,0x33,0x52,0xa6,
+  0x9b,0x45,0xdd,0x39,0xb4,0xbb,0xa0,0x60,0xff,0x33,0x2a,0x4c,0x5c,0x53,0xd7,0xac,
+  0x2c,0x0e,0xb6,0x86,0x23,0xcb,0x29,0xfb,0x05,0x5d,0xbd,0xfc,0xc6,0x5f,0xb1,0x5c,
+  0xe9,0x2c,0x37,0x51,0xb6,0xe2,0x19,0x9d,0xba,0x57,0xce,0xf9,0x5f,0xf9,0xeb,0xfc,
+  0x32,0xf6,0x2b,0xfc,0x6a,0xa4,0xe0,0x7f,0xe4,0x57,0xf1,0xb7,0x72,0xc7,0x5a,0xcc,
+  0xbb,0xb2,0x4c,0xc3,0xec,0x6c,0x58,0x73,0x77,0x55,0x1a,0x6d,0x06,0xe3,0x16,0xf0,
+  0xd1,0x99,0xc5,0x89,0xc5,0x1d,0xf3,0x71,0xf1,0xe4,0x57,0x0f,0x46,0x7e,0x96,0xc9,
+  0x99,0xe7,0xaf,0xf4,0x5d,0x3c,0x59,0x6f,0x2e,0x0e,0x46,0xac,0x97,0x05,0xfa,0x6a,
+  0xf9,0x56,0x19,0x4e,0x8d,0x44,0xac,0xf4,0x83,0xf4,0x87,0xb4,0x2c,0xbd,0x27,0x7d,
+  0x28,0xfd,0xc6,0xbd,0xcd,0x7d,0xca,0x7d,0xcd,0x7d,0xce,0x7d,0xc1,0x5d,0x02,0x91,
+  0x3b,0xcb,0x9d,0xe3,0xbe,0xe1,0x2e,0x70,0x1f,0x73,0x5f,0xc6,0xf6,0x6a,0xf3,0x1a,
+  0x5a,0xdf,0x7b,0x16,0x79,0x18,0xb7,0x67,0xe9,0x96,0x6b,0xac,0x4a,0x21,0x23,0x6c,
+  0x15,0x1e,0x16,0x72,0xc2,0x36,0xe1,0x51,0x61,0x32,0xf2,0x27,0x0c,0x08,0x63,0x42,
+  0x51,0xd8,0x81,0x96,0xad,0xeb,0xfb,0x16,0x9f,0x2f,0x9e,0x3d,0x1d,0x0e,0x63,0x1f,
+  0xe6,0xa7,0xfb,0x5c,0xbe,0x2e,0x56,0x01,0x89,0xfb,0xb1,0x02,0xf4,0x4d,0xfe,0x55,
+  0x55,0x54,0xe9,0x70,0x94,0x29,0x1d,0x56,0x6f,0x4d,0x38,0xbe,0x41,0x13,0x8c,0x24,
+  0x43,0x64,0x8c,0x94,0x36,0x54,0xf7,0xb8,0x57,0xf3,0xa1,0x22,0x95,0x4f,0xe5,0x52,
+  0x69,0x10,0x53,0x3b,0x53,0x13,0xa9,0xb1,0xd4,0x41,0x0f,0x87,0xb3,0xa6,0x76,0xa0,
+  0x6d,0x02,0xfb,0xfc,0x1d,0xd5,0xa9,0x6e,0xb2,0x52,0xea,0xd2,0x63,0xde,0x7d,0x02,
+  0x59,0xd3,0x3a,0x6e,0xeb,0x0d,0xcd,0x15,0x77,0x4b,0xd2,0x93,0x62,0x1a,0xaf,0x36,
+  0x2a,0x96,0x9a,0xea,0xe8,0x88,0xa8,0x18,0x86,0xc8,0x4c,0x8e,0x68,0x53,0x87,0xda,
+  0x6d,0x5a,0x1b,0x05,0xef,0xde,0xf4,0x8f,0xf4,0x9b,0x32,0xbb,0x0f,0x13,0x5b,0x2e,
+  0x47,0x9c,0xfb,0x0c,0xc0,0xbe,0x3f,0xf1,0xec,0xfb,0x2e,0xe2,0x8e,0xb4,0x00,0x96,
+  0x1c,0x80,0x81,0xc7,0x23,0x6e,0x18,0xcf,0xca,0x07,0xde,0x05,0x38,0xf3,0x84,0xda,
+  0xb2,0xdb,0xc1,0x1d,0x91,0x48,0x7c,0x0b,0xe0,0xd4,0xf7,0xec,0xf6,0xbf,0xfa,0x32,
+  0x78,0x7e,0xfd,0xd4,0xe9,0xdc,0xc4,0x73,0xac,0xe7,0x2d,0x80,0xb5,0x37,0x3b,0x9d,
+  0xbf,0xdf,0xef,0x74,0xd6,0x3e,0x40,0xff,0xab,0x00,0x67,0x8d,0x7f,0x01,0xa0,0x9f,
+  0x7c,0x55,0x03,0x5c,0x0b,0xef,0x00,0x00,0x00,0x38,0x65,0x58,0x49,0x66,0x4d,0x4d,
+  0x00,0x2a,0x00,0x00,0x00,0x08,0x00,0x01,0x87,0x69,0x00,0x04,0x00,0x00,0x00,0x01,
+  0x00,0x00,0x00,0x1a,0x00,0x00,0x00,0x00,0x00,0x02,0xa0,0x02,0x00,0x04,0x00,0x00,
+  0x00,0x01,0x00,0x00,0x00,0x30,0xa0,0x03,0x00,0x04,0x00,0x00,0x00,0x01,0x00,0x00,
+  0x00,0x30,0x00,0x00,0x00,0x00,0xf8,0xff,0x4e,0x36,0x00,0x00,0x03,0x62,0x69,0x54,
+  0x58,0x74,0x58,0x4d,0x4c,0x3a,0x63,0x6f,0x6d,0x2e,0x61,0x64,0x6f,0x62,0x65,0x2e,
+  0x78,0x6d,0x70,0x00,0x00,0x00,0x00,0x00,0x3c,0x78,0x3a,0x78,0x6d,0x70,0x6d,0x65,
+  0x74,0x61,0x20,0x78,0x6d,0x6c,0x6e,0x73,0x3a,0x78,0x3d,0x22,0x61,0x64,0x6f,0x62,
+  0x65,0x3a,0x6e,0x73,0x3a,0x6d,0x65,0x74,0x61,0x2f,0x22,0x20,0x78,0x3a,0x78,0x6d,
+  0x70,0x74,0x6b,0x3d,0x22,0x58,0x4d,0x50,0x20,0x43,0x6f,0x72,0x65,0x20,0x35,0x2e,
+  0x34,0x2e,0x30,0x22,0x3e,0x0a,0x20,0x20,0x20,0x3c,0x72,0x64,0x66,0x3a,0x52,0x44,
+  0x46,0x20,0x78,0x6d,0x6c,0x6e,0x73,0x3a,0x72,0x64,0x66,0x3d,0x22,0x68,0x74,0x74,
+  0x70,0x3a,0x2f,0x2f,0x77,0x77,0x77,0x2e,0x77,0x33,0x2e,0x6f,0x72,0x67,0x2f,0x31,
+  0x39,0x39,0x39,0x2f,0x30,0x32,0x2f,0x32,0x32,0x2d,0x72,0x64,0x66,0x2d,0x73,0x79,
+  0x6e,0x74,0x61,0x78,0x2d,0x6e,0x73,0x23,0x22,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,
+  0x20,0x3c,0x72,0x64,0x66,0x3a,0x44,0x65,0x73,0x63,0x72,0x69,0x70,0x74,0x69,0x6f,
+  0x6e,0x20,0x72,0x64,0x66,0x3a,0x61,0x62,0x6f,0x75,0x74,0x3d,0x22,0x22,0x0a,0x20,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x78,0x6d,0x6c,0x6e,0x73,
+  0x3a,0x64,0x63,0x3d,0x22,0x68,0x74,0x74,0x70,0x3a,0x2f,0x2f,0x70,0x75,0x72,0x6c,
+  0x2e,0x6f,0x72,0x67,0x2f,0x64,0x63,0x2f,0x65,0x6c,0x65,0x6d,0x65,0x6e,0x74,0x73,
+  0x2f,0x31,0x2e,0x31,0x2f,0x22,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+  0x20,0x20,0x20,0x78,0x6d,0x6c,0x6e,0x73,0x3a,0x49,0x70,0x74,0x63,0x34,0x78,0x6d,
+  0x70,0x45,0x78,0x74,0x3d,0x22,0x68,0x74,0x74,0x70,0x3a,0x2f,0x2f,0x69,0x70,0x74,
+  0x63,0x2e,0x6f,0x72,0x67,0x2f,0x73,0x74,0x64,0x2f,0x49,0x70,0x74,0x63,0x34,0x78,
+  0x6d,0x70,0x45,0x78,0x74,0x2f,0x32,0x30,0x30,0x38,0x2d,0x30,0x32,0x2d,0x32,0x39,
+  0x2f,0x22,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x78,
+  0x6d,0x6c,0x6e,0x73,0x3a,0x70,0x68,0x6f,0x74,0x6f,0x73,0x68,0x6f,0x70,0x3d,0x22,
+  0x68,0x74,0x74,0x70,0x3a,0x2f,0x2f,0x6e,0x73,0x2e,0x61,0x64,0x6f,0x62,0x65,0x2e,
+  0x63,0x6f,0x6d,0x2f,0x70,0x68,0x6f,0x74,0x6f,0x73,0x68,0x6f,0x70,0x2f,0x31,0x2e,
+  0x30,0x2f,0x22,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x64,
+  0x63,0x3a,0x63,0x72,0x65,0x61,0x74,0x6f,0x72,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x72,0x64,0x66,0x3a,0x53,0x65,0x71,0x3e,
+  0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+  0x3c,0x72,0x64,0x66,0x3a,0x6c,0x69,0x3e,0x4d,0x69,0x63,0x68,0x61,0x65,0x6c,0x20,
+  0x53,0x77,0x65,0x65,0x74,0x3c,0x2f,0x72,0x64,0x66,0x3a,0x6c,0x69,0x3e,0x0a,0x20,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x2f,0x72,0x64,0x66,
+  0x3a,0x53,0x65,0x71,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,
+  0x2f,0x64,0x63,0x3a,0x63,0x72,0x65,0x61,0x74,0x6f,0x72,0x3e,0x0a,0x20,0x20,0x20,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x64,0x63,0x3a,0x72,0x69,0x67,0x68,0x74,0x73,
+  0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x72,
+  0x64,0x66,0x3a,0x41,0x6c,0x74,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x72,0x64,0x66,0x3a,0x6c,0x69,0x20,0x78,
+  0x6d,0x6c,0x3a,0x6c,0x61,0x6e,0x67,0x3d,0x22,0x78,0x2d,0x64,0x65,0x66,0x61,0x75,
+  0x6c,0x74,0x22,0x3e,0x43,0x6f,0x70,0x79,0x72,0x69,0x67,0x68,0x74,0x20,0x32,0x30,
+  0x31,0x30,0x20,0x41,0x70,0x70,0x6c,0x65,0x20,0x49,0x6e,0x63,0x2e,0x3c,0x2f,0x72,
+  0x64,0x66,0x3a,0x6c,0x69,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+  0x20,0x20,0x20,0x3c,0x2f,0x72,0x64,0x66,0x3a,0x41,0x6c,0x74,0x3e,0x0a,0x20,0x20,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x2f,0x64,0x63,0x3a,0x72,0x69,0x67,0x68,
+  0x74,0x73,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x49,0x70,
+  0x74,0x63,0x34,0x78,0x6d,0x70,0x45,0x78,0x74,0x3a,0x48,0x65,0x61,0x64,0x6c,0x69,
+  0x6e,0x65,0x3e,0x4e,0x65,0x77,0x20,0x49,0x6d,0x61,0x67,0x65,0x3c,0x2f,0x49,0x70,
+  0x74,0x63,0x34,0x78,0x6d,0x70,0x45,0x78,0x74,0x3a,0x48,0x65,0x61,0x64,0x6c,0x69,
+  0x6e,0x65,0x3e,0x0a,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x70,0x68,
+  0x6f,0x74,0x6f,0x73,0x68,0x6f,0x70,0x3a,0x48,0x65,0x61,0x64,0x6c,0x69,0x6e,0x65,
+  0x3e,0x4e,0x65,0x77,0x20,0x49,0x6d,0x61,0x67,0x65,0x3c,0x2f,0x70,0x68,0x6f,0x74,
+  0x6f,0x73,0x68,0x6f,0x70,0x3a,0x48,0x65,0x61,0x64,0x6c,0x69,0x6e,0x65,0x3e,0x0a,
+  0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x2f,0x72,0x64,0x66,0x3a,0x44,0x65,0x73,0x63,
+  0x72,0x69,0x70,0x74,0x69,0x6f,0x6e,0x3e,0x0a,0x20,0x20,0x20,0x3c,0x2f,0x72,0x64,
+  0x66,0x3a,0x52,0x44,0x46,0x3e,0x0a,0x3c,0x2f,0x78,0x3a,0x78,0x6d,0x70,0x6d,0x65,
+  0x74,0x61,0x3e,0x0a,0xa0,0x50,0x98,0x64,0x00,0x00,0x02,0xa0,0x50,0x4c,0x54,0x45,
+  0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xfe,0xfe,0xfe,0xff,
+  0xff,0xff,0xfc,0xfc,0xfc,0xff,0xff,0xff,0x00,0x00,0x00,0x01,0x01,0x01,0x02,0x02,
+  0x02,0x03,0x03,0x03,0x04,0x04,0x04,0x05,0x05,0x05,0x06,0x06,0x06,0x07,0x07,0x07,
+  0x08,0x08,0x08,0x09,0x09,0x09,0x0a,0x0a,0x0a,0x0b,0x0b,0x0b,0x0c,0x0c,0x0c,0x0d,
+  0x0d,0x0d,0x0f,0x0f,0x0f,0x10,0x10,0x10,0x11,0x11,0x11,0x12,0x12,0x12,0x13,0x13,
+  0x13,0x14,0x14,0x14,0x15,0x15,0x15,0x16,0x16,0x16,0x18,0x18,0x18,0x19,0x19,0x19,
+  0x1c,0x1c,0x1c,0x1d,0x1d,0x1d,0x1e,0x1e,0x1e,0x1f,0x1f,0x1f,0x20,0x20,0x20,0x21,
+  0x21,0x21,0x22,0x22,0x22,0x23,0x23,0x23,0x24,0x24,0x24,0x25,0x25,0x25,0x26,0x26,
+  0x26,0x27,0x27,0x27,0x28,0x28,0x28,0x29,0x29,0x29,0x2a,0x2a,0x2a,0x2c,0x2c,0x2c,
+  0x2d,0x2d,0x2d,0x2d,0x2e,0x39,0x2e,0x2e,0x2e,0x2e,0x2e,0x39,0x2e,0x2f,0x35,0x2f,
+  0x2f,0x2f,0x2f,0x2f,0x3a,0x30,0x30,0x30,0x31,0x31,0x31,0x32,0x32,0x32,0x33,0x33,
+  0x33,0x34,0x34,0x34,0x35,0x35,0x35,0x36,0x36,0x36,0x37,0x37,0x37,0x38,0x38,0x38,
+  0x38,0x3c,0x55,0x39,0x39,0x39,0x3a,0x3a,0x3a,0x3a,0x3a,0x3c,0x3b,0x3b,0x3b,0x3c,
+  0x3c,0x3c,0x3d,0x3d,0x3d,0x3e,0x3e,0x3e,0x3e,0x43,0x60,0x3f,0x3f,0x3f,0x40,0x40,
+  0x40,0x41,0x41,0x41,0x41,0x42,0x45,0x41,0x44,0x4c,0x42,0x42,0x42,0x43,0x43,0x43,
+  0x44,0x44,0x44,0x45,0x45,0x45,0x46,0x46,0x46,0x47,0x47,0x47,0x48,0x48,0x48,0x49,
+  0x49,0x49,0x4a,0x4a,0x4a,0x4b,0x4b,0x4b,0x4c,0x4c,0x4c,0x4d,0x4d,0x4d,0x4e,0x4e,
+  0x4e,0x4f,0x4f,0x4f,0x50,0x50,0x50,0x51,0x51,0x51,0x52,0x52,0x52,0x53,0x53,0x53,
+  0x54,0x54,0x54,0x55,0x55,0x55,0x56,0x56,0x56,0x57,0x57,0x57,0x58,0x58,0x58,0x59,
+  0x59,0x59,0x5a,0x5a,0x5a,0x5b,0x5b,0x5b,0x5c,0x5c,0x5c,0x5e,0x5e,0x5e,0x5f,0x5f,
+  0x5f,0x5f,0x6e,0x90,0x60,0x60,0x60,0x60,0x69,0xa2,0x61,0x61,0x61,0x62,0x62,0x62,
+  0x63,0x63,0x63,0x65,0x65,0x65,0x66,0x66,0x66,0x67,0x67,0x67,0x68,0x68,0x68,0x6a,
+  0x6a,0x6a,0x6a,0x7a,0xa0,0x6b,0x6b,0x6b,0x6c,0x6c,0x6c,0x6d,0x6d,0x6d,0x71,0x71,
+  0x71,0x71,0x82,0xab,0x71,0x83,0xac,0x72,0x72,0x72,0x74,0x74,0x74,0x76,0x76,0x76,
+  0x77,0x77,0x77,0x79,0x79,0x79,0x7c,0x7c,0x7c,0x7d,0x7d,0x7d,0x7f,0x7f,0x7f,0x80,
+  0x80,0x80,0x81,0x81,0x81,0x82,0x82,0x82,0x83,0x83,0x83,0x84,0x84,0x84,0x85,0x85,
+  0x85,0x86,0x86,0x86,0x87,0x87,0x87,0x8a,0x8a,0x8a,0x8c,0x8c,0x8c,0x8d,0x8d,0x8d,
+  0x8e,0x8e,0x8e,0x90,0x90,0x90,0x91,0x91,0x91,0x92,0x92,0x92,0x93,0x93,0x93,0x96,
+  0x96,0x96,0x98,0x98,0x98,0x9b,0x9b,0x9b,0x9d,0x9d,0x9d,0x9f,0x9f,0x9f,0xa0,0xa0,
+  0xa0,0xa2,0xa2,0xa2,0xa3,0xa3,0xa3,0xa6,0xa6,0xa6,0xa7,0xa7,0xa7,0xa8,0xa8,0xa8,
+  0xaa,0xaa,0xaa,0xab,0xab,0xab,0xad,0xad,0xad,0xae,0xae,0xae,0xaf,0xaf,0xaf,0xb0,
+  0xb0,0xb0,0xb2,0xb2,0xb2,0xb4,0xb4,0xb4,0xb7,0xb7,0xb7,0xb9,0xb9,0xb9,0xba,0xba,
+  0xba,0xbb,0xbb,0xbb,0xbc,0xbc,0xbc,0xbd,0xbd,0xbd,0xbe,0xbe,0xbe,0xc0,0xc0,0xc0,
+  0xc2,0xc2,0xc2,0xc3,0xc3,0xc3,0xc4,0xc4,0xc4,0xc5,0xc5,0xc5,0xc6,0xc6,0xc6,0xc7,
+  0xc7,0xc7,0xc9,0xc9,0xc9,0xca,0xca,0xca,0xcc,0xcc,0xcc,0xcd,0xcd,0xcd,0xce,0xce,
+  0xce,0xd0,0xd0,0xd0,0xd1,0xd1,0xd1,0xd4,0xd4,0xd4,0xd8,0xd8,0xd8,0xd9,0xd9,0xd9,
+  0xda,0xda,0xda,0xdb,0xdb,0xdb,0xdc,0xdc,0xdc,0xdd,0xdd,0xdd,0xde,0xde,0xde,0xdf,
+  0xdf,0xdf,0xe0,0xe0,0xe0,0xe2,0xe2,0xe2,0xe3,0xe3,0xe3,0xe5,0xe5,0xe5,0xe6,0xe6,
+  0xe6,0xe9,0xe9,0xe9,0xea,0xea,0xea,0xeb,0xeb,0xeb,0xed,0xed,0xed,0xee,0xee,0xee,
+  0xef,0xef,0xef,0xf0,0xf0,0xf0,0xf1,0xf1,0xf1,0xf2,0xf2,0xf2,0xf3,0xf3,0xf3,0xf4,
+  0xf4,0xf4,0xf6,0xf6,0xf6,0xf7,0xf7,0xf7,0xf8,0xf8,0xf8,0xf9,0xf9,0xf9,0xfa,0xfa,
+  0xfa,0xfb,0xfb,0xfb,0xfc,0xfc,0xfc,0xfd,0xfd,0xfd,0xfe,0xfe,0xfe,0xff,0xff,0xff,
+  0x96,0xb7,0x1b,0xef,0x00,0x00,0x00,0x08,0x74,0x52,0x4e,0x53,0x00,0x08,0x7f,0xc4,
+  0xdc,0xdc,0xfc,0xfc,0x86,0xfa,0x37,0x3a,0x00,0x00,0x03,0x97,0x49,0x44,0x41,0x54,
+  0x18,0x19,0x95,0xc1,0x6f,0x68,0xd4,0x75,0x1c,0xc0,0xf1,0xf7,0xe7,0xfb,0xfb,0xfe,
+  0xee,0xcf,0xe6,0xb1,0x73,0x53,0xdb,0xfa,0xc3,0xc2,0x1d,0x35,0xcc,0x1c,0x4a,0x60,
+  0x89,0x3e,0x50,0xfa,0x43,0x52,0x4a,0x52,0x94,0x48,0x33,0x0c,0x1f,0x84,0x21,0x3d,
+  0xe8,0x0f,0xe1,0xa3,0x20,0x0c,0x83,0x11,0x42,0x04,0xd2,0x1f,0xb0,0x7a,0x12,0x14,
+  0x66,0xd1,0x13,0x35,0x08,0x4b,0x4b,0x54,0xc4,0xd4,0x5c,0x63,0x78,0xe8,0x6a,0x59,
+  0x6a,0xdb,0xed,0x76,0xdb,0xfd,0xee,0xee,0xf7,0xfd,0xf4,0xbb,0x6d,0xa2,0x79,0x3a,
+  0xcf,0xd7,0x4b,0x10,0xf1,0x4c,0x2f,0xf5,0xe8,0x74,0xa1,0xaa,0x88,0xe9,0xa7,0x7e,
+  0x19,0x67,0xe4,0xf0,0xaf,0xd4,0xaf,0x5f,0x8c,0x37,0x36,0xc0,0x2d,0xf0,0xac,0xa9,
+  0x8c,0xd1,0x73,0xcf,0x2f,0xab,0x16,0x1f,0xb8,0x74,0xac,0x7d,0xf5,0xcc,0x93,0xbb,
+  0x16,0x3c,0xf1,0xc1,0x86,0xc6,0x3d,0x6d,0xb3,0x76,0xf9,0x6b,0x5a,0xa8,0x61,0x4c,
+  0x6f,0xe1,0x08,0x9f,0x8d,0x3c,0xf7,0x6a,0xe9,0xfc,0xce,0x55,0x43,0x7b,0x83,0x2d,
+  0x2f,0x1d,0x3f,0x65,0x0e,0xba,0xf7,0xdb,0x7b,0x96,0xb7,0xed,0xa3,0x56,0xaf,0x25,
+  0x92,0x5c,0x47,0x7b,0x96,0x75,0x0b,0x83,0xdd,0x99,0x0b,0xef,0x5c,0x1c,0x5c,0xbe,
+  0xa3,0x69,0x59,0x7c,0xaf,0x16,0xe6,0x0d,0xf6,0xc0,0x83,0xcf,0xf0,0x3f,0x96,0x88,
+  0x2b,0xc6,0x06,0xdb,0x4f,0x16,0xf9,0xa7,0xab,0x63,0xc6,0x36,0x0b,0xd9,0x1d,0xaf,
+  0xc4,0xbb,0x36,0xcd,0x85,0x1e,0x6a,0x58,0x22,0xe1,0xd6,0x73,0x9b,0x13,0x7c,0x7d,
+  0xac,0xfc,0x7a,0xd3,0xcb,0x2f,0xb6,0x3e,0xf2,0x70,0xf7,0xa7,0xf7,0xb3,0x79,0x5b,
+  0x3a,0xb3,0x91,0x5a,0x92,0x05,0x1e,0xfa,0xb9,0x98,0xe0,0x2b,0x59,0x99,0x00,0x2a,
+  0xe5,0x24,0x93,0xf2,0x29,0xae,0xc3,0x12,0x79,0x96,0x04,0xb4,0x49,0x82,0x88,0xb5,
+  0x4c,0x49,0x71,0x3d,0x92,0xe5,0xd6,0x18,0x6e,0x91,0xe1,0xc6,0x8e,0x0f,0x53,0xcb,
+  0x70,0x63,0x03,0xe3,0x4c,0xf8,0x84,0xab,0x58,0x6a,0x7c,0x91,0xda,0xbf,0xec,0xf1,
+  0x81,0x1f,0x87,0x17,0x15,0x2a,0x67,0x0f,0x94,0xb2,0x1b,0xb2,0xef,0x9d,0x5b,0x9f,
+  0xd8,0xe5,0xaf,0x69,0xe9,0xe9,0x18,0x5f,0x8b,0xa1,0xc6,0xe1,0x43,0x2f,0x7c,0x7e,
+  0xaa,0xb0,0x7d,0xc9,0xc2,0xc3,0x85,0xc2,0xbb,0x99,0xfb,0xbe,0x5f,0xd2,0xf8,0x5a,
+  0x7b,0xcf,0xf2,0xb6,0x7d,0xec,0xf4,0x56,0x82,0x65,0x8a,0x73,0x0a,0x82,0x88,0xb0,
+  0xb6,0xf3,0xd1,0xfe,0x7b,0x57,0x2c,0x22,0xf2,0xd8,0xd2,0x83,0x87,0x62,0xd2,0x18,
+  0xec,0xd5,0xc2,0x3c,0x1a,0x9f,0x04,0x2c,0x13,0xb4,0xd2,0xff,0xe5,0x88,0xb1,0x5e,
+  0x43,0x73,0x6b,0xa7,0x16,0x39,0xf3,0x34,0x57,0xf1,0x82,0x78,0xd7,0xa6,0xb9,0x4c,
+  0xb2,0x44,0x34,0x1c,0xf9,0xb6,0x8f,0x18,0x12,0x8e,0xe6,0x8e,0xfc,0xe0,0x3e,0x72,
+  0xed,0xf3,0x7f,0xe7,0x8a,0xe7,0xdf,0x7c,0x63,0xf3,0xb6,0x74,0x66,0xa3,0x10,0x91,
+  0x2c,0x1a,0x9e,0xf9,0x69,0x80,0x2a,0x1d,0x1d,0x6b,0xca,0xcd,0xba,0xb8,0xa9,0x23,
+  0x01,0xaa,0xea,0xb4,0x70,0x62,0xe6,0x7c,0x81,0xe1,0x34,0xe4,0x53,0x4c,0xb0,0x50,
+  0xd9,0xff,0x21,0x53,0x32,0x7a,0x36,0xd7,0xfc,0x40,0xd2,0x2f,0xeb,0xd8,0xf1,0xd3,
+  0x47,0x7f,0xcb,0xb9,0xa7,0xb6,0xa8,0x40,0x1a,0x48,0x31,0xc9,0xe2,0x8a,0xdf,0x71,
+  0x99,0xeb,0x1b,0xaf,0x54,0x5a,0xf7,0x1c,0x3d,0x9d,0xab,0x58,0x5f,0xc6,0x1a,0xb6,
+  0x76,0x71,0x2d,0x8b,0x2b,0x0e,0x72,0x99,0x1b,0x2d,0xbb,0x6f,0x76,0x83,0xe7,0x25,
+  0x5c,0xe0,0x56,0x74,0xb7,0x18,0x57,0x12,0x2e,0x13,0xf1,0x0c,0x16,0x57,0x62,0x4a,
+  0x30,0x32,0x98,0x0f,0xed,0x0c,0xdf,0x7a,0x7e,0xcc,0x4b,0xfa,0x7e,0xe9,0x63,0x15,
+  0xae,0x08,0x0b,0xa9,0xed,0x09,0x63,0xa1,0xc2,0xa4,0x20,0x48,0xde,0x19,0x36,0x59,
+  0xae,0x6f,0xd8,0xcd,0x69,0xd6,0x51,0xdf,0x58,0x54,0x99,0x14,0x8f,0x13,0x70,0x89,
+  0x1b,0xb8,0x0b,0x55,0x2d,0x2a,0x96,0x2a,0xef,0x76,0x95,0xa1,0x7c,0xd9,0xc8,0x1d,
+  0x56,0x14,0x51,0xe1,0x1a,0xa5,0xbf,0x55,0x41,0x9d,0x62,0x89,0xd8,0xbb,0x8d,0x14,
+  0xfc,0xc5,0x70,0x22,0x96,0x04,0x54,0x94,0x2a,0x51,0x41,0x45,0x89,0x5c,0xc0,0x89,
+  0x52,0x65,0x89,0xa4,0x1b,0xe0,0xdf,0x8e,0x26,0x2d,0xa7,0xd2,0x5c,0x45,0x54,0x50,
+  0x51,0x60,0x30,0xef,0x2b,0x4a,0x95,0x25,0x92,0x68,0x74,0x6e,0xf6,0x5f,0x7f,0x3a,
+  0x3b,0xdb,0x29,0xaa,0xa2,0xa2,0x22,0x88,0x08,0x46,0xc4,0x9a,0x7c,0xdf,0x25,0xdf,
+  0xc7,0x81,0x02,0x96,0xc8,0x1f,0xd9,0xc0,0xa9,0xa2,0x0a,0x28,0x53,0x04,0x04,0x41,
+  0x04,0x35,0x80,0x03,0x42,0xc0,0x52,0xe5,0x7b,0x65,0xa6,0x63,0x7c,0x20,0x54,0x01,
+  0x2c,0x13,0x4c,0x9c,0x9b,0x08,0x15,0x71,0x80,0xa5,0x4e,0xaa,0x28,0x11,0x4b,0x9d,
+  0xd4,0xa1,0x02,0x18,0xea,0xe4,0x50,0x14,0xb0,0x40,0x91,0x3a,0x9c,0xbf,0x4d,0x95,
+  0x88,0x05,0x12,0xd4,0x21,0xe5,0x84,0x2a,0x4b,0xbd,0x1c,0x04,0x80,0xa5,0x4e,0x61,
+  0x09,0x19,0x17,0xb0,0xd4,0x29,0x07,0x41,0xe8,0x09,0x16,0x31,0x4d,0x39,0x6e,0x2e,
+  0x20,0xf0,0xde,0x8a,0x1b,0x4c,0xa7,0xd8,0xa5,0xdc,0xdc,0x50,0xb9,0x65,0xfd,0xdb,
+  0xad,0x0d,0x5e,0xa7,0x75,0x26,0xbe,0x40,0x0f,0xe4,0x98,0x5e,0xbe,0xb9,0x7b,0x56,
+  0x3a,0x95,0x4a,0x88,0xb3,0xa1,0x69,0x98,0xb3,0x28,0x53,0x72,0x4c,0x47,0x6c,0x43,
+  0x7a,0x46,0x32,0xee,0x1b,0x42,0x11,0xd3,0x17,0x8c,0x05,0x65,0x65,0x3a,0x62,0x63,
+  0xc9,0x98,0x35,0x90,0x71,0x82,0x88,0x31,0x27,0x55,0x99,0x96,0x18,0x4f,0xe8,0x74,
+  0xa1,0xea,0x7f,0x66,0xc2,0x6f,0x17,0x59,0xdf,0xbf,0x1b,0x00,0x00,0x00,0x00,0x49,
+  0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
+  
+};
diff -pruN 2.3.3-3/.travis.yml 2.3.3op1-3/.travis.yml
--- 2.3.3-3/.travis.yml	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.3op1-3/.travis.yml	2020-11-27 14:25:26.000000000 +0000
@@ -0,0 +1,30 @@
+#
+# Travis CI configuration file for CUPS.
+#
+
+language: c
+
+script: ./configure --enable-debug --enable-debug-guards --enable-debug-printfs --enable-unit-tests && make && make test
+
+matrix:
+  include:
+    # Linux-specific build stuff
+    - os: linux
+      dist: focal
+      virt: vm
+      sudo: required
+      before_script: sudo sh -c 'echo 0 > /proc/sys/net/ipv6/conf/all/disable_ipv6'
+      addons:
+        apt:
+          packages: [libavahi-client-dev, libgnutls28-dev, zlib1g-dev]
+
+    # macOS-specific build stuff
+    - os: osx
+      osx_image: xcode12.2
+
+
+notifications:
+  email:
+    # TODO: Need mailing list for OpenPrinting CI builds
+    recipients:
+      - msweet@msweet.org
diff -pruN 2.3.3-3/vcnet/config.h 2.3.3op1-3/vcnet/config.h
--- 2.3.3-3/vcnet/config.h	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/vcnet/config.h	2020-11-27 14:25:26.000000000 +0000
@@ -97,8 +97,8 @@ typedef unsigned long useconds_t;
  * Version of software...
  */
 
-#define CUPS_SVERSION "CUPS v2.3.3"
-#define CUPS_MINIMAL "CUPS/2.3.3"
+#define CUPS_SVERSION "CUPS v2.3.3op1"
+#define CUPS_MINIMAL "CUPS/2.3.3op1"
 
 
 /*
@@ -126,6 +126,7 @@ typedef unsigned long useconds_t;
 
 #define CUPS_DEFAULT_LOG_LEVEL "warn"
 #define CUPS_DEFAULT_ACCESS_LOG_LEVEL "none"
+#define CUPS_DEFAULT_MAX_LOG_SIZE "1m"
 
 
 /*
@@ -167,6 +168,13 @@ typedef unsigned long useconds_t;
 
 
 /*
+ * Default ErrorPolicy value...
+ */
+
+#define CUPS_DEFAULT_ERROR_POLICY "stop-printer"
+
+
+/*
  * Default MaxCopies value...
  */
 
@@ -174,6 +182,13 @@ typedef unsigned long useconds_t;
 
 
 /*
+ * Default SyncOnClose value...
+ */
+
+/* #undef CUPS_DEFAULT_SYNC_ON_CLOSE */
+
+
+/*
  * Do we have domain socket support, and if so what is the default one?
  */
 
diff -pruN 2.3.3-3/xcode/config.h 2.3.3op1-3/xcode/config.h
--- 2.3.3-3/xcode/config.h	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/xcode/config.h	2020-11-27 14:25:26.000000000 +0000
@@ -18,8 +18,8 @@
  * Version of software...
  */
 
-#define CUPS_SVERSION "CUPS v2.3.3"
-#define CUPS_MINIMAL "CUPS/2.3.3"
+#define CUPS_SVERSION "CUPS v2.3.3op1"
+#define CUPS_MINIMAL "CUPS/2.3.3op1"
 
 
 /*
@@ -47,6 +47,7 @@
 
 #define CUPS_DEFAULT_LOG_LEVEL "warn"
 #define CUPS_DEFAULT_ACCESS_LOG_LEVEL "none"
+#define CUPS_DEFAULT_MAX_LOG_SIZE "1m"
 
 
 /*
@@ -88,6 +89,13 @@
 
 
 /*
+ * Default ErrorPolicy value...
+ */
+
+#define CUPS_DEFAULT_ERROR_POLICY "stop-printer"
+
+
+/*
  * Default MaxCopies value...
  */
 
@@ -95,6 +103,13 @@
 
 
 /*
+ * Default SyncOnClose value...
+ */
+
+/* #undef CUPS_DEFAULT_SYNC_ON_CLOSE */
+
+
+/*
  * Do we have domain socket support, and if so what is the default one?
  */
 
diff -pruN 2.3.3-3/xcode/CUPS.xcodeproj/project.pbxproj 2.3.3op1-3/xcode/CUPS.xcodeproj/project.pbxproj
--- 2.3.3-3/xcode/CUPS.xcodeproj/project.pbxproj	2020-04-27 18:04:29.000000000 +0000
+++ 2.3.3op1-3/xcode/CUPS.xcodeproj/project.pbxproj	2020-11-27 14:25:26.000000000 +0000
@@ -7298,7 +7298,7 @@
 		72BF96371333042100B1EAD7 /* Project object */ = {
 			isa = PBXProject;
 			attributes = {
-				LastUpgradeCheck = 1100;
+				LastUpgradeCheck = 1220;
 				ORGANIZATIONNAME = "Apple Inc.";
 				TargetAttributes = {
 					270695FD1CADF3E200FFE5FB = {
@@ -11562,6 +11562,7 @@
 				CLANG_WARN_IMPLICIT_SIGN_CONVERSION = YES;
 				CLANG_WARN_INFINITE_RECURSION = YES;
 				CLANG_WARN_OBJC_IMPLICIT_RETAIN_SELF = YES;
+				CLANG_WARN_QUOTED_INCLUDE_IN_FRAMEWORK_HEADER = YES;
 				CLANG_WARN_RANGE_LOOP_ANALYSIS = YES;
 				CLANG_WARN_STRICT_PROTOTYPES = YES;
 				CLANG_WARN_SUSPICIOUS_IMPLICIT_CONVERSION = YES;
@@ -11614,6 +11615,7 @@
 				CLANG_WARN_IMPLICIT_SIGN_CONVERSION = YES;
 				CLANG_WARN_INFINITE_RECURSION = YES;
 				CLANG_WARN_OBJC_IMPLICIT_RETAIN_SELF = YES;
+				CLANG_WARN_QUOTED_INCLUDE_IN_FRAMEWORK_HEADER = YES;
 				CLANG_WARN_RANGE_LOOP_ANALYSIS = YES;
 				CLANG_WARN_STRICT_PROTOTYPES = YES;
 				CLANG_WARN_SUSPICIOUS_IMPLICIT_CONVERSION = YES;
